@@ -89,7 +89,7 @@ static gboolean loadAbinitSpin(VisuData *data, const gchar* filename,
 			       ToolFileFormat *format, int nSet,
                                GCancellable *cancel, GError **error);
 static gpointer parseAbinitThread(gpointer data);
-static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet);
+static GError* loadAbinit(VisuData *data, AbInvars *dt, int nSet);
 static gboolean waitDt(gpointer data);
 static void freeDt(gpointer dt);
 static gchar** readPseudoFiles(AbinitData *dt);
@@ -110,7 +110,7 @@ gboolean abinitInit()
 
   iconPath = g_build_filename(V_SIM_PIXMAPS_DIR, "abinit.png", NULL);
 
-  ab6_mpi_init();
+  ab_mpi_init();
 
   return TRUE;
 }
@@ -194,12 +194,12 @@ static gboolean loadAbinitIn(VisuData *data, const gchar* filename,
   GThread *ld_thread;
 #endif
   AbinitData *dt;
-  Ab6Invars *dataset;
+  AbInvars *dataset;
 
   g_return_val_if_fail(error && !*error, FALSE);
 
   /* Try to see if data has already read this dataset. */
-  dataset = (Ab6Invars*)g_object_get_data(G_OBJECT(data), ABINIT_DT);
+  dataset = (AbInvars*)g_object_get_data(G_OBJECT(data), ABINIT_DT);
   if (dataset)
     {
       *error = loadAbinit(data, dataset, nSet);
@@ -208,7 +208,7 @@ static gboolean loadAbinitIn(VisuData *data, const gchar* filename,
   
   /* Read the file, since it's the first time. */
   dt = abinit_getDirectDt();
-  dt->dt          = (Ab6Invars*)0;
+  dt->dt          = (AbInvars*)0;
   dt->filename    = g_strdup(filename);
   dt->error       = (GError*)0;
   dt->isABFormat  = FALSE;
@@ -256,7 +256,7 @@ static gboolean loadAbinitIn(VisuData *data, const gchar* filename,
 static gpointer parseAbinitThread(gpointer data _U_)
 {
   AbinitData *dt;
-  Ab6Invars *dt_;
+  AbInvars *dt_;
   gchar **pseudos;
 
   DBG_fprintf(stderr, "AB(%p) main: get the dt structure.\n",
@@ -278,9 +278,9 @@ static gpointer parseAbinitThread(gpointer data _U_)
 #ifdef HAVE_NEW_WITH_PSEUDO
       DBG_fprintf(stderr, "AB(%p) main: pseudo list %p.\n",
                   (gpointer)g_thread_self(), (gpointer)pseudos);
-      dt_ = ab6_invars_new_from_file_with_pseudo(dt->filename, (const char**)pseudos);
+      dt_ = ab_invars_new_from_file_with_pseudo(dt->filename, (const char**)pseudos);
 #else
-      dt_ = ab6_invars_new_from_file(dt->filename);
+      dt_ = ab_invars_new_from_file(dt->filename);
       if (pseudos)
         g_warning("Unsupported ABINIT input file with pseudo-potential information.");
 #endif
@@ -365,7 +365,7 @@ static gboolean waitDt(gpointer data _U_)
 static void freeDt(gpointer dt)
 {
   DBG_fprintf(stderr, "AB structure: release ABINIT resources.\n");
-  ab6_invars_free((Ab6Invars*)dt);
+  ab_invars_free((AbInvars*)dt);
 }
 
 static gchar** readPseudoFiles(AbinitData *dt)
@@ -553,7 +553,7 @@ void FC_FUNC(psp_from_data, PSP_FROM_DATA)()
 {
 }
 
-static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
+static GError* loadAbinit(VisuData *data, AbInvars *dt, int nSet)
 {
   int ndtset, i;
   int ntypat, natom, nzero, *index;
@@ -564,7 +564,7 @@ static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
   float rcov, red[3];
   char *ptChar, *name;
   GArray *nattyp, *types;
-  Ab6Error error;
+  AbError error;
   gboolean newEle;
   VisuBox *boxObj;
 
@@ -572,8 +572,8 @@ static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
 
   DBG_fprintf(stderr, "AB structure: transfer data.\n");
   /* Ok, try to find the required keywords. */
-  error = ab6_invars_get_ndtset(dt, &ndtset);
-  if (error != AB6_NO_ERROR)
+  error = ab_invars_get_ndtset(dt, &ndtset);
+  if (error != AB_NO_ERROR)
     return g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_METHOD,
 		       "Abinit loader report error %d while getting n datasets.",
 		       (int)error);
@@ -585,43 +585,43 @@ static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
 		       g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_METHOD,
 				   "Can't load dataset %d.", nSet));
 
-  error = ab6_invars_get_integer(dt, AB6_INVARS_NTYPAT, nSet + 1, &ntypat);
-  if (error != AB6_NO_ERROR)
+  error = ab_invars_get_integer(dt, AB_INVARS_NTYPAT, nSet + 1, &ntypat);
+  if (error != AB_NO_ERROR)
     return g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_METHOD,
 		       "Abinit loader report error:\n %s\nwhile getting attribute '%s'.",
 		       ab6_error_string_from_id(error),
-		       AB6_INVARS_STR(AB6_INVARS_NTYPAT));
-  error = ab6_invars_get_integer(dt, AB6_INVARS_NATOM,  nSet + 1, &natom);
-  if (error != AB6_NO_ERROR)
+		       AB_INVARS_STR(AB_INVARS_NTYPAT));
+  error = ab_invars_get_integer(dt, AB_INVARS_NATOM,  nSet + 1, &natom);
+  if (error != AB_NO_ERROR)
     return g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_METHOD,
 		       "Abinit loader report error:\n %s\nwhile getting attribute '%s'.",
 		       ab6_error_string_from_id(error),
-		       AB6_INVARS_STR(AB6_INVARS_NATOM));
+		       AB_INVARS_STR(AB_INVARS_NATOM));
   DBG_fprintf(stderr, "AB structure: with %d atoms and %d types.\n",
 	      natom, ntypat);
   
   typat = g_malloc(sizeof(int) * natom);
-  error = ab6_invars_get_integer_array(dt, typat, natom,
-				       AB6_INVARS_TYPAT, nSet + 1);
-  if (error != AB6_NO_ERROR)
+  error = ab_invars_get_integer_array(dt, typat, natom,
+				       AB_INVARS_TYPAT, nSet + 1);
+  if (error != AB_NO_ERROR)
     {
       g_free(typat);
       return g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_METHOD,
 			 "Abinit loader report error:\n %s\nwhile getting attribute '%s'.",
 			 ab6_error_string_from_id(error),
-			 AB6_INVARS_STR(AB6_INVARS_TYPAT));
+			 AB_INVARS_STR(AB_INVARS_TYPAT));
     }
 
   znucl = g_malloc(sizeof(double) * ntypat);
-  error = ab6_invars_get_real_array(dt, znucl, ntypat,
-				    AB6_INVARS_ZNUCL, nSet + 1);
-  if (error != AB6_NO_ERROR)
+  error = ab_invars_get_real_array(dt, znucl, ntypat,
+				    AB_INVARS_ZNUCL, nSet + 1);
+  if (error != AB_NO_ERROR)
     {
       g_free(typat); g_free(znucl);
       return g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_METHOD,
 			 "Abinit loader report error:\n %s\nwhile getting attribute '%s'.",
 			 ab6_error_string_from_id(error),
-			 AB6_INVARS_STR(AB6_INVARS_ZNUCL));
+			 AB_INVARS_STR(AB_INVARS_ZNUCL));
     }
   DBG_fprintf(stderr, "AB structure: read znucl OK.\n");
   types = g_array_sized_new(FALSE, FALSE, sizeof(VisuElement*), ntypat);
@@ -686,15 +686,15 @@ static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
   g_array_free(nattyp, TRUE);
   g_array_free(types, TRUE);
 
-  error = ab6_invars_get_real_array(dt, (double*)rprimd, 9,
-				    AB6_INVARS_RPRIMD_ORIG, nSet + 1);
-  if (error != AB6_NO_ERROR)
+  error = ab_invars_get_real_array(dt, (double*)rprimd, 9,
+				    AB_INVARS_RPRIMD_ORIG, nSet + 1);
+  if (error != AB_NO_ERROR)
     {
       g_free(ntypes);
       return g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_METHOD,
 			 "Abinit loader report error:\n %s\nwhile getting attribute '%s'.",
-			 ab6_error_string_from_id(error),
-			 AB6_INVARS_STR(AB6_INVARS_RPRIMD_ORIG));
+			 ab_error_string_from_id(error),
+			 AB_INVARS_STR(AB_INVARS_RPRIMD_ORIG));
     }
   DBG_fprintf(stderr, " | box definition : ( %f %f %f )\n",
 	      rprimd[0][0], rprimd[0][1], rprimd[0][2]);
@@ -703,20 +703,20 @@ static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
   DBG_fprintf(stderr, " |                  ( %f %f %f )\n",
 	      rprimd[2][0], rprimd[2][1], rprimd[2][2]);
   boxObj = visu_box_new_full(rprimd, VISU_BOX_PERIODIC);
-  visu_data_setBox(data, boxObj);
+  visu_boxed_setBox(VISU_BOXED(data), VISU_BOXED(boxObj), FALSE);
   g_object_unref(boxObj);
   
   coord = g_malloc(sizeof(double) * 3 * natom);
-  error = ab6_invars_get_real_array(dt, coord, 3 * natom,
-				    AB6_INVARS_XRED_ORIG, nSet + 1);
-  if (error != AB6_NO_ERROR)
+  error = ab_invars_get_real_array(dt, coord, 3 * natom,
+				    AB_INVARS_XRED_ORIG, nSet + 1);
+  if (error != AB_NO_ERROR)
     {
       g_free(ntypes);
       g_free(coord);
       return g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_METHOD,
 			 "Abinit loader report error:\n %s\nwhile getting attribute '%s'.",
 			 ab6_error_string_from_id(error),
-			 AB6_INVARS_STR(AB6_INVARS_XRED_ORIG));
+			 AB_INVARS_STR(AB_INVARS_XRED_ORIG));
     }
   for (i = 0; i < natom; i++)
     {
@@ -741,15 +741,15 @@ static GError* loadAbinit(VisuData *data, Ab6Invars *dt, int nSet)
      loading method. */
   spinat = g_malloc(sizeof(double) * 3 * natom);
   g_object_set_data_full(G_OBJECT(data), "ABINIT_spinat", (gpointer)spinat, g_free);
-  error = ab6_invars_get_real_array(dt, spinat, 3 * natom,
-				    AB6_INVARS_SPINAT, nSet + 1);
-  if (error != AB6_NO_ERROR)
+  error = ab_invars_get_real_array(dt, spinat, 3 * natom,
+				    AB_INVARS_SPINAT, nSet + 1);
+  if (error != AB_NO_ERROR)
     {
       g_free(spinat);
       return g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_METHOD,
 			 "Abinit loader report error:\n %s\nwhile getting attribute '%s'.",
 			 ab6_error_string_from_id(error),
-			 AB6_INVARS_STR(AB6_INVARS_SPINAT));
+			 AB_INVARS_STR(AB_INVARS_SPINAT));
     }
 
   return (GError*)0;
