@@ -69,16 +69,17 @@ struct cube_reader
   GHashTable   *elements;
   VisuElement **nodeTypes;
   float        *coords;
-  int           mesh[3];
-  double       *density;
+  guint         mesh[3];
+  GArray       *density;
   GIOStatus     status;
   GIOChannel   *flux;
 };
 
 static gboolean cubeAtomicLoad(VisuData *data, const gchar* filename,
-			       ToolFileFormat *format, int nSet, GError **error);
-static gboolean cubeDensityLoad(const gchar *filename, GList **fieldList,
-				GError **error, GHashTable *table);
+			       ToolFileFormat *format, int nSet,
+                               GCancellable *cancel, GError **error);
+static gboolean cubeDensityLoad(VisuScalarFieldMethod *meth, const gchar *filename,
+                                GList **fieldList, GError **error);
 /* static gboolean xvAtomicLoad(VisuData *data, const gchar* filename, */
 /* 			     ToolFileFormat *format, int nSet, GError **error); */
 
@@ -87,8 +88,7 @@ static gchar *iconPath;
 
 gboolean cubeInit()
 {
-  char *typeCube[] = {"*.cube", "*.cub", (char*)0};
-  char *nameCube   = "Cube format (from Gaussian)";
+  const gchar *typeCube[] = {"*.cube", "*.cub", (char*)0};
 /*   char *typeXV[] = {"*.XV", "*.STRUCT_OUT", (char*)0}; */
 /*   char *nameXV   = "Siesta output format"; */
 /*   char *descrXV  = _("Siesta geometric output format"); */
@@ -97,10 +97,10 @@ gboolean cubeInit()
   fmt = tool_file_format_new(_("Gaussian structural/volumetric format"),
                              typeCube);
   visu_rendering_addFileFormat(visu_rendering_getByName(VISU_RENDERING_ATOMIC_NAME), 0,
-                               fmt, 60, cubeAtomicLoad, (GDestroyNotify)0);
+                               fmt, 60, cubeAtomicLoad);
 
-  scalarFieldAdd_loadMethod(nameCube, cubeDensityLoad,
-			    fmt, G_PRIORITY_HIGH - 5);
+  visu_scalar_field_method_new(_("Gaussian structural/volumetric format"), typeCube,
+                               cubeDensityLoad, G_PRIORITY_HIGH - 5);
 
 /*   fmt = tool_file_format_new(descrXV, typeXV); */
 
@@ -109,7 +109,7 @@ gboolean cubeInit()
 /*   meth->fmt = fmt; */
 /*   meth->priority = 61; */
 /*   meth->load = xvAtomicLoad; */
-/*   visu_renderingAtomic_addLoadMethod(meth); */
+/*   visu_rendering_atomic_addLoadMethod(meth); */
 
   iconPath = g_build_filename(V_SIM_PIXMAPS_DIR, "cube.png", NULL);
 
@@ -144,7 +144,7 @@ static void reader_free(struct cube_reader *rd)
   if (rd->coords)
     g_free(rd->coords);
   if (rd->density)
-    g_free(rd->density);
+    g_array_unref(rd->density);
   
   if (g_io_channel_shutdown(rd->flux, FALSE, (GError**)0) != G_IO_STATUS_NORMAL)
     g_warning("Cube: can't close file.");
@@ -220,7 +220,7 @@ static gboolean read_box(struct cube_reader *rd, GError **error)
 			       i + 1);
 	  return FALSE;
 	}
-      if (sscanf(rd->line->str, "%d %lf %lf %lf\n",
+      if (sscanf(rd->line->str, "%u %lf %lf %lf\n",
 		 rd->mesh + i, rd->box[i], rd->box[i] + 1, rd->box[i] + 2) != 4)
 	{
 	  *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
@@ -285,7 +285,7 @@ static gboolean read_coords(struct cube_reader *rd, GError **error)
       rd->coords[3 * i + 2] -= rd->shift[2];
       /* Try to find a z number instead of a name. */
       rcov = -1.f;
-      if (!tool_physic_getElementFromZ(&ptChar, &rcov, zele))
+      if (!tool_physic_getSymbolFromZ(&ptChar, &rcov, zele))
         {
 	  *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
 			       _("Wrong Cube format, one atomic number is 0 or lower,"
@@ -296,7 +296,7 @@ static gboolean read_coords(struct cube_reader *rd, GError **error)
       /* adding nomloc to the hashtable */
       type = visu_element_retrieveFromName(name, &new);
       if (new && rcov > 0.f)
-	visu_renderingAtomic_setRadius(type, rcov * 0.52917720859);
+	visu_rendering_atomic_setRadius(type, rcov * 0.52917720859);
       g_return_val_if_fail(type, FALSE);
       rd->nodeTypes[i] = type;
       infos = (struct VisuMethAscii*)g_hash_table_lookup(rd->elements,
@@ -332,7 +332,8 @@ static gboolean read_density(struct cube_reader *rd, GError **error)
 #endif
 
   n = rd->mesh[0] * rd->mesh[1] * rd->mesh[2];
-  rd->density = g_malloc(sizeof(double) * n);
+  rd->density = g_array_sized_new(FALSE, FALSE, sizeof(double), n);
+  g_array_set_size(rd->density, n);
 
   DBG_fprintf(stderr, "Cube: read density (%gMo).\n",
               sizeof(double) * n / 1024. / 1024.);
@@ -349,7 +350,7 @@ static gboolean read_density(struct cube_reader *rd, GError **error)
       for (j = 0; tokens[j] && i < n; j++)
         if (tokens[j][0])
           {
-            if (sscanf(tokens[j], "%lf", rd->density + i) != 1)
+            if (sscanf(tokens[j], "%lf", &g_array_index(rd->density, double, i)) != 1)
               {
                 *error = g_error_new(VISU_ERROR_RENDERING,
                                      RENDERING_ERROR_FORMAT,
@@ -367,6 +368,7 @@ static gboolean read_density(struct cube_reader *rd, GError **error)
   g_timer_stop(timer);
   fprintf(stderr, "Cube: density parsed in %g milli-s.\n", g_timer_elapsed(timer, &fractionTimer)/1e-3);
   g_timer_destroy(timer);
+  fprintf(stderr, " | %d elements.\n", rd->density->len);
 #endif
   if (rd->status != G_IO_STATUS_NORMAL)
     {
@@ -395,7 +397,7 @@ static int read_cube_file(struct cube_reader *rd, GError **error,
   rd->nodeTypes = (VisuElement**)0;
 
   rd->coords    = (float*)0;
-  rd->density   = (double*)0;
+  rd->density   = (GArray*)0;
 
   /* We read the all the file. */
   if (!read_comment(rd, error))
@@ -419,13 +421,15 @@ static int read_cube_file(struct cube_reader *rd, GError **error,
 }
 
 static gboolean cubeAtomicLoad(VisuData *data, const gchar* filename,
-			       ToolFileFormat *format _U_, int nSet _U_, GError **error)
+			       ToolFileFormat *format _U_, int nSet _U_,
+                               GCancellable *cancel _U_, GError **error)
 {
   int res, iNodes, i;
   struct cube_reader rd;
-  VisuElement **types;
-  unsigned int *nattyp;
+  GArray *nattyp, *types;
   gboolean *flag;
+  VisuBox *boxObj;
+  float xyz[3];
 
   g_return_val_if_fail(error && *error == (GError*)0, FALSE);
   g_return_val_if_fail(data && filename, FALSE);
@@ -440,38 +444,43 @@ static gboolean cubeAtomicLoad(VisuData *data, const gchar* filename,
   if (res == 0)
     {
       /* Allocate the space for the nodes. */
-      types  = g_malloc(sizeof(VisuElement*) * rd.ntype);
-      nattyp = g_malloc(sizeof(int) * rd.ntype);
-      g_hash_table_foreach(rd.elements, (GHFunc)visu_meth_asciiValToType, (gpointer)&types);
-      g_hash_table_foreach(rd.elements, (GHFunc)visu_meth_asciiValToNb, (gpointer)&nattyp);
+      types  = g_array_sized_new(FALSE, FALSE, sizeof(VisuElement*), rd.ntype);
+      nattyp = g_array_sized_new(FALSE, FALSE, sizeof(guint), rd.ntype);
+      g_array_set_size(types, rd.ntype);
+      g_array_set_size(nattyp, rd.ntype);
+      g_hash_table_foreach(rd.elements, (GHFunc)visu_meth_asciiValToType, (gpointer)types);
+      g_hash_table_foreach(rd.elements, (GHFunc)visu_meth_asciiValToNb, (gpointer)nattyp);
 
       DBG_fprintf(stderr, " | begin to transfer data to VisuData.\n");
       /* Begin the storage into VisuData. */
       visu_data_setNSubset(data, 1);
 
-      res = visu_data_setPopulation(data, rd.ntype, nattyp, types);
-      if (!res)
-	{
-	  g_error("Can't store the nodes in the VisuData object.");
-	}
+      visu_node_array_allocate(VISU_NODE_ARRAY(data), types, nattyp);
       DBG_fprintf(stderr, "Cube: there are %d types in this file.\n", rd.ntype);
       if (DEBUG)
 	for (i = 0; i < rd.ntype; i++)
-	  fprintf(stderr, " | %d atom(s) for type %d.\n", nattyp[i], i);
-      g_free(nattyp);
-      g_free(types);
+	  fprintf(stderr, " | %d atom(s) for type %d.\n",
+                  g_array_index(nattyp, guint, i), i);
+      g_array_free(nattyp, TRUE);
+      g_array_free(types, TRUE);
          
       /* Store the coordinates */
-      visu_data_setBoxGeometryFull(data, rd.box, VISU_DATA_BOX_PERIODIC);
+      boxObj = visu_box_new_full(rd.box, VISU_BOX_PERIODIC);
+      visu_boxed_setBox(VISU_BOXED(data), VISU_BOXED(boxObj), FALSE);
+      g_object_unref(boxObj);
       for(iNodes = 0; iNodes < rd.natom; iNodes++)
-	visu_data_addNodeFromElement(data, rd.nodeTypes[iNodes],
-                                     rd.coords + 3 * iNodes, FALSE, FALSE);
-      visu_data_applyBoxGeometry(data);
+        {
+          visu_box_convertFullToCell(boxObj, xyz, rd.coords + 3 * iNodes);
+          visu_data_addNodeFromElement(data, rd.nodeTypes[iNodes],
+                                       xyz, FALSE, FALSE);
+        }
+      visu_box_setMargin(boxObj, visu_node_array_getMaxElementSize(VISU_NODE_ARRAY(data)) +
+                         visu_data_getAllNodeExtens(data, boxObj), TRUE);
       visu_data_setFileCommentary(data, rd.comment, 0);
 
       flag = g_malloc(sizeof(gboolean));
       *flag = TRUE;
-      g_object_set_data_full(G_OBJECT(data), SCALAR_FIELD_DEFINED_IN_STRUCT_FILE,
+      g_object_set_data_full(G_OBJECT(data), VISU_SCALAR_FIELD_DEFINED_IN_STRUCT_FILE,
 			     (gpointer)flag, g_free);
     }
 
@@ -489,12 +498,13 @@ static gboolean cubeAtomicLoad(VisuData *data, const gchar* filename,
   return TRUE;
 }
 
-static gboolean cubeDensityLoad(const gchar *filename, GList **fieldList,
-				GError **error, GHashTable *table _U_)
+static gboolean cubeDensityLoad(VisuScalarFieldMethod *meth _U_, const gchar *filename,
+                                GList **fieldList, GError **error)
 {
   int res;
   struct cube_reader rd;
-  ScalarField *field;
+  VisuScalarField *field;
+  VisuBox *boxObj;
 
   g_return_val_if_fail(filename, FALSE);
   g_return_val_if_fail(*fieldList == (GList*)0, FALSE);
@@ -509,17 +519,20 @@ static gboolean cubeDensityLoad(const gchar *filename, GList **fieldList,
 
   if (res == 0)
     {
-      field = scalarFieldNew(rd.filename);
+      field = visu_scalar_field_new(rd.filename);
       if (!field)
-	g_warning("impossible to create a ScalarField object.");
+	g_warning("impossible to create a VisuScalarField object.");
       else
 	{
-	  scalarFieldSet_periodic(field, TRUE);
-	  scalarFieldSet_commentary(field, rd.comment);
-	  scalarFieldSet_boxFull(field, rd.box);
-	  scalarFieldSet_gridSize(field, rd.mesh);
+	  visu_scalar_field_setCommentary(field, rd.comment);
+          boxObj = visu_box_new_full(rd.box, VISU_BOX_PERIODIC);
+          visu_box_setMargin(boxObj, 0.f, FALSE);
+          visu_boxed_setBox(VISU_BOXED(field), VISU_BOXED(boxObj), FALSE);
+          g_object_unref(boxObj);
+	  visu_scalar_field_setGridSize(field, rd.mesh);
+          visu_scalar_field_setOriginShift(field, rd.shift);
 	  DBG_fprintf(stderr, "Cube: transfer density into field object.\n");
-	  scalarFieldSet_data(field, rd.density, FALSE);
+	  visu_scalar_field_setData(field, rd.density, FALSE);
 	  *fieldList = g_list_append(*fieldList, (gpointer)field);
 	}
     }
