@@ -13,30 +13,32 @@
 
 /* Local methods */
 static gboolean loadNQETSF(VisuData *data, const gchar* filename,
-			   ToolFileFormat *format, int nSet, GError **error);
+			   ToolFileFormat *format, int nSet,
+                           GCancellable *cancel, GError **error);
 
 void nqStructuralInit(VisuRendering *method)
 {
-  char *type[] = {"*.nc", "*-etsf.nc", (char*)0};
+  const gchar *type[] = {"*.nc", "*-etsf.nc", (char*)0};
 
   visu_rendering_addFileFormat(method, 0,
                                tool_file_format_new(_("ETSF file format"),
                                                     type),
-                               5, loadNQETSF, (GDestroyNotify)0);
+                               5, loadNQETSF);
 }
 
 static gboolean loadNQETSF(VisuData *data, const gchar* filename,
-			   ToolFileFormat *format _U_, int nSet _U_, GError **error)
+			   ToolFileFormat *format _U_, int nSet _U_,
+                           GCancellable *cancel _U_, GError **error)
 {
   gboolean res;
-  int netcdfId, status, ret;
-  unsigned int i;
+  int netcdfId, status;
+  guint i;
   int varId;
   size_t dimSize;
   char* varNbElement = "number_of_atom_species";
-  unsigned int nbEle;
+  guint nbEle;
   char* varNbNode = "number_of_atoms";
-  unsigned int nbNode;
+  guint nbNode;
   char* varAtomsNames = "atom_species_names";
   int varIdSymbols;
   size_t dimsSymbols[2];
@@ -44,7 +46,7 @@ static gboolean loadNQETSF(VisuData *data, const gchar* filename,
   char* varNodeToEle = "atom_species";
   int varIdNodeToEle;
   size_t dimsNodeToEle;
-  unsigned int *nodeToEle;
+  guint *nodeToEle;
   char* varCoord = "reduced_atom_positions";
   int varIdCoord;
   size_t dimsCoord[2];
@@ -57,8 +59,8 @@ static gboolean loadNQETSF(VisuData *data, const gchar* filename,
   char *varTitle = "title";
   size_t sizeTitle;
   char title[256];
-  unsigned int *nbNodesPerEle;
-  VisuElement **visuEle;
+  VisuElement *ele;
+  GArray *visuEle, *nbNodesPerEle, *gcoord_c, *gcoord_f;
   float vect[3];
   nc_type ncType;
   gchar *infoUTF8, *name;
@@ -66,6 +68,7 @@ static gboolean loadNQETSF(VisuData *data, const gchar* filename,
   guint nbGrid, nbFGrid, grid[3], *cGrid, *nGrid;
   size_t dimsGrid[3], dimsNGrid[2];
   int varIdGrid, varIdNGrid;
+  VisuBox *box;
 
   g_return_val_if_fail(error && *error == (GError*)0, FALSE);
   g_return_val_if_fail(data && filename, FALSE);
@@ -94,26 +97,6 @@ static gboolean loadNQETSF(VisuData *data, const gchar* filename,
       return TRUE;
     }
   nbNode = (int)dimSize;
-  /* Grep the grid size. */
-  nbGrid = 0;
-  nbFGrid = 0;
-  grid[0] = 0;
-  grid[1] = 0;
-  grid[2] = 0;
-  if (nqGetDim(netcdfId, (GError**)0, "max_number_of_basis_grid_points", &varId, &dimSize))
-    {
-      nbGrid = (guint)dimSize;
-      if (nqGetDim(netcdfId, (GError**)0, "number_of_grid_points_vector1", &varId, &dimSize))
-        grid[0] = (guint)dimSize;
-      if (nqGetDim(netcdfId, (GError**)0, "number_of_grid_points_vector2", &varId, &dimSize))
-        grid[1] = (guint)dimSize;
-      if (nqGetDim(netcdfId, (GError**)0, "number_of_grid_points_vector3", &varId, &dimSize))
-        grid[2] = (guint)dimSize;
-      if (!grid[0] || !grid[1] || !grid[2])
-        nbGrid = 0;
-      DBG_fprintf(stderr, "NQ structure: grid is defined (%d) in %dx%dx%d.\n",
-                  nbGrid, grid[0], grid[1], grid[2]);
-    }
 
   /**************************************************************/
   /* Check the conformance of the arrays to the specifications. */
@@ -160,22 +143,6 @@ static gboolean loadNQETSF(VisuData *data, const gchar* filename,
       nqClose_netcdfFile(netcdfId);
       return TRUE;
     }
-  /* Check the existence of the grid array. */
-  if (nbGrid)
-    {
-      dimsGrid[0] = 1;
-      dimsGrid[1] = nbGrid;
-      dimsGrid[2] = 3;
-      if (!nqCheckVar(netcdfId, (GError**)0, "coordinates_of_basis_grid_points", &varIdGrid,
-                      NC_INT, 3, dimsGrid))
-        nbGrid = 0;
-      dimsNGrid[0] = 1;
-      dimsNGrid[1] = nbGrid;
-      if (!nqCheckVar(netcdfId, (GError**)0, "number_of_coefficients_per_grid_point",
-                      &varIdNGrid, NC_INT, 2, dimsNGrid))
-        nbGrid = 0;
-      DBG_fprintf(stderr, "NQ structure: grid is present %d.\n", nbGrid);
-    }
 
   /****************************/
   /* Retrieve now the arrays. */
@@ -258,12 +225,114 @@ static gboolean loadNQETSF(VisuData *data, const gchar* filename,
       g_free(coord);
       return TRUE;
     }
-  /* Grep the grid definition, if any. */
-  cGrid = (guint*)0;
-  nGrid = (guint*)0;
+
+  /* Prepare the arrays for memory allocation in the VisuData object. */
+  box = visu_box_new_full(rprimd, VISU_BOX_PERIODIC);
+  visu_boxed_setBox(VISU_BOXED(data), VISU_BOXED(box), FALSE);
+  g_object_unref(box);
+
+  nbNodesPerEle = g_array_sized_new(FALSE, TRUE, sizeof(guint), nbEle);
+  g_array_set_size(nbNodesPerEle, nbEle);
+  for (i = 0; i < nbNode; i++)
+    g_array_index(nbNodesPerEle, guint, nodeToEle[i]) += 1;
+  visuEle = g_array_sized_new(FALSE, FALSE, sizeof(VisuElement*), nbEle);
+  for (i = 0; i < nbEle; i++)
+    {
+      name = g_strstrip(symbols + i * (dimsSymbols[1] + 1));
+      ele = visu_element_retrieveFromName(name, (gboolean*)0);
+      g_array_append_val(visuEle, ele);
+    }
+
+  DBG_fprintf(stderr, "NQ structure : File '%s' parsed.\n", filename);
+  DBG_fprintf(stderr, " | box definition : ( %f %f %f )\n",
+	      rprimd[0][0], rprimd[0][1], rprimd[0][2]);
+  DBG_fprintf(stderr, " |                  ( %f %f %f )\n",
+	      rprimd[1][0], rprimd[1][1], rprimd[1][2]);
+  DBG_fprintf(stderr, " |                  ( %f %f %f )\n",
+	      rprimd[2][0], rprimd[2][1], rprimd[2][2]);
+  DBG_fprintf(stderr, " | number of nodes per element (%d):\n", nbEle);
+  for (i = 0; i < nbEle ; i++)
+    DBG_fprintf(stderr, " |  %d nodes for '%s' (%p)\n",
+                g_array_index(nbNodesPerEle, guint, i),
+                g_array_index(visuEle, VisuElement*, i)->name,
+                g_array_index(visuEle, gpointer, i));
+  g_free(symbols);
+
+  visu_node_array_allocate(VISU_NODE_ARRAY(data), visuEle, nbNodesPerEle);
+  for (i = 0; i < nbNode; i++)
+    {
+      vect[0] = coord[3 * i + 0];
+      vect[1] = coord[3 * i + 1];
+      vect[2] = coord[3 * i + 2];
+      visu_data_addNodeFromElement(data, g_array_index(visuEle, VisuElement*,
+                                                       nodeToEle[i]),
+                                   vect, TRUE, FALSE);
+    }
+  visu_box_setMargin(box, visu_node_array_getMaxElementSize(VISU_NODE_ARRAY(data)) +
+                     visu_data_getAllNodeExtens(data, box), TRUE);
+  visu_box_setUnit(box, TOOL_UNITS_BOHR);
+
+  g_free(nodeToEle);
+  g_free(coord);
+  g_array_free(nbNodesPerEle, TRUE);
+  g_array_free(visuEle, TRUE);
+
+  /**********************/
+  /* Optional elements. */
+  /**********************/
+  status = nc_inq_att(netcdfId, NC_GLOBAL, varTitle, &ncType, &sizeTitle);
+  if (status == NC_NOERR && ncType == NC_CHAR && sizeTitle < 255)
+    {
+  	  status = nc_get_att_text(netcdfId, NC_GLOBAL, varTitle, title);
+  	  if (status == NC_NOERR)
+  	    {
+  	      title[sizeTitle] = '\0';
+	      infoUTF8 = g_locale_to_utf8(title, -1, NULL, NULL, NULL);
+	      if (infoUTF8)
+		{
+		  visu_data_setFileCommentary(data, infoUTF8, 0);
+		  g_free(infoUTF8);
+		}
+	      else
+		g_warning("Can't convert '%s' to UTF8.\n", title);
+  	    }
+    }
+  /* Support for BigDFT grid points. */
+  nbGrid = 0;
+  grid[0] = 0;
+  grid[1] = 0;
+  grid[2] = 0;
+  if (nqGetDim(netcdfId, (GError**)0, "max_number_of_basis_grid_points", &varId, &dimSize))
+    {
+      nbGrid = (guint)dimSize;
+      if (nqGetDim(netcdfId, (GError**)0, "number_of_grid_points_vector1", &varId, &dimSize))
+        grid[0] = (guint)dimSize;
+      if (nqGetDim(netcdfId, (GError**)0, "number_of_grid_points_vector2", &varId, &dimSize))
+        grid[1] = (guint)dimSize;
+      if (nqGetDim(netcdfId, (GError**)0, "number_of_grid_points_vector3", &varId, &dimSize))
+        grid[2] = (guint)dimSize;
+      if (!grid[0] || !grid[1] || !grid[2])
+        nbGrid = 0;
+      DBG_fprintf(stderr, "NQ structure: grid is defined (%d) in %dx%dx%d.\n",
+                  nbGrid, grid[0], grid[1], grid[2]);
+      dimsGrid[0] = 1;
+      dimsGrid[1] = nbGrid;
+      dimsGrid[2] = 3;
+      if (!nqCheckVar(netcdfId, (GError**)0, "coordinates_of_basis_grid_points",
+                      &varIdGrid, NC_INT, 3, dimsGrid))
+        nbGrid = 0;
+      dimsNGrid[0] = 1;
+      dimsNGrid[1] = nbGrid;
+      if (!nqCheckVar(netcdfId, (GError**)0, "number_of_coefficients_per_grid_point",
+                      &varIdNGrid, NC_INT, 2, dimsNGrid))
+        nbGrid = 0;
+      DBG_fprintf(stderr, "NQ structure: grid is present %d and valid.\n", nbGrid);
+    }
   if (nbGrid)
     {
+      nbFGrid = 0;
       cGrid = g_malloc(sizeof(guint) * nbGrid * 3);
+      nGrid = (guint*)0;
       status = nc_get_vara_int(netcdfId, varIdGrid, start,
                                dimsGrid, (int*)cGrid);
       if (status != NC_NOERR)
@@ -284,127 +353,38 @@ static gboolean loadNQETSF(VisuData *data, const gchar* filename,
             }
           else
             {
-              nbEle += 1;
               /* Calculate the number of fine grid points. */
               nbFGrid = 0;
               for (i = 0; i < nbGrid; i++)
                 if (nGrid[i] > 1) nbFGrid += 1;
-              if (nbFGrid > 0) nbEle += 1;
             }
         }
-      DBG_fprintf(stderr, "NQ structure: grid has been read, nbEle is now %d.\n", nbEle);
-    }
-
-  /* Prepare the arrays for memory allocation in the VisuData object. */
-  res = visu_data_setBoxGeometryFull(data, rprimd, VISU_DATA_BOX_PERIODIC);
-  if (!res)
-    {
-      *error = g_error_new(NQ_ERROR, NQ_ERROR_FILE_FORMAT,
-			   _("The variable '%s' is not well formed (the basis is not 3D)."),
-			   varRprimd);
-      nqClose_netcdfFile(netcdfId);
-      g_free(symbols);
-      g_free(nodeToEle);
-      g_free(coord);
-      return TRUE;
-    }
-  nbNodesPerEle = g_malloc(sizeof(int) * nbEle);
-  for (i = 0; i < nbEle; i++)
-    nbNodesPerEle[i] = 0;
-  for (i = 0; i < nbNode; i++)
-    nbNodesPerEle[nodeToEle[i]] += 1;
-  if (nbGrid)
-    {
-      if (nbFGrid > 0)
-        nbNodesPerEle[nbEle - 2] = nbFGrid;
-      nbNodesPerEle[nbEle - 1] = nbGrid;
-    }
-  visuEle = g_malloc(sizeof(VisuElement*) * nbEle);
-  for (i = 0; i < nbEle; i++)
-    {
-      name = (gchar*)0;
-      if ((nbGrid && nbFGrid && i < nbEle - 2) ||
-          (nbGrid && !nbFGrid && i < nbEle - 1) || !nbGrid)
-        name = g_strstrip(symbols + i * (dimsSymbols[1] + 1));
-      else if (i == nbEle - 2)
-        name = "G";
-      else if (i == nbEle - 1)
-        name = "g";
-      visuEle[i] = visu_element_retrieveFromName(name, (gboolean*)0);
-    }
-
-  DBG_fprintf(stderr, "NQ structure : File '%s' parsed.\n", filename);
-  DBG_fprintf(stderr, " | box definition : ( %f %f %f )\n",
-	      rprimd[0][0], rprimd[0][1], rprimd[0][2]);
-  DBG_fprintf(stderr, " |                  ( %f %f %f )\n",
-	      rprimd[1][0], rprimd[1][1], rprimd[1][2]);
-  DBG_fprintf(stderr, " |                  ( %f %f %f )\n",
-	      rprimd[2][0], rprimd[2][1], rprimd[2][2]);
-  DBG_fprintf(stderr, " | number of nodes per element (%d):\n", nbEle);
-  for (i = 0; i < nbEle ; i++)
-    DBG_fprintf(stderr, " |  %d nodes for '%s' (%p)\n", nbNodesPerEle[i],
-		visuEle[i]->name, (gpointer)visuEle[i]);
-
-  g_free(symbols);
-
-  ret = visu_data_setPopulation(data, nbEle, nbNodesPerEle, visuEle);
-  if (!ret)
-    {
-      g_error("Can't store the nodes in the VisuData object.\n");
-    }
-  for (i = 0; i < nbNode; i++)
-    {
-      vect[0] = coord[3 * i + 0];
-      vect[1] = coord[3 * i + 1];
-      vect[2] = coord[3 * i + 2];
-      visu_data_addNodeFromElement(data, visuEle[nodeToEle[i]], vect, TRUE, FALSE);
-    }
-  /* Add the grid nodes. */
-  if (nbGrid)
-    {
-      for (i = 0; i < nbGrid; i++)
+      DBG_fprintf(stderr, "NQ structure: grid has been read.\n");
+      if (cGrid && nGrid)
         {
-          vect[0] = (float)cGrid[i * 3 + 0] / (float)grid[0];
-          vect[1] = (float)cGrid[i * 3 + 1] / (float)grid[1];
-          vect[2] = (float)cGrid[i * 3 + 2] / (float)grid[2];
-          visu_data_addNodeFromElement(data, visuEle[nbEle - 1], vect, TRUE, FALSE);
-          if (nGrid[i] > 1)
-            visu_data_addNodeFromElement(data, visuEle[nbEle - 2], vect, TRUE, FALSE);
+          /* Add the grid nodes. */
+          gcoord_c = g_array_sized_new(FALSE, FALSE, sizeof(gfloat) * 3, nbGrid);
+          gcoord_f = (GArray*)0;
+          if (nbFGrid > 0)
+            gcoord_f = g_array_sized_new(FALSE, FALSE, sizeof(gfloat) * 3, nbFGrid);
+          for (i = 0; i < nbGrid; i++)
+            {
+              vect[0] = (float)cGrid[i * 3 + 0] / (float)grid[0];
+              vect[1] = (float)cGrid[i * 3 + 1] / (float)grid[1];
+              vect[2] = (float)cGrid[i * 3 + 2] / (float)grid[2];
+              g_array_append_val(gcoord_c, vect);
+              if (nGrid[i] > 1)
+                g_array_append_val(gcoord_f, vect);
+            }
+          g_free(cGrid);
+          g_free(nGrid);
+          g_object_set_data_full(G_OBJECT(data), "BigDFT_coarse_grid",
+                                 (gpointer)gcoord_c, (GDestroyNotify)g_array_unref);
+          if (nbFGrid > 0)
+            g_object_set_data_full(G_OBJECT(data), "BigDFT_fine_grid",
+                                   (gpointer)gcoord_f, (GDestroyNotify)g_array_unref);
         }
     }
-  visu_data_applyBoxGeometry(data);
-  visu_data_setUnit(data, unit_bohr);
-
-  g_free(nodeToEle);
-  g_free(coord);
-  g_free(nbNodesPerEle);
-  g_free(visuEle);
-  if (nbGrid)
-    {
-      g_free(cGrid);
-      g_free(nGrid);
-    }
-
-  /**********************/
-  /* ToolOptional elements. */
-  /**********************/
-  status = nc_inq_att(netcdfId, NC_GLOBAL, varTitle, &ncType, &sizeTitle);
-  if (status == NC_NOERR && ncType == NC_CHAR && sizeTitle < 255)
-    {
-  	  status = nc_get_att_text(netcdfId, NC_GLOBAL, varTitle, title);
-  	  if (status == NC_NOERR)
-  	    {
-  	      title[sizeTitle] = '\0';
-	      infoUTF8 = g_locale_to_utf8(title, -1, NULL, NULL, NULL);
-	      if (infoUTF8)
-		{
-		  visu_data_setFileCommentary(data, infoUTF8, 0);
-		  g_free(infoUTF8);
-		}
-	      else
-		g_warning("Can't convert '%s' to UTF8.\n", title);
-  	    }
-    }
 
   nqClose_netcdfFile(netcdfId);
   
@@ -413,7 +393,7 @@ static gboolean loadNQETSF(VisuData *data, const gchar* filename,
   /******************************************/
   flag = g_malloc(sizeof(gboolean));
   *flag = TRUE;
-  g_object_set_data_full(G_OBJECT(data), SCALAR_FIELD_DEFINED_IN_STRUCT_FILE,
+  g_object_set_data_full(G_OBJECT(data), VISU_SCALAR_FIELD_DEFINED_IN_STRUCT_FILE,
 			 (gpointer)flag, g_free);
 
   return TRUE;
