@@ -228,15 +228,11 @@ static void initialisePython()
   Py_SetProgramName((char*)commandLineGet_programName());
   Py_Initialize();
   DBG_fprintf(stderr, "Panel PythonGI: import sys.\n"
-              "sys.path = [\"" GI_TYPELIBS_DIR "\"] + sys.path;\n"
-              "sys.path = [\"" PYGI_EXEC_DIR "\"] + sys.path;\n"
               "import os;\n"
-              "os.putenv(\"GI_TYPELIB_PATH\", \"" VISU_TYPELIBS_DIR "\");\n"
-              "sys.path = [\"" VISU_EXEC_DIR "\"] + sys.path\n");
+              "os.putenv(\"GI_TYPELIB_PATH\", \"" VISU_TYPELIBS_DIR "\")\n");
   PyRun_SimpleString("import os;"
                      "os.putenv(\"GI_TYPELIB_PATH\", \"" VISU_TYPELIBS_DIR "\");"
                      "import sys;"
-                     "sys.path = [\"" VISU_EXEC_DIR "\"] + sys.path;"
                      "sys.argv = ['']\n"
                      "from gi.repository import v_sim");
   DBG_fprintf(stderr, " | done.\n");
