@@ -52,6 +52,7 @@
 
 #include "visu_openGL.h"
 #include <visu_tools.h>
+#include <openGLFunctions/text.h>
 
 static Display *dpy = (Display*)0;
 static gboolean Xerror = FALSE;
@@ -59,19 +60,66 @@ static gboolean Xerror = FALSE;
 struct _VisuPixmapContext
 {
   GLXContext context;
+#ifdef HAVE_PBUFFER
+  GLXPbuffer glxPbuffer;
+#else
   GLXPixmap glxPixmap;
+#endif
   Pixmap pixmap;
   guint width, height;
 };
 
-int handler(Display *dpy _U_, XErrorEvent *error _U_)
+struct _VisuGLXFont
+{
+  GLuint id;
+  GLsizei len;
+  XFontStruct *font;
+};
+
+static GHashTable *fonts = (GHashTable*)0;
+
+static int handler(Display *dpy _U_, XErrorEvent *error _U_)
 {
   DBG_fprintf(stderr, "Visu GLX: ouch one X error.\n");
   Xerror = TRUE;
   return 0;
 }
 
-XVisualInfo* visuOpenGLGet_visualInfo(Display *dpy, int screenId)
+#ifdef HAVE_PBUFFER
+static XVisualInfo* _visualInfoFromFB(Display *dpy, int screenId, GLXFBConfig **fb)
+{
+  XVisualInfo *vinfo;
+  GLXFBConfig *fbconfig;
+  int nitems;
+  int attrib[] = {
+    GLX_DOUBLEBUFFER,  False,
+    GLX_RED_SIZE,      1,
+    GLX_GREEN_SIZE,    1,
+    GLX_BLUE_SIZE,     1,
+    GLX_DEPTH_SIZE,    1,
+    GLX_RENDER_TYPE,   GLX_RGBA_BIT,
+    GLX_DRAWABLE_TYPE, GLX_PBUFFER_BIT,
+    None
+  };
+
+  fbconfig = glXChooseFBConfig(dpy, screenId, attrib, &nitems);
+  if (fbconfig == (GLXFBConfig*)0 || nitems == 0)
+    {
+      g_warning("Can't get FBConfig.");
+      return (XVisualInfo*)0;
+    }
+  *fb = fbconfig;
+  vinfo = glXGetVisualFromFBConfig(dpy, fbconfig[0]);
+  if (!vinfo)
+    {
+      g_warning("Can't get RGBA Visual.");
+      return (XVisualInfo*)0;
+    }  
+
+  return vinfo;
+}
+#endif
+XVisualInfo* visu_gl_getVisualInfo(Display *dpy, int screenId)
 {
   XVisualInfo *vinfo;
   int list[] = {
@@ -113,12 +161,26 @@ VisuPixmapContext* visu_pixmap_context_new(guint width, guint height)
 {
   VisuPixmapContext *image;
   int screenId, res;
+  Bool direct;
   XVisualInfo *visualInfo;
+#ifdef HAVE_PBUFFER
+  GLXFBConfig *fbconfig;
+  int pbufAttrib[] = {
+    GLX_PBUFFER_WIDTH,   0,
+    GLX_PBUFFER_HEIGHT,  0,
+    GLX_LARGEST_PBUFFER, False,
+    None
+  };
+#endif
 
   DBG_fprintf(stderr, "Visu GLX: creating a off-screen buffer (%dx%d).\n", width, height);
   image = g_malloc(sizeof(VisuPixmapContext));
   image->pixmap = (Pixmap)0;
+#ifdef HAVE_PBUFFER
+  image->glxPbuffer = (GLXPbuffer)0;
+#else
   image->glxPixmap = (GLXPixmap)0;
+#endif
   image->context = (GLXContext)0;
 
   if (!dpy)
@@ -133,7 +195,16 @@ VisuPixmapContext* visu_pixmap_context_new(guint width, guint height)
   DBG_fprintf(stderr, "Visu GLX: display opened.\n");
 
   screenId = DefaultScreen(dpy);
-  visualInfo = visuOpenGLGet_visualInfo(dpy, screenId);
+#ifdef HAVE_PBUFFER
+  visualInfo = _visualInfoFromFB(dpy, screenId, &fbconfig);
+#else
+  visualInfo = visu_gl_getVisualInfo(dpy, screenId);
+#endif
+  if (!visualInfo)
+    {
+      g_free(image);
+      return (VisuPixmapContext*)0;
+    }
 
   image->width = width;
   image->height = height;
@@ -148,7 +219,23 @@ VisuPixmapContext* visu_pixmap_context_new(guint width, guint height)
     }
   DBG_fprintf(stderr, "Visu GLX: X pixmap created.\n");
 
+#ifdef HAVE_PBUFFER
+  pbufAttrib[1] = width;
+  pbufAttrib[3] = height;
+  image->glxPbuffer = glXCreatePbuffer(dpy, fbconfig[0], pbufAttrib);
+  DBG_fprintf(stderr, "Visu GLX: use pBuffer.\n");
+  if (!image->glxPbuffer)
+    {
+      g_warning("Cannot allocate a GLXPbuffer for the indirect rendering.");
+      XFreePixmap(dpy, image->pixmap);
+      g_free(image);
+      XFree(visualInfo);
+      return (VisuPixmapContext*)0;
+    }
+  direct = GL_TRUE;
+#else
   image->glxPixmap = glXCreateGLXPixmap(dpy, visualInfo, image->pixmap);
+  DBG_fprintf(stderr, "Visu GLX: use GLXPixmap.\n");
   if (!image->glxPixmap)
     {
       g_warning("Cannot allocate a GLXPixmap for the indirect rendering.");
@@ -157,14 +244,20 @@ VisuPixmapContext* visu_pixmap_context_new(guint width, guint height)
       XFree(visualInfo);
       return (VisuPixmapContext*)0;
     }
-  DBG_fprintf(stderr, "Visu GLX: GLX pixmap created.\n");
+  direct = GL_FALSE;
+#endif
+  DBG_fprintf(stderr, "Visu GLX: GLX off-creen surface created.\n");
 
-  image->context = glXCreateContext(dpy, visualInfo, 0, GL_FALSE);
+  image->context = glXCreateContext(dpy, visualInfo, 0, direct);
   if (!image->context)
     {
       g_warning("Cannot create indirect GLX context.");
       XFreePixmap(dpy, image->pixmap);
+#ifdef HAVE_PBUFFER
+      glXDestroyPbuffer(dpy, image->glxPbuffer);
+#else
       glXDestroyGLXPixmap(dpy, image->glxPixmap);
+#endif
       g_free(image);
       XFree(visualInfo);
       return (VisuPixmapContext*)0;
@@ -173,19 +266,30 @@ VisuPixmapContext* visu_pixmap_context_new(guint width, guint height)
 
   Xerror = FALSE;
   XSetErrorHandler(handler);
+#ifdef HAVE_PBUFFER
+  res = glXMakeCurrent(dpy, image->glxPbuffer, image->context);
+#else
   res = glXMakeCurrent(dpy, image->glxPixmap, image->context);
+#endif
   XSetErrorHandler(NULL);
   if (!res || Xerror)
     {
       g_warning("Cannot make current the pixmap context.");
       XFreePixmap(dpy, image->pixmap);
+#ifdef HAVE_PBUFFER
+      glXDestroyPbuffer(dpy, image->glxPbuffer);
+#else
       glXDestroyGLXPixmap(dpy, image->glxPixmap);
+#endif
       g_free(image);
       XFree(visualInfo);
       return (VisuPixmapContext*)0;
     }
   DBG_fprintf(stderr, "Visu GLX: pixmap context is now current.\n");
 
+  /* Changing context, update fonts. */
+  visu_gl_text_onNewContext();
+
   XFree(visualInfo);
 
   glXWaitX();
@@ -205,10 +309,17 @@ void visu_pixmap_context_free(VisuPixmapContext *dumpData)
 
   if (dpy)
     {
+#ifdef HAVE_PBUFFER
+      DBG_fprintf(stderr, "Visu GLX: free the GLX pbuffer 0x%x.\n",
+		  (int)dumpData->glxPbuffer);
+      if (dumpData->glxPbuffer)
+        glXDestroyPbuffer(dpy, dumpData->glxPbuffer);
+#else
       DBG_fprintf(stderr, "Visu GLX: free the GLX pixmap 0x%x.\n",
 		  (int)dumpData->glxPixmap);
       if (dumpData->glxPixmap)
-	glXDestroyGLXPixmap(dpy, dumpData->glxPixmap);
+        glXDestroyGLXPixmap(dpy, dumpData->glxPixmap);
+#endif
 
       DBG_fprintf(stderr, "Visu GLX: free the X pixmap 0x%x.\n",
 		  (int)dumpData->pixmap);
@@ -228,44 +339,86 @@ void visu_pixmap_context_free(VisuPixmapContext *dumpData)
   g_free(dumpData);
 }
 
-GLuint visuOpenGLinit_fontList(guint size)
+static void freeFont(gpointer data)
+{
+  struct _VisuGLXFont *font = (struct _VisuGLXFont*)data;
+
+  if (!dpy)
+    dpy = XOpenDisplay(0);
+
+  DBG_fprintf(stderr, "Visu GLX: delete font %d.\n", font->id);
+  glDeleteLists(font->id, font->len);
+  XFreeFont(dpy, font->font);
+  g_free(data);
+}
+
+GLuint visu_gl_initFontList(guint size)
 {
   XFontStruct *fontInfo = (XFontStruct*)0;
-  unsigned int first, last; 
-  char name[256];
-  GLuint BASE;
-  static Display *dpy = (Display*)0;
+  guint first, last; 
+  gchar *name;
+  struct _VisuGLXFont *font;
 
-  sprintf(name, "-adobe-helvetica-medium-r-normal-*-%d-*-*-*-p-*-iso8859-1", size);
-        
+  name = g_strdup_printf("-misc-fixed-bold-r-normal-*-%d-*-*-*-*-*-iso8859-1", size);
   DBG_fprintf(stderr, "Visu GLX: initialise fonts (%s).\n", name);
-  if (!fontInfo)
+        
+  if (!dpy)
+    dpy = XOpenDisplay(0);
+  if (!fonts)
+    fonts = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, freeFont);
+
+  /* Delete previous lists for this size. */
+  DBG_fprintf(stderr, " | remove previous entry %p if any from %p (%d).\n",
+              GINT_TO_POINTER(size), (gpointer)fonts, g_hash_table_size(fonts));
+  g_hash_table_remove(fonts, name);
+
+  DBG_fprintf(stderr, " | get the X font description.\n");
+  Xerror = FALSE;
+  XSetErrorHandler(handler);
+  if ((fontInfo = XLoadQueryFont(dpy, name)) == NULL) 
     {
-      if (!dpy)
-	dpy = XOpenDisplay(0);
-      if ((fontInfo = XLoadQueryFont(dpy, name)) == NULL) 
-	{
-	  g_warning("Specified font not available in gl_font_init\n" 
-		    "Trying to use fixed font\n"); 
-	  if ((fontInfo = XLoadQueryFont(dpy, "fixed")) == NULL) 
-	    {
-	      g_error("Fixed font not available.\n"); 
-	    }
-	}
-      DBG_fprintf(stderr, " | Found XFontStruct.\n");
+      g_message("Specified font not available in gl_font_init\n" 
+                "Trying to use fixed font\n"); 
+      if ((fontInfo = XLoadQueryFont(dpy, "fixed")) == NULL) 
+        {
+          g_error("Fixed font not available.\n"); 
+        }
     }
+  XSetErrorHandler(NULL);
+  if (Xerror)
+    {
+      g_warning("No font for this surface.");
+      return 0;
+    }
+  DBG_fprintf(stderr, " | Found XFontStruct.\n");
+
   first = fontInfo->min_char_or_byte2; 
   last = fontInfo->max_char_or_byte2; 
   DBG_fprintf(stderr, " | XFontStruct OK (%d %d).\n", first, last);
  
   /* this creates display lists 1 to 256 (not checked) */ 
-  BASE = glGenLists(last+1);
-  if (!BASE)
-    return 0;
+  font = g_malloc(sizeof(struct _VisuGLXFont));
+  font->font = fontInfo;
+  font->len = last + 1;
+  font->id = glGenLists(font->len);
+  if (!font->id)
+    {
+      g_free(font);
+      g_free(name);
+      return 0;
+    }
+  g_hash_table_insert(fonts, name, (gpointer)font);
     
-  DBG_fprintf(stderr, " | list id %d\n", BASE);
-  glXUseXFont(fontInfo->fid, first, last-first+1, BASE+first); 
+  Xerror = FALSE;
+  XSetErrorHandler(handler);
+  glXUseXFont(fontInfo->fid, first, last-first+1, font->id+first);
+  XSetErrorHandler(NULL);
+  if (Xerror)
+    {
+      g_warning("No font generation for this surface.");
+      font->id = 0;
+    }
+  DBG_fprintf(stderr, " | list id %d\n", font->id);
 
-/*   XFreeFont(dpy, fontInfo); */
-  return BASE; 
+  return font->id; 
 }
