@@ -59,18 +59,19 @@
  */
 
 /**
- * visuOpenGLGet_pixmapData:
+ * visu_pixmap_getData:
  * @width: an integer ;
  * @height: an integer ;
  * @hasAlpha: if TRUE, read also the alpha channel.
  *
  * Dump the pixels of the current GL area, assuming that its size
  * is given by @widthx@height. This method should not be used directly, see
- * openGLWidgetGet_pixmapData() to dump a given OpenGL area.
+ * visu_ui_gl_widget_getPixmapData() to dump a given OpenGL area.
  *
- * Returns: (transfer none) (element-type int8): newly allocated dump data (use g_free() after use).
+ * Returns: (transfer full) (element-type gint8): newly allocated dump
+ * data (use g_array_unref() after use).
  */
-GArray* visuOpenGLGet_pixmapData(guint width, guint height, gboolean hasAlpha)
+GArray* visu_pixmap_getData(guint width, guint height, gboolean hasAlpha)
 {
   GArray *image;
   guchar *row_tab;
@@ -84,8 +85,7 @@ GArray* visuOpenGLGet_pixmapData(guint width, guint height, gboolean hasAlpha)
     row_length = 3 * width;
   row_tab = g_malloc(sizeof(guchar) * row_length);
 
-  image = g_array_sized_new(FALSE, FALSE, sizeof(guchar),
-			    row_length * height * sizeof(guchar));
+  image = g_array_sized_new(FALSE, FALSE, sizeof(guchar), row_length * height);
 
   glPixelStorei(GL_PACK_ALIGNMENT,1); /* just in case */
 
