@@ -41,8 +41,8 @@
 	knowledge of the CeCILL license and that you accept its terms. You can
 	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
 */
-#ifndef VISU_OPENGL_H
-#define VISU_OPENGL_H
+#ifndef VISU_GL_H
+#define VISU_GL_H
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -90,27 +90,27 @@
 /**
  * VisuPixmapContext:
  *
- * Short way to address #VisuPixmapContext_struct objects.
+ * Short way to address #_VisuPixmapContext objects.
  */
 typedef struct _VisuPixmapContext VisuPixmapContext;
 
-GArray* visuOpenGLGet_pixmapData(guint width, guint height, gboolean hasAlpha);
+GArray* visu_pixmap_getData(guint width, guint height, gboolean hasAlpha);
 VisuPixmapContext* visu_pixmap_context_new(guint width, guint height);
 void visu_pixmap_context_free(VisuPixmapContext *dumpData);
 
 /**
- * visuOpenGLinit_fontList:
+ * visu_gl_initFontList:
  * @size: the size of the text.
  *
  * This method create a list with a default font.
  *
- * Returns: the GL id of the list storing the font.
+ * Returns: (type guint32) (transfer none): the GL id of the list storing the font.
  */
-GLuint visuOpenGLinit_fontList(guint size);
+GLuint visu_gl_initFontList(guint size);
 
 #ifdef IMPL_GTKGLEXT
 /**
- * visuOpenGLGet_glConfig:
+ * visu_gl_getGLConfig:
  * @screen: a #GdkScreen.
  *
  * Call gdk_gl_config_new_for_screen(), trying to acquire a RGBA visual with stereo 
@@ -118,11 +118,11 @@ GLuint visuOpenGLinit_fontList(guint size);
  *
  * Returns: a matching #GdkGLConfig.
  */
-GdkGLConfig* visuOpenGLGet_glConfig(GdkScreen *screen);
+GdkGLConfig* visu_gl_getGLConfig(GdkScreen *screen);
 #endif
 #ifdef IMPL_BUILTIN_X11
 /**
- * visuOpenGLGet_visualInfo:
+ * visu_gl_getVisualInfo:
  * @dpy: an X display ;
  * @screenId: an X screen id.
  *
@@ -131,17 +131,17 @@ GdkGLConfig* visuOpenGLGet_glConfig(GdkScreen *screen);
  *
  * Returns: an allocated XVisualInfo.
  */
-XVisualInfo* visuOpenGLGet_visualInfo(Display *dpy, int screenId);
+XVisualInfo* visu_gl_getVisualInfo(Display *dpy, int screenId);
 #endif
 #ifdef IMPL_BUILTIN_WIN32
 /**
- * visuOpenGLSetup_pixelFormat:
+ * visu_gl_setupPixelFormat:
  * @hDC: an HDC.
  *
  * Call ChoosePixelFormat() and SetPixelFormat(), trying to acquire a RGBA visual.
  * This method is used internaly and should not be used elsewhere.
  */
-void visuOpenGLSetup_pixelFormat(HDC hDC);
+void visu_gl_setupPixelFormat(HDC hDC);
 #endif
 
 #endif
