@@ -58,20 +58,20 @@
  */
 
 /**
- * tool_configFile_getQuark:
+ * tool_config_file_getQuark:
  *
  * Internal routine for error handling.
  *
  * Returns: the #GQuark associated to errors related to configuration
  * files.
  */
-GQuark tool_configFile_getQuark()
+GQuark tool_config_file_getQuark()
 {
   return g_quark_from_static_string("visu_configFile");
 }
 
 /**
- * tool_configFile_readFloatFromTokens:
+ * tool_config_file_readFloatFromTokens:
  * @tokens: array of tokens resulting from a call to g_strsplit() with " " as separator ;
  * @position: IN, the position of the beginning in @tokens ; OUT, one token
  *            after the last read ;
@@ -86,7 +86,7 @@ GQuark tool_configFile_getQuark()
  *
  * Returns: TRUE if no error occured.
  */
-gboolean tool_configFile_readFloatFromTokens(gchar **tokens, int *position, float *values,
+gboolean tool_config_file_readFloatFromTokens(gchar **tokens, int *position, float *values,
 					guint size, int lineId, GError **error)
 {
   int res;
@@ -105,7 +105,7 @@ gboolean tool_configFile_readFloatFromTokens(gchar **tokens, int *position, floa
 	  res = sscanf(tokens[i], "%f", values + nb);
 	  if (res != 1)
 	    {
-	      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_READ,
+	      *error = g_error_new(TOOL_CONFIG_FILE_ERROR, TOOL_CONFIG_FILE_ERROR_READ,
 				   _("Parse error at line %d, %d floating point"
 				     " values should appear here.\n"), lineId, size);
 	      *position = i;
@@ -118,7 +118,7 @@ gboolean tool_configFile_readFloatFromTokens(gchar **tokens, int *position, floa
 
   if (nb != size)
     {
-      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_MISSING,
+      *error = g_error_new(TOOL_CONFIG_FILE_ERROR, TOOL_CONFIG_FILE_ERROR_MISSING,
 			   _("Parse error at line %d, %d floating point value(s)"
 			     " should appear here but %d has been found.\n"),
 			   lineId, size, nb);
@@ -127,7 +127,7 @@ gboolean tool_configFile_readFloatFromTokens(gchar **tokens, int *position, floa
   return TRUE;
 }
 /**
- * tool_configFile_readFloat:
+ * tool_config_file_readFloat:
  * @line: string where values are read from ;
  * @position: the number of the line of the config
  *            file which the @line argument is taken from ;
@@ -139,7 +139,7 @@ gboolean tool_configFile_readFloatFromTokens(gchar **tokens, int *position, floa
  *
  * Returns: TRUE if no error occured.
  */
-gboolean tool_configFile_readFloat(gchar *line, int position, float *values,
+gboolean tool_config_file_readFloat(gchar *line, int position, float *values,
 			      guint size, GError **error)
 {
   int id;
@@ -147,15 +147,15 @@ gboolean tool_configFile_readFloat(gchar *line, int position, float *values,
   gchar **tokens;
 
   /* Read @size floating point values from @line. */
-  tokens = g_strsplit_set(line, " \n", MAX_LINE_LENGTH);
+  tokens = g_strsplit_set(line, " \n", TOOL_MAX_LINE_LENGTH);
   id = 0;
-  res = tool_configFile_readFloatFromTokens(tokens, &id, values, size, position, error);
+  res = tool_config_file_readFloatFromTokens(tokens, &id, values, size, position, error);
   g_strfreev(tokens);
 
   return res;
 }
 /**
- * tool_configFile_readBooleanFromTokens:
+ * tool_config_file_readBooleanFromTokens:
  * @tokens: array of tokens resulting from a call to g_strsplit() with " " as separator ;
  * @position: IN, the position of the beginning in @tokens ; OUT, one token
  *            after the last read ;
@@ -170,7 +170,7 @@ gboolean tool_configFile_readFloat(gchar *line, int position, float *values,
  *
  * Returns: TRUE if no error occured.
  */
-gboolean tool_configFile_readBooleanFromTokens(gchar **tokens, int *position, gboolean *values,
+gboolean tool_config_file_readBooleanFromTokens(gchar **tokens, int *position, gboolean *values,
 					  guint size, int lineId, GError **error)
 {
   int res;
@@ -189,7 +189,7 @@ gboolean tool_configFile_readBooleanFromTokens(gchar **tokens, int *position, gb
 	  res = sscanf(tokens[i], "%d", values + nb);
 	  if (res != 1)
 	    {
-	      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_READ,
+	      *error = g_error_new(TOOL_CONFIG_FILE_ERROR, TOOL_CONFIG_FILE_ERROR_READ,
 				   _("Parse error at line %d, %d boolean"
 				     " values should appear here.\n"), lineId, size);
 	      *position = i;
@@ -202,7 +202,7 @@ gboolean tool_configFile_readBooleanFromTokens(gchar **tokens, int *position, gb
 
   if (nb != size)
     {
-      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_MISSING,
+      *error = g_error_new(TOOL_CONFIG_FILE_ERROR, TOOL_CONFIG_FILE_ERROR_MISSING,
 			   _("Parse error at line %d, %d boolean(s)"
 			     " values should appear here but %d has been found.\n"),
 			   lineId, size, nb);
@@ -211,7 +211,7 @@ gboolean tool_configFile_readBooleanFromTokens(gchar **tokens, int *position, gb
   return TRUE;
 }
 /**
- * tool_configFile_readBoolean:
+ * tool_config_file_readBoolean:
  * @line: string where values are read from ;
  * @position: the number of the line of the config
  *            file which the @line argument is taken from ;
@@ -223,7 +223,7 @@ gboolean tool_configFile_readBooleanFromTokens(gchar **tokens, int *position, gb
  *
  * Returns: TRUE if no error occured.
  */
-gboolean tool_configFile_readBoolean(gchar *line, int position, gboolean *values,
+gboolean tool_config_file_readBoolean(gchar *line, int position, gboolean *values,
 				guint size, GError **error)
 {
   int id;
@@ -231,15 +231,15 @@ gboolean tool_configFile_readBoolean(gchar *line, int position, gboolean *values
   gchar **tokens;
 
   /* Read @size boolean values from @line. */
-  tokens = g_strsplit_set(line, " \n", MAX_LINE_LENGTH);
+  tokens = g_strsplit_set(line, " \n", TOOL_MAX_LINE_LENGTH);
   id = 0;
-  res = tool_configFile_readBooleanFromTokens(tokens, &id, values, size, position, error);
+  res = tool_config_file_readBooleanFromTokens(tokens, &id, values, size, position, error);
   g_strfreev(tokens);
 
   return res;
 }
 /**
- * tool_configFile_readStringFromTokens:
+ * tool_config_file_readStringFromTokens:
  * @tokens: array of tokens resulting from a call to g_strsplit() with " " as separator ;
  * @position: IN, the position of the beginning in @tokens ; OUT, one token
  *            after the last read ;
@@ -254,7 +254,7 @@ gboolean tool_configFile_readBoolean(gchar *line, int position, gboolean *values
  *
  * Returns: TRUE if no error occured.
  */
-gboolean tool_configFile_readStringFromTokens(gchar **tokens, int *position, gchar ***values,
+gboolean tool_config_file_readStringFromTokens(gchar **tokens, int *position, gchar ***values,
 					  guint size, int lineId, GError **error)
 {
   guint i, nb;
@@ -274,7 +274,7 @@ gboolean tool_configFile_readStringFromTokens(gchar **tokens, int *position, gch
 
   if (nb != size)
     {
-      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_MISSING,
+      *error = g_error_new(TOOL_CONFIG_FILE_ERROR, TOOL_CONFIG_FILE_ERROR_MISSING,
 			   _("Parse error at line %d, %d string(s)"
 			     " should appear here but %d has been found.\n"),
 			   lineId, size, nb);
@@ -285,7 +285,7 @@ gboolean tool_configFile_readStringFromTokens(gchar **tokens, int *position, gch
   return TRUE;
 }
 /**
- * tool_configFile_readString:
+ * tool_config_file_readString:
  * @line: string where values are read from ;
  * @position: the number of the line of the config
  *            file which the @line argument is taken from ;
@@ -303,7 +303,7 @@ gboolean tool_configFile_readStringFromTokens(gchar **tokens, int *position, gch
  *          memory area that is NULL terminated and that must be freed
  *          with g_strfreev().
  */
-gboolean tool_configFile_readString(gchar *line, int position, gchar ***values,
+gboolean tool_config_file_readString(gchar *line, int position, gchar ***values,
 			       guint size, gboolean join, GError **error)
 {
   guint i, nb;
@@ -313,7 +313,7 @@ gboolean tool_configFile_readString(gchar *line, int position, gchar ***values,
   g_return_val_if_fail(values, FALSE);
   
   /* Read @size floating point values from @line. */
-  *values = g_strsplit_set(line, " \n", MAX_LINE_LENGTH);
+  *values = g_strsplit_set(line, " \n", TOOL_MAX_LINE_LENGTH);
   nb = 0;
   for (i = 0; (*values)[i]; i++)
     if ((*values)[i][0] != '\0')
@@ -328,7 +328,7 @@ gboolean tool_configFile_readString(gchar *line, int position, gchar ***values,
     {
       if (nb != size)
 	{
-	  *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_MISSING,
+	  *error = g_error_new(TOOL_CONFIG_FILE_ERROR, TOOL_CONFIG_FILE_ERROR_MISSING,
 			       _("Parse error at line %d, %d string(s)"
 				 " should appear here but %d has been found.\n"),
 			       position, size, nb);
@@ -347,7 +347,7 @@ gboolean tool_configFile_readString(gchar *line, int position, gchar ***values,
   return TRUE;
 }
 /**
- * tool_configFile_readFloatWithElement:
+ * tool_config_file_readFloatWithElement:
  * @line: string where values are read from ;
  * @position: the number of the line of the config
  *            file which the @line argument is taken from ;
@@ -356,12 +356,12 @@ gboolean tool_configFile_readString(gchar *line, int position, gchar ***values,
  * @ele: a pointer to a #VisuElement location ;
  * @error: a location to store a possible reading error.
  *
- * Same as tool_configFile_readFloat() but begins by reading an element
+ * Same as tool_config_file_readFloat() but begins by reading an element
  * at the begining of the line.
  *
  * Returns: TRUE if no error occured.
  */
-gboolean tool_configFile_readFloatWithElement(gchar *line, int position, float *values,
+gboolean tool_config_file_readFloatWithElement(gchar *line, int position, float *values,
 					 guint size, VisuElement **ele, GError **error)
 {
   int id;
@@ -369,21 +369,21 @@ gboolean tool_configFile_readFloatWithElement(gchar *line, int position, float *
   gchar **tokens;
 
   /* Read @size boolean values from @line. */
-  tokens = g_strsplit_set(line, " \n", MAX_LINE_LENGTH);
+  tokens = g_strsplit_set(line, " \n", TOOL_MAX_LINE_LENGTH);
   id = 0;
-  res = tool_configFile_readElementFromTokens(tokens, &id, ele, 1, position, error);
+  res = tool_config_file_readElementFromTokens(tokens, &id, ele, 1, position, error);
   if (!res)
     {
       g_strfreev(tokens);
       return FALSE;
     }
-  res = tool_configFile_readFloatFromTokens(tokens, &id, values, size, position, error);
+  res = tool_config_file_readFloatFromTokens(tokens, &id, values, size, position, error);
   g_strfreev(tokens);
 
   return res;
 }
 /**
- * tool_configFile_readBooleanWithElement:
+ * tool_config_file_readBooleanWithElement:
  * @line: string where values are read from ;
  * @position: the number of the line of the config
  *            file which the @line argument is taken from ;
@@ -392,12 +392,12 @@ gboolean tool_configFile_readFloatWithElement(gchar *line, int position, float *
  * @ele: a pointer to a #VisuElement location ;
  * @error: a location to store a possible reading error.
  *
- * Same as tool_configFile_readBoolean() but begins by reading an element
+ * Same as tool_config_file_readBoolean() but begins by reading an element
  * at the begining of the line.
  *
  * Returns: TRUE if no error occured.
  */
-gboolean tool_configFile_readBooleanWithElement(gchar *line, int position, gboolean *values,
+gboolean tool_config_file_readBooleanWithElement(gchar *line, int position, gboolean *values,
 					   guint size, VisuElement **ele, GError **error)
 {
   int id;
@@ -405,21 +405,21 @@ gboolean tool_configFile_readBooleanWithElement(gchar *line, int position, gbool
   gchar **tokens;
 
   /* Read @size boolean values from @line. */
-  tokens = g_strsplit_set(line, " \n", MAX_LINE_LENGTH);
+  tokens = g_strsplit_set(line, " \n", TOOL_MAX_LINE_LENGTH);
   id = 0;
-  res = tool_configFile_readElementFromTokens(tokens, &id, ele, 1, position, error);
+  res = tool_config_file_readElementFromTokens(tokens, &id, ele, 1, position, error);
   if (!res)
     {
       g_strfreev(tokens);
       return FALSE;
     }
-  res = tool_configFile_readBooleanFromTokens(tokens, &id, values, size, position, error);
+  res = tool_config_file_readBooleanFromTokens(tokens, &id, values, size, position, error);
   g_strfreev(tokens);
 
   return res;
 }
 /**
- * tool_configFile_readStringWithElement:
+ * tool_config_file_readStringWithElement:
  * @line: string where values are read from ;
  * @position: the number of the line of the config
  *            file which the @line argument is taken from ;
@@ -428,14 +428,14 @@ gboolean tool_configFile_readBooleanWithElement(gchar *line, int position, gbool
  * @ele: a pointer to a #VisuElement location ;
  * @error: a location to store a possible reading error.
  *
- * Same as tool_configFile_readString() but begins by reading an element
+ * Same as tool_config_file_readString() but begins by reading an element
  * at the begining of the line.
  *
  * Returns: TRUE if no error occured, then @values point on an allocated
  *          memory area that is NULL terminated and that must be freed
  *          with g_strfreev().
  */
-gboolean tool_configFile_readStringWithElement(gchar *line, int position, gchar ***values,
+gboolean tool_config_file_readStringWithElement(gchar *line, int position, gchar ***values,
 					  guint size, VisuElement **ele, GError **error)
 {
   int id;
@@ -443,21 +443,21 @@ gboolean tool_configFile_readStringWithElement(gchar *line, int position, gchar
   gchar **tokens;
 
   /* Read @size boolean values from @line. */
-  tokens = g_strsplit_set(line, " \n", MAX_LINE_LENGTH);
+  tokens = g_strsplit_set(line, " \n", TOOL_MAX_LINE_LENGTH);
   id = 0;
-  res = tool_configFile_readElementFromTokens(tokens, &id, ele, 1, position, error);
+  res = tool_config_file_readElementFromTokens(tokens, &id, ele, 1, position, error);
   if (!res)
     {
       g_strfreev(tokens);
       return FALSE;
     }
-  res = tool_configFile_readStringFromTokens(tokens, &id, values, size, position, error);
+  res = tool_config_file_readStringFromTokens(tokens, &id, values, size, position, error);
   g_strfreev(tokens);
 
   return res;
 }
 /**
- * tool_configFile_readElementFromTokens:
+ * tool_config_file_readElementFromTokens:
  * @tokens: array of tokens resulting from a call to g_strsplit() with " " as separator ;
  * @position: IN, the position of the beginning in @tokens ; OUT, one token
  *            after the last read ;
@@ -472,7 +472,7 @@ gboolean tool_configFile_readStringWithElement(gchar *line, int position, gchar
  *
  * Returns: TRUE if no error occured.
  */
-gboolean tool_configFile_readElementFromTokens(gchar **tokens, int *position, VisuElement **values,
+gboolean tool_config_file_readElementFromTokens(gchar **tokens, int *position, VisuElement **values,
 					  guint size, int lineId, GError **error)
 {
   guint i, nb;
@@ -490,7 +490,7 @@ gboolean tool_configFile_readElementFromTokens(gchar **tokens, int *position, Vi
 	  values[nb] = visu_element_retrieveFromName(tokens[i], (gboolean*)0);
 	  if (!values[nb])
 	    {
-              *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_BAD_ELEMENT_NAME,
+              *error = g_error_new(TOOL_CONFIG_FILE_ERROR, TOOL_CONFIG_FILE_ERROR_BAD_ELEMENT_NAME,
                                    _("Parse error at line %d, '%s' wrong"
                                      " element name.\n"), lineId, tokens[i]);
               *position = i;
@@ -503,7 +503,7 @@ gboolean tool_configFile_readElementFromTokens(gchar **tokens, int *position, Vi
 
   if (nb != size)
     {
-      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_MISSING,
+      *error = g_error_new(TOOL_CONFIG_FILE_ERROR, TOOL_CONFIG_FILE_ERROR_MISSING,
 			   _("Parse error at line %d, %d elements"
 			     " should appear here but %d has been found.\n"),
 			   lineId, size, nb);
@@ -512,7 +512,7 @@ gboolean tool_configFile_readElementFromTokens(gchar **tokens, int *position, Vi
   return TRUE;
 }
 /**
- * tool_configFile_readIntegerFromTokens:
+ * tool_config_file_readIntegerFromTokens:
  * @tokens: array of tokens resulting from a call to g_strsplit() with " " as separator ;
  * @position: IN, the position of the beginning in @tokens ; OUT, one token
  *            after the last read ;
@@ -527,7 +527,7 @@ gboolean tool_configFile_readElementFromTokens(gchar **tokens, int *position, Vi
  *
  * Returns: TRUE if no error occured.
  */
-gboolean tool_configFile_readIntegerFromTokens(gchar **tokens, int *position, int *values,
+gboolean tool_config_file_readIntegerFromTokens(gchar **tokens, int *position, int *values,
 					  guint size, int lineId, GError **error)
 {
   int res;
@@ -546,7 +546,7 @@ gboolean tool_configFile_readIntegerFromTokens(gchar **tokens, int *position, in
 	  res = sscanf(tokens[i], "%d", values + nb);
 	  if (res != 1)
 	    {
-	      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_READ,
+	      *error = g_error_new(TOOL_CONFIG_FILE_ERROR, TOOL_CONFIG_FILE_ERROR_READ,
 				   _("Parse error at line %d, %d integer"
 				     " values should appear here.\n"), lineId, size);
 	      *position = i;
@@ -559,7 +559,7 @@ gboolean tool_configFile_readIntegerFromTokens(gchar **tokens, int *position, in
 
   if (nb != size)
     {
-      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_MISSING,
+      *error = g_error_new(TOOL_CONFIG_FILE_ERROR, TOOL_CONFIG_FILE_ERROR_MISSING,
 			   _("Parse error at line %d, %d integer(s)"
 			     " values should appear here but %d has been found.\n"),
 			   lineId, size, nb);
@@ -568,7 +568,7 @@ gboolean tool_configFile_readIntegerFromTokens(gchar **tokens, int *position, in
   return TRUE;
 }
 /**
- * tool_configFile_readInteger:
+ * tool_config_file_readInteger:
  * @line: string where values are read from ;
  * @position: the number of the line of the config
  *            file which the @line argument is taken from ;
@@ -580,7 +580,7 @@ gboolean tool_configFile_readIntegerFromTokens(gchar **tokens, int *position, in
  *
  * Returns: TRUE if no error occured.
  */
-gboolean tool_configFile_readInteger(gchar *line, int position, int *values,
+gboolean tool_config_file_readInteger(gchar *line, int position, int *values,
 				guint size, GError **error)
 {
   int id;
@@ -588,15 +588,15 @@ gboolean tool_configFile_readInteger(gchar *line, int position, int *values,
   gchar **tokens;
 
   /* Read @size floating point values from @line. */
-  tokens = g_strsplit_set(line, " \n", MAX_LINE_LENGTH);
+  tokens = g_strsplit_set(line, " \n", TOOL_MAX_LINE_LENGTH);
   id = 0;
-  res = tool_configFile_readIntegerFromTokens(tokens, &id, values, size, position, error);
+  res = tool_config_file_readIntegerFromTokens(tokens, &id, values, size, position, error);
   g_strfreev(tokens);
 
   return res;
 }
 /**
- * tool_configFile_clampFloat:
+ * tool_config_file_clampFloat:
  * @variable: a pointer to a storage for the value ;
  * @value: the value to put in the storage ;
  * @min: a lower bound ;
@@ -611,7 +611,7 @@ gboolean tool_configFile_readInteger(gchar *line, int position, int *values,
  *
  * Returns: TRUE if the value is out of bounds.
  */
-gboolean tool_configFile_clampFloat(float *variable, float value, float min, float max)
+gboolean tool_config_file_clampFloat(float *variable, float value, float min, float max)
 {
   g_return_val_if_fail(variable, FALSE);
 
