@@ -72,12 +72,30 @@
  * properties can be iterated on using a #ToolFileFormatIter iterator.</para>
  */
 
+/**
+ * ToolFileFormatIter:
+ * @lst: internal pointer.
+ * @name: name of the current iterated property (read only).
+ * @label: label of the current iterated property (read only).
+ * @val: its value (read only).
+ *
+ * Iterator on #ToolFileFormat object properties. See
+ * tool_file_format_iterNextProperty().
+ *
+ * Since: 3.6
+ */
+
 GQuark tool_file_format_getQuark(void)
 {
   return g_quark_from_static_string("ToolFileFormat");
 }
 
-struct _ToolFileFormat
+/**
+ * ToolFileFormatPrivate:
+ *
+ * Private attributes of #ToolFileFormat objects.
+ **/
+struct _ToolFileFormatPrivate
 {
   /* This is the list of file patterns, for example (*.jpg; *.jpeg; *.jpe). */
   GList *fileType;
@@ -86,122 +104,118 @@ struct _ToolFileFormat
   /* This is a short text to describe this file format.
      It should not be bigger than 30 characters. */
   gchar *name;
-
   /* This is a private field, it is a concatenation
      of "name ({patterns},)". */
   gchar *labelString;
 
+  /* A vlidating routine for this file format. */
+  ToolFileFormatValidate validate;
+
   /* This is a private field. It enables to add some properties
      to a file format. See fileFormatAdd_property*() and tool_file_format_property_get*()
      to control them. */
   GList *properties;
+
+  gboolean dispose_has_run;
 };
 
-static ToolFileFormat* _new(gchar* descr, gchar** patterns, gboolean uncompleteList)
-{
-  int nbCharacterMax = 45;
-  ToolFileFormat *res;
-  int lg, n;
+enum {
+    PROP_0,
+    NAME_PROP,
+    LABEL_PROP,
+    IGNORE_PROP
+};
 
-  lg = strlen(descr);
-  if (lg > nbCharacterMax)
-    {
-      g_warning("The descr parameter given to 'tool_file_format_new' is bigger than"
-		" %d characters and it will be truncated.", nbCharacterMax);
-      lg = nbCharacterMax;
-    }
+static void tool_file_format_dispose (GObject *obj);
+static void tool_file_format_finalize(GObject *obj);
+static void tool_file_format_get_property(GObject* obj, guint property_id,
+                                          GValue *value, GParamSpec *pspec);
+static void tool_file_format_set_property(GObject* obj, guint property_id,
+                                          const GValue *value, GParamSpec *pspec);
 
-  res = g_malloc(sizeof(ToolFileFormat));
-  DBG_fprintf(stderr, "Tool ToolFileFormat: new file format %p.\n", (gpointer)res);
-  res->name           = g_strndup(descr, lg);
-  res->fileType       = (GList*)0;
-  res->labelString    = (gchar*)0;
-  res->properties     = (GList*)0;
-  res->ignoreFileType = uncompleteList;
-  for (n = 0; patterns[n]; n++)
-    res->fileType = g_list_append(res->fileType, g_strdup(patterns[n]));
-  
-  return res;
-}
-static void _buildLabel(ToolFileFormat *format)
+G_DEFINE_TYPE(ToolFileFormat, tool_file_format, G_TYPE_OBJECT)
+
+static void tool_file_format_class_init(ToolFileFormatClass *klass)
 {
-  GList *lst;
-  GString *tmpStr;
-  
-  tmpStr = g_string_new(format->name);
-  g_string_append_printf(tmpStr, " (");
-  for (lst = format->fileType; lst; lst = g_list_next(lst))
-    {
-      g_string_append_printf(tmpStr, "%s", (gchar*) lst->data);
-      if (lst->next)
-	g_string_append_printf(tmpStr, ", ");
-    }
-  if (!format->fileType)
-    g_string_append_printf(tmpStr, "no filter");
-  if (format->fileType && format->ignoreFileType)
-    g_string_append_printf(tmpStr, ", ...");
-  g_string_append_printf(tmpStr, ")");
-  format->labelString = tmpStr->str;
-  g_string_free(tmpStr, FALSE);
+  DBG_fprintf(stderr, "Tool FileFormat: creating the class of the object.\n");
+
+  G_OBJECT_CLASS(klass)->dispose      = tool_file_format_dispose;
+  G_OBJECT_CLASS(klass)->finalize     = tool_file_format_finalize;
+  G_OBJECT_CLASS(klass)->set_property = tool_file_format_set_property;
+  G_OBJECT_CLASS(klass)->get_property = tool_file_format_get_property;
+
+  /**
+   * ToolFileFormat::name:
+   *
+   * The name identifying one file format, can be translate and used in a UI.
+   *
+   * Since: 3.7
+   */
+  g_object_class_install_property
+    (G_OBJECT_CLASS(klass), NAME_PROP,
+     g_param_spec_string("name", _("Name"), _("File format description."), "",
+                         G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE | G_PARAM_READABLE));
+  /**
+   * ToolFileFormat::label:
+   *
+   * The label giving the file pattern, can be translate and used in a UI.
+   *
+   * Since: 3.7
+   */
+  g_object_class_install_property
+    (G_OBJECT_CLASS(klass), LABEL_PROP,
+     g_param_spec_string("label", _("Label"), _("Label used to show the file pattern."), "",
+                         G_PARAM_READABLE));
+  /**
+   * ToolFileFormat::ignore-type:
+   *
+   * Store if the patterns of format descibes all possible patterns
+   * for the file format.
+   *
+   * Since: 3.7
+   */
+  g_object_class_install_property
+    (G_OBJECT_CLASS(klass), IGNORE_PROP,
+     g_param_spec_boolean("ignore-type", _("Ignore file patterns"),
+                          _("Don't restrict file matching to the given patterns."),
+                          FALSE, G_PARAM_WRITABLE | G_PARAM_READABLE));
+
+  g_type_class_add_private(klass, sizeof(ToolFileFormatPrivate));
 }
 
-/**
- * tool_file_format_newRestricted:
- * @descr: a short string to label a new file format.
- * @patterns: a set of patterns to identify files of this format.
- *
- * Allocate a new #ToolFileFormat. The @patterns argument is copied in
- * the #ToolFileFormat object and can be freed safely after the call to this method.
- * The @patterns list is not all the patterns supported by the format.
- *
- * Returns: (transfer none): a newly allocated ToolFileFormat,
- * or NULL if something goes wrong.
- */
-ToolFileFormat* tool_file_format_newRestricted(gchar* descr, gchar** patterns)
+static void tool_file_format_init(ToolFileFormat *fmt)
 {
-  ToolFileFormat *format;
+  DBG_fprintf(stderr, "Tool FileFormat: initializing new object (%p).\n",
+	      (gpointer)fmt);
 
-  g_return_val_if_fail(descr && descr[0] && patterns, (ToolFileFormat*)0);
-
-  format = _new(descr, patterns, TRUE);
-  _buildLabel(format);
-  return format;
+  fmt->priv = G_TYPE_INSTANCE_GET_PRIVATE(fmt, TOOL_TYPE_FILE_FORMAT, ToolFileFormatPrivate);
+  fmt->priv->name           = (gchar*)0;
+  fmt->priv->fileType       = (GList*)0;
+  fmt->priv->labelString    = (gchar*)0;
+  fmt->priv->validate       = (ToolFileFormatValidate)0;
+  fmt->priv->properties     = (GList*)0;
+  fmt->priv->ignoreFileType = FALSE;
 }
 
-/**
- * tool_file_format_new:
- * @descr: a short string to label a new file format.
- * @patterns: (array zero-terminated=1) (element-type utf8): a set of patterns to identify files of this format.
- *
- * Allocate a new #ToolFileFormat. The @patterns argument is copied in
- * the #ToolFileFormat object and can be freed safely after the call to this method.
- *
- * Returns: (transfer none): a newly allocated ToolFileFormat,
- * or NULL if something goes wrong.
- */
-ToolFileFormat* tool_file_format_new(gchar* descr, gchar** patterns)
+static void tool_file_format_dispose(GObject *obj)
 {
-  ToolFileFormat *format;
+  DBG_fprintf(stderr, "Tool FileFormat: dispose object %p.\n", (gpointer)obj);
 
-  g_return_val_if_fail(descr && descr[0] && patterns, (ToolFileFormat*)0);
+  if (TOOL_FILE_FORMAT(obj)->priv->dispose_has_run)
+    return;
 
-  format = _new(descr, patterns, FALSE);
-  _buildLabel(format);
-  return format;
+  TOOL_FILE_FORMAT(obj)->priv->dispose_has_run = TRUE;
+  /* Chain up to the parent class */
+  G_OBJECT_CLASS(tool_file_format_parent_class)->dispose(obj);
 }
-/**
- * tool_file_format_free:
- * @format: a #ToolFileFormat to free.
- *
- * Free all the memory used by @format. If @format is NULL, the method
- * writes a warning on the eror output.
- */
-void tool_file_format_free(ToolFileFormat *format)
+static void tool_file_format_finalize(GObject *obj)
 {
+  ToolFileFormatPrivate *format;
   GList *tmpLst;
 
-  if (!format)
-    return;
+  DBG_fprintf(stderr, "Tool FileFormat: finalize object %p.\n", (gpointer)obj);
+
+  format = TOOL_FILE_FORMAT(obj)->priv;
 
   if (format->name)
     g_free(format->name);
@@ -217,7 +231,156 @@ void tool_file_format_free(ToolFileFormat *format)
     tool_option_free(tmpLst->data);
   g_list_free(format->properties);
 
-  g_free(format);
+  /* Chain up to the parent class */
+  G_OBJECT_CLASS(tool_file_format_parent_class)->finalize(obj);
+
+  DBG_fprintf(stderr, "Tool FileFormat: freeing ... OK.\n");
+}
+static void tool_file_format_get_property(GObject* obj, guint property_id,
+                                          GValue *value, GParamSpec *pspec)
+{
+  ToolFileFormatPrivate *self = TOOL_FILE_FORMAT(obj)->priv;
+
+  DBG_fprintf(stderr, "Tool FileFormat: get property '%s' -> ",
+	      g_param_spec_get_name(pspec));
+  switch (property_id)
+    {
+    case NAME_PROP:
+      g_value_set_string(value, self->name); DBG_fprintf(stderr, "%s.\n", self->name); break;
+    case LABEL_PROP:
+      g_value_set_string(value, self->labelString);
+      DBG_fprintf(stderr, "%s.\n", self->labelString); break;
+    case IGNORE_PROP:
+      g_value_set_boolean(value, self->ignoreFileType);
+      DBG_fprintf(stderr, "%d.\n", self->ignoreFileType); break;
+    default:
+      /* We don't have any other property... */
+      G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
+      break;
+    }
+}
+static void tool_file_format_set_property(GObject* obj, guint property_id,
+                                          const GValue *value, GParamSpec *pspec)
+{
+  ToolFileFormatPrivate *self = TOOL_FILE_FORMAT(obj)->priv;
+  gint nbCharacterMax = 45, lg;
+
+  DBG_fprintf(stderr, "Tool FileFormat: set property '%s' -> ",
+	      g_param_spec_get_name(pspec));
+  switch (property_id)
+    {
+    case NAME_PROP:
+      lg = strlen(g_value_get_string(value));
+      if (lg > nbCharacterMax)
+        {
+          g_warning("The label property is bigger than"
+                    " %d characters and it will be truncated.", nbCharacterMax);
+          lg = nbCharacterMax;
+        }
+      self->name = g_strndup(g_value_get_string(value), lg);
+      DBG_fprintf(stderr, "%s.\n", self->name); break;
+    case IGNORE_PROP:
+      self->ignoreFileType = g_value_get_boolean(value);
+      DBG_fprintf(stderr, "%d.\n", self->ignoreFileType); break;
+    default:
+      /* We don't have any other property... */
+      G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
+      break;
+    }
+}
+
+static void _buildLabel(ToolFileFormat *format)
+{
+  GList *lst;
+  GString *tmpStr;
+  
+  tmpStr = g_string_new(format->priv->name);
+  g_string_append_printf(tmpStr, " (");
+  for (lst = format->priv->fileType; lst; lst = g_list_next(lst))
+    {
+      g_string_append_printf(tmpStr, "%s", (gchar*) lst->data);
+      if (lst->next)
+	g_string_append_printf(tmpStr, ", ");
+    }
+  if (!format->priv->fileType)
+    g_string_append_printf(tmpStr, "no filter");
+  if (format->priv->fileType && format->priv->ignoreFileType)
+    g_string_append_printf(tmpStr, ", ...");
+  g_string_append_printf(tmpStr, ")");
+  if (format->priv->labelString)
+    g_free(format->priv->labelString);
+  format->priv->labelString = tmpStr->str;
+  g_string_free(tmpStr, FALSE);
+}
+
+/**
+ * tool_file_format_newRestricted:
+ * @descr: a short string to label a new file format.
+ * @patterns: a set of patterns to identify files of this format.
+ *
+ * Allocate a new #ToolFileFormat. The @patterns argument is copied in
+ * the #ToolFileFormat object and can be freed safely after the call to this method.
+ * The @patterns list is not all the patterns supported by the format.
+ *
+ * Returns: (transfer none): a newly allocated ToolFileFormat,
+ * or NULL if something goes wrong.
+ */
+ToolFileFormat* tool_file_format_newRestricted(const gchar* descr, const gchar** patterns)
+{
+  ToolFileFormat *format;
+
+  g_return_val_if_fail(descr && descr[0] && patterns, (ToolFileFormat*)0);
+
+  format = TOOL_FILE_FORMAT(g_object_new(TOOL_TYPE_FILE_FORMAT,
+                                         "name", descr, "ignore-type", TRUE, NULL));
+  tool_file_format_addPatterns(format, patterns);
+
+  return format;
+}
+
+/**
+ * tool_file_format_new:
+ * @descr: a short string to label a new file format.
+ * @patterns: (array zero-terminated=1) (element-type utf8): a set of patterns to identify files of this format.
+ *
+ * Allocate a new #ToolFileFormat. The @patterns argument is copied in
+ * the #ToolFileFormat object and can be freed safely after the call to this method.
+ *
+ * Returns: (transfer none): a newly allocated ToolFileFormat,
+ * or NULL if something goes wrong.
+ */
+ToolFileFormat* tool_file_format_new(const gchar* descr, const gchar** patterns)
+{
+  ToolFileFormat *format;
+
+  g_return_val_if_fail(descr && descr[0] && patterns, (ToolFileFormat*)0);
+
+  format = TOOL_FILE_FORMAT(g_object_new(TOOL_TYPE_FILE_FORMAT,
+                                         "name", descr, "ignore-type", FALSE, NULL));
+  tool_file_format_addPatterns(format, patterns);
+
+  return format;
+}
+/**
+ * tool_file_format_addPatterns:
+ * @fmt: a #ToolFileFormat object.
+ * @patterns: (array zero-terminated=1): a list of matching patterns.
+ *
+ * A file format may have pattern for the naming scheme of files, like
+ * "*.jpg" and "*.jpeg" for JPEG files. It's not mandatory for a file
+ * format to match its own pattern anyway.
+ *
+ * Since: 3.7
+ **/
+void tool_file_format_addPatterns(ToolFileFormat *fmt, const gchar **patterns)
+{
+  gint n;
+
+  g_return_if_fail(IS_TOOL_FILE_FORMAT(fmt));
+
+  for (n = 0; patterns[n]; n++)
+    fmt->priv->fileType = g_list_append(fmt->priv->fileType, g_strdup(patterns[n]));
+  _buildLabel(fmt);
 }
 /**
  * tool_file_format_copy:
@@ -227,8 +390,8 @@ void tool_file_format_free(ToolFileFormat *format)
  *
  * Since: 3.6
  *
- * Returns: (transfer none): a newly created #ToolFileFormat. Should
- * be freed with tool_file_format_free().
+ * Returns: (transfer full): a newly created #ToolFileFormat. Should
+ * be freed with g_object_unref().
  */
 ToolFileFormat* tool_file_format_copy(const ToolFileFormat *from)
 {
@@ -237,19 +400,18 @@ ToolFileFormat* tool_file_format_copy(const ToolFileFormat *from)
 
   g_return_val_if_fail(from, (ToolFileFormat*)0);
 
-  to = g_malloc(sizeof(ToolFileFormat));
+  to = TOOL_FILE_FORMAT(g_object_new(TOOL_TYPE_FILE_FORMAT,
+                                     "name", from->priv->name,
+                                     "ignore-type", from->priv->ignoreFileType, NULL));
   DBG_fprintf(stderr, "Tool ToolFileFormat: copy to file format %p.\n", (gpointer)to);
-  to->name           = g_strdup(from->name);
-  to->ignoreFileType = from->ignoreFileType;
-  to->fileType       = (GList*)0;
-  for (lst = from->fileType; lst; lst = g_list_next(lst))
-    to->fileType = g_list_append(to->fileType, g_strdup((gchar*)lst->data));
-  to->labelString    = (gchar*)0;
+  to->priv->fileType       = (GList*)0;
+  for (lst = from->priv->fileType; lst; lst = g_list_next(lst))
+    to->priv->fileType = g_list_append(to->priv->fileType, g_strdup((gchar*)lst->data));
   _buildLabel(to);
-  to->properties     = (GList*)0;
-  for (lst = from->properties; lst; lst = g_list_next(lst))
-    to->properties = g_list_append(to->properties,
-                                   tool_option_copy((ToolOption*)lst->data));
+  to->priv->properties     = (GList*)0;
+  for (lst = from->priv->properties; lst; lst = g_list_next(lst))
+    to->priv->properties = g_list_append(to->priv->properties,
+                                         tool_option_copy((ToolOption*)lst->data));
   
   return to;
 }
@@ -267,7 +429,7 @@ const gchar* tool_file_format_getName(ToolFileFormat *format)
   DBG_fprintf(stderr, "Tool ToolFileFormat: get the name of format '%p'.\n",
 	      (gpointer)format);
   g_return_val_if_fail(format, (gchar*)0);
-  return format->name;
+  return format->priv->name;
 }
 /**
  * tool_file_format_getLabel:
@@ -284,7 +446,7 @@ const gchar* tool_file_format_getLabel(ToolFileFormat *format)
   DBG_fprintf(stderr, "Tool ToolFileFormat: get the label of format '%p'.\n",
 	      (gpointer)format);
   g_return_val_if_fail(format, (gchar*)0);
-  return format->labelString;
+  return format->priv->labelString;
 }
 /**
  * tool_file_format_getFilePatterns:
@@ -302,7 +464,7 @@ const GList* tool_file_format_getFilePatterns(ToolFileFormat *format)
   DBG_fprintf(stderr, "Tool ToolFileFormat: get the file patterns of format '%p'.\n",
 	      (gpointer)format);
   g_return_val_if_fail(format, (GList*)0);
-  return format->fileType;
+  return format->priv->fileType;
 }
 
 /**
@@ -310,9 +472,9 @@ const GList* tool_file_format_getFilePatterns(ToolFileFormat *format)
  * @format: a #ToolFileFormat.
  *
  * This method is used to know if the file pattern list can be used
- * to match a given filename with @tool_file_format_match().
+ * to match a given filename with tool_file_format_match().
  *
- * Returns: TRUE if a call to @tool_file_format_match() is safe.
+ * Returns: TRUE if a call to tool_file_format_match() is safe.
  *
  * Since: 3.6
  */
@@ -320,7 +482,7 @@ gboolean tool_file_format_canMatch(ToolFileFormat* format)
 {
   g_return_val_if_fail(format, FALSE);
 
-  return !format->ignoreFileType;
+  return !format->priv->ignoreFileType;
 }
 /**
  * tool_file_format_match:
@@ -339,13 +501,75 @@ const gchar* tool_file_format_match(ToolFileFormat *format, const gchar *filenam
   g_return_val_if_fail(format, FALSE);
 
   DBG_fprintf(stderr, "Tool FileFormat: try to match '%s' with '%s' -> ",
-              filename, format->name);
-  tmpLst = format->fileType;
+              filename, format->priv->name);
+  tmpLst = format->priv->fileType;
   while(tmpLst && !g_pattern_match_simple(tmpLst->data, filename))
     tmpLst = g_list_next(tmpLst);
   DBG_fprintf(stderr, "%d.\n", (tmpLst != (GList*)0));
   return (tmpLst)?(const gchar*)tmpLst->data:(const gchar*)0;
 }
+/**
+ * tool_file_format_validate:
+ * @format: a #ToolFileFormat ;
+ * @filename: a string to match.
+ *
+ * This method runs a minimal parsing routine set with
+ * tool_file_format_setValidator() to check if the provided filename
+ * correspond to this file format.
+ *
+ * Since: 3.7
+ *
+ * Returns: TRUE, if the file (after minimal parsing) is of this file
+ * format. If there is no validator routine, it returns FALSE anyway.
+ */
+gboolean tool_file_format_validate(ToolFileFormat *format, const gchar *filename)
+{
+  gboolean res;
+
+  g_return_val_if_fail(format, FALSE);
+
+  DBG_fprintf(stderr, "Tool FileFormat: try to validate '%s' with '%s' -> ",
+              filename, format->priv->name);
+  if (format->priv->validate)
+    res = format->priv->validate(filename);
+  else
+    res = FALSE;
+  DBG_fprintf(stderr, "%d.\n", res);
+  return res;
+}
+/**
+ * tool_file_format_setValidator:
+ * @format: a #ToolFileFormat ;
+ * @validate: (scope call): a pointer to a validator routine.
+ *
+ * Set up a validating routine that do a minimal parsing to check that
+ * a provided file corresponds to this file format.
+ *
+ * Since: 3.7
+ */
+void tool_file_format_setValidator(ToolFileFormat *format,
+                                   ToolFileFormatValidate validate)
+{
+  g_return_if_fail(format);
+  format->priv->validate = validate;
+}
+
+/**
+ * tool_file_format_addOption:
+ * @format: a #ToolFileFormat object.
+ * @opt: a #ToolOption object.
+ *
+ * File format may have options, like pseudo-potential pparameters in
+ * case of BigDFT calculations.
+ *
+ * Since: 3.7
+ **/
+void tool_file_format_addOption(ToolFileFormat *format, ToolOption *opt)
+{
+  g_return_if_fail(IS_TOOL_FILE_FORMAT(format));
+
+  format->priv->properties = g_list_append(format->priv->properties, (gpointer)opt);
+}
 
 /**
  * tool_file_format_addPropertyBoolean:
@@ -365,11 +589,14 @@ ToolOption* tool_file_format_addPropertyBoolean(ToolFileFormat *format,
   ToolOption *opt;
   GValue *val;
 
-  opt = tool_option_new(name, label, G_TYPE_BOOLEAN);
+  opt = tool_file_format_getPropertyByName(format, name);
+  if (!opt)
+    {
+      opt = tool_option_new(name, label, G_TYPE_BOOLEAN);
+      format->priv->properties = g_list_append(format->priv->properties, (gpointer)opt);
+    }
   val = tool_option_getValue(opt);
   g_value_set_boolean(val, defaultVal);
-  format->properties = g_list_append(format->properties, (gpointer)opt);
-
   return opt;
 }
 /**
@@ -390,28 +617,45 @@ ToolOption* tool_file_format_addPropertyInt(ToolFileFormat *format,
   ToolOption *opt;
   GValue *val;
 
-  opt = tool_option_new(name, label, G_TYPE_INT);
+  opt = tool_file_format_getPropertyByName(format, name);
+  if (!opt)
+    {
+      opt = tool_option_new(name, label, G_TYPE_INT);
+      format->priv->properties = g_list_append(format->priv->properties, (gpointer)opt);
+    }
   val = tool_option_getValue(opt);
   g_value_set_int(val, defaultVal);
-  format->properties = g_list_append(format->properties, (gpointer)opt);
-
   return opt;
 }
-
 /**
- * tool_file_format_getPropertyList:
- * @format: a #ToolFileFormat.
+ * tool_file_format_addPropertyDouble:
+ * @format: the #ToolFileFormat object.
+ * @name: a name ;
+ * @label: a description ;
+ * @defaultVal: a default value.
  *
- * Use this method to get a list of stored properties for the given #ToolFileFormat.
- * The GList is composed of #ToolOption objects.
- * 
- * Returns: (transfer none) (element-type ToolOption*): a
- * GList* that is read-only.
+ * Add a new integer property to the file format @format.
+ *
+ * Since: 3.7
+ *
+ * Returns: (transfer none): a newly created #ToolOption, free with tool_option_free().
  */
-const GList* tool_file_format_getPropertyList(ToolFileFormat *format)
+ToolOption* tool_file_format_addPropertyDouble(ToolFileFormat *format,
+                                               const gchar *name, const gchar *label,
+                                               gdouble defaultVal)
 {
-  g_return_val_if_fail(format, (GList*)0);
-  return format->properties;
+  ToolOption *opt;
+  GValue *val;
+
+  opt = tool_file_format_getPropertyByName(format, name);
+  if (!opt)
+    {
+      opt = tool_option_new(name, label, G_TYPE_DOUBLE);
+      format->priv->properties = g_list_append(format->priv->properties, (gpointer)opt);
+    }
+  val = tool_option_getValue(opt);
+  g_value_set_double(val, defaultVal);
+  return opt;
 }
 
 /**
@@ -431,7 +675,7 @@ gboolean tool_file_format_iterNextProperty(ToolFileFormat *format,
                                            ToolFileFormatIter *iter)
 {
   if (!iter->lst)
-    iter->lst = format->properties;
+    iter->lst = format->priv->properties;
   else
     iter->lst = g_list_next(iter->lst);
 
@@ -466,7 +710,7 @@ ToolOption* tool_file_format_getPropertyByName(ToolFileFormat *format,
 
   DBG_fprintf(stderr, "Tool FileFormat: grep property '%s' from file format %p.\n",
               name, (gpointer)format);
-  for (lst = format->properties; lst; lst = g_list_next(lst))
+  for (lst = format->priv->properties; lst; lst = g_list_next(lst))
     if (!strcmp(name, tool_option_getName((ToolOption*)lst->data)))
       return (ToolOption*)lst->data;
   return (ToolOption*)0;
