@@ -90,6 +90,22 @@ G_BEGIN_DECLS
  */
 #define TOOL_XYZ_MASK_ALL (7)
 
+/**
+ * ToolXyzDir:
+ * @TOOL_XYZ_X: the x axis;
+ * @TOOL_XYZ_Y: the y axis;
+ * @TOOL_XYZ_Z: the z axis.
+ *
+ * The three space axis.
+ *
+ * Since: 3.8
+ */
+typedef enum {
+  TOOL_XYZ_X,
+  TOOL_XYZ_Y,
+  TOOL_XYZ_Z
+} ToolXyzDir;
+
 void tool_matrix_setIdentity(float mat[3][3]);
 void tool_matrix_dtof(float mf[3][3], double md[3][3]);
 void tool_matrix_productMatrix(float matRes[3][3], float matA[3][3], float matB[3][3]);
