@@ -59,7 +59,7 @@ typedef struct _ToolOption ToolOption;
 struct _ToolOption;
 
 ToolOption* tool_option_new(const gchar *name, const gchar *label, GType g_type);
-void tool_option_free(gpointer data);
+void tool_option_free(ToolOption *option);
 ToolOption* tool_option_copy(const ToolOption *from);
 
 const gchar* tool_option_getName(ToolOption *option);
