@@ -132,34 +132,34 @@ typedef struct _Nodes {
 typedef struct _Cube{
   Node *root;
   ColorPacket color, *colormap;
-  unsigned int depth;
+  guint depth;
   unsigned long colors, pruning_threshold, next_pruning_threshold,
          distance, squares[MaxRGB+MaxRGB+1];
-  unsigned int shift[MaxTreeDepth+1], nodes, free_nodes, color_number;
+  guint shift[MaxTreeDepth+1], nodes, free_nodes, color_number;
   Node *next_node;
   Nodes *node_queue;
 } Cube;
 
 static Cube cube;
 
-static unsigned int tree_depth = 8;
+static guint tree_depth = 8;
 
-static unsigned int Assignment();
-static unsigned int Classification(GError **error);
+static guint Assignment();
+static guint Classification(GError **error);
 static void ClosestColor(register Node *node);
 static void Map(register Node *node);
-static unsigned int DitherImage();
-static unsigned int InitializeCube(unsigned int number_pixels, GError **error);
+static guint DitherImage();
+static guint InitializeCube(guint number_pixels, GError **error);
 static Node *InitializeNode(
-  unsigned int id,unsigned int level,Node *parent,
-  unsigned int mid_red,unsigned int mid_green,unsigned int mid_blue);
+  guint id,guint level,Node *parent,
+  guint mid_red,guint mid_green,guint mid_blue);
 static void PruneChild(register Node *node);
 static void PruneLevel(register Node *node);
 static void Reduce(register Node *node);
-static void Reduction(unsigned int number_colors);
+static void Reduction(guint number_colors);
   
-static unsigned int LZWEncodeImage(unsigned int data_size);
-static void LSBFirstWriteShort(unsigned int value);
+static guint LZWEncodeImage(guint data_size);
+static void LSBFirstWriteShort(guint value);
 
 static gboolean writeViewInGifFormat(ToolFileFormat *format, const char* filename,
 				     int width, int height, VisuData *dataObj,
@@ -177,26 +177,26 @@ void dumpToGif_setImage(Image *data)
 
 /******************************************************************************/
 
-unsigned int Assignment() {
+guint Assignment() {
 
 
   img->colormap=g_malloc(cube.colors*sizeof(ColorPacket));
   cube.colormap=img->colormap;
   cube.colors=0;
   Map(cube.root);
-  img->colors=(unsigned int) cube.colors;
+  img->colors=(guint) cube.colors;
   if (DitherImage()) return 1;
   return 0;
 }
 
 /******************************************************************************/
 
-unsigned int Classification(GError **error) {
+guint Classification(GError **error) {
 
-  register unsigned int i;
+  register guint i;
   register Node *node;
   register  ColorPacket *p;
-  register unsigned int bisect, id, level;
+  register guint bisect, id, level;
 
   p=img->pixels;
   for (i=0; i < img->packets; i++) {
@@ -214,7 +214,7 @@ unsigned int Classification(GError **error) {
       if (node->child[id] == (Node *) NULL) {
           /* Set colors of new node to contain pixel. */
           node->children|=1 << id;
-          bisect=(unsigned int) (1 << (MaxTreeDepth-level)) >> 1;
+          bisect=(guint) (1 << (MaxTreeDepth-level)) >> 1;
           node->child[id]=InitializeNode(id,level,node,
             node->mid_red+(id & 1 ? bisect : -bisect),
             node->mid_green+(id & 2 ? bisect : -bisect),
@@ -252,7 +252,7 @@ unsigned int Classification(GError **error) {
 
 void ClosestColor(register Node *node) {
 
-  register unsigned int id;
+  register guint id;
 
   /* Traverse any children. */
   if (node->children != 0)
@@ -261,7 +261,7 @@ void ClosestColor(register Node *node) {
         ClosestColor(node->child[id]);
   if (node->number_unique != 0) {
       register ColorPacket *color;
-      register unsigned int blue_distance, green_distance, red_distance;
+      register guint blue_distance, green_distance, red_distance;
       register unsigned long distance;
 
       /* Determine if this color is "closest". */
@@ -282,7 +282,7 @@ void ClosestColor(register Node *node) {
 /******************************************************************************/
 
 void Map(register Node *node) {
-  register unsigned int id;
+  register guint id;
 
   /* Traverse any children*/
   if (node->children != 0)
@@ -303,7 +303,7 @@ void Map(register Node *node) {
  
 /******************************************************************************/
 
-unsigned int DitherImage() {
+guint DitherImage() {
 
 #define MaxError  16
 
@@ -317,9 +317,9 @@ unsigned int DitherImage() {
   register ColorPacket *q;
   register ErrorPacket *cs, *ns;
   register unsigned char *range_limit;
-  register unsigned int id;
+  register guint id;
   unsigned char blue, green, *range_table, red;
-  unsigned int i, x, y;
+  guint i, x, y;
   unsigned short index;
 
   
@@ -424,11 +424,11 @@ unsigned int DitherImage() {
 
 /******************************************************************************/
 
-unsigned int InitializeCube(unsigned int number_pixels, GError **error) {
+guint InitializeCube(guint number_pixels, GError **error) {
   
   char c;
   register int i;
-  unsigned int bits, level, max_shift;
+  guint bits, level, max_shift;
 
   cube.node_queue=(Nodes *) NULL;
   cube.nodes=0;
@@ -437,7 +437,7 @@ unsigned int InitializeCube(unsigned int number_pixels, GError **error) {
   /* Initialize the shift values. */
   c=1;
   for (bits=0; c != (char) 0; bits++) c<<=1;
-  for (max_shift=sizeof(unsigned int)*bits; number_pixels != 0; max_shift--)
+  for (max_shift=sizeof(guint)*bits; number_pixels != 0; max_shift--)
        number_pixels>>=1;
   for (level=0; level <= cube.depth; level++) {
     cube.shift[level]=max_shift;
@@ -465,8 +465,8 @@ unsigned int InitializeCube(unsigned int number_pixels, GError **error) {
 /******************************************************************************/
 
 Node *InitializeNode(
-  unsigned int id,unsigned int level,Node *parent,
-  unsigned int mid_red,unsigned int mid_green,unsigned int mid_blue) {
+  guint id,guint level,Node *parent,
+  guint mid_red,guint mid_green,guint mid_blue) {
   
   register int i;
 
@@ -536,7 +536,7 @@ void PruneLevel(register Node *node) {
 /******************************************************************************/
 
 void Reduce(register Node *node) {
-  register unsigned int id;
+  register guint id;
 
   /* Traverse any children. */
   if (node->children != 0)
@@ -556,7 +556,7 @@ void Reduce(register Node *node) {
 
 /******************************************************************************/
 
-void Reduction(unsigned int number_colors)
+void Reduction(guint number_colors)
 {
   float i;
 
@@ -580,7 +580,7 @@ void Reduction(unsigned int number_colors)
 
 /******************************************************************************/
 
-unsigned int dumpToGif_quantizeImage(unsigned int number_colors, GError **error,
+guint dumpToGif_quantizeImage(guint number_colors, GError **error,
 				     ToolVoidDataFunc functionWait, gpointer data)
 {
   Nodes *nodes;
@@ -611,7 +611,7 @@ unsigned int dumpToGif_quantizeImage(unsigned int number_colors, GError **error,
 /******************************************************************************/
 
 /* Function LZWEncodeImage compresses an image via LZW-coding. */
-unsigned int LZWEncodeImage(unsigned int data_size) {
+guint LZWEncodeImage(guint data_size) {
 #define MaxCode(number_bits)  ((1 << (number_bits))-1)
 #define MaxHashTable  5003
 #define MaxLZWBits  12
@@ -746,7 +746,7 @@ unsigned int LZWEncodeImage(unsigned int data_size) {
 /* LSBFirstWriteShort writes a long value as a 16 bit quantity in
    least-significant byte first order.
 */
-void LSBFirstWriteShort(unsigned int value) {
+void LSBFirstWriteShort(guint value) {
 
   unsigned char buffer[2];
 
@@ -760,7 +760,7 @@ void LSBFirstWriteShort(unsigned int value) {
 
 void dumpToGif_syncImage(void) {
 
-  register unsigned int i;
+  register guint i;
   register ColorPacket *p;
   register unsigned short index;
 
@@ -808,22 +808,11 @@ static void write_comment_comm(unsigned char comm[]) {
 VisuDump* dumpToGif_init()
 {
   VisuDump *gif;
-  char *typeGIF[] = {"*.gif", (char*)0};
+  const gchar *typeGIF[] = {"*.gif", (char*)0};
   #define descrGIF _("Gif (256 colors) file")
-  ToolFileFormat* fmt;
 
-  gif = g_malloc(sizeof(VisuDump));
-  fmt = tool_file_format_new(descrGIF, typeGIF);
-  if (!fmt)
-    {
-      g_error("Can't initialize the GIF dump module, aborting.\n");
-    }
-
-  gif->bitmap = TRUE;
-  gif->hasAlpha = FALSE;
-  gif->glRequired = TRUE;
-  gif->fileType = fmt;
-  gif->writeFunc = writeViewInGifFormat;
+  gif = visu_dump_new(descrGIF, typeGIF, writeViewInGifFormat, TRUE);
+  visu_dump_setHasAlpha(gif, FALSE);
 
   waitData = (gpointer)0;
   waitFunc = (ToolVoidDataFunc)0;
@@ -837,11 +826,11 @@ static gboolean writeViewInGifFormat(ToolFileFormat *format _U_, const char* fil
 				     guchar* imageData, GError **error,
 				     ToolVoidDataFunc functionWait, gpointer data)
 {
-  register unsigned int i;
+  register guint i;
   register ColorPacket *q;
   register unsigned char *p;
   unsigned char bits_per_pixel, c;
-  unsigned int status;
+  guint status;
 
   g_return_val_if_fail(error && !*error, FALSE);
   g_return_val_if_fail(imageData, FALSE);
@@ -907,7 +896,7 @@ static gboolean writeViewInGifFormat(ToolFileFormat *format _U_, const char* fil
     (void) fputc((int)(char) img->colormap[i].green,file);
     (void) fputc((int)(char) img->colormap[i].blue,file);
   }
-  for ( ; i < (unsigned int)(1 << bits_per_pixel) ; i++) {
+  for ( ; i < (guint)(1 << bits_per_pixel) ; i++) {
     (void) fputc(0x0,file);
     (void) fputc(0x0,file);
     (void) fputc(0x0,file);
