@@ -100,54 +100,38 @@ static gboolean writeViewInPdfFormat(ToolFileFormat *format, const char* filenam
 				     guchar* imageData, GError **error,
 				     ToolVoidDataFunc functionWait, gpointer data);
 
-VisuDump* dumpToPS_init()
+static VisuDump *ps;
+const VisuDump* visu_dump_bitmap_ps_getStatic()
 {
-  VisuDump *ps;
-  char *typePS[] = {"*.ps", (char*)0};
+  const gchar *typePS[] = {"*.ps", (char*)0};
   #define descrPS _("Bitmap in a postscript (v3.0) file")
-  ToolFileFormat* fmt;
 
-  ps = g_malloc(sizeof(VisuDump));
-  fmt = tool_file_format_new(descrPS, typePS);
-  if (!fmt)
-    {
-      g_error("Can't initialize the PS dump module, aborting.\n");
-    }
+  if (ps)
+    return ps;
 
-  ps->bitmap = TRUE;
-  ps->hasAlpha = FALSE;
-  ps->glRequired = TRUE;
-  ps->fileType = fmt;
-  ps->writeFunc = writeViewInPsFormat;
+  ps = visu_dump_new(descrPS, typePS, writeViewInPsFormat, TRUE);
+  visu_dump_setHasAlpha(ps, FALSE);
 
   waitFunc = (ToolVoidDataFunc)0;
   waitData = (gpointer)0;
 
-  tool_file_format_addPropertyBoolean(fmt, "reduced_colormap",
+  tool_file_format_addPropertyBoolean(TOOL_FILE_FORMAT(ps), "reduced_colormap",
                                       _("Use a reduced colormap (256 colors)"), FALSE);
   
   return ps;
 }
-VisuDump* dumpToPDF_init()
+static VisuDump *pdf;
+const VisuDump* visu_dump_bitmap_pdf_getStatic()
 {
-  VisuDump *pdf;
-  char *typePDF[] = {"*.pdf", (char*)0};
+  const gchar *typePDF[] = {"*.pdf", (char*)0};
 #define descrPDF _("Bitmap in a PDF (v. 1.2)")
-  ToolFileFormat* fmt;
 
-  pdf = g_malloc(sizeof(VisuDump));
-  fmt = tool_file_format_new(descrPDF, typePDF);
-  if (!fmt)
-    {
-      g_error("Can't initialize the PS dump module, aborting.\n");
-    }
+  if (pdf)
+    return pdf;
+
+  pdf = visu_dump_new(descrPDF, typePDF, writeViewInPdfFormat, TRUE);
+  visu_dump_setHasAlpha(pdf, FALSE);
 
-  pdf->bitmap = TRUE;
-  pdf->hasAlpha = FALSE;
-  pdf->glRequired = TRUE;
-  pdf->fileType = fmt;
-  pdf->writeFunc = writeViewInPdfFormat;
-  
   waitFunc = (ToolVoidDataFunc)0;
   waitData = (gpointer)0;
 
@@ -278,7 +262,7 @@ static void OutputDataPS256() {
 #define LZWEod 257
    int prefix[4096], suffix[4096], next[4096];
    int idx, next_idx, last_code;
-   unsigned int i;
+   guint i;
          
    accumulator = 0ul;
    cnt = 0;
@@ -606,7 +590,7 @@ static gboolean writeViewInPs256Format(const char* filename,
   time_t timer;
   float facx, facy, fac;
   int wu, hu;
-  register unsigned int i;
+  register guint i;
   register ColorPacket *q;
   register unsigned char *p;
          
