@@ -49,6 +49,7 @@
 #include <math.h>
 
 #include <visu_tools.h>
+#include <extraFunctions/extraNode.h>
 
 /**
  * SECTION:dumpToXyz
@@ -66,28 +67,21 @@ static gboolean writeDataInXyz(ToolFileFormat *format, const char* filename,
 static gpointer waitData;
 static ToolVoidDataFunc waitFunc;
 
-VisuDump* dumpToXyz_init()
+static VisuDump *xyz;
+
+const VisuDump* visu_dump_xyz_getStatic()
 {
-  VisuDump *xyz;
-  char *typeXYZ[] = {"*.xyz", (char*)0};
+  const gchar *typeXYZ[] = {"*.xyz", (char*)0};
 #define descrXYZ _("Xyz file (current positions)")
-  ToolFileFormat* fmt;
 
-  xyz = g_malloc(sizeof(VisuDump));
-  fmt = tool_file_format_new(descrXYZ, typeXYZ);
-  if (!fmt)
-    {
-      g_error("Can't initialize the XYZ dump module, aborting.\n");
-    }
+  if (xyz)
+    return xyz;
 
-  xyz->bitmap = FALSE;
-  xyz->glRequired = FALSE;
-  xyz->fileType = fmt;
-  xyz->writeFunc = writeDataInXyz;
+  xyz = visu_dump_new(descrXYZ, typeXYZ, writeDataInXyz, FALSE);
   
-  tool_file_format_addPropertyBoolean(fmt, "expand_box",
+  tool_file_format_addPropertyBoolean(TOOL_FILE_FORMAT(xyz), "expand_box",
                                       _("Expand the bounding box"), TRUE);
-  tool_file_format_addPropertyBoolean(fmt, "type_alignment",
+  tool_file_format_addPropertyBoolean(TOOL_FILE_FORMAT(xyz), "type_alignment",
                                       _("Export nodes sorted by elements"), FALSE);
 
   waitData = (gpointer)0;
@@ -101,16 +95,20 @@ static gboolean writeDataInXyz(ToolFileFormat *format, const char* filename,
 				 guchar* imageData _U_, GError **error,
 				 ToolVoidDataFunc functionWait, gpointer data)
 {
-  gchar *nom, *prevFile;
+  const gchar *nom;
+  gchar *prevFile;
   ToolOption *prop;
   gchar firstLine[256];
   gboolean expand, eleSort;
   gint nb;
   float xyz[3], ext[3], vertices[8][3];
-  VisuDataIter iter;
+  VisuNodeArrayIter iter;
   GString *output;
-  VisuDataBoxBoundaries bc;
+  VisuBoxBoundaries bc;
   gchar *bcStr[5] = {"periodic", "surface", "surface", "surface", "FreeBC"};
+  const gchar *nodeComment;
+  double ene;
+  VisuBox *boxObj;
 
   g_return_val_if_fail(error && !*error, FALSE);
 
@@ -127,13 +125,14 @@ static gboolean writeDataInXyz(ToolFileFormat *format, const char* filename,
 
   output = g_string_new("");
 
-  visu_data_iterNew(dataObj, &iter);
+  boxObj = visu_boxed_getBox(VISU_BOXED(dataObj));
+  visu_node_array_iterNew(VISU_NODE_ARRAY(dataObj), &iter);
   /* The number of elements will be prepended later... */
   /* The commentary line. */
-  bc = visu_data_getBoundaryConditions(dataObj);
-  if (bc != VISU_DATA_BOX_FREE)
+  bc = visu_box_getBoundary(boxObj);
+  if (bc != VISU_BOX_FREE)
     {
-      visu_data_getBoxVertices(dataObj, vertices, expand);
+      visu_box_getVertices(boxObj, vertices, expand);
       if (vertices[1][1] == 0.f && vertices[1][2] == 0.f &&
 	  vertices[3][0] == 0.f && vertices[3][2] == 0.f &&
 	  vertices[4][0] == 0.f && vertices[4][1] == 0.f)
@@ -156,9 +155,9 @@ static gboolean writeDataInXyz(ToolFileFormat *format, const char* filename,
     }
   g_string_append(output, "\n");
 
-  visu_data_getBoxVertices(dataObj, vertices, FALSE);
+  visu_box_getVertices(boxObj, vertices, FALSE);
   if (expand)
-    visu_data_getExtension(dataObj, ext);
+    visu_box_getExtension(boxObj, ext);
   else
     {
       ext[0] = 0.;
@@ -167,9 +166,9 @@ static gboolean writeDataInXyz(ToolFileFormat *format, const char* filename,
     }
 
   nb = 0;
-  for (visu_data_iterStartNumber(dataObj, &iter); iter.node && iter.element;
-       (eleSort)?visu_data_iterNext(dataObj, &iter):
-       visu_data_iterNextNodeNumber(dataObj, &iter))
+  for (visu_node_array_iterStartNumber(VISU_NODE_ARRAY(dataObj), &iter); iter.node && iter.element;
+       (eleSort)?visu_node_array_iterNext(VISU_NODE_ARRAY(dataObj), &iter):
+       visu_node_array_iterNextNodeNumber(VISU_NODE_ARRAY(dataObj), &iter))
     {
       visu_data_getNodePosition(dataObj, iter.node, xyz);
       if (iter.element->rendered && iter.node->rendered)
@@ -180,22 +179,33 @@ static gboolean writeDataInXyz(ToolFileFormat *format, const char* filename,
 	  xyz[2] += ext[2] * vertices[4][2];
 
 	  nb += 1;
-	  g_string_append_printf(output, "%s %17.8g %17.8g %17.8g\n",
+	  g_string_append_printf(output, "%s %17.8g %17.8g %17.8g",
 				 iter.element->name,
 				 xyz[0], xyz[1], xyz[2]);
+	  nodeComment = visu_extra_node_getLabel(dataObj, iter.node);
+	  if (nodeComment)
+	    g_string_append_printf(output, " %s", nodeComment);
+          g_string_append(output, "\n");
 	}
     }
 
-  switch (visu_data_getUnit(dataObj))
+  g_string_prepend(output, "\n");
+  g_object_get(G_OBJECT(dataObj), "totalEnergy", &ene, NULL);
+  if (ene != G_MAXFLOAT)
     {
-    case unit_angstroem:
-      sprintf(firstLine, " %d angstroem\n", nb);
+      sprintf(firstLine, " %22.16f", ene / 27.21138386);
+      g_string_prepend(output, firstLine);
+    }
+  switch (visu_box_getUnit(boxObj))
+    {
+    case TOOL_UNITS_ANGSTROEM:
+      sprintf(firstLine, " %d angstroem", nb);
       break;
-    case unit_bohr:
-      sprintf(firstLine, " %d atomic\n", nb);
+    case TOOL_UNITS_BOHR:
+      sprintf(firstLine, " %d atomic", nb);
       break;
     default:
-      sprintf(firstLine, " %d\n", nb);
+      sprintf(firstLine, " %d", nb);
       break;
     }
   g_string_prepend(output, firstLine);
