@@ -53,22 +53,24 @@
 #include "dumpToAscii.h"
 #include "dumpToXyz.h"
 #include "dumpToABINIT.h"
+#ifdef HAVE_CAIRO
 #include "dumpToSVG.h"
+#endif
 
 static VisuDumpInitFunc listInitDumpModuleFunc[] = {
-  dumpToAscii_init,
-  dumpToXyz_init,
-  dumpToABINIT_init,
-  dumpToJPEG_init,
-  dumpToPNG_init,
-  dumpToTIFF_init,
+  visu_dump_ascii_getStatic,
+  visu_dump_xyz_getStatic,
+  visu_dump_abinit_getStatic,
+  visu_dump_jpeg_getStatic,
+  visu_dump_png_getStatic,
+  visu_dump_tiff_getStatic,
 #ifdef HAVE_CAIRO
-  dumpToCairoSVG_init,
-  dumpToCairoPDF_init,
+  visu_dump_cairo_svg_getStatic,
+  visu_dump_cairo_pdf_getStatic,
 #endif
-  dumpToPS_init,
-  dumpToPDF_init,
-  dumpToGif_init,
+  visu_dump_bitmap_pdf_getStatic,
+  visu_dump_bitmap_ps_getStatic,
+  (VisuDumpInitFunc)dumpToGif_init,
   (VisuDumpInitFunc)0};
 
 
