@@ -556,6 +556,9 @@ static void visu_gl_ext_bg_rebuild(VisuGlExt *ext)
   glClearColor(bg->priv->bgRGB[0], bg->priv->bgRGB[1],
                bg->priv->bgRGB[2], bg->priv->bgRGB[3]);
   visu_gl_ext_bg_draw(bg);
+  glNewList(visu_gl_ext_getGlList(ext), GL_COMPILE);
+  glCallList(visu_gl_ext_getGlList(ext) + 2);
+  glEndList();
 
   /* To be moved... */
   if (bg->priv->view && visu_gl_ext_fog_getOn())
