@@ -549,13 +549,14 @@ static void onPairsParametersChange(VisuGlView *view _U_, gpointer data)
       visu_gl_ext_pairs_draw(pairs);
     }
 }
+static gboolean idle_draw(gpointer data);
 static void onNodePopulationChanged(VisuNodeArray *array _U_, int *nodes _U_,
 				    gpointer data)
 {
   VisuGlExtPairs *pairs = VISU_GL_EXT_PAIRS(data);
 
   pairs->priv->isBuilt = FALSE;
-  g_idle_add((GSourceFunc)visu_gl_ext_pairs_draw, (gpointer)pairs);
+  g_idle_add(idle_draw, (gpointer)pairs);
 }
 static void onNodeVisibilityChanged(VisuNodeArray *array _U_, gpointer data)
 {
@@ -862,6 +863,11 @@ void visu_gl_ext_pairs_draw(VisuGlExtPairs *pairs)
 
   pairs->priv->isBuilt = TRUE;
 }
+static gboolean idle_draw(gpointer data)
+{
+  visu_gl_ext_pairs_draw(VISU_GL_EXT_PAIRS(data));
+  return FALSE;
+}
 
 /**************/
 /* Resources. */
