@@ -140,6 +140,8 @@ struct _VisuMap
 #define DESC_RESOURCE_LEG_POS "Choose the legend position ; two floats (between 0 and 1)"
 #define DEFT_RESOURCE_LEG_POS 0.f
 
+static float legendScale, legendPosition[2];
+
 static void exportResources(GString *data, VisuData *dataObj, VisuGlView *view);
 
 static Triangle* triangle_new(float ABC[3][3], guint level);
@@ -1140,19 +1142,19 @@ void visu_map_init()
   conf = visu_config_file_addFloatArrayEntry(VISU_CONFIG_FILE_RESOURCE,
                                              FLAG_RESOURCE_LEG_SCALE,
                                              DESC_RESOURCE_LEG_SCALE,
-                                             1, &visu_map_legendScale, rgWidth);
+                                             1, &legendScale, rgWidth);
   visu_config_file_entry_setVersion(conf, 3.7f);
   conf = visu_config_file_addFloatArrayEntry(VISU_CONFIG_FILE_RESOURCE,
                                              FLAG_RESOURCE_LEG_POS,
                                              DESC_RESOURCE_LEG_POS,
-                                             2, visu_map_legendPosition, rgPos);
+                                             2, legendPosition, rgPos);
   visu_config_file_entry_setVersion(conf, 3.7f);
   visu_config_file_addExportFunction(VISU_CONFIG_FILE_RESOURCE,
 				   exportResources);
 
-  visu_map_legendScale = DEFT_RESOURCE_LEG_SCALE;
-  visu_map_legendPosition[0] = DEFT_RESOURCE_LEG_POS;
-  visu_map_legendPosition[1] = DEFT_RESOURCE_LEG_POS;
+  legendScale = DEFT_RESOURCE_LEG_SCALE;
+  legendPosition[0] = DEFT_RESOURCE_LEG_POS;
+  legendPosition[1] = DEFT_RESOURCE_LEG_POS;
 }
 
 /*************************/
@@ -1162,12 +1164,19 @@ static void exportResources(GString *data, VisuData *dataObj _U_, VisuGlView *vi
 {
   visu_config_file_exportComment(data, DESC_RESOURCE_LEG_SCALE);
   visu_config_file_exportEntry(data, FLAG_RESOURCE_LEG_SCALE, NULL,
-                               "%f", visu_map_legendScale);
+                               "%f", legendScale);
 
   visu_config_file_exportComment(data, DESC_RESOURCE_LEG_POS);
   visu_config_file_exportEntry(data, FLAG_RESOURCE_LEG_POS, NULL,
-                               "%f %f", visu_map_legendPosition[0],
-                               visu_map_legendPosition[1]);
+                               "%f %f", legendPosition[0], legendPosition[1]);
 
   visu_config_file_exportComment(data, "");
 }
+float visu_map_getLegendScale()
+{
+  return legendScale;
+}
+float visu_map_getLegendPosition(ToolXyzDir dir)
+{
+  return (dir == TOOL_XYZ_X || dir == TOOL_XYZ_Y)?legendPosition[dir]:0.f;
+}
