@@ -52,6 +52,7 @@
 #include "scalarFields.h"
 #include "plane.h"
 #include <coreTools/toolShade.h>
+#include <coreTools/toolMatrix.h>
 
 /**
  * VisuMapExportFormat:
@@ -77,8 +78,6 @@ typedef enum
  */
 typedef struct _VisuMap VisuMap;
 
-float visu_map_legendScale, visu_map_legendPosition[2];
-
 #define VISU_TYPE_MAP (visu_map_get_type())
 GType    visu_map_get_type(void);
 
@@ -98,6 +97,9 @@ VisuPlane* visu_map_getPlane(VisuMap *map);
 float* visu_map_getScaledMinMax(VisuMap *map);
 float* visu_map_getFieldMinMax(VisuMap *map);
 
+float visu_map_getLegendScale();
+float visu_map_getLegendPosition(ToolXyzDir dir);
+
 void visu_map_compute(VisuMap *map);
 void visu_map_draw(VisuMap *map, float prec, ToolShade *shade, float *rgb,
                    gboolean alpha);
