@@ -51,7 +51,7 @@
 #include <visu_rendering.h>
 #include <opengl.h> /* for highlight methods*/
 #include <openGLFunctions/objectList.h> /* permit to draw arrow */
-#include <visu_extension.h>
+#include <extensions/node_vectors.h>
 #include <visu_basic.h>
 
 /**
@@ -71,7 +71,6 @@
 
 #define OMEGA_COEFF 0.05f
 #define AMPL_COEFF 0.5f
-#define PHONON "Vibration"
 
 /* Displacement vector per atom is (U+iV) = (Ux + iVx, ...).
    Current applied displacement on one atom is (dx, dy, dz).
@@ -81,6 +80,9 @@ enum
     Ux,
     Uy,
     Uz,
+    mod,
+    theta,
+    phi,
     Vx,
     Vy,
     Vz,
@@ -91,19 +93,14 @@ enum
     nData
   };
 
-/* Local variables. */
-VisuExtension *extSpin = NULL;
-
 /*Local Method */
 static void freeVib(gpointer data);
-static void spinCreate_openGLExtension();
 static void freeVibe(gpointer obj, gpointer data _U_);
 static gpointer newOrCopyVibe(gconstpointer obj, gpointer data _U_);
 static void vibrationIncr(VisuData *data, gboolean time, gboolean phase);
 static void onPopulationChanged(VisuData *dataObj, gint *ids, gpointer data);
-static void onPositionChanged(VisuData *dataObj, gpointer data);
+static void onPositionChanged(VisuData *dataObj, VisuElement *ele, gpointer data);
 static gboolean move(gpointer data);
-static gboolean xyzspin(VisuData *data);
 
 typedef struct vibration_
 {
@@ -132,7 +129,7 @@ typedef struct vibration_
 
 /**
  * visu_vibration_play:
- * @data : a #VisuData object.
+ * @data: a #VisuData object.
  *
  * Make the phonon displace the #VisuNode of @data according to their
  * definitions (see visu_vibration_setDisplacements() and
@@ -147,7 +144,7 @@ guint visu_vibration_play(VisuData *data)
   Vibration *vib;
   guint timeoutID = 0;
 
-  vib = (Vibration*)g_object_get_data(G_OBJECT(data), PHONON);
+  vib = (Vibration*)g_object_get_data(G_OBJECT(data), VISU_VIBRATION_ID);
   g_return_val_if_fail(vib, 0);
 
   timeoutID = g_timeout_add(50, (GSourceFunc)move, data);
@@ -195,6 +192,7 @@ static gpointer newOrCopyVibe(gconstpointer obj, gpointer data _U_)
       spinData[Ux] = ((float*)obj)[0];
       spinData[Uy] = ((float*)obj)[1];
       spinData[Uz] = ((float*)obj)[2];
+      tool_matrix_cartesianToSpherical(spinData + mod, (float*)obj);
       spinData[Vx] = ((float*)obj)[3];
       spinData[Vy] = ((float*)obj)[4];
       spinData[Vz] = ((float*)obj)[5];
@@ -226,18 +224,15 @@ gboolean visu_vibration_init(VisuData *data, guint n, guint nNodes)
 {
   Vibration *vib;
   gboolean new;
-  VisuNodeArray *nodes;
   guint i;
 
-  nodes = visu_data_getNodeArray(data);
-
   new = FALSE;
-  vib = (Vibration*)g_object_get_data(G_OBJECT(data), PHONON);
+  vib = (Vibration*)g_object_get_data(G_OBJECT(data), VISU_VIBRATION_ID);
   if (!vib)
     {
       new = TRUE;
       vib = g_malloc(sizeof(Vibration));
-      g_object_set_data_full(G_OBJECT(data), PHONON, (gpointer)vib, freeVib);
+      g_object_set_data_full(G_OBJECT(data), VISU_VIBRATION_ID, (gpointer)vib, freeVib);
       vib->q     = g_malloc(sizeof(float) * n * 3);
       vib->omega = g_malloc(sizeof(float) * n);
       vib->en    = g_malloc(sizeof(float) * n);
@@ -245,9 +240,9 @@ gboolean visu_vibration_init(VisuData *data, guint n, guint nNodes)
       vib->nUs   = 6 * nNodes;
       vib->u     = g_malloc(sizeof(float) * n * vib->nUs);
       vib->norm  = g_malloc(sizeof(float) * n);
-      g_signal_connect(G_OBJECT(data), "NodePopulationIncrease",
+      g_signal_connect(G_OBJECT(data), "PopulationIncrease",
 		       G_CALLBACK(onPopulationChanged), (gpointer)0);
-      vib->signal = g_signal_connect(G_OBJECT(data), "NodePositionChanged",
+      vib->signal = g_signal_connect(G_OBJECT(data), "PositionChanged",
 				     G_CALLBACK(onPositionChanged), (gpointer)0);
     }
   else if (n != vib->n || vib->nUs != 6 * nNodes)
@@ -313,7 +308,7 @@ gboolean visu_vibration_setDisplacements(VisuData *data, guint iph,
 
   g_return_val_if_fail(data && vibes, FALSE);
 
-  vib = (Vibration*)g_object_get_data(G_OBJECT(data), PHONON);
+  vib = (Vibration*)g_object_get_data(G_OBJECT(data), VISU_VIBRATION_ID);
   g_return_val_if_fail(vib && iph < vib->n, FALSE);
 
   DBG_fprintf(stderr, "Vibration: set vibration data for phonon %d (%d).\n",
@@ -338,10 +333,10 @@ gboolean visu_vibration_setDisplacements(VisuData *data, guint iph,
 		tmpVibeValues[2] * tmpVibeValues[2] +
 		tmpVibeValues[3] * tmpVibeValues[3] +
 		tmpVibeValues[4] * tmpVibeValues[4] +
-		tmpVibeValues[5] * tmpVibeValues[5], max);
+		tmpVibeValues[5] * tmpVibeValues[6], max);
       DBG_fprintf(stderr, "| %d -> (%g,%g,%g) + i (%g,%g,%g)\n", i,
-		  tmpVibeValues[Ux], tmpVibeValues[Uy], tmpVibeValues[Uz],
-		  tmpVibeValues[Vx], tmpVibeValues[Vy], tmpVibeValues[Vz]);
+		  tmpVibeValues[0], tmpVibeValues[1], tmpVibeValues[2],
+		  tmpVibeValues[3], tmpVibeValues[4], tmpVibeValues[5]);
     }
   vib->norm[iph] = sqrt(max);
   DBG_fprintf(stderr, "Vibration: set norm to %f.\n", vib->norm[iph]);
@@ -366,12 +361,12 @@ gboolean visu_vibration_setDisplacements(VisuData *data, guint iph,
  */
 gboolean visu_vibration_setCurrentMode(VisuData *data, guint iph, GError **error)
 {
-  float *tmpVibeValues, xyz[3], *vals;
-  VisuDataIter iter;
+  float *tmpVibeValues, xyz[3], red[3], *vals;
+  float  *mM;
+  VisuNodeArrayIter iter;
   VisuNodeProperty *nodevibe;
   GValue vibeValue = {0.0, {{0.0}, {0.0}}};
   Vibration *vib;
-  VisuNodeArray *nodes;
   gboolean new, ok;
   int i, iNode;
 
@@ -379,75 +374,85 @@ gboolean visu_vibration_setCurrentMode(VisuData *data, guint iph, GError **error
 
   DBG_fprintf(stderr, "Vibration: set current mode to %d.\n", iph);
 
-  vib = (Vibration*)g_object_get_data(G_OBJECT(data), PHONON);
+  vib = (Vibration*)g_object_get_data(G_OBJECT(data), VISU_VIBRATION_ID);
   g_return_val_if_fail(vib && iph < vib->n, FALSE);
 
   if (!vib->loaded[iph])
     {
       visu_data_freePopulation(data);
-      ok = visu_basic_loadData(data, (ToolFileFormat*)0, iph, error);
+      ok = visu_object_load(VISU_OBJECT_INSTANCE, data,
+                            iph, (GCancellable*)0, error);
       if (!ok)
 	return FALSE;
     }
   g_return_val_if_fail(vib->loaded[iph], FALSE);
 
-  /* We copy for all the nodes the displacements into the PHONON
+  /* We copy for all the nodes the displacements into the VISU_VIBRATION_ID
      node property. */
-  nodes = visu_data_getNodeArray(data);
-  nodevibe = visu_node_array_getProperty(nodes, PHONON);
+  nodevibe = visu_node_array_getProperty(VISU_NODE_ARRAY(data), VISU_VIBRATION_ID);
   new = (nodevibe == (VisuNodeProperty*)0);
 
   /*Associate the table to a VisuNodeArray as a new property*/
   if (new)
-    nodevibe = visu_node_property_newPointer(visu_data_getNodeArray(data),
-					   PHONON, freeVibe, newOrCopyVibe,
-					   (gpointer)0 );
-
+    nodevibe = visu_node_array_property_newPointer(VISU_NODE_ARRAY(data),
+                                             VISU_VIBRATION_ID, freeVibe, newOrCopyVibe,
+                                             (gpointer)0);
   /*for each node*/
   i   = 0;
   g_value_init(&vibeValue, G_TYPE_POINTER);
-  visu_data_iterNew(data, &iter);
-  for(visu_data_iterStart(data, &iter); iter.node;
-      visu_data_iterNext(data, &iter))
+  visu_node_array_iterNew(VISU_NODE_ARRAY(data), &iter);
+  for(visu_node_array_iterStart(VISU_NODE_ARRAY(data), &iter); iter.node;
+      visu_node_array_iterNext(VISU_NODE_ARRAY(data), &iter))
     {
-      iNode = visu_node_array_getOriginal(nodes, iter.node->number);
+      iNode = visu_node_array_getOriginal(VISU_NODE_ARRAY(data), iter.node->number);
       iNode = (iNode >= 0)?iNode:(int)iter.node->number;
       vals = vib->u + iph * vib->nUs + iNode * 6;
       if (new)
-	{
-	  tmpVibeValues = newOrCopyVibe(vals, (gpointer)0);
-	  g_value_set_pointer(&vibeValue, tmpVibeValues);
-	  visu_node_property_setValue(nodevibe, iter.node, &vibeValue);
-	}
+        {
+          tmpVibeValues = newOrCopyVibe(vals, (gpointer)0);
+          g_value_set_pointer(&vibeValue, tmpVibeValues);
+          visu_node_property_setValue(nodevibe, iter.node, &vibeValue);
+        }
       else
-	{
-	  visu_node_property_getValue(nodevibe, iter.node, &vibeValue);
-	  tmpVibeValues = (float*)g_value_get_pointer(&vibeValue);
-	  tmpVibeValues[Ux] = vals[0];
-	  tmpVibeValues[Uy] = vals[1];
-	  tmpVibeValues[Uz] = vals[2];
-	  tmpVibeValues[Vx] = vals[3];
-	  tmpVibeValues[Vy] = vals[4];
-	  tmpVibeValues[Vz] = vals[5];
-	  tmpVibeValues[dx] = 0.f;
-	  tmpVibeValues[dy] = 0.f;
-	  tmpVibeValues[dz] = 0.f;
-	}
+        {
+          visu_node_property_getValue(nodevibe, iter.node, &vibeValue);
+          tmpVibeValues = (float*)g_value_get_pointer(&vibeValue);
+          tmpVibeValues[Ux] = vals[0];
+          tmpVibeValues[Uy] = vals[1];
+          tmpVibeValues[Uz] = vals[2];
+          tool_matrix_cartesianToSpherical(tmpVibeValues + mod, vals);
+          tmpVibeValues[Vx] = vals[3];
+          tmpVibeValues[Vy] = vals[4];
+          tmpVibeValues[Vz] = vals[5];
+          tmpVibeValues[dx] = 0.f;
+          tmpVibeValues[dy] = 0.f;
+          tmpVibeValues[dz] = 0.f;
+        }
       /* Set the phase. */
-      visu_data_getReducedNodePosition(data, iter.node, xyz);
+      visu_data_getNodePosition(data, iter.node, xyz);
+      visu_box_convertXYZtoBoxCoordinates(visu_boxed_getBox(VISU_BOXED(data)), red, xyz);
       tmpVibeValues[qr] = 2.f * G_PI *
-	(xyz[0] * vib->q[3 * iph + 0] +
-	 xyz[1] * vib->q[3 * iph + 1] +
-	 xyz[2] * vib->q[3 * iph + 2]);
+        (red[0] * vib->q[3 * iph + 0] +
+         red[1] * vib->q[3 * iph + 1] +
+         red[2] * vib->q[3 * iph + 2]);
       DBG_fprintf(stderr, "| %d -> (%g,%g,%g) + i (%g,%g,%g) | (%g,%g,%g) %g\n", i,
-		  tmpVibeValues[Ux], tmpVibeValues[Uy], tmpVibeValues[Uz],
-		  tmpVibeValues[Vx], tmpVibeValues[Vy], tmpVibeValues[Vz],
-		  tmpVibeValues[dx], tmpVibeValues[dy], tmpVibeValues[dz],
-		  tmpVibeValues[qr]);
+        	  tmpVibeValues[Ux], tmpVibeValues[Uy], tmpVibeValues[Uz],
+        	  tmpVibeValues[Vx], tmpVibeValues[Vy], tmpVibeValues[Vz],
+        	  tmpVibeValues[dx], tmpVibeValues[dy], tmpVibeValues[dz],
+        	  tmpVibeValues[qr]);
 
       i += 1;
     }
 
+  /* Set the norm of the phonon. */
+  mM = (float*)g_object_get_data(G_OBJECT(data), "max_" VISU_VIBRATION_ID);
+  if (!mM)
+    {
+      mM = g_malloc(sizeof(float) * 2);
+      g_object_set_data_full(G_OBJECT(data), "max_" VISU_VIBRATION_ID, mM, g_free);
+    }
+  mM[1] = vib->norm[iph];
+
   vib->iph = iph;
 
   return new;
@@ -474,7 +479,7 @@ gboolean visu_vibration_setCharacteristic(VisuData *data, guint n,
 
   g_return_val_if_fail(data, FALSE);
 
-  vib = (Vibration*)g_object_get_data(G_OBJECT(data), PHONON);
+  vib = (Vibration*)g_object_get_data(G_OBJECT(data), VISU_VIBRATION_ID);
   g_return_val_if_fail(vib || vib->n <= n, FALSE);
 
   vib->q[n * 3 + 0] = q[0];
@@ -507,7 +512,7 @@ gboolean visu_vibration_getCharacteristic(VisuData *data, guint n,
 
   g_return_val_if_fail(data && en && omega, FALSE);
 
-  vib = (Vibration*)g_object_get_data(G_OBJECT(data), PHONON);
+  vib = (Vibration*)g_object_get_data(G_OBJECT(data), VISU_VIBRATION_ID);
   g_return_val_if_fail(vib || vib->n <= n, FALSE);
 
   q[0]   = vib->q[n * 3 + 0];
@@ -536,7 +541,7 @@ gboolean visu_vibration_getNPhonons(VisuData *data, guint *n)
 
   g_return_val_if_fail(data && n, FALSE);
 
-  vib = (Vibration*)g_object_get_data(G_OBJECT(data), PHONON);
+  vib = (Vibration*)g_object_get_data(G_OBJECT(data), VISU_VIBRATION_ID);
   g_return_val_if_fail(vib, FALSE);
 
   *n = vib->n;
@@ -559,7 +564,7 @@ void visu_vibration_setUserFrequency(VisuData *data, float freq)
 
   g_return_if_fail(data);
 
-  vib = (Vibration*)g_object_get_data(G_OBJECT(data), PHONON);
+  vib = (Vibration*)g_object_get_data(G_OBJECT(data), VISU_VIBRATION_ID);
   g_return_if_fail(vib);
 
   f = vib->freq;
@@ -588,7 +593,7 @@ gboolean visu_vibration_setAmplitude(VisuData *data, float ampl)
 
   g_return_val_if_fail(data, FALSE);
 
-  vib = (Vibration*)g_object_get_data(G_OBJECT(data), PHONON);
+  vib = (Vibration*)g_object_get_data(G_OBJECT(data), VISU_VIBRATION_ID);
   g_return_val_if_fail(vib, FALSE);
 
   if (vib->ampl == ampl)
@@ -613,7 +618,7 @@ guint visu_vibration_getCurrentMode(VisuData *data)
 
   g_return_val_if_fail(data, 0);
 
-  vib = (Vibration*)g_object_get_data(G_OBJECT(data), PHONON);
+  vib = (Vibration*)g_object_get_data(G_OBJECT(data), VISU_VIBRATION_ID);
   g_return_val_if_fail(vib, 0);
 
   return vib->iph;
@@ -622,11 +627,11 @@ guint visu_vibration_getCurrentMode(VisuData *data)
 static gboolean getVibration(VisuNodeProperty **nodevibe, Vibration **vib,
 			     GValue *vibeValue, VisuData *data)
 {
-  *vib = (Vibration*)g_object_get_data(G_OBJECT(data), PHONON);
+  *vib = (Vibration*)g_object_get_data(G_OBJECT(data), VISU_VIBRATION_ID);
   g_return_val_if_fail(*vib, FALSE);
 
   g_value_init(vibeValue, G_TYPE_POINTER);
-  *nodevibe = visu_node_array_getProperty(visu_data_getNodeArray(data), PHONON);
+  *nodevibe = visu_node_array_getProperty(VISU_NODE_ARRAY(data), VISU_VIBRATION_ID);
 
   return TRUE;
 }
@@ -635,7 +640,7 @@ static void vibrationIncr(VisuData *data, gboolean time, gboolean phase)
 {
   GValue vibeValue = {0.0, {{0.0}, {0.0}}};
   float *dxyz, t, c, wdtr, wdti, dU[3];
-  VisuDataIter iter;
+  VisuNodeArrayIter iter;
   VisuNodeProperty *nodevibe;
   Vibration *vib;
   gboolean set;
@@ -660,9 +665,9 @@ static void vibrationIncr(VisuData *data, gboolean time, gboolean phase)
 
   DBG_fprintf(stderr, " | c = %g, t = %g.\n", c, t);
 
-  visu_data_iterNew(data, &iter);
-  for(visu_data_iterStart(data, &iter); iter.node;
-      visu_data_iterNext(data, &iter))
+  visu_node_array_iterNew(VISU_NODE_ARRAY(data), &iter);
+  for(visu_node_array_iterStart(VISU_NODE_ARRAY(data), &iter); iter.node;
+      visu_node_array_iterNext(VISU_NODE_ARRAY(data), &iter))
     {
       /* Get the vector of vibration of the node (GValue) */
       visu_node_property_getValue(nodevibe, iter.node, &vibeValue );
@@ -670,32 +675,33 @@ static void vibrationIncr(VisuData *data, gboolean time, gboolean phase)
       dxyz = (float*)g_value_get_pointer(&vibeValue);
 
       /* calculate xyz(t) */
-      wdtr = c * sin(((time)?t:0.f) + ((phase)?dxyz[qr]:0.f));
-      wdti = -c * cos(((time)?t:0.f) + ((phase)?dxyz[qr]:G_PI_2));
-      dU[0] = dxyz[Ux] * wdtr + dxyz[Vx] * wdti;
-      dU[1] = dxyz[Uy] * wdtr + dxyz[Vy] * wdti;
-      dU[2] = dxyz[Uz] * wdtr + dxyz[Vz] * wdti;
-      iter.node->translation[0] += dU[0] - dxyz[dx];
-      iter.node->translation[1] += dU[1] - dxyz[dy];
-      iter.node->translation[2] += dU[2] - dxyz[dz];
-      dxyz[dx] = dU[0];
-      dxyz[dy] = dU[1];
-      dxyz[dz] = dU[2];
+      if (dxyz)
+        {
+          wdtr = c * sin(((time)?t:0.f) + ((phase)?dxyz[qr]:0.f));
+          wdti = -c * cos(((time)?t:0.f) + ((phase)?dxyz[qr]:G_PI_2));
+          dU[0] = dxyz[Ux] * wdtr + dxyz[Vx] * wdti;
+          dU[1] = dxyz[Uy] * wdtr + dxyz[Vy] * wdti;
+          dU[2] = dxyz[Uz] * wdtr + dxyz[Vz] * wdti;
+          iter.node->translation[0] += dU[0] - dxyz[dx];
+          iter.node->translation[1] += dU[1] - dxyz[dy];
+          iter.node->translation[2] += dU[2] - dxyz[dz];
+          dxyz[dx] = dU[0];
+          dxyz[dy] = dU[1];
+          dxyz[dz] = dU[2];
 
-      DBG_fprintf(stderr, " | dx = %f, dy = %f, dz = %f\n",
-		  dU[0], dU[1], dU[2]);
+          DBG_fprintf(stderr, " | dx = %f, dy = %f, dz = %f\n",
+                      dU[0], dU[1], dU[2]);
+        }
     }
   vib->haveTime  = time;
   vib->havePhase = phase;
-     
+
   /*emit signal for pairs and other things */   
   g_signal_handler_block(G_OBJECT(data), vib->signal);
-  visu_data_emitNodePositionChanged(data);
+  g_signal_emit_by_name(G_OBJECT(data), "PositionChanged", (VisuElement*)0, NULL);
   g_signal_handler_unblock(G_OBJECT(data), vib->signal);
-  /* re-create the nodes list */
-  visu_data_createAllNodes(data);
   /* redraw with the new values */
-  VISU_ADD_REDRAW;
+  VISU_REDRAW_ADD;
 }
 static gboolean move(gpointer data)
 {
@@ -729,143 +735,6 @@ void visu_vibration_setZeroTime(VisuData *data)
 {
   vibrationIncr(data, FALSE, TRUE);
 }
-
-static gboolean xyzspin(VisuData *data)
-{
-  GValue vibeValue = {0.0, {{0.0}, {0.0}}};
-  float xyz[3], *dxyz;
-  float vals[3], sph[3], fact, eleSize;
-  VisuDataIter iter;
-  VisuNodeProperty *nodevibe;
-  GLUquadricObj *obj;
-  Vibration *vib;
-
-  vib = (Vibration*)g_object_get_data(G_OBJECT(data), PHONON);
-  g_return_val_if_fail(vib, FALSE);
-
-  if (vib->iph < 0)
-    return TRUE;
-
-  obj = gluNewQuadric();
-
-  /* We compute the maximum size of the arrow tail. */
-  fact = 2.f * AMPL_COEFF * vib->ampl / vib->norm[vib->iph];
-
-  g_value_init(&vibeValue, G_TYPE_POINTER);
-  visu_data_iterNew(data, &iter);
-  nodevibe = visu_node_array_getProperty(visu_data_getNodeArray(data), PHONON);
-  g_return_val_if_fail(nodevibe, FALSE);
-
-  for(visu_data_iterStart(data, &iter); iter.element;
-      visu_data_iterNextElement(data, &iter))
-    {
-      /* change spin color*/
-      openGLSet_highlightColor(iter.element->material,
-			       iter.element->rgb, 1.f);
-      eleSize = visu_rendering_getSizeOfElement(visu_object_getRendering(VISU_INSTANCE),
-					       iter.element);
-
-      for(visu_data_iterRestartNode(data, &iter); iter.node;
-	  visu_data_iterNextNode(data, &iter))
-	{
-	  /* Get the vector of vibration of the node (GValue) */
-	  visu_node_property_getValue(nodevibe, iter.node, &vibeValue );
-	  /* Convert GValue to Float[3]  */
-	  dxyz = (float*)g_value_get_pointer(&vibeValue);
-
-	  /* Spherical coordonates of dxyz */
-	  tool_matrix_cartesianToSpherical(sph, dxyz);
-	  vals[TOOL_MATRIX_SPHERICAL_MODULUS] = sph[0];
-	  vals[TOOL_MATRIX_SPHERICAL_THETA]   = sph[1];
-	  vals[TOOL_MATRIX_SPHERICAL_PHI]     = sph[2];
-
-	  if (vals[TOOL_MATRIX_SPHERICAL_MODULUS] > 0.05f * vib->norm[vib->iph])
-	    {
-	      /* get the nodes position in the box */
-	      visu_data_getNodePosition(data, iter.node, xyz);
-  
-	      DBG_fprintf(stderr, "Vibration: drawing an arrow for the node \n");
-
-	      glPushMatrix();
-
-	      /* translate and rotate the arrow */
-	      glTranslated(xyz[0] - dxyz[dx],
-			   xyz[1] - dxyz[dy],
-			   xyz[2] - dxyz[dz]);
-	      glRotated(vals[TOOL_MATRIX_SPHERICAL_PHI], 0, 0, 1);
-	      glRotated(vals[TOOL_MATRIX_SPHERICAL_THETA], 0, 1, 0);
-
-	      /* draw a smooth arrow */
-	      visu_openGL_drawSmoothArrow
-		(obj, -1, VISU_OPENGL_ARROW_TAIL_CENTERED,
-                 vals[TOOL_MATRIX_SPHERICAL_MODULUS] * fact + 2.5f * eleSize,
-                 eleSize * 0.2f, 10, FALSE, 0.5f * eleSize, eleSize * 0.3f, 10, FALSE);
-
-	      glPopMatrix();
-	    }
-	}
-    }
-
-  gluDeleteQuadric(obj);
-
-  return TRUE;
-}
-/**
- * visu_vibration_buildListSpin:
- * @data: a #VisuData object.
- *
- * Make a new list to make OpenGl know that he draw spins or not.
- *
- * Since: 3.5
- */
-void visu_vibration_buildListSpin(VisuData *data)
-{
-
-  DBG_fprintf(stderr, "Vibration: rebuilding object list for visuData %p.\n",
-	      (gpointer)data);
-  if (!extSpin)
-    spinCreate_openGLExtension();
-
-  glNewList(extSpin->objectListId, GL_COMPILE);
-  xyzspin(data);
-  glEndList();
-}
-
-static void spinCreate_openGLExtension()
-{
-  int id;
-
-  /* Get an OpenGL identifier to store the arrows and labels. */
-  id      = visu_openGL_objectList_new(1);
-  extSpin = visu_extension_new("vibration", "vibration",
-				"arrows representing node moves.",
-				id, visu_vibration_buildListSpin);
-  visu_extension_setPriority(extSpin, VISU_EXTENSION_PRIORITY_NODE_DECORATIONS);
-  extSpin->used = 0;
-  visuExtensions_add(extSpin);
-}
-/**
- * visu_vibration_setUseSpin:
- * @value: the value of the checkbox that allow to draw spin or not;
- *
- * Tells openGl if he has to draw the spin/phonons list
- *
- * Since: 3.5
- *
- * Returns: TRUE if status changed.
- */
-gboolean visu_vibration_setUseSpin(gboolean value)
-{
-  if (!extSpin)
-    spinCreate_openGLExtension();
-
-  if (value == extSpin->used)
-    return FALSE;
-
-  extSpin->used = value;
-
-  return TRUE;
-}
 /**
  * visu_vibration_isSet:
  * @data: a #VisuData object.
@@ -878,7 +747,7 @@ gboolean visu_vibration_setUseSpin(gboolean value)
  */
 gboolean visu_vibration_isSet(VisuData *data)
 {
-  return (g_object_get_data(G_OBJECT(data), PHONON) != (Vibration*)0);
+  return (g_object_get_data(G_OBJECT(data), VISU_VIBRATION_ID) != (Vibration*)0);
 }
 static void onPopulationChanged(VisuData *dataObj, gint *ids, gpointer data _U_)
 {
@@ -886,47 +755,48 @@ static void onPopulationChanged(VisuData *dataObj, gint *ids, gpointer data _U_)
   VisuNode *node;
   VisuNodeProperty *nodevibe;
   GValue vibeValue = {0.0, {{0.0}, {0.0}}};
-  float *dxyz ,xyz[3];
+  float *dxyz ,xyz[3], red[3];
   Vibration *vib;
 
-  vib = (Vibration*)g_object_get_data(G_OBJECT(dataObj), PHONON);
+  vib = (Vibration*)g_object_get_data(G_OBJECT(dataObj), VISU_VIBRATION_ID);
   g_return_if_fail(vib);
 
   if (vib->iph < 0)
     return;
 
   g_value_init(&vibeValue, G_TYPE_POINTER);
-  nodevibe = visu_node_array_getProperty(visu_data_getNodeArray(dataObj), PHONON);
+  nodevibe = visu_node_array_getProperty(VISU_NODE_ARRAY(dataObj), VISU_VIBRATION_ID);
 
   DBG_fprintf(stderr, "Vibration: on population increase recalculate pahse.\n");
   /* We need to recalculate the phase of the new ones. */
   for (i = 2; ids[i] >= 0; i++)
     {
-      node = visu_data_getNodeFromNumber(dataObj, ids[i]);
+      node = visu_node_array_getFromId(VISU_NODE_ARRAY(dataObj), ids[i]);
       /* Get the vector of vibration of the node (GValue) */
       visu_node_property_getValue(nodevibe, node, &vibeValue );
       /* Convert GValue to Float[3]  */
       dxyz = (float*)g_value_get_pointer(&vibeValue);
       
-      visu_data_getReducedNodePosition(dataObj, node, xyz);
+      visu_data_getNodePosition(dataObj, node, xyz);
+      visu_box_convertXYZtoBoxCoordinates(visu_boxed_getBox(VISU_BOXED(dataObj)), red, xyz);
       DBG_fprintf(stderr, " | node %d, %f -> %f.\n", ids[i], dxyz[3],
-		  xyz[0] * vib->q[3 * vib->iph + 0] +
-		  xyz[1] * vib->q[3 * vib->iph + 1] +
-		  xyz[2] * vib->q[3 * vib->iph + 2]);
+		  red[0] * vib->q[3 * vib->iph + 0] +
+		  red[1] * vib->q[3 * vib->iph + 1] +
+		  red[2] * vib->q[3 * vib->iph + 2]);
       dxyz[qr] = 2.f * G_PI *
-	(xyz[0] * vib->q[3 * vib->iph + 0] +
-	 xyz[1] * vib->q[3 * vib->iph + 1] +
-	 xyz[2] * vib->q[3 * vib->iph + 2]);
+	(red[0] * vib->q[3 * vib->iph + 0] +
+	 red[1] * vib->q[3 * vib->iph + 1] +
+	 red[2] * vib->q[3 * vib->iph + 2]);
     }
 }
-static void onPositionChanged(VisuData *dataObj, gpointer data _U_)
+static void onPositionChanged(VisuData *dataObj, VisuElement *ele _U_, gpointer data _U_)
 {
-  VisuDataIter iter;
+  VisuNodeArrayIter iter;
   VisuNodeProperty *nodevibe;
   GValue vibeValue = {0.0, {{0.0}, {0.0}}};
   Vibration *vib;
   gboolean set;
-  float *dxyz ,xyz[3];
+  float *dxyz ,xyz[3], red[3];
 
   DBG_fprintf(stderr, "Vibration: on position changed recalculate phase.\n");
 
@@ -937,23 +807,24 @@ static void onPositionChanged(VisuData *dataObj, gpointer data _U_)
     return;
 
   /* We need to recalculate the phase of the new ones. */
-  visu_data_iterNew(dataObj, &iter);
-  for(visu_data_iterStart(dataObj, &iter); iter.node;
-      visu_data_iterNext(dataObj, &iter))
+  visu_node_array_iterNew(VISU_NODE_ARRAY(dataObj), &iter);
+  for(visu_node_array_iterStart(VISU_NODE_ARRAY(dataObj), &iter); iter.node;
+      visu_node_array_iterNext(VISU_NODE_ARRAY(dataObj), &iter))
     {
       /* Get the vector of vibration of the node (GValue) */
       visu_node_property_getValue(nodevibe, iter.node, &vibeValue );
       /* Convert GValue to Float[3]  */
       dxyz = (float*)g_value_get_pointer(&vibeValue);
       
-      visu_data_getReducedNodePosition(dataObj, iter.node, xyz);
+      visu_data_getNodePosition(dataObj, iter.node, xyz);
+      visu_box_convertXYZtoBoxCoordinates(visu_boxed_getBox(VISU_BOXED(dataObj)), red, xyz);
       DBG_fprintf(stderr, " | node %d, %f -> %f.\n", iter.node->number, dxyz[qr],
-		  xyz[0] * vib->q[3 * vib->iph + 0] +
-		  xyz[1] * vib->q[3 * vib->iph + 1] +
-		  xyz[2] * vib->q[3 * vib->iph + 2]);
+		  red[0] * vib->q[3 * vib->iph + 0] +
+		  red[1] * vib->q[3 * vib->iph + 1] +
+		  red[2] * vib->q[3 * vib->iph + 2]);
       dxyz[qr] = 2.f * G_PI *
-	(xyz[0] * vib->q[3 * vib->iph + 0] +
-	 xyz[1] * vib->q[3 * vib->iph + 1] +
-	 xyz[2] * vib->q[3 * vib->iph + 2]);
+	(red[0] * vib->q[3 * vib->iph + 0] +
+	 red[1] * vib->q[3 * vib->iph + 1] +
+	 red[2] * vib->q[3 * vib->iph + 2]);
     }
 }
