@@ -47,6 +47,14 @@
 
 #include <visu_data.h>
 
+/**
+ * VISU_VIBRATION_ID:
+ *
+ * The default name used for the #VisuGlExt representing
+ * vibrations, see visu_gl_ext_getFromName().
+ */
+#define VISU_VIBRATION_ID "Vibration"
+
 gboolean visu_vibration_init(VisuData *data, guint n, guint nNodes);
 gboolean visu_vibration_getNPhonons(VisuData *data, guint *n);
 gboolean visu_vibration_setCurrentMode(VisuData *data, guint iph, GError **error);
@@ -66,10 +74,6 @@ void visu_vibration_resetPosition(VisuData *data);
 void visu_vibration_setZeroTime(VisuData *data);
 gboolean visu_vibration_setAmplitude(VisuData *data, float ampl);
 
-void visu_vibration_buildListSpin(VisuData *data);
-
-gboolean visu_vibration_setUseSpin(gboolean value);
-
 gboolean visu_vibration_isSet(VisuData *data);
 
 #endif
