@@ -58,17 +58,20 @@
  * @short_description: A specialised curve widget to draw distance
  * distribution for pairs.
  *
+ * <para>This is a psecialised widget to display g(r)
+ * information.</para>
+ *
  * Since: 3.6
  */
 
 /**
- * CurveFrame:
+ * VisuUiCurveFrame:
  *
- * An opaque structure defining a #CurveFrame widget.
+ * An opaque structure defining a #VisuUiCurveFrame widget.
  *
  * Since: 3.6
  */
-struct _CurveFrame
+struct _VisuUiCurveFrame
 {
   GtkDrawingArea parent;
 
@@ -79,7 +82,7 @@ struct _CurveFrame
   float heights[2];
   float hlRange[2];
 
-  CurveFrameStyle style;
+  VisuUiCurveFrameStyle style;
   gchar *filter;
   GHashTable *data;
   guint nSteps;
@@ -87,13 +90,13 @@ struct _CurveFrame
 };
 
 /**
- * CurveFrameClass:
+ * VisuUiCurveFrameClass:
  *
- * An opaque structure defining the class of a #CurveFrame widget.
+ * An opaque structure defining the class of a #VisuUiCurveFrame widget.
  *
  * Since: 3.6
  */
-struct _CurveFrameClass
+struct _VisuUiCurveFrameClass
 {
   GtkDrawingAreaClass parent_class;
 };
@@ -101,41 +104,48 @@ struct _CurveFrameClass
 #define SPACER "\302\240-\302\240"
 #define ALL    _("All")
 
-G_DEFINE_TYPE (CurveFrame, curveFrame, GTK_TYPE_DRAWING_AREA)
+/**
+ * visu_ui_curve_frame_get_type:
+ *
+ * Internal routine to get #VISU_UI_TYPE_CURVE_FRAME value.
+ *
+ * Since: 3.6
+ */
+G_DEFINE_TYPE (VisuUiCurveFrame, visu_ui_curve_frame, GTK_TYPE_DRAWING_AREA)
 
 #if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
-static gboolean curveFrame_expose(GtkWidget *curve, GdkEventExpose *event);
+static gboolean visu_ui_curve_frame_expose(GtkWidget *curve, GdkEventExpose *event);
 #endif
-static gboolean curveFrame_draw(GtkWidget *curve, cairo_t *cr);
-static void curveFrame_dispose(GObject *obj);
-static void curveFrame_finalize(GObject *obj);
+static gboolean visu_ui_curve_frame_drawCairo(GtkWidget *curve, cairo_t *cr);
+static void visu_ui_curve_frame_dispose(GObject *obj);
+static void visu_ui_curve_frame_finalize(GObject *obj);
 static void redraw(GtkWidget *widget);
 static void hashDraw(gpointer key, gpointer value, gpointer usre_data);
-static void drawData(CurveFrame *curve, cairo_t *cr, const gchar *name,
+static void drawData(VisuUiCurveFrame *curve, cairo_t *cr, const gchar *name,
 		     const guint *data, double w, double h, double dw,
-		     CurveFrameStyle style);
+		     VisuUiCurveFrameStyle style);
 
-static void curveFrame_class_init (CurveFrameClass *class)
+static void visu_ui_curve_frame_class_init (VisuUiCurveFrameClass *class)
 {
   GtkWidgetClass *widget_class;
 
   widget_class = GTK_WIDGET_CLASS (class);
 
 #if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
-  widget_class->expose_event = curveFrame_expose;
+  widget_class->expose_event = visu_ui_curve_frame_expose;
 #else
-  widget_class->draw = curveFrame_draw;
+  widget_class->draw = visu_ui_curve_frame_drawCairo;
 #endif
-  G_OBJECT_CLASS(class)->dispose  = curveFrame_dispose;
-  G_OBJECT_CLASS(class)->finalize = curveFrame_finalize;
+  G_OBJECT_CLASS(class)->dispose  = visu_ui_curve_frame_dispose;
+  G_OBJECT_CLASS(class)->finalize = visu_ui_curve_frame_finalize;
 }
 
-static void curveFrame_init(CurveFrame *curve)
+static void visu_ui_curve_frame_init(VisuUiCurveFrame *curve)
 {
   curve->dispose_has_run = FALSE;
 
   curve->style = CURVE_LINEAR;
-  curve->scale = logarithm;
+  curve->scale = TOOL_MATRIX_SCALING_LOG;
 
   curve->heights[0] = 0.;
   curve->heights[1] = 5.;
@@ -146,27 +156,27 @@ static void curveFrame_init(CurveFrame *curve)
   curve->data = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_free);
 }
 
-static void curveFrame_dispose(GObject *obj)
+static void visu_ui_curve_frame_dispose(GObject *obj)
 {
   DBG_fprintf(stderr, "Gtk Curve: dispose object %p.\n", (gpointer)obj);
 
-  if (CURVE_FRAME(obj)->dispose_has_run)
+  if (VISU_UI_CURVE_FRAME(obj)->dispose_has_run)
     return;
 
-  CURVE_FRAME(obj)->dispose_has_run = TRUE;
+  VISU_UI_CURVE_FRAME(obj)->dispose_has_run = TRUE;
   /* Chain up to the parent class */
-  G_OBJECT_CLASS(curveFrame_parent_class)->dispose(obj);
+  G_OBJECT_CLASS(visu_ui_curve_frame_parent_class)->dispose(obj);
 }
-static void curveFrame_finalize(GObject *obj)
+static void visu_ui_curve_frame_finalize(GObject *obj)
 {
   g_return_if_fail(obj);
 
   DBG_fprintf(stderr, "Gtk Curve: finalize object %p.\n", (gpointer)obj);
 
-  g_hash_table_destroy(CURVE_FRAME(obj)->data);
+  g_hash_table_destroy(VISU_UI_CURVE_FRAME(obj)->data);
 
   /* Chain up to the parent class */
-  G_OBJECT_CLASS(curveFrame_parent_class)->finalize(obj);
+  G_OBJECT_CLASS(visu_ui_curve_frame_parent_class)->finalize(obj);
 
   DBG_fprintf(stderr, " | freeing ... OK.\n");
 }
@@ -197,7 +207,7 @@ static double tickDist(float dists[2], int length, ToolMatrixScalingFlag scale)
   l = (int)((l < 0.f)?l - 1.f:l);
   s = s / exp(l * log(10));
 
-  if (scale == linear)
+  if (scale == TOOL_MATRIX_SCALING_LINEAR)
     {
       if (s <= 1.25) n = 1.f;
       else if (s <= 3.75) n = 2.5f;
@@ -256,13 +266,13 @@ static void setCairoColor(cairo_t *cr, const gchar *filter, const gchar *data)
 
 struct _drawData
 {
-  CurveFrame *curve;
+  VisuUiCurveFrame *curve;
   cairo_t *cr;
   double w;
   double h;
   double dw;
 };
-static gboolean curveFrame_draw(GtkWidget *wd, cairo_t *cr)
+static gboolean visu_ui_curve_frame_drawCairo(GtkWidget *wd, cairo_t *cr)
 {
 #define BUF 3.
   double x, s, f, g, w, h, dw, dh, xp, wl, hl, yp;
@@ -271,13 +281,13 @@ static gboolean curveFrame_draw(GtkWidget *wd, cairo_t *cr)
   cairo_text_extents_t ext;
   struct _drawData  dt;
   guint *data;
-  CurveFrame *curve;
+  VisuUiCurveFrame *curve;
   GList *eles, *tmpLst;
   GtkAllocation allocation;
 
   DBG_fprintf(stderr, "Gtk Curve: general redraw.\n");
 
-  curve = CURVE_FRAME(wd);
+  curve = VISU_UI_CURVE_FRAME(wd);
   dists = curve->dists;
   heights = curve->heights;
   gtk_widget_get_allocation(wd, &allocation);
@@ -333,7 +343,7 @@ static gboolean curveFrame_draw(GtkWidget *wd, cairo_t *cr)
   cairo_set_line_width(cr, 2.);
   f = w / (dists[1] - dists[0]);
   g = 1.f / f;
-  s = tickDist(dists, w, linear) * f;
+  s = tickDist(dists, w, TOOL_MATRIX_SCALING_LINEAR) * f;
   for (x = - dists[0] * f; x <= w; x += s)
     if (x >= 0.)
       {
@@ -349,17 +359,17 @@ static gboolean curveFrame_draw(GtkWidget *wd, cairo_t *cr)
 		      allocation.height - ext.height - ext.y_bearing - BUF);
 	cairo_show_text(cr, val);
       }
-  if (curve->scale == logarithm)
+  if (curve->scale == TOOL_MATRIX_SCALING_LOG)
     f = h / log(heights[1] + 0.5f);
   else
     {
       f = h / heights[1];
       s = tickDist(heights, h, curve->scale);
     }
-  for (x = (curve->scale == logarithm)?1.:0.; x <= heights[1];
-       x = (curve->scale == logarithm)?x * 10:x + s)
+  for (x = (curve->scale == TOOL_MATRIX_SCALING_LOG)?1.:0.; x <= heights[1];
+       x = (curve->scale == TOOL_MATRIX_SCALING_LOG)?x * 10:x + s)
     {
-      if (curve->scale == logarithm)
+      if (curve->scale == TOOL_MATRIX_SCALING_LOG)
 	{
 	  cairo_set_line_width(cr, 1.);
 	  for (xp = x * 2.; xp < x * 10.; xp += x)
@@ -465,9 +475,9 @@ static void hashDraw(gpointer key, gpointer value, gpointer user_data)
   drawData(dt->curve, dt->cr, (gchar*)key, (guint*)value,
 	   dt->w, dt->h, dt->dw, dt->curve->style);
 }
-static void drawData(CurveFrame *curve, cairo_t *cr, const gchar *name,
+static void drawData(VisuUiCurveFrame *curve, cairo_t *cr, const gchar *name,
 		     const guint *data, double w, double h, double dw,
-		     CurveFrameStyle style)
+		     VisuUiCurveFrameStyle style)
 {
   float step, fx, x, fy, y, val, init;
   int nSteps, i;
@@ -491,7 +501,7 @@ static void drawData(CurveFrame *curve, cairo_t *cr, const gchar *name,
 
   cairo_move_to(cr, dw, h - 0.5);
   fx = w / (curve->dists[1] - curve->dists[0]);
-  if (curve->scale == linear)
+  if (curve->scale == TOOL_MATRIX_SCALING_LINEAR)
     fy = (h - 1.) / (curve->heights[1] - curve->heights[0]);
   else
     fy = (h - 1.) / log(curve->heights[1] + 0.5);
@@ -503,7 +513,7 @@ static void drawData(CurveFrame *curve, cairo_t *cr, const gchar *name,
 	    x = dw + val * fx + bw / 2.;
 	    if (style == CURVE_BAR)
 	      cairo_move_to(cr, x, h - 0.5);
-	    if (curve->scale == linear)
+	    if (curve->scale == TOOL_MATRIX_SCALING_LINEAR)
 	      cairo_line_to(cr, x, h - 0.5 - data[i] * fy);
 	    else
 	      cairo_line_to(cr, x, h - 0.5 - log(MAX(data[i] + 0.5, 1)) * fy);
@@ -520,7 +530,7 @@ static void drawData(CurveFrame *curve, cairo_t *cr, const gchar *name,
       dd.nValues = (guint)nSteps;
       dd.initValue = init;
       dd.stepValue = step;
-      if (curve->scale == linear)
+      if (curve->scale == TOOL_MATRIX_SCALING_LINEAR)
         dd.nNodesEle1 = dd.nNodesEle2 = h / fy / 1.5;
       else
         dd.nNodesEle1 = dd.nNodesEle2 = exp(h / fy / 1.5);
@@ -534,7 +544,7 @@ static void drawData(CurveFrame *curve, cairo_t *cr, const gchar *name,
           x = val * fx + bw / 2. + 1.;
           x = (x + ext.width >= w)?w - ext.width:x;
           y = h - 0.5;
-          if (curve->scale == linear)
+          if (curve->scale == TOOL_MATRIX_SCALING_LINEAR)
             y -= data[pos] * fy;
           else
             y -= log(MAX(data[pos] + 0.5, 1)) * fy;
@@ -550,7 +560,7 @@ static void drawData(CurveFrame *curve, cairo_t *cr, const gchar *name,
 }
 
 #if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
-static gboolean curveFrame_expose(GtkWidget *curve, GdkEventExpose *event)
+static gboolean visu_ui_curve_frame_expose(GtkWidget *curve, GdkEventExpose *event)
 {
   cairo_t *cr;
   gboolean res;
@@ -563,7 +573,7 @@ static gboolean curveFrame_expose(GtkWidget *curve, GdkEventExpose *event)
 		   event->area.width, event->area.height);
   cairo_clip (cr);
         
-  res = curveFrame_draw(curve, cr);
+  res = visu_ui_curve_frame_drawCairo(curve, cr);
 
   cairo_destroy (cr);
 
@@ -571,7 +581,7 @@ static gboolean curveFrame_expose(GtkWidget *curve, GdkEventExpose *event)
 }
 #endif
 /**
- * curveFrameNew:
+ * visu_ui_curve_frame_new:
  * @distMin: a float.
  * @distMax: a float (bigger than @distMin).
  *
@@ -580,26 +590,26 @@ static gboolean curveFrame_expose(GtkWidget *curve, GdkEventExpose *event)
  *
  * Since: 3.6
  *
- * Returns: a newly craeted #CurveFrame widget.
+ * Returns: a newly craeted #VisuUiCurveFrame widget.
  */
-GtkWidget *curveFrameNew(float distMin, float distMax)
+GtkWidget *visu_ui_curve_frame_new(float distMin, float distMax)
 {
   GtkWidget *obj;
 
   g_return_val_if_fail(distMin >= 0.f && distMax > distMin, (GtkWidget*)0);
 
-  obj = g_object_new(CURVE_FRAME_TYPE, NULL);
+  obj = g_object_new(VISU_UI_TYPE_CURVE_FRAME, NULL);
   g_return_val_if_fail(obj, (GtkWidget*)0);
 
-  curveFrame_init(CURVE_FRAME(obj));
-  CURVE_FRAME(obj)->dists[0] = distMin;
-  CURVE_FRAME(obj)->dists[1] = distMax;
+  visu_ui_curve_frame_init(VISU_UI_CURVE_FRAME(obj));
+  VISU_UI_CURVE_FRAME(obj)->dists[0] = distMin;
+  VISU_UI_CURVE_FRAME(obj)->dists[1] = distMax;
 
   return obj;
 }
 /**
- * curveFrameSet_span:
- * @curve: a #CurveFrame widget.
+ * visu_ui_curve_frame_setSpan:
+ * @curve: a #VisuUiCurveFrame widget.
  * @span: two floats.
  *
  * Changes the distance range that is displayed on the curve.
@@ -608,11 +618,11 @@ GtkWidget *curveFrameNew(float distMin, float distMax)
  *
  * Returns: TRUE if the distance displayed is actually changed.
  */
-gboolean curveFrameSet_span(CurveFrame *curve, float span[2])
+gboolean visu_ui_curve_frame_setSpan(VisuUiCurveFrame *curve, float span[2])
 {
   gboolean update;
 
-  g_return_val_if_fail(IS_CURVE_FRAME(curve), FALSE);
+  g_return_val_if_fail(VISU_UI_IS_CURVE_FRAME(curve), FALSE);
   g_return_val_if_fail(span[0] >= 0.f && span[1] > span[0], FALSE);
 
   update = (curve->dists[0] != span[0] ||
@@ -624,24 +634,24 @@ gboolean curveFrameSet_span(CurveFrame *curve, float span[2])
   return update;
 }
 /**
- * curveFrameGet_span:
- * @curve: a #CurveFrame widget.
+ * visu_ui_curve_frame_getSpan:
+ * @curve: a #VisuUiCurveFrame widget.
  * @span: a location for two floats.
  *
  * Retrieves the distances inside which the distribution is displayed.
  *
  * Since: 3.6
  */
-void curveFrameGet_span(CurveFrame *curve, float span[2])
+void visu_ui_curve_frame_getSpan(VisuUiCurveFrame *curve, float span[2])
 {
-  g_return_if_fail(IS_CURVE_FRAME(curve));
+  g_return_if_fail(VISU_UI_IS_CURVE_FRAME(curve));
 
   span[0] = curve->dists[0];
   span[1] = curve->dists[1];
 }
 /**
- * curveFrameHas_data:
- * @curve: a #CurveFrame widget.
+ * visu_ui_curve_frame_hasData:
+ * @curve: a #VisuUiCurveFrame widget.
  *
  * Retrieve if some distance data have been added to the @curve.
  *
@@ -649,29 +659,29 @@ void curveFrameGet_span(CurveFrame *curve, float span[2])
  *
  * Returns: TRUE if the @curve has some data associated.
  */
-gboolean curveFrameHas_data(CurveFrame *curve)
+gboolean visu_ui_curve_frame_hasData(VisuUiCurveFrame *curve)
 {
-  g_return_val_if_fail(IS_CURVE_FRAME(curve), FALSE);
+  g_return_val_if_fail(VISU_UI_IS_CURVE_FRAME(curve), FALSE);
 
   return (g_hash_table_size(curve->data) > 0 && curve->step > 0.f);
 }
 /**
- * curveFrameSet_data:
- * @curve: a #CurveFrame widget.
+ * visu_ui_curve_frame_setData:
+ * @curve: a #VisuUiCurveFrame widget.
  * @step: the stepping distance.
  * @min: the minimum distance for the distribution.
  * @max: the maximum distance for the distribution.
  *
  * Compute and allocate the required size to store distributions, see
- * curveFrameAdd_data() to actually setup the distribution values.
+ * visu_ui_curve_frame_addData() to actually setup the distribution values.
  *
  * Since: 3.6
  */
-void curveFrameSet_data(CurveFrame *curve, float step, float min, float max)
+void visu_ui_curve_frame_setData(VisuUiCurveFrame *curve, float step, float min, float max)
 {
   guint *storage;
 
-  g_return_if_fail(IS_CURVE_FRAME(curve));
+  g_return_if_fail(VISU_UI_IS_CURVE_FRAME(curve));
   g_return_if_fail(min >= 0.f && step >= 0.f && max > min);
 
   g_hash_table_remove_all(curve->data);
@@ -689,8 +699,8 @@ void curveFrameSet_data(CurveFrame *curve, float step, float min, float max)
     redraw(GTK_WIDGET(curve));
 }
 /**
- * curveFrameAdd_data:
- * @curve: a #CurveFrame widget.
+ * visu_ui_curve_frame_addData:
+ * @curve: a #VisuUiCurveFrame widget.
  * @eleName: a string.
  * @lkName: a string.
  * @data: an array of frequencies.
@@ -704,14 +714,14 @@ void curveFrameSet_data(CurveFrame *curve, float step, float min, float max)
  * 
  * Since: 3.6
  */
-void curveFrameAdd_data(CurveFrame *curve, const gchar *eleName, const gchar *lkName,
+void visu_ui_curve_frame_addData(VisuUiCurveFrame *curve, const gchar *eleName, const gchar *lkName,
 			const guint *data, guint nSteps, float init, float step)
 {
   guint max, i;
   guint *storage, *all, *ele1, *ele2;
   gchar *link1, *link2;
 
-  g_return_if_fail(IS_CURVE_FRAME(curve));
+  g_return_if_fail(VISU_UI_IS_CURVE_FRAME(curve));
   g_return_if_fail(eleName && eleName[0] && lkName && lkName[0] && data);
   g_return_if_fail(curve->nSteps == nSteps &&
 		   curve->init == init &&
@@ -734,6 +744,8 @@ void curveFrameAdd_data(CurveFrame *curve, const gchar *eleName, const gchar *lk
     {
       /* Remove it from the element data and all data. */
       g_return_if_fail(all && ele1 && ele2);
+      DBG_fprintf(stderr, "Gtk Curve: remove previously stored"
+                  " values for link '%s'.\n", link1);
       for (i = 0; i < nSteps; i++)
 	{
 	  ele1[i] -= storage[i];
@@ -741,8 +753,8 @@ void curveFrameAdd_data(CurveFrame *curve, const gchar *eleName, const gchar *lk
 	    ele2[i] -= storage[i];
 	  all[i] -= storage[i];
 	}
-      g_free(storage);
     }
+  DBG_fprintf(stderr, "Gtk Curve: copy histo values.\n");
   storage = g_memdup(data, sizeof(int) * nSteps);
   g_hash_table_insert(curve->data, link1, (gpointer)storage);
   if (link2)
@@ -782,8 +794,8 @@ void curveFrameAdd_data(CurveFrame *curve, const gchar *eleName, const gchar *lk
   DBG_fprintf(stderr, " | max %g becomes %g.\n", (double)max, curve->heights[1]);
 }
 /**
- * curveFrameSet_nNodes:
- * @curve: a #CurveFrame widget.
+ * visu_ui_curve_frame_setNNodes:
+ * @curve: a #VisuUiCurveFrame widget.
  * @ele: a string.
  * @n: a number.
  *
@@ -791,11 +803,11 @@ void curveFrameAdd_data(CurveFrame *curve, const gchar *eleName, const gchar *lk
  *
  * Since: 3.6
  */
-void curveFrameSet_nNodes(CurveFrame *curve, const gchar *ele, guint n)
+void visu_ui_curve_frame_setNNodes(VisuUiCurveFrame *curve, const gchar *ele, guint n)
 {
   guint *data;
 
-  g_return_if_fail(IS_CURVE_FRAME(curve));
+  g_return_if_fail(VISU_UI_IS_CURVE_FRAME(curve));
 
   data = (guint*)g_hash_table_lookup(curve->data, ele);
   g_return_if_fail(data);
@@ -809,8 +821,8 @@ void curveFrameSet_nNodes(CurveFrame *curve, const gchar *ele, guint n)
 	      n, ele, data[curve->nSteps - 1]);
 }
 /**
- * curveFrameSet_style:
- * @curve: a #CurveFrame object.
+ * visu_ui_curve_frame_setStyle:
+ * @curve: a #VisuUiCurveFrame object.
  * @style: a style id.
  *
  * Modify the rendering style of the graph.
@@ -819,9 +831,9 @@ void curveFrameSet_nNodes(CurveFrame *curve, const gchar *ele, guint n)
  *
  * Returns: TRUE if the style is actually changed.
  */
-gboolean curveFrameSet_style(CurveFrame *curve, CurveFrameStyle style)
+gboolean visu_ui_curve_frame_setStyle(VisuUiCurveFrame *curve, VisuUiCurveFrameStyle style)
 {
-  g_return_val_if_fail(IS_CURVE_FRAME(curve), FALSE);
+  g_return_val_if_fail(VISU_UI_IS_CURVE_FRAME(curve), FALSE);
 
   if (curve->style == style)
     return FALSE;
@@ -831,8 +843,8 @@ gboolean curveFrameSet_style(CurveFrame *curve, CurveFrameStyle style)
   return TRUE;
 }
 /**
- * curveFrameSet_filter:
- * @curve: a #CurveFrame widget.
+ * visu_ui_curve_frame_setFilter:
+ * @curve: a #VisuUiCurveFrame widget.
  * @filter: a string.
  *
  * Modify the filter used to draw all or single #VisuElement
@@ -842,9 +854,9 @@ gboolean curveFrameSet_style(CurveFrame *curve, CurveFrameStyle style)
  *
  * Returns: TRUE if filter is actually changed.
  */
-gboolean curveFrameSet_filter(CurveFrame *curve, const gchar* filter)
+gboolean visu_ui_curve_frame_setFilter(VisuUiCurveFrame *curve, const gchar* filter)
 {
-  g_return_val_if_fail(IS_CURVE_FRAME(curve), FALSE);
+  g_return_val_if_fail(VISU_UI_IS_CURVE_FRAME(curve), FALSE);
 
   if (curve->filter && filter && !strcmp(curve->filter, filter))
     return FALSE;
@@ -859,20 +871,20 @@ gboolean curveFrameSet_filter(CurveFrame *curve, const gchar* filter)
   return TRUE;
 }
 /**
- * curveFrameSet_highlightRange:
- * @curve: a #CurveFrame widget.
+ * visu_ui_curve_frame_setHighlightRange:
+ * @curve: a #VisuUiCurveFrame widget.
  * @range: two floats.
  *
  * Modify the distance span that is used for highlight rendering and
- * calculation, see curveFrameGet_meanInRange().
+ * calculation, see visu_ui_curve_frame_getMeanInRange().
  *
  * Since: 3.6
  *
  * Returns: TRUE if range is actually changed.
  */
-gboolean curveFrameSet_highlightRange(CurveFrame *curve, float range[2])
+gboolean visu_ui_curve_frame_setHighlightRange(VisuUiCurveFrame *curve, float range[2])
 {
-  g_return_val_if_fail(IS_CURVE_FRAME(curve), FALSE);
+  g_return_val_if_fail(VISU_UI_IS_CURVE_FRAME(curve), FALSE);
 
   DBG_fprintf(stderr, "Gtk Curve: set highlight range to %gx%g.\n",
 	      range[0], range[1]);
@@ -893,20 +905,20 @@ gboolean curveFrameSet_highlightRange(CurveFrame *curve, float range[2])
   return TRUE;
 }
 /**
- * curveFrameGet_highlightRange:
- * @curve: a #CurveFrame widget.
+ * visu_ui_curve_frame_getHighlightRange:
+ * @curve: a #VisuUiCurveFrame widget.
  * @range: a location for two floats.
  *
  * Retrieves the distance span that is used for highlight rendering and
- * calculation, see curveFrameSet_highlightRange().
+ * calculation, see visu_ui_curve_frame_setHighlightRange().
  *
  * Since: 3.6
  *
  * Returns: TRUE if range has been set already.
  */
-gboolean curveFrameGet_highlightRange(CurveFrame *curve, float range[2])
+gboolean visu_ui_curve_frame_getHighlightRange(VisuUiCurveFrame *curve, float range[2])
 {
-  g_return_val_if_fail(IS_CURVE_FRAME(curve), FALSE);
+  g_return_val_if_fail(VISU_UI_IS_CURVE_FRAME(curve), FALSE);
 
   DBG_fprintf(stderr, "Gtk Curve: get highlight range of %gx%g.\n",
 	      curve->hlRange[0], curve->hlRange[1]);
@@ -918,40 +930,40 @@ gboolean curveFrameGet_highlightRange(CurveFrame *curve, float range[2])
   return TRUE;
 }
 /**
- * curveFrameRedraw:
- * @curve: a #CurveFrame widget.
+ * visu_ui_curve_frame_draw:
+ * @curve: a #VisuUiCurveFrame widget.
  *
  * Forces to redraw the widget.
  *
  * Since: 3.6
  */
-void curveFrameRedraw(CurveFrame *curve)
+void visu_ui_curve_frame_draw(VisuUiCurveFrame *curve)
 {
-  g_return_if_fail(IS_CURVE_FRAME(curve));
+  g_return_if_fail(VISU_UI_IS_CURVE_FRAME(curve));
 
   redraw(GTK_WIDGET(curve));
 }
 /**
- * curveFrameGet_integralInRange:
- * @curve: a #CurveFrame widget.
+ * visu_ui_curve_frame_getIntegralInRange:
+ * @curve: a #VisuUiCurveFrame widget.
  * @label: a location to a string.
  *
  * Calculates the integral of the displayed distribution (see
- * curveFrameSet_filter()) in the given range (see
- * curveFrameSet_highlightRange()). If @label is present, it will points on a
+ * visu_ui_curve_frame_setFilter()) in the given range (see
+ * visu_ui_curve_frame_setHighlightRange()). If @label is present, it will points on a
  * string labeling the displayed distribution. The string is owned by V_Sim.
  *
  * Since: 3.6
  *
  * Returns: the integral.
  */
-float curveFrameGet_integralInRange(CurveFrame *curve, gchar **label)
+float visu_ui_curve_frame_getIntegralInRange(VisuUiCurveFrame *curve, gchar **label)
 {
   guint *data;
   float val, d;
   guint i;
   
-  g_return_val_if_fail(IS_CURVE_FRAME(curve), 0.f);
+  g_return_val_if_fail(VISU_UI_IS_CURVE_FRAME(curve), 0.f);
 
   if (label && curve->filter)
     *label = curve->filter;
@@ -979,26 +991,26 @@ float curveFrameGet_integralInRange(CurveFrame *curve, gchar **label)
   return val / (float)data[curve->nSteps - 1];
 }
 /**
- * curveFrameGet_meanInRange:
- * @curve: a #CurveFrame widget.
+ * visu_ui_curve_frame_getMeanInRange:
+ * @curve: a #VisuUiCurveFrame widget.
  * @label: a location to a string.
  *
  * Calculates the average distance value of the displayed distribution (see
- * curveFrameSet_filter()) in the given range (see
- * curveFrameSet_highlightRange()). If @label is present, it will points on a
+ * visu_ui_curve_frame_setFilter()) in the given range (see
+ * visu_ui_curve_frame_setHighlightRange()). If @label is present, it will points on a
  * string labeling the displayed distribution. The string is owned by V_Sim.
  *
  * Since: 3.6
  *
  * Returns: the average distance value.
  */
-float curveFrameGet_meanInRange(CurveFrame *curve, gchar **label)
+float visu_ui_curve_frame_getMeanInRange(VisuUiCurveFrame *curve, gchar **label)
 {
   guint *data;
   float val, d;
   guint i, n;
   
-  g_return_val_if_fail(IS_CURVE_FRAME(curve), 0.f);
+  g_return_val_if_fail(VISU_UI_IS_CURVE_FRAME(curve), 0.f);
 
   if (label && curve->filter)
     *label = curve->filter;
