@@ -45,7 +45,6 @@
 
 #include <visu_gtk.h>
 #include "gtk_dumpDialogWidget.h"
-#include <opengl.h>
 #include <support.h>
 
 /**
@@ -63,23 +62,23 @@
  * <para>This widget is also a dialog, and should be used with
  * gtk_dialog_run(). After the response GTK_RESPONSE_ACCEPT has been
  * recieved, one can grep the selected filename with
- * dumpDialogGet_fileName(). The dialog does not call the exporting
+ * visu_ui_dump_dialog_getFilename(). The dialog does not call the exporting
  * routine by itself, the calling method should take care of
  * that. When doing it, the filechoosing part should be made
- * insensitive, using dumpDialogStart() and the progress bar should be
+ * insensitive, using visu_ui_dump_dialog_start() and the progress bar should be
  * updated accordingly (get it with
- * dumpDialogGet_progressBar()).</para>
+ * visu_ui_dump_dialog_getProgressBar()).</para>
  *
  * <para>The user interface propose also to change the size  (see
- * dumpDialogGet_heightValue() and dumpDialogGet_widthValue()) and if
+ * visu_ui_dump_dialog_getHeight() and visu_ui_dump_dialog_getWidth()) and if
  * some options are associated to a file format, these options are
  * displayed.</para>
  */
 
-static void dumpDialog_dispose (GObject *obj);
-static void dumpDialog_finalize(GObject *obj);
+static void visu_ui_dump_dialog_dispose (GObject *obj);
+static void visu_ui_dump_dialog_finalize(GObject *obj);
 
-struct _DumpDialog
+struct _VisuUiDumpDialog
 {
   GtkDialog dialog;
 
@@ -104,7 +103,7 @@ struct _DumpDialog
   gboolean dispose_has_run;
 };
 
-struct _DumpDialogClass
+struct _VisuUiDumpDialogClass
 {
   GtkDialogClass parent_class;
 
@@ -113,7 +112,7 @@ struct _DumpDialogClass
 
   guint formatId;
 
-  void (*dumpDialog) (DumpDialog *dump);
+  void (*dumpDialog) (VisuUiDumpDialog *dump);
 };
 
 /* Local callbacks */
@@ -121,26 +120,26 @@ static void onWidthHeightChanged(GtkSpinButton *spin, gpointer data);
 static void onSpinPropertyChange(GtkSpinButton *spin, gpointer data);
 static void onCheckPropertyChange(GtkToggleButton *toggle, gpointer data);
 static void onComboToolFileFormatChange(GtkComboBox *combo, gpointer data);
-static void onDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *data);
+static void onVisuUiDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *data);
 
-G_DEFINE_TYPE(DumpDialog, dumpDialog, GTK_TYPE_DIALOG)
+G_DEFINE_TYPE(VisuUiDumpDialog, visu_ui_dump_dialog, GTK_TYPE_DIALOG)
 
-static void dumpDialog_class_init(DumpDialogClass *klass)
+static void visu_ui_dump_dialog_class_init(VisuUiDumpDialogClass *klass)
 {
-  DBG_fprintf(stderr, "Gtk DumpDialog: creating the class of the widget.\n");
+  DBG_fprintf(stderr, "Gtk VisuUiDumpDialog: creating the class of the widget.\n");
 
   klass->width  = 0;
   klass->height = 0;
   klass->current_dir = (gchar*)0;
   klass->formatId = 0;
 
-  G_OBJECT_CLASS(klass)->dispose = dumpDialog_dispose;
-  G_OBJECT_CLASS(klass)->finalize = dumpDialog_finalize;
+  G_OBJECT_CLASS(klass)->dispose = visu_ui_dump_dialog_dispose;
+  G_OBJECT_CLASS(klass)->finalize = visu_ui_dump_dialog_finalize;
 }
 
-static void dumpDialog_init(DumpDialog *dumpDialog)
+static void visu_ui_dump_dialog_init(VisuUiDumpDialog *dumpDialog)
 {
-  DBG_fprintf(stderr, "Gtk DumpDialog: initializing new object (%p).\n",
+  DBG_fprintf(stderr, "Gtk VisuUiDumpDialog: initializing new object (%p).\n",
 	      (gpointer)dumpDialog);
 
   dumpDialog->selectedToolFileFormat = (VisuDump*)0;
@@ -148,45 +147,62 @@ static void dumpDialog_init(DumpDialog *dumpDialog)
   dumpDialog->dataObj = (VisuData*)0;
 
   g_signal_connect(G_OBJECT(dumpDialog), "response",
-		   G_CALLBACK(onDumpDialogResponse), (gpointer)dumpDialog);
+		   G_CALLBACK(onVisuUiDumpDialogResponse), (gpointer)dumpDialog);
 }
 
-static void dumpDialog_dispose(GObject *obj)
+static void visu_ui_dump_dialog_dispose(GObject *obj)
 {
-  DBG_fprintf(stderr, "Gtk DumpDialog: dispose object %p.\n", (gpointer)obj);
+  DBG_fprintf(stderr, "Gtk VisuUiDumpDialog: dispose object %p.\n", (gpointer)obj);
 
-  if (DUMP_DIALOG(obj)->dispose_has_run)
+  if (VISU_UI_DUMP_DIALOG(obj)->dispose_has_run)
     return;
 
-  DUMP_DIALOG(obj)->dispose_has_run = TRUE;
+  VISU_UI_DUMP_DIALOG(obj)->dispose_has_run = TRUE;
   /* Chain up to the parent class */
-  G_OBJECT_CLASS(dumpDialog_parent_class)->dispose(obj);
+  G_OBJECT_CLASS(visu_ui_dump_dialog_parent_class)->dispose(obj);
 }
-static void dumpDialog_finalize(GObject *obj)
+static void visu_ui_dump_dialog_finalize(GObject *obj)
 {
-  DumpDialog *dialog;
+  VisuUiDumpDialog *dialog;
 
   g_return_if_fail(obj);
 
-  DBG_fprintf(stderr, "Gtk DumpDialog: finalize object %p.\n", (gpointer)obj);
+  DBG_fprintf(stderr, "Gtk VisuUiDumpDialog: finalize object %p.\n", (gpointer)obj);
 
-  dialog = DUMP_DIALOG(obj);
+  dialog = VISU_UI_DUMP_DIALOG(obj);
   if (dialog->dumpFileName)
     /* Free the stored filename. */
     g_free(dialog->dumpFileName);
 
   /* Chain up to the parent class */
-  G_OBJECT_CLASS(dumpDialog_parent_class)->finalize(obj);
+  G_OBJECT_CLASS(visu_ui_dump_dialog_parent_class)->finalize(obj);
 
-  DBG_fprintf(stderr, "Gtk DumpDialog: freeing ... OK.\n");
+  DBG_fprintf(stderr, "Gtk VisuUiDumpDialog: freeing ... OK.\n");
 }
 
-
-GtkWidget* dumpDialog_new(VisuData *dataObj, GtkWindow *parent,
-			  const gchar *suggestedFilename)
+/**
+ * visu_ui_dump_dialog_new :
+ * @dataObj: (allow-none): a #VisuData object (can be NULL) ;
+ * @parent: (allow-none): the parent window ;
+ * @suggestedFilename: (allow-none): a string or NULL.
+ * @suggestedWidth: a positive suggested width for exportation or a
+ * negative value to get the default.
+ * @suggestedHeight: idem for height.
+ *
+ * A #VisuUiDumpDialog widget is complete dialog window widget, but it is already
+ * prepared for dumping, proposing known file formats. It is usefull to get
+ * an filename to export to. It has also a progress bar that can illustrate
+ * the process. The given @dataObj argument is used to initialize some
+ * values related to the data to be dumped.
+ *
+ * Returns: a newly created #VisuUiDumpDialog widget.
+ */
+GtkWidget* visu_ui_dump_dialog_new(VisuData *dataObj, GtkWindow *parent,
+                                   const gchar *suggestedFilename,
+                                   gint suggestedWidth, gint suggestedHeight)
 {
-  DumpDialog *dumpDialog;
-  DumpDialogClass *klass;
+  VisuUiDumpDialog *dumpDialog;
+  VisuUiDumpDialogClass *klass;
   gchar *directory;
   const gchar *filename, *labelType;
   GList *format;
@@ -194,22 +210,16 @@ GtkWidget* dumpDialog_new(VisuData *dataObj, GtkWindow *parent,
   GtkWidget *label;
   GtkWidget *wd;
   GtkWidget *vbox;
-  VisuOpenGLView *view;
-
-  if (dataObj)
-    view = visu_data_getOpenGLView(dataObj);
-  else
-    view = (VisuOpenGLView*)0;
 
   if (!parent)
-    parent = visuGtkGet_render();
+    parent = visu_ui_getRenderWindow();
 
-  DBG_fprintf(stderr, "Gtk DumpDialog: creating a new DumpDialog object.\n");
+  DBG_fprintf(stderr, "Gtk VisuUiDumpDialog: creating a new VisuUiDumpDialog object.\n");
 
-  dumpDialog = DUMP_DIALOG(g_object_new(DUMP_DIALOG_TYPE, NULL));
+  dumpDialog = VISU_UI_DUMP_DIALOG(g_object_new(VISU_UI_TYPE_DUMP_DIALOG, NULL));
   gtk_window_set_title(GTK_WINDOW(dumpDialog),
 		       _("Export to a file (image, atomic structures...)"));
-  klass = DUMP_DIALOG_CLASS(G_OBJECT_GET_CLASS(dumpDialog));
+  klass = VISU_UI_DUMP_DIALOG_CLASS(G_OBJECT_GET_CLASS(dumpDialog));
   /* This is to avoid a bug in gtk 2.4 */
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   gtk_window_set_modal(GTK_WINDOW(dumpDialog), TRUE);
@@ -224,6 +234,7 @@ GtkWidget* dumpDialog_new(VisuData *dataObj, GtkWindow *parent,
 
   /* Create the file chooser part. */
   dumpDialog->fileChooser = gtk_file_chooser_widget_new(GTK_FILE_CHOOSER_ACTION_SAVE);
+  gtk_widget_set_size_request(dumpDialog->fileChooser, -1, 350);
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 7
   gtk_file_chooser_set_do_overwrite_confirmation
     (GTK_FILE_CHOOSER(dumpDialog->fileChooser), TRUE);
@@ -238,7 +249,7 @@ GtkWidget* dumpDialog_new(VisuData *dataObj, GtkWindow *parent,
   dumpDialog->dataObj = dataObj;
   if (dataObj)
     filename = (const gchar*)g_object_get_data(G_OBJECT(dataObj),
-					       "dumpDialog_filename");
+					       "visu_ui_dump_dialog_filename");
   if (!filename)
     filename = suggestedFilename;
   if (filename)
@@ -291,9 +302,9 @@ GtkWidget* dumpDialog_new(VisuData *dataObj, GtkWindow *parent,
   if (klass->width > 0)
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(dumpDialog->spinWidth),
 			      (gdouble)klass->width);
-  else if (view)
+  else if (suggestedWidth > 0)
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(dumpDialog->spinWidth),
-			      (gdouble)view->window->width);
+			      (gdouble)suggestedWidth);
   gtk_box_pack_start(GTK_BOX(hbox), dumpDialog->spinWidth, FALSE, FALSE, 0);
   label = gtk_label_new(_("px"));
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -306,9 +317,9 @@ GtkWidget* dumpDialog_new(VisuData *dataObj, GtkWindow *parent,
   if (klass->height > 0)
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(dumpDialog->spinHeight),
 			      (gdouble)klass->height);
-  else if (view)
+  else if (suggestedHeight > 0)
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(dumpDialog->spinHeight),
-			      (gdouble)view->window->height);
+			      (gdouble)suggestedHeight);
   gtk_box_pack_start(GTK_BOX(hbox), dumpDialog->spinHeight, FALSE, FALSE, 0);
   label = gtk_label_new(_("px"));
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -347,7 +358,7 @@ GtkWidget* dumpDialog_new(VisuData *dataObj, GtkWindow *parent,
 
   /* Setting default values. */
   gtk_widget_set_name(GTK_WIDGET(dumpDialog), "filesel");
-  directory = visuGtkGet_lastOpenDirectory();
+  directory = visu_ui_getLastOpenDirectory();
   if (klass->current_dir)
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dumpDialog->fileChooser),
 					klass->current_dir);
@@ -356,7 +367,7 @@ GtkWidget* dumpDialog_new(VisuData *dataObj, GtkWindow *parent,
 					directory);
   for (format = visu_dump_getAllModules(); format; format = g_list_next(format))
     {
-      labelType = tool_file_format_getLabel(((VisuDump*)format->data)->fileType);
+      labelType = tool_file_format_getLabel(TOOL_FILE_FORMAT(format->data));
       if (labelType)
 	gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(dumpDialog->comboType),
                                   (const gchar*)0, labelType);
@@ -375,109 +386,110 @@ static void onSpinPropertyChange(GtkSpinButton *spin, gpointer data)
 {
   GValue *val;
 
-  val = tool_option_getValue((ToolOption*)data);
+  val = (GValue*)data;
   g_value_set_int(val, (int)gtk_spin_button_get_value(spin));
+  DBG_fprintf(stderr, "Gtk VisuUiDumpDialog: set property spin to %d.\n",
+              g_value_get_int(val));
 }
 static void onCheckPropertyChange(GtkToggleButton *toggle, gpointer data)
 {
   GValue *val;
 
-  val = tool_option_getValue((ToolOption*)data);
+  val = (GValue*)data;
   g_value_set_boolean(val, gtk_toggle_button_get_active(toggle));
-  DBG_fprintf(stderr, "Gtk DumpDialog: set property '%s' to %d.\n",
-              tool_option_getName((ToolOption*)data), g_value_get_boolean(val));
+  DBG_fprintf(stderr, "Gtk VisuUiDumpDialog: set property check to %d.\n",
+              g_value_get_boolean(val));
 }
 static void onComboToolFileFormatChange(GtkComboBox *combo, gpointer data)
 {
   int formatInt, i;
   GList *dumpTypes;
-  const GList *formatProperties;
+  ToolFileFormatIter iter;
   GtkWidget *wd, *label, *hbox, *vbox;
-  GValue *val;
 
-  g_return_if_fail(IS_DUMP_DIALOG(data));
+  g_return_if_fail(VISU_UI_IS_DUMP_DIALOG(data));
 
   /* Empty the expander for properties. */
-  wd = gtk_bin_get_child(GTK_BIN(DUMP_DIALOG(data)->expanderToolFileFormat));
+  wd = gtk_bin_get_child(GTK_BIN(VISU_UI_DUMP_DIALOG(data)->expanderToolFileFormat));
   if (wd)
     gtk_widget_destroy(wd);
 
   dumpTypes = visu_dump_getAllModules();
   formatInt = gtk_combo_box_get_active(combo);
-  DUMP_DIALOG_GET_CLASS(data)->formatId = (guint)formatInt;
-  DBG_fprintf(stderr, "Gtk DumpDialog: On file format change (%d).\n", formatInt);
+  VISU_UI_DUMP_DIALOG_GET_CLASS(data)->formatId = (guint)formatInt;
+  DBG_fprintf(stderr, "Gtk VisuUiDumpDialog: On file format change (%d).\n", formatInt);
   /* Select auto file format -> no properties. */
   if (formatInt == 0)
     {
-      gtk_widget_set_sensitive(DUMP_DIALOG(data)->expanderToolFileFormat, FALSE);
-      gtk_widget_set_sensitive(DUMP_DIALOG(data)->checkFileExtension, FALSE);
+      gtk_widget_set_sensitive(VISU_UI_DUMP_DIALOG(data)->expanderToolFileFormat, FALSE);
+      gtk_widget_set_sensitive(VISU_UI_DUMP_DIALOG(data)->checkFileExtension, FALSE);
       return;
     }
   else
     /* Search for the selected property. */
     for(i = 0; i < formatInt - 1; i++) dumpTypes = g_list_next(dumpTypes);
   /* Set the check box for extension auto completion. */
-  gtk_widget_set_sensitive(DUMP_DIALOG(data)->checkFileExtension, TRUE);
+  gtk_widget_set_sensitive(VISU_UI_DUMP_DIALOG(data)->checkFileExtension, TRUE);
   /* Get properties if exist for this format. */
-  formatProperties = tool_file_format_getPropertyList(((VisuDump*)(dumpTypes->data))->fileType);
-  if (!formatProperties)
+  iter.lst = (GList*)0;
+  tool_file_format_iterNextProperty(TOOL_FILE_FORMAT(dumpTypes->data), &iter);
+  if (!iter.lst)
     {
-      gtk_widget_set_sensitive(DUMP_DIALOG(data)->expanderToolFileFormat, FALSE);
+      gtk_widget_set_sensitive(VISU_UI_DUMP_DIALOG(data)->expanderToolFileFormat, FALSE);
       return;
     }
-  gtk_widget_set_sensitive(DUMP_DIALOG(data)->expanderToolFileFormat, TRUE);
+  gtk_widget_set_sensitive(VISU_UI_DUMP_DIALOG(data)->expanderToolFileFormat, TRUE);
   vbox = gtk_vbox_new(FALSE, 0);
-  gtk_container_add(GTK_CONTAINER(DUMP_DIALOG(data)->expanderToolFileFormat), vbox);
-  while (formatProperties)
+  gtk_container_add(GTK_CONTAINER(VISU_UI_DUMP_DIALOG(data)->expanderToolFileFormat), vbox);
+  iter.lst = (GList*)0;
+  for (tool_file_format_iterNextProperty(TOOL_FILE_FORMAT(dumpTypes->data), &iter); iter.lst;
+       tool_file_format_iterNextProperty(TOOL_FILE_FORMAT(dumpTypes->data), &iter))
     {
       hbox = gtk_hbox_new(FALSE, 0);
       gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
-      label = gtk_label_new(tool_option_getLabel((ToolOption*)formatProperties->data));
+      label = gtk_label_new(iter.label);
       gtk_misc_set_alignment(GTK_MISC(label), 1., 0.5);
       gtk_misc_set_padding(GTK_MISC(label), 10, 0);
       gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
-      val = tool_option_getValue((ToolOption*)formatProperties->data);
-      switch (tool_option_getType((ToolOption*)formatProperties->data))
+      switch (G_VALUE_TYPE(iter.val))
 	{
 	case G_TYPE_INT:
 	  wd = gtk_spin_button_new_with_range(0., 100., 1.);
-	  gtk_spin_button_set_value(GTK_SPIN_BUTTON(wd), (gdouble)g_value_get_int(val));
+	  gtk_spin_button_set_value(GTK_SPIN_BUTTON(wd), (gdouble)g_value_get_int(iter.val));
 	  gtk_box_pack_start(GTK_BOX(hbox), wd, FALSE, FALSE, 0);
 	  g_signal_connect(G_OBJECT(wd), "value-changed",
-			   G_CALLBACK(onSpinPropertyChange), formatProperties->data);
+			   G_CALLBACK(onSpinPropertyChange), iter.val);
 	  break;
 	case G_TYPE_BOOLEAN:
 	  wd = gtk_check_button_new();
-	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wd), g_value_get_boolean(val));
+	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wd), g_value_get_boolean(iter.val));
 	  gtk_box_pack_start(GTK_BOX(hbox), wd, FALSE, FALSE, 0);
 	  g_signal_connect(G_OBJECT(wd), "toggled",
-			   G_CALLBACK(onCheckPropertyChange), formatProperties->data);
+			   G_CALLBACK(onCheckPropertyChange), iter.val);
 	  break;
 	default:
 	  g_warning("Unknown, or nsupprted file format property"
 		    " given to 'onComboToolFileFormatChange'.");
 	};
-
-      formatProperties = g_list_next(formatProperties);
     }
   gtk_widget_show_all(vbox);
   /* Expand the option expander. */
-  gtk_expander_set_expanded(GTK_EXPANDER(DUMP_DIALOG(data)->expanderToolFileFormat), TRUE);
+  gtk_expander_set_expanded(GTK_EXPANDER(VISU_UI_DUMP_DIALOG(data)->expanderToolFileFormat), TRUE);
 }
-static void onDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *data)
+static void onVisuUiDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *data)
 {
   gchar *filename;
   int formatInt;
   gchar *ext, *pattern;
   GList *dumpTypes;
-  DumpDialog *dumpDialog;
-  DumpDialogClass *klass;
+  VisuUiDumpDialog *dumpDialog;
+  VisuUiDumpDialogClass *klass;
 
-  g_return_if_fail(IS_DUMP_DIALOG(data));
+  g_return_if_fail(VISU_UI_IS_DUMP_DIALOG(data));
 
-  dumpDialog = DUMP_DIALOG(data);
+  dumpDialog = VISU_UI_DUMP_DIALOG(data);
 
-  DBG_fprintf(stderr, "Gtk DumpDialog: catch the 'response' signal:"
+  DBG_fprintf(stderr, "Gtk VisuUiDumpDialog: catch the 'response' signal:"
 	      " %d (ACCEPT is %d).\n", id, GTK_RESPONSE_ACCEPT);
   /* Get the filename. */
   filename = (gchar*)0;
@@ -489,7 +501,7 @@ static void onDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *data)
       if (!filename)
 	{
 	  /* Autodetect failed, no format match the given filename */
-	  visuGtkRaise_warning(_("Saving a file"),
+	  visu_ui_raiseWarning(_("Saving a file"),
 			       _("No filename chosen."),
 			       GTK_WINDOW(dialog));
 	  g_signal_stop_emission_by_name(G_OBJECT(dumpDialog), "response");
@@ -504,25 +516,25 @@ static void onDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *data)
 	/* The automatic format has been selected, we look in the pattern list to
 	   find a matching pattern. */
 	while (dumpTypes && !tool_file_format_match
-               ( ((VisuDump*)dumpTypes->data)->fileType, filename))
+               (TOOL_FILE_FORMAT(dumpTypes->data), filename))
 	  dumpTypes = g_list_next(dumpTypes);
       else
         dumpTypes = g_list_nth(dumpTypes, formatInt - 1);
       if (!dumpTypes)
 	{
 	  /* Autodetect failed, no format match the given filename */
-	  visuGtkRaise_warning(_("Saving a file"),
+	  visu_ui_raiseWarning(_("Saving a file"),
 			       _("The filename doesn't match any known format."),
 			       GTK_WINDOW(dialog));
 	  g_free(filename);
 	  g_signal_stop_emission_by_name(G_OBJECT(dumpDialog), "response");
 	  return;
 	}
-      DBG_fprintf(stderr, "Gtk DumpDialog: export to dump %p.\n", dumpTypes->data);
+      DBG_fprintf(stderr, "Gtk VisuUiDumpDialog: export to dump %p.\n", dumpTypes->data);
 
       /* Special warning for non bitmap exportation with translations. */
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 17
-      if (!((VisuDump*)dumpTypes->data)->bitmap &&
+      if (!visu_dump_getBitmapStatus(VISU_DUMP(dumpTypes->data)) &&
           visu_data_getTranslationStatus(dumpDialog->dataObj) &&
           !gtk_widget_get_visible(dumpDialog->infoBar))
         {
@@ -536,12 +548,11 @@ static void onDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *data)
       if (formatInt > 0 &&
 	  gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(dumpDialog->checkFileExtension)))
 	{
-	  if (tool_file_format_canMatch(((VisuDump*)dumpTypes->data)->fileType) &&
-              !tool_file_format_match( ((VisuDump*)dumpTypes->data)->fileType,
-                                       filename))
+	  if (tool_file_format_canMatch(TOOL_FILE_FORMAT(dumpTypes->data)) &&
+              !tool_file_format_match(TOOL_FILE_FORMAT(dumpTypes->data), filename))
 	    {
 	      pattern = (gchar*) tool_file_format_getFilePatterns
-                (((VisuDump*)dumpTypes->data)->fileType)->data;
+                (TOOL_FILE_FORMAT(dumpTypes->data))->data;
 	      ext = g_strrstr(pattern, ".");
 	      dumpDialog->dumpFileName = g_strdup_printf("%s%s", filename, ext);
 	      g_free(filename);
@@ -551,16 +562,16 @@ static void onDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *data)
 	}
       else
 	dumpDialog->dumpFileName = filename;
-      dumpDialog->selectedToolFileFormat = (VisuDump*)dumpTypes->data;
-      DBG_fprintf(stderr, "Gtk DumpDialog: '%s' file format chosen.\n",
-		  tool_file_format_getName(dumpDialog->selectedToolFileFormat->fileType));
+      dumpDialog->selectedToolFileFormat = VISU_DUMP(dumpTypes->data);
+      DBG_fprintf(stderr, "Gtk VisuUiDumpDialog: '%s' file format chosen.\n",
+		  tool_file_format_getName(TOOL_FILE_FORMAT(dumpDialog->selectedToolFileFormat)));
       /* Save the filename in a property of the VisuData object. */
       filename = g_path_get_basename(dumpDialog->dumpFileName);
-      g_object_set_data_full(G_OBJECT(dumpDialog->dataObj), "dumpDialog_filename",
+      g_object_set_data_full(G_OBJECT(dumpDialog->dataObj), "visu_ui_dump_dialog_filename",
 			     (gpointer)filename, g_free);
 
       /* Save the dirname in the class. */
-      klass = DUMP_DIALOG_CLASS(G_OBJECT_GET_CLASS(dumpDialog));
+      klass = VISU_UI_DUMP_DIALOG_CLASS(G_OBJECT_GET_CLASS(dumpDialog));
       if (klass->current_dir)
 	g_free(klass->current_dir);
       klass->current_dir = g_path_get_dirname(dumpDialog->dumpFileName);
@@ -574,51 +585,43 @@ static void onWidthHeightChanged(GtkSpinButton *spin, gpointer data)
 /******************/
 /* Public methods */
 /******************/
-gchar* dumpDialogGet_fileName(DumpDialog *dialog)
+gchar* visu_ui_dump_dialog_getFilename(VisuUiDumpDialog *dialog)
 {
   g_return_val_if_fail(dialog, (gchar*)0);
   return dialog->dumpFileName;
 }
-VisuDump* dumpDialogGet_dumpType(DumpDialog *dialog)
+VisuDump* visu_ui_dump_dialog_getType(VisuUiDumpDialog *dialog)
 {
   g_return_val_if_fail(dialog, (VisuDump*)0);
   return dialog->selectedToolFileFormat;
 }
-ToolFileFormat* dumpDialogGet_fileFormat(DumpDialog *dialog)
-{
-  g_return_val_if_fail(dialog, (ToolFileFormat*)0);
-  if (dialog->selectedToolFileFormat)
-    return dialog->selectedToolFileFormat->fileType;
-  else
-    return (ToolFileFormat*)0;
-}
-GtkProgressBar* dumpDialogGet_progressBar(DumpDialog *dialog)
+GtkProgressBar* visu_ui_dump_dialog_getProgressBar(VisuUiDumpDialog *dialog)
 {
   g_return_val_if_fail(dialog, (GtkProgressBar*)0);
   return GTK_PROGRESS_BAR(dialog->progressBar);
 }
-GtkButton* dumpDialogGet_cancelButton(DumpDialog *dialog)
+GtkButton* visu_ui_dump_dialog_getCancelButton(VisuUiDumpDialog *dialog)
 {
   g_return_val_if_fail(dialog, (GtkButton*)0);
   return GTK_BUTTON(dialog->cancelButton);
 }
-gint dumpDialogGet_widthValue(DumpDialog *dialog)
+gint visu_ui_dump_dialog_getWidth(VisuUiDumpDialog *dialog)
 {
   g_return_val_if_fail(dialog, 0);
   return (gint)gtk_spin_button_get_value(GTK_SPIN_BUTTON(dialog->spinWidth));
 }
-gint dumpDialogGet_heightValue(DumpDialog *dialog)
+gint visu_ui_dump_dialog_getHeight(VisuUiDumpDialog *dialog)
 {
   g_return_val_if_fail(dialog, 0);
   return (gint)gtk_spin_button_get_value(GTK_SPIN_BUTTON(dialog->spinHeight));
 }
-void dumpDialogStart(DumpDialog *dialog)
+void visu_ui_dump_dialog_start(VisuUiDumpDialog *dialog)
 {
   /* Put everything except the progress bar insensitive */
   gtk_widget_set_sensitive(dialog->fileChooser, FALSE);
   gtk_widget_set_sensitive(dialog->hBoxOptions, FALSE);
 }
-void dumpDialogStop(DumpDialog *dialog)
+void visu_ui_dump_dialog_stop(VisuUiDumpDialog *dialog)
 {
   /* Put everything except the progress bar sensitive */
   gtk_widget_set_sensitive(dialog->fileChooser, TRUE);
