@@ -43,6 +43,7 @@
 */
 #include <gtk/gtk.h>
 
+#include <support.h>
 #include "gtk_lineObjectWidget.h"
 #include "gtk_stippleComboBoxWidget.h"
 #include "gtk_colorComboBoxWidget.h"
@@ -50,17 +51,11 @@
 
 /**
  * SECTION:gtk_lineObjectWidget
- * @short_description: Defines a specialised #GtkHBox to choose
+ * @short_description: Defines a specialised #GtkBox to choose
  * all characteristic of lines.
- * @see_also: #ColorComboBox and #StippleComboBox
+ * @see_also: #VisuUiColorCombobox and #VisuUiStippleCombobox
  *
- * <para>This widget looks like a #GtkComboBox and it displays a list
- * of preset patterns for line. These patterns are defined by a
- * guint16 value that is given to OpenGL for line stipple.</para>
- * <para>This widget can emit a #LineObject::stipple-selected
- * signal that is a wrapper around the #GtkComboBox::changed signal,
- * but it is emitted only when a stipple is selected and this stipple
- * is passed to the call back.</para>
+ * <para></para>
  *
  * Since: 3.4
  */
@@ -73,12 +68,19 @@ enum {
   LAST_SIGNAL
 };
 
-static void lineObject_dispose (GObject *obj);
-static void lineObject_finalize(GObject *obj);
+static void visu_ui_line_dispose (GObject *obj);
+static void visu_ui_line_finalize(GObject *obj);
 
-static guint lineObject_signals[LAST_SIGNAL] = { 0 };
+static guint visu_ui_line_signals[LAST_SIGNAL] = { 0 };
 
-struct _LineObject
+/**
+ * VisuUiLine:
+ *
+ * Private structure to store informations of a #VisuUiLine object.
+ *
+ * Since: 3.4
+ */
+struct _VisuUiLine
 {
   GtkVBox box;
 
@@ -98,140 +100,154 @@ struct _LineObject
   /* Memory gestion. */
   gboolean dispose_has_run;
 };
-
-struct _LineObjectClass
+/**
+ * VisuUiLineClass
+ *
+ * Private structure to store informations of a #VisuUiLineClass object.
+ *
+ * Since: 3.4
+ */
+struct _VisuUiLineClass
 {
   GtkComboBoxClass parent_class;
 
-  void (*lineObject) (LineObject *box);
+  void (*lineObject) (VisuUiLine *box);
 };
 
 /* Local callbacks. */
-static void onUseChanged(GtkCheckButton *check, LineObject *line);
-static void onWidthChanged(GtkSpinButton *spin, LineObject *line);
-static void onStippleChanged(StippleComboBox *wd, guint stipple, LineObject *line);
-static void onRGBValueChanged(GtkRange *rg, LineObject *line);
-static void onAddClicked(GtkButton *bt, LineObject *line);
-static void onColorChanged(ColorComboBox *combo, ToolColor *color, LineObject *line);
+static void onUseChanged(GtkCheckButton *check, VisuUiLine *line);
+static void onWidthChanged(GtkSpinButton *spin, VisuUiLine *line);
+static void onStippleChanged(VisuUiStippleCombobox *wd, guint stipple, VisuUiLine *line);
+static void onRGBValueChanged(GtkRange *rg, VisuUiLine *line);
+static void onAddClicked(GtkButton *bt, VisuUiLine *line);
+static void onColorChanged(VisuUiColorCombobox *combo, ToolColor *color, VisuUiLine *line);
 
 /* Local methods. */
+/**
+ * visu_ui_line_get_type
+ *
+ * #GType are unique numbers to identify objects.
+ *
+ * Returns: the #GType associated with #VisuUiLine objects.
+ *
+ * Since: 3.4
+ */
+G_DEFINE_TYPE(VisuUiLine, visu_ui_line, GTK_TYPE_VBOX)
 
-G_DEFINE_TYPE(LineObject, lineObject, GTK_TYPE_VBOX)
-
-static void lineObject_class_init(LineObjectClass *klass)
+static void visu_ui_line_class_init(VisuUiLineClass *klass)
 {
-  DBG_fprintf(stderr, "Gtk LineObject: creating the class of the widget.\n");
+  DBG_fprintf(stderr, "Gtk VisuUiLine: creating the class of the widget.\n");
   DBG_fprintf(stderr, "                     - adding new signals ;\n");
   /**
-   * LineObject::use-changed:
-   * @line: the #LineObject that emits the signal ;
+   * VisuUiLine::use-changed:
+   * @line: the #VisuUiLine that emits the signal ;
    * @used: TRUE if the line is used.
    *
    * This signal is emitted when the usage check box is changed.
    *
    * Since: 3.4
    */
-  lineObject_signals[LINE_USE_CHANGED_SIGNAL] =
+  visu_ui_line_signals[LINE_USE_CHANGED_SIGNAL] =
     g_signal_new ("use-changed",
 		  G_TYPE_FROM_CLASS (klass),
 		  G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION,
-		  G_STRUCT_OFFSET (LineObjectClass, lineObject),
+		  G_STRUCT_OFFSET (VisuUiLineClass, lineObject),
 		  NULL, 
 		  NULL,                
 		  g_cclosure_marshal_VOID__BOOLEAN,
 		  G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
   /**
-   * LineObject::width-changed:
-   * @line: the #LineObject that emits the signal ;
+   * VisuUiLine::width-changed:
+   * @line: the #VisuUiLine that emits the signal ;
    * @width: the new width.
    *
    * This signal is emitted when the width of the line is changed.
    *
    * Since: 3.4
    */
-  lineObject_signals[LINE_WIDTH_CHANGED_SIGNAL] =
+  visu_ui_line_signals[LINE_WIDTH_CHANGED_SIGNAL] =
     g_signal_new ("width-changed",
 		  G_TYPE_FROM_CLASS (klass),
 		  G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION,
-		  G_STRUCT_OFFSET (LineObjectClass, lineObject),
+		  G_STRUCT_OFFSET (VisuUiLineClass, lineObject),
 		  NULL, 
 		  NULL,                
 		  g_cclosure_marshal_VOID__INT,
 		  G_TYPE_NONE, 1, G_TYPE_INT);
   /**
-   * LineObject::stipple-changed:
-   * @line: the #LineObject that emits the signal ;
+   * VisuUiLine::stipple-changed:
+   * @line: the #VisuUiLine that emits the signal ;
    * @stipple: the new stipple pattern.
    *
    * This signal is emitted when the stipple pattern of the line is changed.
    *
    * Since: 3.4
    */
-  lineObject_signals[LINE_STIPPLE_CHANGED_SIGNAL] =
+  visu_ui_line_signals[LINE_STIPPLE_CHANGED_SIGNAL] =
     g_signal_new ("stipple-changed",
 		  G_TYPE_FROM_CLASS (klass),
 		  G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION,
-		  G_STRUCT_OFFSET (LineObjectClass, lineObject),
+		  G_STRUCT_OFFSET (VisuUiLineClass, lineObject),
 		  NULL, 
 		  NULL,                
 		  g_cclosure_marshal_VOID__UINT,
 		  G_TYPE_NONE, 1, G_TYPE_UINT);
   /**
-   * LineObject::color-changed:
-   * @line: the #LineObject that emits the signal ;
+   * VisuUiLine::color-changed:
+   * @line: the #VisuUiLine that emits the signal ;
    * @color: the new color values (three RGB values).
    *
    * This signal is emitted when the colour of the line is changed.
    *
    * Since: 3.4
    */
-  lineObject_signals[LINE_COLOR_CHANGED_SIGNAL] =
+  visu_ui_line_signals[LINE_COLOR_CHANGED_SIGNAL] =
     g_signal_new ("color-changed",
 		  G_TYPE_FROM_CLASS (klass),
 		  G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION,
-		  G_STRUCT_OFFSET (LineObjectClass, lineObject),
+		  G_STRUCT_OFFSET (VisuUiLineClass, lineObject),
 		  NULL, 
 		  NULL,                
 		  g_cclosure_marshal_VOID__POINTER,
 		  G_TYPE_NONE, 1, G_TYPE_POINTER);
   
   /* Connect freeing methods. */
-  G_OBJECT_CLASS(klass)->dispose = lineObject_dispose;
-  G_OBJECT_CLASS(klass)->finalize = lineObject_finalize;
+  G_OBJECT_CLASS(klass)->dispose = visu_ui_line_dispose;
+  G_OBJECT_CLASS(klass)->finalize = visu_ui_line_finalize;
 }
 
-static void lineObject_dispose(GObject *obj)
+static void visu_ui_line_dispose(GObject *obj)
 {
-  DBG_fprintf(stderr, "Gtk LineObject: dispose object %p.\n", (gpointer)obj);
+  DBG_fprintf(stderr, "Gtk VisuUiLine: dispose object %p.\n", (gpointer)obj);
 
-  if (LINE_OBJECT(obj)->dispose_has_run)
+  if (VISU_UI_LINE(obj)->dispose_has_run)
     return;
 
-  LINE_OBJECT(obj)->dispose_has_run = TRUE;
+  VISU_UI_LINE(obj)->dispose_has_run = TRUE;
   /* Chain up to the parent class */
-  G_OBJECT_CLASS(lineObject_parent_class)->dispose(obj);
+  G_OBJECT_CLASS(visu_ui_line_parent_class)->dispose(obj);
 }
-static void lineObject_finalize(GObject *obj)
+static void visu_ui_line_finalize(GObject *obj)
 {
   g_return_if_fail(obj);
 
-  DBG_fprintf(stderr, "Gtk LineObject: finalize object %p.\n", (gpointer)obj);
+  DBG_fprintf(stderr, "Gtk VisuUiLine: finalize object %p.\n", (gpointer)obj);
 
   /* Chain up to the parent class */
-  G_OBJECT_CLASS(lineObject_parent_class)->finalize(obj);
+  G_OBJECT_CLASS(visu_ui_line_parent_class)->finalize(obj);
 
   DBG_fprintf(stderr, " | freeing ... OK.\n");
 }
 
 
-static void lineObject_init(LineObject *line)
+static void visu_ui_line_init(VisuUiLine *line)
 {
   GtkWidget *vbox, *hbox, *label, *align, *table;
   char *rgb[3];
   char *rgbName[3] = {"scroll_r", "scroll_g", "scroll_b"};
   int i;
 
-  DBG_fprintf(stderr, "Gtk LineObject: initializing new object (%p).\n",
+  DBG_fprintf(stderr, "Gtk VisuUiLine: initializing new object (%p).\n",
 	      (gpointer)line);
 
   gtk_box_set_spacing(GTK_BOX(line), 5);
@@ -299,7 +315,7 @@ static void lineObject_init(LineObject *line)
   align = gtk_alignment_new(1., 0.5, 1, 1);
   gtk_alignment_set_padding(GTK_ALIGNMENT(align), 0, 0, 5, 0);
   gtk_box_pack_start(GTK_BOX(hbox), align, FALSE, FALSE, 3);
-  line->stipple = stippleComboBox_new();
+  line->stipple = visu_ui_stipple_combobox_new();
   gtk_container_add(GTK_CONTAINER(align), line->stipple);
   g_signal_connect(G_OBJECT(line->stipple), "stipple-selected",
 		   G_CALLBACK(onStippleChanged), (gpointer)line);
@@ -337,14 +353,14 @@ static void lineObject_init(LineObject *line)
   vbox = gtk_vbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 0);
   label = gtk_label_new(_("color:"));
-  line->color = colorComboBox_new(FALSE);
+  line->color = visu_ui_color_combobox_new(FALSE);
   line->colorSignal = g_signal_connect(G_OBJECT(line->color), "color-selected",
 				       G_CALLBACK(onColorChanged), (gpointer)line);
   gtk_misc_set_alignment(GTK_MISC(label), 0., 0.5);
   gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
   hbox = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
-  colorComboBoxSet_printValues(COLOR_COMBOX(line->color), FALSE);
+  visu_ui_color_combobox_setPrintValues(VISU_UI_COLOR_COMBOBOX(line->color), FALSE);
   gtk_box_pack_start(GTK_BOX(hbox), line->color, FALSE, FALSE, 0);
   align = gtk_alignment_new(0.5, 0.5, 0, 1);
   gtk_box_pack_end(GTK_BOX(hbox), align, FALSE, FALSE, 0);
@@ -362,16 +378,30 @@ static void lineObject_init(LineObject *line)
   gtk_widget_show_all(GTK_WIDGET(line));
 }
 
-GtkWidget* lineObjectNew(const gchar* label)
+/**
+ * visu_ui_line_new :
+ * @label: the name of the group, output in bold.
+ *
+ * A #VisuUiLine widget is a widget allowing to choose the
+ * properties of a line. These properties are the line stipple
+ * pattern, its colour and its width. The colour is available through
+ * #GtkRange and with a #VisuUiColorCombobox widget. There is also a
+ * checkbox allowing to turn the line on or off.
+ *
+ * Returns: (transfer full): a newly created #VisuUiLine widget.
+ *
+ * Since: 3.4
+ */
+GtkWidget* visu_ui_line_new(const gchar* label)
 {
-  LineObject *line;
+  VisuUiLine *line;
   gchar *markup;
 
-  DBG_fprintf(stderr, "Gtk LineObject: creating new object.\n");
+  DBG_fprintf(stderr, "Gtk VisuUiLine: creating new object.\n");
 
-  line = LINE_OBJECT(g_object_new(lineObject_get_type(), NULL));
+  line = VISU_UI_LINE(g_object_new(visu_ui_line_get_type(), NULL));
 
-  DBG_fprintf(stderr, "Gtk LineObject: build widgets.\n");
+  DBG_fprintf(stderr, "Gtk VisuUiLine: build widgets.\n");
   markup = g_markup_printf_escaped("<b>%s</b>", label);
   gtk_label_set_markup(GTK_LABEL(line->label), markup);
   g_free(markup);
@@ -380,27 +410,27 @@ GtkWidget* lineObjectNew(const gchar* label)
 }
 
 
-static void onUseChanged(GtkCheckButton *check, LineObject *line)
+static void onUseChanged(GtkCheckButton *check, VisuUiLine *line)
 {
-  g_signal_emit(G_OBJECT(line), lineObject_signals[LINE_USE_CHANGED_SIGNAL],
+  g_signal_emit(G_OBJECT(line), visu_ui_line_signals[LINE_USE_CHANGED_SIGNAL],
 		0, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check)), NULL);
 }
-static void onWidthChanged(GtkSpinButton *spin, LineObject *line)
+static void onWidthChanged(GtkSpinButton *spin, VisuUiLine *line)
 {
-  g_signal_emit(G_OBJECT(line), lineObject_signals[LINE_WIDTH_CHANGED_SIGNAL],
+  g_signal_emit(G_OBJECT(line), visu_ui_line_signals[LINE_WIDTH_CHANGED_SIGNAL],
 		0, (gint)gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin)), NULL);
 }
-static void onStippleChanged(StippleComboBox *wd _U_, guint stipple, LineObject *line)
+static void onStippleChanged(VisuUiStippleCombobox *wd _U_, guint stipple, VisuUiLine *line)
 {
-  g_signal_emit(G_OBJECT(line), lineObject_signals[LINE_STIPPLE_CHANGED_SIGNAL],
+  g_signal_emit(G_OBJECT(line), visu_ui_line_signals[LINE_STIPPLE_CHANGED_SIGNAL],
 		0, stipple, NULL);
 }
-static void onRGBValueChanged(GtkRange *rg _U_, LineObject *line)
+static void onRGBValueChanged(GtkRange *rg _U_, VisuUiLine *line)
 {
   float rgba[4];
   int i;
 
-  g_return_if_fail(IS_LINE_OBJECT(line));
+  g_return_if_fail(VISU_UI_IS_LINE(line));
 
   rgba[0] = gtk_range_get_value(GTK_RANGE(line->rgRGB[0]));
   rgba[1] = gtk_range_get_value(GTK_RANGE(line->rgRGB[1]));
@@ -417,54 +447,81 @@ static void onRGBValueChanged(GtkRange *rg _U_, LineObject *line)
 
   gtk_widget_set_sensitive(line->btColor, (i < 0));
 
-  g_signal_emit(G_OBJECT(line), lineObject_signals[LINE_COLOR_CHANGED_SIGNAL],
+  g_signal_emit(G_OBJECT(line), visu_ui_line_signals[LINE_COLOR_CHANGED_SIGNAL],
 		0, (gpointer)rgba, NULL);
 }
-static void onAddClicked(GtkButton *bt _U_, LineObject *line)
+static void onAddClicked(GtkButton *bt _U_, VisuUiLine *line)
 {
   float rgba[4];
   int selected;
-  ToolColor *color;
 
-  g_return_if_fail(IS_LINE_OBJECT(line));
+  g_return_if_fail(VISU_UI_IS_LINE(line));
 
-  DBG_fprintf(stderr, "Gtk LineObject: adding a new color from ranges.\n");
+  DBG_fprintf(stderr, "Gtk VisuUiLine: adding a new color from ranges.\n");
 
   rgba[0] = gtk_range_get_value(GTK_RANGE(line->rgRGB[0]));
   rgba[1] = gtk_range_get_value(GTK_RANGE(line->rgRGB[1]));
   rgba[2] = gtk_range_get_value(GTK_RANGE(line->rgRGB[2]));
   rgba[3] = 1.f;
-  color = tool_color_addFloatRGBA(rgba, &selected);
+  tool_color_addFloatRGBA(rgba, &selected);
   g_signal_handler_block(G_OBJECT(line->color), line->colorSignal);
   gtk_combo_box_set_active(GTK_COMBO_BOX(line->color), selected);
   g_signal_handler_unblock(G_OBJECT(line->color), line->colorSignal);
   gtk_widget_set_sensitive(line->btColor, FALSE);
 }
-static void onColorChanged(ColorComboBox *combo _U_, ToolColor *color, LineObject *line)
+static void onColorChanged(VisuUiColorCombobox *combo _U_, ToolColor *color, VisuUiLine *line)
 {
-  lineObjectSet_color(line, color->rgba);
+  visu_ui_line_setColor(line, color->rgba);
 }
 
-
-
-
-void lineObjectSet_use(LineObject *line, gboolean status)
+/**
+ * visu_ui_line_setUsed:
+ * @line: the object to modify ;
+ * @status: a boolean.
+ *
+ * The line can be turn on or off, call this routine to change the
+ * interface status.
+ *
+ * Since: 3.4
+ */
+void visu_ui_line_setUsed(VisuUiLine *line, gboolean status)
 {
-  g_return_if_fail(IS_LINE_OBJECT(line));
+  g_return_if_fail(VISU_UI_IS_LINE(line));
 
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(line->used), status);
 }
-void lineObjectSet_width(LineObject *line, gint width)
+/**
+ * visu_ui_line_setWidth:
+ * @line: the object to modify ;
+ * @width: a value.
+ *
+ * The line can be drawn with a given width, call this routine to change the
+ * interface value.
+ *
+ * Since: 3.4
+ */
+void visu_ui_line_setWidth(VisuUiLine *line, gint width)
 {
-  g_return_if_fail(IS_LINE_OBJECT(line) && width > 0 && width < 11);
+  g_return_if_fail(VISU_UI_IS_LINE(line) && width > 0 && width < 11);
 
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(line->width), (gdouble)width);
 }
-void lineObjectSet_color(LineObject *line, float rgb[3])
+/**
+ * visu_ui_line_setColor:
+ * @line: the object to modify ;
+ * @rgb: a RGB array.
+ *
+ * The line can is drawn in a given colour. Change the interface
+ * values using this routine. The colour ranges are updated and if it
+ * correspond to a registered colour, it is selected in the combobox.
+ *
+ * Since: 3.4
+ */
+void visu_ui_line_setColor(VisuUiLine *line, float rgb[3])
 {
   gboolean change;
 
-  g_return_if_fail(IS_LINE_OBJECT(line));
+  g_return_if_fail(VISU_UI_IS_LINE(line));
 
   g_signal_handler_block(G_OBJECT(line->rgRGB[0]), line->rgSignals[0]);
   g_signal_handler_block(G_OBJECT(line->rgRGB[1]), line->rgSignals[1]);
@@ -494,29 +551,39 @@ void lineObjectSet_color(LineObject *line, float rgb[3])
   if (change)
     onRGBValueChanged((GtkRange*)0, line);
 }
-void lineObjectSet_stipple(LineObject *line, guint16 stipple)
+/**
+ * visu_ui_line_setStipple:
+ * @line: the object to modify ;
+ * @stipple: a value.
+ *
+ * The line can be drawn with a given stipple pattern, call this
+ * routine to change the interface value.
+ *
+ * Since: 3.4
+ */
+void visu_ui_line_setStipple(VisuUiLine *line, guint16 stipple)
 {
-  g_return_if_fail(IS_LINE_OBJECT(line));
+  g_return_if_fail(VISU_UI_IS_LINE(line));
 
-  if (!stippleComboBoxSet_selectionByStipple(STIPPLE_COMBOX(line->stipple), stipple))
+  if (!visu_ui_stipple_combobox_setSelection(VISU_UI_STIPPLE_COMBOBOX(line->stipple), stipple))
     {
-      stippleComboBoxAdd_pattern(STIPPLE_COMBOX(line->stipple), stipple);
-      stippleComboBoxSet_selectionByStipple(STIPPLE_COMBOX(line->stipple), stipple);
+      visu_ui_stipple_combobox_add(VISU_UI_STIPPLE_COMBOBOX(line->stipple), stipple);
+      visu_ui_stipple_combobox_setSelection(VISU_UI_STIPPLE_COMBOBOX(line->stipple), stipple);
     }
 }
 /**
- * lineObjectGet_optionVBox:
+ * visu_ui_line_getOptionBox:
  * @line:  the object to get the GtkVBox.
  *
  * Give access to the #GtkVBox of the expander.
  *
  * Since: 3.6
  *
- * Returns: a #GtkWidget.
+ * Returns: (transfer none): a #GtkWidget.
  */
-GtkWidget* lineObjectGet_optionVBox(LineObject *line)
+GtkWidget* visu_ui_line_getOptionBox(VisuUiLine *line)
 {
-  g_return_val_if_fail(IS_LINE_OBJECT(line), (GtkWidget*)0);
+  g_return_val_if_fail(VISU_UI_IS_LINE(line), (GtkWidget*)0);
 
   return gtk_bin_get_child(GTK_BIN(line->expand));
 }
