@@ -51,99 +51,75 @@
 
 G_BEGIN_DECLS
 /**
- * VALUE_IO_TYPE:
+ * VISU_UI_TYPE_VALUE_IO:
  *
- * Get the associated #GType to the ValueIO objects.
+ * Get the associated #GType to the VisuUiValueIo objects.
  *
  * Since: 3.5
  */
-#define VALUE_IO_TYPE         (valueIO_get_type ())
+#define VISU_UI_TYPE_VALUE_IO         (visu_ui_value_io_get_type ())
 /**
- * VALUE_IO:
+ * VISU_UI_VALUE_IO:
  * @obj: the widget to cast.
  *
- * Cast the given object to a #ValueIO object.
+ * Cast the given object to a #VisuUiValueIo object.
  *
  * Since: 3.5
  */
-#define VALUE_IO(obj)         (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALUE_IO_TYPE, ValueIO))
+#define VISU_UI_VALUE_IO(obj)         (G_TYPE_CHECK_INSTANCE_CAST ((obj), VISU_UI_TYPE_VALUE_IO, VisuUiValueIo))
 /**
- * VALUE_IO_CLASS:
+ * VISU_UI_VALUE_IO_CLASS:
  * @klass: the class to cast.
  *
- * Cast the given class to a #ValueIOClass object.
+ * Cast the given class to a #VisuUiValueIoClass object.
  *
  * Since: 3.5
  */
-#define VALUE_IO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALUE_IO_TYPE, ValueIOClass))
+#define VISU_UI_VALUE_IO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VISU_UI_TYPE_VALUE_IO, VisuUiValueIoClass))
 /**
- * IS_VALUE_IO:
+ * VISU_UI_IS_VALUE_IO:
  * @obj: the object to test.
  *
- * Get if the given object is a valid #ValueIO object.
+ * Get if the given object is a valid #VisuUiValueIo object.
  *
  * Since: 3.5
  */
-#define IS_VALUE_IO(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALUE_IO_TYPE))
+#define VISU_UI_IS_VALUE_IO(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VISU_UI_TYPE_VALUE_IO))
 /**
- * IS_VALUE_IO_CLASS:
+ * VISU_UI_IS_VALUE_IO_CLASS:
  * @klass: the class to test.
  *
- * Get if the given class is a valid #ValueIOClass class.
+ * Get if the given class is a valid #VisuUiValueIoClass class.
  *
  * Since: 3.5
  */
-#define IS_VALUE_IO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALUE_IO_TYPE))
+#define VISU_UI_IS_VALUE_IO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VISU_UI_TYPE_VALUE_IO))
 
-/**
- * ValueIO:
- *
- * Private structure to store informations of a #ValueIO object.
- *
- * Since: 3.5
- */
-typedef struct _ValueIO ValueIO;
-/* typedef struct ValueIOPrivate_struct ValueIOPrivate; */
-/**
- * ValueIOClass
- *
- * Private structure to store informations of a #ValueIOClass object.
- *
- * Since: 3.5
- */
-typedef struct _ValueIOClass ValueIOClass;
+typedef struct _VisuUiValueIo VisuUiValueIo;
+typedef struct _VisuUiValueIoClass VisuUiValueIoClass;
 
-/**
- * valueIO_get_type
- *
- * #GType are unique numbers to identify objects.
- *
- * Returns: the #GType associated with #ValueIO objects.
- *
- * Since: 3.5
- */
-GType valueIO_get_type(void);
-GtkWidget* valueIONew(GtkWindow *parent, const gchar*tipsOpen,
+GType visu_ui_value_io_get_type(void);
+GtkWidget* visu_ui_value_io_new(GtkWindow *parent, const gchar*tipsOpen,
 		      const gchar*tipsSave, const gchar*tipsSaveAs);
 
 /**
- * ValueIOCallback:
+ * VisuUiValueIoCallback:
  * @filename: the name of the file to be saved or opened ;
  * @error: a location to store a possible error.
  *
  * Prototypes of functions to be called when an IO file is saved or
- * opened, see valueIOConnect_open() and valueIOConnect_save().
+ * opened, see visu_ui_value_io_connectOnOpen() and visu_ui_value_io_connectOnSave().
  *
  * Returns: should return TRUE if the action of the callback succeed.
  */
-typedef gboolean (*ValueIOCallback)(const gchar *filename, GError **error);
+typedef gboolean (*VisuUiValueIoCallback)(const gchar *filename, GError **error);
 
-void valueIOConnect_open(ValueIO *valueio, ValueIOCallback open);
-void valueIOConnect_save(ValueIO *valueio, ValueIOCallback save);
-void valueIOSet_openSensitive(ValueIO *valueio, gboolean status);
-void valueIOSet_saveSensitive(ValueIO *valueio, gboolean status);
-gboolean valueIOSet_filename(ValueIO *valueio, const gchar *filename);
-gchar* valueIOGet_saveFilename(GtkWindow *parent);
+void visu_ui_value_io_connectOnOpen(VisuUiValueIo *valueio, VisuUiValueIoCallback open);
+void visu_ui_value_io_connectOnSave(VisuUiValueIo *valueio, VisuUiValueIoCallback save);
+void visu_ui_value_io_setSensitiveOpen(VisuUiValueIo *valueio, gboolean status);
+void visu_ui_value_io_setSensitiveSave(VisuUiValueIo *valueio, gboolean status);
+gboolean visu_ui_value_io_setFilename(VisuUiValueIo *valueio, const gchar *filename);
+gchar* visu_ui_value_io_getFilename(GtkWindow *parent);
 
 G_END_DECLS
 
