@@ -56,46 +56,46 @@
 #include "gtk_renderingWindowWidget.h"
 
 /**
- * VISU_UIMAIN_TYPE:
+ * VISU_UI_TYPE_MAIN:
  *
  * return the type of #VisuUiMain.
  */
-#define VISU_UIMAIN_TYPE	     (visu_ui_main_get_type ())
+#define VISU_UI_TYPE_MAIN	     (visu_ui_main_get_type ())
 /**
- * VISU_UIMAIN:
+ * VISU_UI_MAIN:
  * @obj: a #GObject to cast.
  *
  * Cast the given @obj into #VisuUiMain type.
  */
-#define VISU_UIMAIN(obj)	     (G_TYPE_CHECK_INSTANCE_CAST(obj, VISU_UIMAIN_TYPE, VisuUiMain))
+#define VISU_UI_MAIN(obj)	     (G_TYPE_CHECK_INSTANCE_CAST(obj, VISU_UI_TYPE_MAIN, VisuUiMain))
 /**
- * VISU_UIMAIN_CLASS:
+ * VISU_UI_MAIN_CLASS:
  * @klass: a #GObjectClass to cast.
  *
  * Cast the given @klass into #VisuUiMainClass.
  */
-#define VISU_UIMAIN_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST(klass, VISU_UIMAIN_TYPE, VisuUiMainClass))
+#define VISU_UI_MAIN_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST(klass, VISU_UI_TYPE_MAIN, VisuUiMainClass))
 /**
- * IS_VISU_UIMAIN_TYPE:
+ * VISU_UI_IS_MAIN_TYPE:
  * @obj: a #GObject to test.
  *
  * Test if the given @ogj is of the type of #VisuUiMain object.
  */
-#define IS_VISU_UIMAIN_TYPE(obj)    (G_TYPE_CHECK_INSTANCE_TYPE(obj, VISU_UIMAIN_TYPE))
+#define VISU_UI_IS_MAIN_TYPE(obj)    (G_TYPE_CHECK_INSTANCE_TYPE(obj, VISU_UI_TYPE_MAIN))
 /**
- * IS_VISU_UIMAIN_CLASS:
+ * VISU_UI_IS_MAIN_CLASS:
  * @klass: a #GObjectClass to test.
  *
  * Test if the given @klass is of the type of #VisuUiMainClass class.
  */
-#define IS_VISU_UIMAIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE(klass, VISU_UIMAIN_TYPE))
+#define VISU_UI_IS_MAIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE(klass, VISU_UI_TYPE_MAIN))
 /**
- * VISU_UIMAIN_GET_CLASS:
+ * VISU_UI_MAIN_GET_CLASS:
  * @obj: a #GObject to get the class of.
  *
  * It returns the class of the given @obj.
  */
-#define VISU_UIMAIN_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS(obj, VISU_UIMAIN_TYPE, VisuUiMainClass))
+#define VISU_UI_MAIN_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS(obj, VISU_UI_TYPE_MAIN, VisuUiMainClass))
 
 /**
  * VisuUiMain_private:
@@ -104,7 +104,7 @@
  */
 typedef struct VisuUiMain_private_struct VisuUiMain_private;
 /**
- * VisuUiMain:
+ * _VisuUiMain:
  * @parent: the parent object, a #GtkWindow here ;
  * @renderingWindow: a pointer on the associated rendering window ;
  * @pairsDialog: a pointer to the corresponding pair dialog, or NULL
@@ -115,6 +115,7 @@ typedef struct VisuUiMain_private_struct VisuUiMain_private;
  *
  * This structure describes a #VisuUiMain object.
  */
+typedef struct _VisuUiMain VisuUiMain;
 struct _VisuUiMain
 {
   GtkWindow parent;
@@ -131,7 +132,6 @@ struct _VisuUiMain
   /* Private data. */
   VisuUiMain_private *private;
 };
-typedef struct _VisuUiMain VisuUiMain;
 /**
  * VisuUiMainClass:
  *
@@ -142,7 +142,7 @@ typedef struct _VisuUiMainClass VisuUiMainClass;
 /**
  * visu_ui_main_get_type:
  *
- * This method returns the type of #VisuUiMain, use VISU_UIMAIN_TYPE instead.
+ * This method returns the type of #VisuUiMain, use VISU_UI_TYPE_MAIN instead.
  *
  * Returns: the type of #VisuUiMain.
  */
@@ -185,7 +185,7 @@ void visu_ui_main_buildInteractiveDialog(VisuUiMain *main);
  *
  * Call the get routines from the command line module and associate
  * the different tasks to the different panels. For a version that do
- * not use the panels, call visuGtkRun_commandLine() instead.
+ * not use the panels, call visu_ui_runCommandLine() instead.
  *
  * Returns: always FALSE.
  */
@@ -204,47 +204,31 @@ gboolean visu_ui_main_initPanels(gpointer data);
 
 
 /**
- * visu_uiMainClass_setRememberPosition:
+ * visu_ui_main_class_setRememberPosition:
  * @val: an boolean.
  *
  * V_Sim can try to remember the position of its main windows, then
  * open them again will result in a positioning on screen equivalent
  * to previous position.
  */
-void visu_uiMainClass_setRememberPosition(gboolean val);
+void visu_ui_main_class_setRememberPosition(gboolean val);
 /**
- * visu_uiMainClass_getRememberPosition:
+ * visu_ui_main_class_getRememberPosition:
  *
  * V_Sim can store the position of its main windows. Use this routine
  * to get the status of this capability.
  *
  * Returns: TRUE if set.
  */
-gboolean visu_uiMainClass_getRememberPosition();
+gboolean visu_ui_main_class_getRememberPosition();
 
 
-VisuUiMain* visu_uiMainClass_getCurrentPanel();
-/**
- * gtkMainClassSet_currentPanel:
- * @main: a command panel.
- *
- * After having created the command panel with visu_ui_main_new(), use this
- * routine to declare it as the current command panel.
- */
-void gtkMainClassSet_currentPanel(VisuUiMain *main);
+VisuUiMain* visu_ui_main_class_getCurrentPanel();
+void visu_ui_main_class_setCurrentPanel(VisuUiMain *main);
 
-/**
- * visu_uiMainClass_createMain:
- * @panel: a location for a #GtkWindow ;
- * @renderWindow: a location for a #GtkWindow ;
- * @renderArea: a location for a #GtkWidget.
- *
- * A convenience routine to create a command panel, a rendering window
- * and links them together.
- */
-void visu_uiMainClass_createMain(GtkWindow **panel, GtkWindow **renderWindow,
-			     GtkWidget **renderArea);
+void visu_ui_main_class_createMain(GtkWindow **panel,
+                                   GtkWindow **renderWindow, GtkWidget **renderArea);
 
-VisuRenderingWindow* visu_uiMainClass_getDefaultRendering();
+VisuUiRenderingWindow* visu_ui_main_class_getDefaultRendering();
 
 #endif
