@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -46,6 +46,7 @@
 #endif
 
 #include <unistd.h> /* For the access markers R_OK, W_OK ... */
+#include <string.h>
 
 #include "gtk_save.h"
 
@@ -57,15 +58,24 @@
 #include "visu_basic.h"
 #include "gtk_renderingWindowWidget.h"
 #include "visu_commandLine.h"
+#include "gtk_pick.h"
+#include "panelModules/panelPlanes.h"
+#include "panelModules/panelSurfaces.h"
+#include "panelModules/panelGeometry.h"
 
 /**
  * SECTION: gtk_save
- * @short_description: The load/save dialog for resources and parameters.
+ * @short_description: The load/save dialog for resources and
+ * parameters.
+ *
+ * <para>The save dialog proposes to load or save resources, both
+ * parameters or resources.</para>
  */
 
 static guint saveResourcesContextId, saveParametersContextId;
 static gchar *lastParsedDir;
 static GtkWidget *checkXMLResources, *checkXMLParameters, *checkXMLCommandLine;
+static GtkWidget *checkExportXML;
 
 /* Local Callbacks. */
 static void onLoadResButtonClicked(GtkButton *button, gpointer data);
@@ -87,7 +97,12 @@ enum
     GTK_SAVE_NB_COLUMNS
   };
 
-void gtkSaveInit()
+/**
+ * visu_ui_save_initBuild: (skip)
+ *
+ * Create the save window, conect the signals and run it as a modal dialog.
+ */
+void visu_ui_save_initBuild()
 {
   GtkWidget *saveDialog;
   GtkWidget *wd, *label;
@@ -97,6 +112,8 @@ void gtkSaveInit()
   GtkListStore *listOfFiles;
   const gchar *currentResPath;
   int i, j;
+  GDir *gdir;
+  const gchar *fileFromDir;
 
   saveDialog = create_saveDialog();
   gtk_widget_set_name(saveDialog, "message");
@@ -130,7 +147,7 @@ void gtkSaveInit()
 
   /* Set default values. */
   wd = lookup_widget(saveDialog, "checkLimitOnVisuData");
-  if (visu_rendering_window_getVisuData(visu_uiMainClass_getDefaultRendering()))
+  if (visu_ui_rendering_window_getData(visu_ui_main_class_getDefaultRendering()))
     gtk_widget_set_sensitive(wd, TRUE);
   else
     gtk_widget_set_sensitive(wd, FALSE);
@@ -149,7 +166,7 @@ void gtkSaveInit()
 
   /* Set initial values. */
   wd = lookup_widget(saveDialog, "filechooserwidgetResources");
-  directory = visuGtkGet_lastOpenDirectory();
+  directory = visu_ui_getLastOpenDirectory();
   if (directory)
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(wd), directory);
   g_signal_connect(G_OBJECT(wd), "selection-changed",
@@ -163,11 +180,11 @@ void gtkSaveInit()
 
   wd = lookup_widget(saveDialog, "comboboxentryParameters");
   gtk_widget_set_name(wd, "message_entry");
-  resList = visu_configFile_getPathList(VISU_CONFIGFILE_PARAMETER);
-  for (file = visu_configFile_getNextValidPath(VISU_CONFIGFILE_PARAMETER,
+  resList = visu_config_file_getPathList(VISU_CONFIG_FILE_PARAMETER);
+  for (file = visu_config_file_getNextValidPath(VISU_CONFIG_FILE_PARAMETER,
 					      W_OK, &resList, 1);
        file;
-       file = visu_configFile_getNextValidPath(VISU_CONFIGFILE_PARAMETER,
+       file = visu_config_file_getNextValidPath(VISU_CONFIG_FILE_PARAMETER,
 					      W_OK, &resList, 1))
     gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(wd), (const gchar*)0, file);
   completion = gtk_entry_completion_new();
@@ -184,20 +201,46 @@ void gtkSaveInit()
 
   wd = lookup_widget(saveDialog, "comboboxentryResources");
   gtk_widget_set_name(wd, "message_entry");
-  currentResPath = visu_configFile_getPathToResources();
+  currentResPath = visu_config_file_getPathToResources();
+  DBG_fprintf(stderr, " | current resource path '%s'.\n", currentResPath);
   j = i = 0;
-  resList = visu_configFile_getPathList(VISU_CONFIGFILE_RESOURCE);
-  for (file = visu_configFile_getNextValidPath(VISU_CONFIGFILE_RESOURCE,
-					      W_OK, &resList, 1);
+  resList = visu_config_file_getPathList(VISU_CONFIG_FILE_RESOURCE);
+  for (file = visu_config_file_getNextValidPath(VISU_CONFIG_FILE_RESOURCE,
+                                                W_OK, &resList, 1);
        file;
-       file = visu_configFile_getNextValidPath(VISU_CONFIGFILE_RESOURCE,
-					      W_OK, &resList, 1))
+       file = visu_config_file_getNextValidPath(VISU_CONFIG_FILE_RESOURCE,
+                                                W_OK, &resList, 1))
     {
       if (!strcmp(file, currentResPath))
 	j = i;
+      DBG_fprintf(stderr, " | '%s' (%s).\n", file, currentResPath);
       gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(wd), (const gchar*)0, file);
       i += 1;
     }
+  /* Add all res file of the cwd. */
+  DBG_fprintf(stderr, "Gtk Save: looking for res files in '%s'.\n", currentResPath);
+  directory = g_get_current_dir();
+  gdir = g_dir_open(directory, 0, NULL);
+  if (gdir)
+    {
+      fileFromDir = g_dir_read_name(gdir);
+      while(fileFromDir)
+        {
+          if (g_strrstr(fileFromDir, ".res") &&
+              strcmp(fileFromDir, "v_sim.res") &&
+              !access(fileFromDir, W_OK))
+            {
+              file = g_build_filename(directory, fileFromDir, NULL);
+              DBG_fprintf(stderr, " | '%s'.\n", file);
+              gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(wd), (const gchar*)0, file);
+              g_free(file);
+            }
+          fileFromDir = g_dir_read_name(gdir);
+        }
+      g_dir_close(gdir);
+    }
+  g_free(directory);
+
   completion = gtk_entry_completion_new();
   gtk_entry_completion_set_model(completion, GTK_TREE_MODEL(listOfFiles));
   gtk_entry_completion_set_text_column(completion, GTK_SAVE_FILE_NAME);
@@ -260,6 +303,14 @@ void gtkSaveInit()
   checkXMLCommandLine = (GtkWidget*)0;
 #endif
 
+  wd = lookup_widget(saveDialog, "vbox16");
+  checkExportXML =
+    gtk_check_button_new_with_mnemonic(_("Append all settings in a single XML file (including planes, surfaces…)"));
+  gtk_box_pack_start(GTK_BOX(wd), checkExportXML, FALSE, FALSE, 0);
+  gtk_container_set_border_width(GTK_CONTAINER(checkExportXML), 5);
+  gtk_widget_set_name(checkExportXML, "message_radio");
+  gtk_widget_show(checkExportXML);
+
   wd = lookup_widget(saveDialog, "vbox18");
   label = gtk_label_new("");
   gtk_label_set_line_wrap(GTK_LABEL(label), FALSE);
@@ -313,7 +364,9 @@ static void onLoadResButtonClicked(GtkButton *button _U_, gpointer data)
   int res;
   GString *message;
   GError *error;
+  VisuUiRenderingWindow *window;
   VisuData *dataObj;
+  VisuGlView *view;
 
   g_return_if_fail(GTK_DIALOG(data));
 
@@ -322,15 +375,17 @@ static void onLoadResButtonClicked(GtkButton *button _U_, gpointer data)
 
   filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(file_selector));
   directory = gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER(file_selector));
-  visuGtkSet_lastOpenDirectory(directory, VISU_DIR_CONF);
+  visu_ui_setLastOpenDirectory(directory, VISU_UI_DIR_CONF);
   g_free(directory);
 
-  dataObj = visu_rendering_window_getVisuData(visu_uiMainClass_getDefaultRendering());
+  window = visu_ui_main_class_getDefaultRendering();
+  dataObj = visu_ui_rendering_window_getData(window);
+  view = visu_ui_rendering_window_getGlView(window);
   error = (GError*)0;
-  res = visu_configFile_load(VISU_CONFIGFILE_RESOURCE, filename, dataObj, &error);
+  res = visu_config_file_load(VISU_CONFIG_FILE_RESOURCE, filename, dataObj, view, &error);
   if (error)
     {
-      visuGtkRaise_warningLong(_("Loading a file"), error->message,
+      visu_ui_raiseWarningLong(_("Loading a file"), error->message,
 			       GTK_WINDOW(data));
       g_error_free(error);
     }
@@ -343,15 +398,15 @@ static void onLoadResButtonClicked(GtkButton *button _U_, gpointer data)
   else
     g_string_append_printf(message, _("File '%s' not or partially loaded."),
 			   basename);
-  showAlertMessage(GTK_WIDGET(data), message->str, !res, VISU_CONFIGFILE_RESOURCE);
+  showAlertMessage(GTK_WIDGET(data), message->str, !res, VISU_CONFIG_FILE_RESOURCE);
   g_string_free(message, TRUE);
   g_free(basename);
 
   if (res && dataObj)
     {
       /* We rebuild all list. */
-      visuExtensions_rebuildAllLists(dataObj);
-      VISU_ADD_REDRAW;
+      visu_gl_ext_rebuildAll();
+      VISU_REDRAW_ADD;
     }
 }
 
@@ -363,8 +418,17 @@ static void onSaveResButtonClicked(GtkButton *button _U_, gpointer data)
 
   entry = gtk_bin_get_child
     (GTK_BIN(lookup_widget(GTK_WIDGET(data), "comboboxentryResources")));
-  saveAction(VISU_CONFIGFILE_RESOURCE, GTK_WIDGET(data), GTK_ENTRY(entry));
-  gtk_widget_grab_default(lookup_widget(GTK_WIDGET(data), "closeButtonSave"));
+
+  if (!strstr(gtk_entry_get_text(GTK_ENTRY(entry)), ".xml") &&
+      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkExportXML)))
+    {
+      showAlertMessage(GTK_WIDGET(data), _("Choose a filename with '.xml' to append other settings."), TRUE, VISU_CONFIG_FILE_RESOURCE);
+    }
+  else
+    {
+      saveAction(VISU_CONFIG_FILE_RESOURCE, GTK_WIDGET(data), GTK_ENTRY(entry));
+      gtk_widget_grab_default(lookup_widget(GTK_WIDGET(data), "closeButtonSave"));
+    }
 }
 
 static void onSaveParButtonClicked(GtkButton *button _U_, gpointer data)
@@ -375,10 +439,36 @@ static void onSaveParButtonClicked(GtkButton *button _U_, gpointer data)
 
   entry = gtk_bin_get_child
     (GTK_BIN(lookup_widget(GTK_WIDGET(data), "comboboxentryParameters")));
-  saveAction(VISU_CONFIGFILE_PARAMETER, GTK_WIDGET(data), GTK_ENTRY(entry));
+  saveAction(VISU_CONFIG_FILE_PARAMETER, GTK_WIDGET(data), GTK_ENTRY(entry));
   gtk_widget_grab_default(lookup_widget(GTK_WIDGET(data), "closeButtonSave"));
 }
 
+static gboolean _appendAllSettings(const gchar *filename, GError **error)
+{
+  VisuPlane **planes;
+  VisuPaths *paths;
+
+  planes = visu_ui_panel_planes_getAll(FALSE);
+  if (!visu_plane_class_exportXMLFile(filename, planes, error))
+    {
+      g_free(planes);
+      return FALSE;
+    }
+  g_free(planes);
+
+  if (!visu_ui_interactive_pick_exportXMLFile(filename, error))
+    return FALSE;
+
+  if (!visu_ui_panel_surfaces_exportXMLFile(filename, error))
+    return FALSE;
+
+  paths = visu_ui_panel_geometry_getPaths();
+  if (!visu_paths_exportXMLFile(paths, filename, error))
+    return FALSE;
+
+  return TRUE;
+}
+
 static void saveAction(int type, GtkWidget *saveDialog, GtkEntry *entry)
 {
   GtkWidget *wd;
@@ -387,14 +477,16 @@ static void saveAction(int type, GtkWidget *saveDialog, GtkEntry *entry)
   gboolean resOk;
   gsize ecrit, lu;
   int lines;
+  VisuUiRenderingWindow *window;
   VisuData *dataObj;
+  VisuGlView *view;
   GError *error;
   GtkTreeIter iter;
   GtkListStore *listOfFiles;
   GtkEntryCompletion *completion;
 
-  g_return_if_fail(type == VISU_CONFIGFILE_RESOURCE ||
-		   type == VISU_CONFIGFILE_PARAMETER);
+  g_return_if_fail(type == VISU_CONFIG_FILE_RESOURCE ||
+		   type == VISU_CONFIG_FILE_PARAMETER);
   g_return_if_fail(saveDialog && entry);
 
   file = g_filename_from_utf8(gtk_entry_get_text(entry), -1, &lu, &ecrit, NULL);
@@ -402,38 +494,43 @@ static void saveAction(int type, GtkWidget *saveDialog, GtkEntry *entry)
   if (g_file_test(file, G_FILE_TEST_IS_DIR))
     {
       tmpFile=
-	g_build_filename(file, visu_configFile_getDefaultFilename(type), NULL);
+	g_build_filename(file, visu_config_file_getDefaultFilename(type), NULL);
       g_free(file);
       file = tmpFile;
     }
   
-  if (type == VISU_CONFIGFILE_RESOURCE)
+  wd = lookup_widget(saveDialog, "checkLimitOnVisuData");
+  dataObj = (VisuData*)0;
+  view = (VisuGlView*)0;
+  if (type == VISU_CONFIG_FILE_RESOURCE)
     {
-      wd = lookup_widget(saveDialog, "checkLimitOnVisuData");
+      window = visu_ui_main_class_getDefaultRendering();
       if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wd)))
-	dataObj = visu_rendering_window_getVisuData(visu_uiMainClass_getDefaultRendering());
-      else
-	dataObj = (VisuData*)0;
+        dataObj = visu_ui_rendering_window_getData(window);
+      view = visu_ui_rendering_window_getGlView(window);
     }
-  else
-    dataObj = (VisuData*)0;
 
   error = (GError*)0;
   lines = 0;
-  if (type == VISU_CONFIGFILE_RESOURCE && checkXMLResources &&
+  if (type == VISU_CONFIG_FILE_RESOURCE && checkXMLResources &&
       gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkXMLResources)))
-    resOk = visu_configFile_exportToXML(file, VISU_CONFIGFILE_RESOURCE, &error);
-  else if (type == VISU_CONFIGFILE_PARAMETER && checkXMLParameters &&
+    resOk = visu_config_file_exportToXML(file, VISU_CONFIG_FILE_RESOURCE, &error);
+  else if (type == VISU_CONFIG_FILE_RESOURCE && strstr(file, ".xml"))
+    {
+      resOk = visu_config_file_saveResourcesToXML(file, &lines, dataObj, view, &error);
+      resOk = resOk && _appendAllSettings(file, &error);
+    }
+  else if (type == VISU_CONFIG_FILE_PARAMETER && checkXMLParameters &&
 	   gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkXMLParameters)))
-    resOk = visu_configFile_exportToXML(file, VISU_CONFIGFILE_PARAMETER, &error);
-  else if (type == VISU_CONFIGFILE_PARAMETER && checkXMLCommandLine &&
+    resOk = visu_config_file_exportToXML(file, VISU_CONFIG_FILE_PARAMETER, &error);
+  else if (type == VISU_CONFIG_FILE_PARAMETER && checkXMLCommandLine &&
 	   gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkXMLCommandLine)))
     resOk = commandLineExport(file, &error);
   else
-    resOk = visu_configFile_save(type, file, &lines, dataObj, &error);
+    resOk = visu_config_file_save(type, file, &lines, dataObj, view, &error);
   if (!resOk)
     {
-      visuGtkRaise_warningLong(_("Saving a file"), error->message,
+      visu_ui_raiseWarningLong(_("Saving a file"), error->message,
 			       GTK_WINDOW(saveDialog));
       g_error_free(error);
     }
@@ -476,11 +573,11 @@ static void showAlertMessage(GtkWidget *saveDialog, gchar* message, gboolean war
 {
   GtkWidget *wd;
 
-  g_return_if_fail(type == VISU_CONFIGFILE_RESOURCE ||
-		   type == VISU_CONFIGFILE_PARAMETER);
+  g_return_if_fail(type == VISU_CONFIG_FILE_RESOURCE ||
+		   type == VISU_CONFIG_FILE_PARAMETER);
   g_return_if_fail(saveDialog);
 
-  if (type == VISU_CONFIGFILE_RESOURCE)
+  if (type == VISU_CONFIG_FILE_RESOURCE)
     wd = lookup_widget(saveDialog, "imageWarningResources");
   else
     wd = lookup_widget(saveDialog, "imageWarningParameters");
@@ -489,7 +586,7 @@ static void showAlertMessage(GtkWidget *saveDialog, gchar* message, gboolean war
   else
     gtk_widget_hide(wd);
 
-  if (type == VISU_CONFIGFILE_RESOURCE)
+  if (type == VISU_CONFIG_FILE_RESOURCE)
     {
       wd = lookup_widget(saveDialog, "statusbarResources");
       gtk_statusbar_pop(GTK_STATUSBAR(wd), saveResourcesContextId);
