@@ -941,9 +941,14 @@ static gboolean observe(VisuInteractive *inter, VisuGlView *view,
     if (ev->button != 4 && ev->button != 5 )
       {
 	if (ev->button == 1)
-	  g_signal_emit(G_OBJECT(inter),
-			interactive_signals[INTERACTIVE_OBSERVE_SIGNAL],
-			0 , FALSE, NULL);
+          {
+            g_signal_emit(G_OBJECT(inter),
+                          interactive_signals[INTERACTIVE_OBSERVE_SIGNAL],
+                          0 , FALSE, NULL);
+            DBG_fprintf(stderr, "Visu Interactive: redraw on observe.\n");
+            g_idle_add_full(G_PRIORITY_HIGH_IDLE, visu_object_redrawForce,
+                            (gpointer)__func__, (GDestroyNotify)0);
+          }
 	return FALSE;
       }
 
@@ -1060,9 +1065,12 @@ static gboolean observe(VisuInteractive *inter, VisuGlView *view,
 	  inter->yOrig = ev->y;
 	}
       else
-        g_signal_emit(G_OBJECT(inter),
-                      interactive_signals[INTERACTIVE_OBSERVE_SIGNAL],
-                      0 , FALSE, NULL);
+        {
+          g_signal_emit(G_OBJECT(inter),
+                        interactive_signals[INTERACTIVE_OBSERVE_SIGNAL],
+                        0 , FALSE, NULL);
+          reDrawNeeded = TRUE;
+        }
     }
   else if (ev->letter == 'r')
     {
