@@ -49,6 +49,7 @@
 #include "view.h"
 #include <visu_nodes.h>
 #include <visu_data.h>
+#include <extensions/nodes.h>
 #include <renderingBackend/visu_actionInterface.h>
 
 /**
@@ -145,46 +146,46 @@ typedef enum
   } VisuInteractivePickError;
 
 /**
- * VISU_INTERACTIVE_TYPE:
+ * VISU_TYPE_INTERACTIVE:
  *
  * return the type of #VisuInteractive.
  */
-#define VISU_INTERACTIVE_TYPE	     (visuInteractive_get_type ())
+#define VISU_TYPE_INTERACTIVE	     (visu_interactive_get_type ())
 /**
  * VISU_INTERACTIVE:
  * @obj: a #GObject to cast.
  *
  * Cast the given @obj into #VisuInteractive type.
  */
-#define VISU_INTERACTIVE(obj)	     (G_TYPE_CHECK_INSTANCE_CAST(obj, VISU_INTERACTIVE_TYPE, VisuInteractive))
+#define VISU_INTERACTIVE(obj)	     (G_TYPE_CHECK_INSTANCE_CAST(obj, VISU_TYPE_INTERACTIVE, VisuInteractive))
 /**
  * VISU_INTERACTIVE_CLASS:
  * @klass: a #GObjectClass to cast.
  *
  * Cast the given @klass into #VisuInteractiveClass.
  */
-#define VISU_INTERACTIVE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST(klass, VISU_INTERACTIVE_TYPE, VisuInteractiveClass))
+#define VISU_INTERACTIVE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST(klass, VISU_TYPE_INTERACTIVE, VisuInteractiveClass))
 /**
- * IS_VISU_INTERACTIVE:
+ * VISU_IS_INTERACTIVE:
  * @obj: a #GObject to test.
  *
  * Test if the given @ogj is of the type of #VisuInteractive object.
  */
-#define IS_VISU_INTERACTIVE(obj)    (G_TYPE_CHECK_INSTANCE_TYPE(obj, VISU_INTERACTIVE_TYPE))
+#define VISU_IS_INTERACTIVE(obj)    (G_TYPE_CHECK_INSTANCE_TYPE(obj, VISU_TYPE_INTERACTIVE))
 /**
- * IS_VISU_INTERACTIVE_CLASS:
+ * VISU_IS_INTERACTIVE_CLASS:
  * @klass: a #GObjectClass to test.
  *
  * Test if the given @klass is of the type of #VisuInteractiveClass class.
  */
-#define IS_VISU_INTERACTIVE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE(klass, VISU_INTERACTIVE_TYPE))
+#define VISU_IS_INTERACTIVE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE(klass, VISU_TYPE_INTERACTIVE))
 /**
  * VISU_INTERACTIVE_GET_CLASS:
  * @obj: a #GObject to get the class of.
  *
  * It returns the class of the given @obj.
  */
-#define VISU_INTERACTIVE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS(obj, VISU_INTERACTIVE_TYPE, VisuInteractiveClass))
+#define VISU_INTERACTIVE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS(obj, VISU_TYPE_INTERACTIVE, VisuInteractiveClass))
 
 /**
  * VisuInteractive:
@@ -200,16 +201,16 @@ typedef struct _VisuInteractive VisuInteractive;
 typedef struct _VisuInteractiveClass VisuInteractiveClass;
 
 /**
- * visuInteractive_get_type:
+ * visu_interactive_get_type:
  *
- * This method returns the type of #VisuInteractive, use VISU_INTERACTIVE_TYPE instead.
+ * This method returns the type of #VisuInteractive, use VISU_TYPE_INTERACTIVE instead.
  *
  * Returns: the type of #VisuInteractive.
  */
-GType visuInteractive_get_type(void);
+GType visu_interactive_get_type(void);
 
 /**
- * visuInteractiveClassSet_preferedObserveMethod:
+ * visu_interactive_class_setPreferedObserveMethod:
  * @method: an integer that identify the method, see #OPENGL_OBSERVE_CONSTRAINED,
  *          and #OPENGL_OBSERVE_WALKER flags.
  *
@@ -217,9 +218,9 @@ GType visuInteractive_get_type(void);
  * two methods are described in the commentary of the keys #OPENGL_OBSERVE_CONSTRAINED
  * an d#OPENGL_OBSERVE_WALKER.
  */
-void visuInteractiveClassSet_preferedObserveMethod(VisuInteractiveMethod method);
+void visu_interactive_class_setPreferedObserveMethod(VisuInteractiveMethod method);
 /**
- * visuInteractiveClassGet_preferedObserveMethod:
+ * visu_interactive_class_getPreferedObserveMethod:
  *
  * There are two methods to move the camera in a pick and observe sesion. These
  * two methods are described in the commentary of the keys #OPENGL_OBSERVE_CONSTRAINED
@@ -228,26 +229,32 @@ void visuInteractiveClassSet_preferedObserveMethod(VisuInteractiveMethod method)
  * Returns: an integer that identify the method, see #OPENGL_OBSERVE_CONSTRAINED,
  *          and #OPENGL_OBSERVE_WALKER flags.
  */
-VisuInteractiveMethod visuInteractiveClassGet_preferedObserveMethod();
+VisuInteractiveMethod visu_interactive_class_getPreferedObserveMethod();
 
-VisuInteractive* visuInteractiveNew(VisuInteractiveId type);
+VisuInteractive* visu_interactive_new(VisuInteractiveId type);
+void visu_interactive_apply(VisuInteractive *inter, VisuNodeArray *array);
 
-VisuInteractiveId visuInteractiveGet_type(VisuInteractive *inter);
+gboolean visu_interactive_setType(VisuInteractive *inter, VisuInteractiveId id);
+VisuInteractiveId visu_interactive_getType(VisuInteractive *inter);
 
-void visuInteractiveHandle_event(VisuInteractive *inter, VisuData *dataObj,
-				 SimplifiedEvents *ev);
+void visu_interactive_handleEvent(VisuInteractive *inter,
+                                  VisuGlView *view, ToolSimplifiedEvents *ev);
+ToolSimplifiedEvents* visu_interactive_getEvent(VisuInteractive *inter);
 
-void visuInteractiveSet_movingNodes(VisuInteractive *inter, GList *nodeIds);
-void visuInteractiveSet_movingAxe(VisuInteractive *inter, float axe[3]);
+void visu_interactive_setNodeList(VisuInteractive *inter, VisuGlExtNodes *nodes);
+void visu_interactive_setMovingNodes(VisuInteractive *inter, GList *nodeIds);
+void visu_interactive_setMovingAxe(VisuInteractive *inter, float axe[3]);
 
-VisuOpenGLCamera* visuInteractivePop_savedCamera(VisuInteractive *inter);
-void visuInteractivePush_savedCamera(VisuInteractive *inter, VisuOpenGLCamera *camera);
-void visuInteractiveGet_savedCameras(VisuInteractive *inter,
+void visu_interactive_highlight(VisuInteractive *inter, VisuData *dataObj, guint nodeId);
+
+VisuGlCamera* visu_interactive_popSavedCamera(VisuInteractive *inter);
+void visu_interactive_pushSavedCamera(VisuInteractive *inter, VisuGlCamera *camera);
+void visu_interactive_getSavedCameras(VisuInteractive *inter,
 				     GList **cameras, GList **head);
-void visuInteractiveSet_references(VisuInteractive *inter, VisuInteractive *from);
+void visu_interactive_setReferences(VisuInteractive *inter, VisuInteractive *from);
 
 /**
- * getNodes2DCoordinates:
+ * visu_interactive_class_getNodes2DCoordinates: (skip)
  * @dataObj: a #VisuData object ;
  * @nodeIds: an array of #VisuNode ids ;
  * @nNodes: the number of nodes in the array ;
@@ -256,7 +263,7 @@ void visuInteractiveSet_references(VisuInteractive *inter, VisuInteractive *from
  *
  * From nodes ids, compute and store in @coordinates2D their 2D coordinates.
  */
-void getNodes2DCoordinates(VisuData *dataObj, unsigned int *nodeIds,
-	unsigned int nNodes, float *coordinates2D, unsigned int *size);
+void visu_interactive_class_getNodes2DCoordinates(VisuData *dataObj, guint *nodeIds,
+	guint nNodes, float *coordinates2D, guint *size);
 
 #endif
