@@ -63,32 +63,9 @@
  * return unused ids when needed.</para>
  *
  * <para>Here are also defined the common primitive for drawing, see
- * visu_openGL_drawDistance() for instance.</para>
+ * visu_gl_drawDistance() for instance.</para>
  */
 
-#define N_BRIGHT_COLORS 20
-static ToolColor brightColors[N_BRIGHT_COLORS] =
-  {{{1,0,0, 1.f}, (gpointer)0},
-   {{0,1,0, 1.f}, (gpointer)0},
-   {{0,0,1, 1.f}, (gpointer)0},
-   {{1,0,1, 1.f}, (gpointer)0},
-   {{0,1,1, 1.f}, (gpointer)0},
-   {{1,1,0, 1.f}, (gpointer)0},
-   {{1,0.5,0, 1.f}, (gpointer)0},
-   {{0.5,0,0.5, 1.f}, (gpointer)0},
-   {{0,0.5,0.5, 1.f}, (gpointer)0},
-   {{0.5,0.5,0, 1.f}, (gpointer)0},
-   {{0.5,0,0, 1.f}, (gpointer)0},
-   {{0,0.5,0, 1.f}, (gpointer)0},
-   {{0,0,0.5, 1.f}, (gpointer)0},
-   {{0.5,0.5,0.5, 1.f}, (gpointer)0},
-   {{1,0,0.5, 1.f}, (gpointer)0},
-   {{0.5,1,0, 1.f}, (gpointer)0},
-   {{0.5,0,1, 1.f}, (gpointer)0},
-   {{0,1,0.5, 1.f}, (gpointer)0},
-   {{0,0.5,1, 1.f}, (gpointer)0},
-   {{0,0,0, 1.f}, (gpointer)0}};
-
 /* Variables to store the glObjectList. */
 /* The default size of the table to store the user
    lists. */
@@ -106,11 +83,11 @@ static int nbGlObjectListRegistered;
 static int lastGlObjectListSize;
 
 /**
- * initObjectList: (skip)
+ * visu_gl_objectlist_init: (skip)
  *
  * Used to initialise this part of code, don't use it.
  */
-void initObjectList(void)
+void visu_gl_objectlist_init(void)
 {
   /* Initialisation of the table that stores the user
      glObjectList. */
@@ -122,7 +99,7 @@ void initObjectList(void)
 
 
 /**
- * visu_openGL_objectList_new:
+ * visu_gl_objectlist_new:
  * @size: the requested size.
  *
  * It returns the id that can be used to link glObjectList.
@@ -133,7 +110,7 @@ void initObjectList(void)
  *
  * Returns: an identifier used by OpenGl as a list.
  */
-int visu_openGL_objectList_new(int size)
+int visu_gl_objectlist_new(int size)
 {
   if (nbGlObjectListRegistered >= glObjectListRegisteredSize)
     {
@@ -249,8 +226,8 @@ static void drawEdgedTail(float tail_length, float tail_height)
 }
 
 /**
- * visu_openGL_drawSmoothArrow:
- * @obj: ...
+ * visu_gl_drawSmoothArrow:
+ * @obj: (type gpointer): ...
  * @material_id: an OpenGL list id for material change.
  * @centering: a flag.
  * @tailLength: length of tail part.
@@ -263,25 +240,25 @@ static void drawEdgedTail(float tail_length, float tail_height)
  * @hatUseMat: use the material colour for the hat part.
  *
  * Draw arrows, using sqaure edges. For rounded arrows, see
- * visu_openGL_drawEdgeArrow().
+ * visu_gl_drawEdgeArrow().
  * 
  * Since: 3.6
  */
-void visu_openGL_drawSmoothArrow(GLUquadricObj *obj, int material_id,
-				      VisuOpenGLArrowCentering centering,
+void visu_gl_drawSmoothArrow(GLUquadricObj *obj, int material_id,
+				      VisuGlArrowCentering centering,
 				      float tailLength, float tailRadius, float tailN,
 				      gboolean tailUseMat, float hatLength,
 				      float hatRadius, float hatN, gboolean hatUseMat)
 {
   switch (centering)
     {
-    case VISU_OPENGL_ARROW_TAIL_CENTERED:
+    case VISU_GL_ARROW_TAIL_CENTERED:
       glTranslatef(0.f, 0.f, tailLength / 2.f);
       break;
-    case VISU_OPENGL_ARROW_CENTERED:
+    case VISU_GL_ARROW_CENTERED:
       glTranslatef(0.f, 0.f, -(hatLength - tailLength) / 2.f);
       break;
-    case VISU_OPENGL_ARROW_BOTTOM_CENTERED:
+    case VISU_GL_ARROW_BOTTOM_CENTERED:
       glTranslatef(0.f, 0.f, tailLength);
       break;
     default:
@@ -317,7 +294,7 @@ void visu_openGL_drawSmoothArrow(GLUquadricObj *obj, int material_id,
     }
 }
 /**
- * visu_openGL_drawEdgeArrow:
+ * visu_gl_drawEdgeArrow:
  * @material_id: an OpenGL list id for material change.
  * @centering: a flag.
  * @tailLength: length of tail part.
@@ -328,11 +305,11 @@ void visu_openGL_drawSmoothArrow(GLUquadricObj *obj, int material_id,
  * @hatUseMat: use the material colour for the hat part.
  *
  * Draw arrows, using sqaure edges. For rounded arrows, see
- * visu_openGL_drawSmoothArrow().
+ * visu_gl_drawSmoothArrow().
  * 
  * Since: 3.6
  */
-void visu_openGL_drawEdgeArrow(int material_id, VisuOpenGLArrowCentering centering,
+void visu_gl_drawEdgeArrow(int material_id, VisuGlArrowCentering centering,
 				    float tailLength, float tailRadius,
 				    gboolean tailUseMat, float hatLength,
 				    float hatRadius, gboolean hatUseMat)
@@ -340,13 +317,13 @@ void visu_openGL_drawEdgeArrow(int material_id, VisuOpenGLArrowCentering centeri
   /* This one is a edged arrow. */
   switch (centering)
     {
-    case VISU_OPENGL_ARROW_TAIL_CENTERED:
+    case VISU_GL_ARROW_TAIL_CENTERED:
       glTranslatef(0.f, 0.f, tailLength / 2.f);
       break;
-    case VISU_OPENGL_ARROW_CENTERED:
+    case VISU_GL_ARROW_CENTERED:
       glTranslatef(0.f, 0.f, tailLength - (hatLength + tailLength) / 2.f);
       break;
-    case VISU_OPENGL_ARROW_BOTTOM_CENTERED:
+    case VISU_GL_ARROW_BOTTOM_CENTERED:
       glTranslatef(0.f, 0.f, tailLength);
       break;
     default:
@@ -377,8 +354,8 @@ void visu_openGL_drawEdgeArrow(int material_id, VisuOpenGLArrowCentering centeri
     }
 }
 /**
- * visu_openGL_drawEllipsoid:
- * @obj: ...
+ * visu_gl_drawEllipsoid:
+ * @obj: (type gpointer): ...
  * @material_id:  an OpenGL list id for material change.
  * @aAxis: length of long axis.
  * @bAxis: length of short axis.
@@ -389,7 +366,7 @@ void visu_openGL_drawEdgeArrow(int material_id, VisuOpenGLArrowCentering centeri
  *
  * Since: 3.6
  */
-void visu_openGL_drawEllipsoid(GLUquadricObj *obj, int material_id,
+void visu_gl_drawEllipsoid(GLUquadricObj *obj, int material_id,
 				    float aAxis, float bAxis,
 				    float n, gboolean useMat)
 {
@@ -402,8 +379,8 @@ void visu_openGL_drawEllipsoid(GLUquadricObj *obj, int material_id,
   gluSphere(obj, bAxis, n, n);
 }
 /**
- * visu_openGL_drawTorus:
- * @obj: ...
+ * visu_gl_drawTorus:
+ * @obj: (type gpointer): ...
  * @material_id:  an OpenGL list id for material change.
  * @radius: global radius.
  * @ratio: ratio on internal radius over global radius.
@@ -415,7 +392,7 @@ void visu_openGL_drawEllipsoid(GLUquadricObj *obj, int material_id,
  *
  * Since: 3.5
  */
-void visu_openGL_drawTorus(GLUquadricObj *obj _U_, int material_id, float radius,
+void visu_gl_drawTorus(GLUquadricObj *obj _U_, int material_id, float radius,
 				float ratio, int nA, int nB, gboolean useMat)
 {
   int i, j;
@@ -509,7 +486,7 @@ void visu_openGL_drawTorus(GLUquadricObj *obj _U_, int material_id, float radius
 }
 
 /**
- * visu_openGL_drawDistance:
+ * visu_gl_drawDistance:
  * @xyzRef: cartesian coordinates of first ref.
  * @xyz: cartesian coordinates of current point.
  * @drawLength: a boolean.
@@ -520,7 +497,7 @@ void visu_openGL_drawTorus(GLUquadricObj *obj _U_, int material_id, float radius
  *
  * Since: 3.6
  */
-void visu_openGL_drawDistance(float xyzRef[3], float xyz[3], gboolean drawLength)
+void visu_gl_drawDistance(float xyzRef[3], float xyz[3], gboolean drawLength)
 {
   float dist;
   int i;
@@ -548,12 +525,12 @@ void visu_openGL_drawDistance(float xyzRef[3], float xyz[3], gboolean drawLength
       glRasterPos3f((xyzRef[0] + xyz[0]) / 2.f,
 		    (xyzRef[1] + xyz[1]) / 2.f,
 		    (xyzRef[2] + xyz[2]) / 2.f); 
-      openGLText_drawChars(distStr, TEXT_NORMAL);
+      visu_gl_text_drawChars(distStr, VISU_GL_TEXT_NORMAL);
     }
 }
 
 /**
- * visu_openGL_drawAngle:
+ * visu_gl_drawAngle:
  * @xyzRef: cartesian coordinates of first ref.
  * @xyzRef2: cartesian coordinates of second ref.
  * @xyz: cartesian coordinates of current point.
@@ -567,12 +544,12 @@ void visu_openGL_drawDistance(float xyzRef[3], float xyz[3], gboolean drawLength
  *
  * Since: 3.6
  */
-void visu_openGL_drawAngle(float xyzRef[3], float xyzRef2[3],
+void visu_gl_drawAngle(float xyzRef[3], float xyzRef2[3],
 				float xyz[3], guint id, gboolean drawLength)
 {
   float dist, u[3], v[3], M[3], c, s, theta, thetaM, l;
   int i, iM;
-  char distStr[8];
+  char distStr[9];
 
   /* We calculate the new basis set. */
   u[0] = xyz[0] - xyzRef[0];
@@ -600,8 +577,8 @@ void visu_openGL_drawAngle(float xyzRef[3], float xyzRef2[3],
   iM     = MAX((int)(thetaM / G_PI * 20.f), 2);
   if (drawLength)
     {
-      sprintf(distStr, "%5.1f", thetaM * 180.f / G_PI);
-      distStr[7] = '\0';
+      sprintf(distStr, "%5.1f\302\260", thetaM * 180.f / G_PI);
+      distStr[8] = '\0';
       DBG_fprintf(stderr, "OpenGL Objects: the angle is %g.\n",
 		  thetaM * 180.f / G_PI);
     }
@@ -635,7 +612,7 @@ void visu_openGL_drawAngle(float xyzRef[3], float xyzRef2[3],
 
   glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 
-  glColor4fv(brightColors[id % N_BRIGHT_COLORS].rgba);
+  glColor4fv(tool_color_new_bright(id)->rgba);
   if (drawLength)
     {
       theta = 0.5f * thetaM;
@@ -645,7 +622,7 @@ void visu_openGL_drawAngle(float xyzRef[3], float xyzRef2[3],
       M[1] = xyzRef[1] + (u[1] * c + v[1] * s) * l * 1.33f;
       M[2] = xyzRef[2] + (u[2] * c + v[2] * s) * l * 1.33f;
       glRasterPos3fv(M);
-      openGLText_drawChars(distStr, TEXT_SMALL); 
+      visu_gl_text_drawChars(distStr, VISU_GL_TEXT_SMALL); 
     }
 
   glLineWidth(1);
