@@ -45,6 +45,9 @@
 #include <stdlib.h>
 #include <math.h>
 
+#include <GL/gl.h>
+#include <GL/glu.h> 
+
 #include "opengl.h"
 
 #include "visu_extension.h"
@@ -84,21 +87,21 @@
 /******************************************************************************/
 
 /* static int stereo; */
-static LightEnvironnement *currentLights = NULL;
+static VisuGlLights *currentLights = NULL;
 
 #define FLAG_PARAMETER_OPENGL_IMMEDIATE   "opengl_immediateDrawing"
 #define DESC_PARAMETER_OPENGL_IMMEDIATE   "If true, changes of parameters means immediate redrawing ; boolean 0 or 1"
 #define PARAMETER_OPENGL_IMMEDIATE_DEFAULT 1
-static int opengl_immediate;
-static gboolean readOpenGLImmediate(gchar **lines, int nbLines, int position,
-				       VisuData *dataObj, GError **error);
+static gboolean opengl_immediate;
+static gboolean readOpenGLImmediate(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+                                    VisuData *dataObj, VisuGlView *view, GError **error);
 
 #define FLAG_PARAMETER_OPENGL_ANTIALIAS "opengl_antialias"
 #define DESC_PARAMETER_OPENGL_ANTIALIAS "If true, lines are drawn smoother ; boolean 0 or 1"
 #define PARAMETER_OPENGL_ANTIALIAS_DEFAULT 0
-static int antialias;
-static gboolean readOpenGLAntialias(gchar **lines, int nbLines, int position,
-				       VisuData *dataObj, GError **error);
+static gboolean antialias;
+static gboolean readOpenGLAntialias(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+                                    VisuData *dataObj, VisuGlView *view, GError **error);
 
 #define FLAG_PARAMETER_OPENGL_FAKEBS "opengl_fakeBackingStore"
 #define DESC_PARAMETER_OPENGL_FAKEBS "If true, V_Sim catches the Expose event from the X server and calls a redraw ; boolean 0 or 1"
@@ -108,69 +111,71 @@ static int fakeBackingStore;
 #define FLAG_PARAMETER_OPENGL_TRANS "opengl_trueTransparency"
 #define DESC_PARAMETER_OPENGL_TRANSS "If true, the transparency rendering is enhanced ; boolean 0 or 1"
 static gboolean trueTransparency = FALSE;
-static gboolean readOpenGLTransparency(gchar **lines, int nbLines, int position,
-				       VisuData *dataObj, GError **error);
+static gboolean readOpenGLTransparency(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+				       VisuData *dataObj, VisuGlView *view,
+                                       GError **error);
 
 #define FLAG_PARAMETER_OPENGL_ANGLE "opengl_stereoAngle"
 #define DESC_PARAMETER_OPENGL_ANGLE "Give the angle of the two receivers in stereo output ; float positive"
 static float stereoAngles[2];
 #define PARAMETER_OPENGL_ANGLE_DEFAULT 5.f
-static gboolean readOpenGLStereoAngle(gchar **lines, int nbLines, int position,
-				       VisuData *dataObj, GError **error);
+static gboolean readOpenGLStereoAngle(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+                                      VisuData *dataObj, VisuGlView *view,
+                                      GError **error);
 
 #define FLAG_PARAMETER_OPENGL_STEREO "opengl_stereo"
 #define DESC_PARAMETER_OPENGL_STEREO "If true, try to draw in stereo ; boolean 0 or 1"
 static gboolean stereoStatus = FALSE;
-static gboolean readOpenGLStereo(gchar **lines, int nbLines, int position,
-				       VisuData *dataObj, GError **error);
+static gboolean readOpenGLStereo(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+                                 VisuData *dataObj, VisuGlView *view, GError **error);
 
 /* Local methods. */
-static void exportParametersOpenGL(GString *data, VisuData *dataObj);
+static void exportParametersOpenGL(GString *data, VisuData *dataObj, VisuGlView *view);
 static void glSetAntiAlias();
 
 /******************************************************************************/
 
 /**
- * initOpengl:
+ * visu_gl_init:
  *
  * This initialises the drawing window and all the variables used
  * by this module. It must be called once by the main program and should
  * not be used otherwise.
  */
-void initOpengl()
+void visu_gl_init()
 {
   VisuConfigFileEntry *resourceEntry;
 
   DBG_fprintf(stderr, "OpenGl: initialization.\n");
 
   /* Parameters */
-  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
+  resourceEntry = visu_config_file_addEntry(VISU_CONFIG_FILE_PARAMETER,
 					  FLAG_PARAMETER_OPENGL_TRANS,
 					  DESC_PARAMETER_OPENGL_TRANSS,
 					  1, readOpenGLTransparency);
-  visu_configFile_entry_setVersion(resourceEntry, 3.4f);
-  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
+  visu_config_file_entry_setVersion(resourceEntry, 3.4f);
+  resourceEntry = visu_config_file_addEntry(VISU_CONFIG_FILE_PARAMETER,
 					  FLAG_PARAMETER_OPENGL_ANTIALIAS,
 					  DESC_PARAMETER_OPENGL_ANTIALIAS,
 					  1, readOpenGLAntialias);
-  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
+  resourceEntry = visu_config_file_addEntry(VISU_CONFIG_FILE_PARAMETER,
 					  FLAG_PARAMETER_OPENGL_IMMEDIATE,
 					  DESC_PARAMETER_OPENGL_IMMEDIATE,
 					  1, readOpenGLImmediate);
-  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
+  resourceEntry = visu_config_file_addEntry(VISU_CONFIG_FILE_PARAMETER,
 					  FLAG_PARAMETER_OPENGL_ANGLE,
 					  DESC_PARAMETER_OPENGL_ANGLE,
 					  1, readOpenGLStereoAngle);
-  visu_configFile_entry_setVersion(resourceEntry, 3.4f);
-  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
+  visu_config_file_entry_setVersion(resourceEntry, 3.4f);
+  resourceEntry = visu_config_file_addEntry(VISU_CONFIG_FILE_PARAMETER,
 					  FLAG_PARAMETER_OPENGL_STEREO,
 					  DESC_PARAMETER_OPENGL_STEREO,
 					  1, readOpenGLStereo);
-  visu_configFile_entry_setVersion(resourceEntry, 3.4f);
-  visu_configFile_addExportFunction(VISU_CONFIGFILE_PARAMETER,
+  visu_config_file_entry_setVersion(resourceEntry, 3.4f);
+  visu_config_file_addExportFunction(VISU_CONFIG_FILE_PARAMETER,
 				   exportParametersOpenGL);
   
-  g_type_class_ref(visuInteractive_get_type());
+  g_type_class_ref(visu_interactive_get_type());
 
   antialias = PARAMETER_OPENGL_ANTIALIAS_DEFAULT;
   fakeBackingStore = PARAMETER_OPENGL_FAKEBS_DEFAULT;
@@ -178,41 +183,37 @@ void initOpengl()
   stereoAngles[0] = +PARAMETER_OPENGL_ANGLE_DEFAULT;
   stereoAngles[1] = -PARAMETER_OPENGL_ANGLE_DEFAULT;
 
-  initObjectList();
+  visu_gl_objectlist_init();
 }
 /**
- * initOpenglGraphics:
+ * visu_gl_initGraphics:
  *
  * Internal use only. Call at startup to call OpenGL initialisation routines.
  *
  * Since: 3.6
  */
-void initOpenglGraphics()
+void visu_gl_initGraphics()
 {
   /* Deals with lights. */
-  currentLights = lightEnvironnement_new();
-  lightEnvironnementAdd_light(currentLights, light_newDefault());
+  currentLights = visu_gl_lights_new();
+  visu_gl_lights_add(currentLights, visu_gl_light_newDefault());
 
   /* Initialise others sub-modules dealing with OpenGL. */
-  openGLInit_renderingMode();
-  VisuOpenGLViewInit();
-
-  /* Charge toutes les extensions OpenGL. */
-  DBG_fprintf(stderr,"--- Initialising external OpenGL Extensions ---\n");
-  loadExtensions();
+  visu_gl_rendering_init();
+  g_type_class_ref(VISU_TYPE_GL_VIEW);
 }
 
 /**
- * openGLGet_currentLights:
+ * visu_gl_getLights:
  *
  * V_Sim proposes a wrapper around the OpenGL light definitions.
  *
  * Returns: the set of current lights.
  */
-LightEnvironnement* openGLGet_currentLights()
+VisuGlLights* visu_gl_getLights()
 {
   if (!currentLights)
-    initOpenglGraphics();
+    visu_gl_initGraphics();
 
   return currentLights;
 }
@@ -220,68 +221,70 @@ LightEnvironnement* openGLGet_currentLights()
 /******************************************************************************/
 
 /**
- * openGLSet_color:
+ * visu_gl_setColor:
  * @material: a 5 elements array with the material properties ;
  * @rgba: a 4 elements array with the color values.
  *
  * This method call glMaterial to create the right shiningness, emission, diffuse...
  */
-void openGLSet_color(float* material, float* rgba)
+void visu_gl_setColor(float* material, float* rgba)
 {
   float mm[4] = {0.0f, 0.0f, 0.0f, 0.0f};
 
+  DBG_fprintf(stderr, "OpenGL: set rgba colours %gx%gx%gx%g.\n",
+              rgba[0], rgba[1], rgba[2], rgba[3]);
   glColor4fv(rgba);
 
   mm[3] = rgba[3];
-  mm[0] = material[material_amb] * rgba[0];
-  mm[1] = material[material_amb] * rgba[1];
-  mm[2] = material[material_amb] * rgba[2];
+  mm[0] = material[VISU_GL_LIGHT_MATERIAL_AMB] * rgba[0];
+  mm[1] = material[VISU_GL_LIGHT_MATERIAL_AMB] * rgba[1];
+  mm[2] = material[VISU_GL_LIGHT_MATERIAL_AMB] * rgba[2];
   glMaterialfv(GL_FRONT, GL_AMBIENT, mm);
-  mm[0] = material[material_dif] * rgba[0];
-  mm[1] = material[material_dif] * rgba[1];
-  mm[2] = material[material_dif] * rgba[2];
+  mm[0] = material[VISU_GL_LIGHT_MATERIAL_DIF] * rgba[0];
+  mm[1] = material[VISU_GL_LIGHT_MATERIAL_DIF] * rgba[1];
+  mm[2] = material[VISU_GL_LIGHT_MATERIAL_DIF] * rgba[2];
   glMaterialfv(GL_FRONT, GL_DIFFUSE, mm);
-  glMaterialf(GL_FRONT, GL_SHININESS, material[material_shi] * 128.0f);
-  mm[0] = material[material_spe];
-  mm[1] = material[material_spe];
-  mm[2] = material[material_spe];
+  glMaterialf(GL_FRONT, GL_SHININESS, material[VISU_GL_LIGHT_MATERIAL_SHI] * 128.0f);
+  mm[0] = material[VISU_GL_LIGHT_MATERIAL_SPE];
+  mm[1] = material[VISU_GL_LIGHT_MATERIAL_SPE];
+  mm[2] = material[VISU_GL_LIGHT_MATERIAL_SPE];
   glMaterialfv(GL_FRONT, GL_SPECULAR, mm);
-  mm[0] = material[material_emi] * rgba[0];
-  mm[1] = material[material_emi] * rgba[1];
-  mm[2] = material[material_emi] * rgba[2];
+  mm[0] = material[VISU_GL_LIGHT_MATERIAL_EMI] * rgba[0];
+  mm[1] = material[VISU_GL_LIGHT_MATERIAL_EMI] * rgba[1];
+  mm[2] = material[VISU_GL_LIGHT_MATERIAL_EMI] * rgba[2];
   glMaterialfv(GL_FRONT, GL_EMISSION, mm);
 }
 /**
- * openGLSet_highlightColor:
+ * visu_gl_setHighlightColor:
  * @material: a 5 elements array with the material properties ;
  * @rgb: a 3 elements array with the color values.
  * @alpha: the alpha channel.
  *
  * This method try to set a colour that will contrast with @rgb.
  */
-void openGLSet_highlightColor(float material[5], float rgb[3], float alpha)
+void visu_gl_setHighlightColor(float material[5], float rgb[3], float alpha)
 {
   float rgba[4], hsl[3];
   
   tool_color_convertRGBtoHSL(hsl, rgb);
-  hsl[0] = fModulo(0.5f + hsl[0], 1);
+  hsl[0] = tool_modulo_float(0.5f + hsl[0], 1);
   hsl[1] = 1.f;
   hsl[2] = .5f;
   tool_color_convertHSLtoRGB(rgba, hsl);
   rgba[3] = alpha;
-  openGLSet_color(material, rgba);
+  visu_gl_setColor(material, rgba);
 }
 
 /**
- * openGLInit_context:
+ * visu_gl_initContext:
  *
  * This method is called when an OpenGL surface is created for the first time.
  * It sets basic OpenGL options and calls other OpenGLFunctions used in V_Sim.
  */
-void openGLInit_context()
+void visu_gl_initContext()
 {
   if (!currentLights)
-    initOpengl();
+    visu_gl_initGraphics();
 
   /* Set the openGL flags. */
   glEnable(GL_DEPTH_TEST);
@@ -297,8 +300,8 @@ void openGLInit_context()
   glEnable(GL_BLEND);
   glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 
-  lightEnvironnementApply(currentLights);
-  openGLApply_renderingMode(openGLGet_globalRenderingOption());
+  visu_gl_lights_apply(currentLights);
+  visu_gl_rendering_applyMode(visu_gl_rendering_getGlobalMode());
 
   glSetAntiAlias();
 }
@@ -306,21 +309,22 @@ void openGLInit_context()
 /******************************************************************************/
 
 /**
- * openGL_reDraw:
- * @lists: (array zero-terminated=1) (allow-none): a string array, NULL terminated.
- * @data: the #VisuData to redraw.
+ * visu_gl_redraw:
+ * @view: (transfer none): a #VisuGlView object with the camera settings.
+ * @lists: (element-type v_sim.GlExt) (transfer none) (allow-none): a
+ * #VisuGlExt array or %NULL.
  *
  * Basic drawing method : it clears the OpenGL area and call all lists if @lists
- * is NULL, or draw only the given lists.
+ * is %NULL, or draw only the given lists.
  */
-void openGL_reDraw(const char **lists, VisuData *data)
+void visu_gl_redraw(VisuGlView *view, GList *lists)
 {
-  int i, i_stereo, stereo;
+  int i_stereo, stereo;
   static int stereo_buf[2] = {GL_BACK_LEFT, GL_BACK_RIGHT};
-  VisuOpenGLView *view;
   GLboolean glStereo;
   float centre[3];
-
+  GList *ext, *lst;
+  VisuBox *box;
 #if DEBUG == 1
   GTimer *timer;
   gulong fractionTimer;
@@ -331,10 +335,19 @@ void openGL_reDraw(const char **lists, VisuData *data)
   g_timer_start(timer);
 #endif
   
-  g_return_if_fail(IS_VISU_DATA_TYPE(data));
+  box = visu_boxed_getBox(VISU_BOXED(view));
+  if (box)
+    visu_box_getCentre(box, centre);
+  else
+    {
+      centre[0] = 0.f;
+      centre[1] = 0.f;
+      centre[2] = 0.f;
+    }
 
-  view = visu_data_getOpenGLView(data);
-  visu_data_getBoxCentre(data, centre);
+  ext = lists;
+  if (!lists)
+    ext = visu_gl_ext_getAll();
 
   glGetBooleanv(GL_STEREO, &glStereo);
   stereo = (view && glStereo && stereoStatus)?1:0;
@@ -359,51 +372,47 @@ void openGL_reDraw(const char **lists, VisuData *data)
 
       glEnable(GL_DEPTH_TEST);
 
-      if (!lists && !trueTransparency)
-        {
-          visuExtensions_callAllLists();
-          visuExtensions_callAllLastLists();
-        }
-      else if (!lists && trueTransparency)
-        {
-          glDepthMask(1);
-          glEnable(GL_ALPHA_TEST);
-          glAlphaFunc(GL_EQUAL, 1.);
-          visuExtensions_callAllLists();
-          DBG_fprintf(stderr, "OpenGL: second pass for transparency.\n");
-          glAlphaFunc(GL_LESS, 1.);
-          glDepthMask(0);
-          visuExtensions_callAllLists();
-          glDepthMask(1);
-          glAlphaFunc(GL_ALWAYS, 1.);
-          glDisable(GL_ALPHA_TEST);
-          visuExtensions_callAllLastLists();
-        }
-      else if (!trueTransparency)
-        {
-          for (i = 0; lists[i]; i++)
-            visuExtensions_callList(lists[i], FALSE);
-          for (i = 0; lists[i]; i++)
-            visuExtensions_callList(lists[i], TRUE);
-        }
+      /* if (!lists && !trueTransparency) */
+      /*   { */
+      /*     visu_gl_ext_callAll(FALSE); */
+      /*     visu_gl_ext_callAll(TRUE); */
+      /*   } */
+      /* else if (!lists && trueTransparency) */
+      /*   { */
+      /*     glDepthMask(1); */
+      /*     glEnable(GL_ALPHA_TEST); */
+      /*     glAlphaFunc(GL_EQUAL, 1.); */
+      /*     visu_gl_ext_callAll(FALSE); */
+      /*     DBG_fprintf(stderr, "OpenGL: second pass for transparency.\n"); */
+      /*     glAlphaFunc(GL_LESS, 1.); */
+      /*     glDepthMask(0); */
+      /*     visu_gl_ext_callAll(FALSE); */
+      /*     glDepthMask(1); */
+      /*     glAlphaFunc(GL_ALWAYS, 1.); */
+      /*     glDisable(GL_ALPHA_TEST); */
+      /*     visu_gl_ext_callAll(TRUE); */
+      /*   } */
+      /* else */ if (!trueTransparency)
+        for (lst = ext; lst; lst = g_list_next(lst))
+          visu_gl_ext_call(VISU_GL_EXT(lst->data), FALSE);
       else
         {
           glDepthMask(1);
           glEnable(GL_ALPHA_TEST);
           glAlphaFunc(GL_EQUAL, 1.);
-          for (i = 0; lists[i]; i++)
-            visuExtensions_callList(lists[i], FALSE);
+          for (lst = ext; lst; lst = g_list_next(lst))
+            visu_gl_ext_call(VISU_GL_EXT(lst->data), FALSE);
           DBG_fprintf(stderr, "OpenGL: second pass for transparency.\n");
           glAlphaFunc(GL_LESS, 1.);
           glDepthMask(0);
-          for (i = 0; lists[i]; i++)
-            visuExtensions_callList(lists[i], FALSE);
+          for (lst = ext; lst; lst = g_list_next(lst))
+            visu_gl_ext_call(VISU_GL_EXT(lst->data), FALSE);
           glDepthMask(1);
           glAlphaFunc(GL_ALWAYS, 1.);
           glDisable(GL_ALPHA_TEST);
-          for (i = 0; lists[i]; i++)
-            visuExtensions_callList(lists[i], TRUE);
         }
+      for (lst = ext; lst; lst = g_list_next(lst))
+        visu_gl_ext_call(VISU_GL_EXT(lst->data), TRUE);
 
       glPopMatrix();
     }
@@ -439,23 +448,45 @@ static void glSetAntiAlias()
 /*       glDisable(GL_BLEND); */
     }
 }
-int openGLSet_antialias(int value)
+/**
+ * visu_gl_setAntialias:
+ * @value: a boolean to activate or not the lines antialias.
+ *
+ * To set the antialiasing on lines.
+ *
+ * Returns: TRUE if the signal OpenGLAskForReDraw should be emitted.
+ */
+gboolean visu_gl_setAntialias(gboolean value)
 {
   if (value == antialias)
-    return 0;
+    return FALSE;
 
   antialias = value;
   glSetAntiAlias();
   
-  return 1;
+  return TRUE;
 }
-/* Get the value of the antialiasing parameter. */
-int openGLGet_antialias()
+/**
+ * visu_gl_getAntialias:
+ *
+ * Get the value of the antialiasing parameter.
+ *
+ * Returns: wether or not the antialising for lines is activated.
+ */
+gboolean visu_gl_getAntialias()
 {
   return antialias;
 }
 
-gboolean openGLSet_trueTransparency(gboolean status)
+/**
+ * visu_gl_setTrueTransparency:
+ * @status: a boolean.
+ *
+ * If true the rendering is done twice to respect the transparency.
+ *
+ * Returns: TRUE if redraw should be done.
+ */
+gboolean visu_gl_setTrueTransparency(gboolean status)
 {
   if (status == trueTransparency)
     return FALSE;
@@ -463,25 +494,55 @@ gboolean openGLSet_trueTransparency(gboolean status)
   trueTransparency = status;  
   return TRUE;
 }
-gboolean openGLGet_trueTransparency()
+/**
+ * visu_gl_getTrueTransparency:
+ *
+ * The drawing can be done in one pass or two to respect transparency.
+ *
+ * Returns: TRUE if the drawing is done twice.
+ */
+gboolean visu_gl_getTrueTransparency()
 {
   return trueTransparency;
 }
 
-/* If true all changes are applied only when the refresh button
-   is pushed. */
-void openGLSet_immediate(int bool)
+/**
+ * visu_gl_setImmediate:
+ * @bool: a boolean to set or not the immediateDrawing option.
+ *
+ * If true all changes are applied only when the refresh button
+ * is pushed.
+ *
+ * Returns: TRUE if the value is changed.
+ */
+gboolean visu_gl_setImmediate(gboolean bool)
 {
   if (bool == opengl_immediate)
-    return;
+    return FALSE;
 
   opengl_immediate = bool;
+  return TRUE;
 }
-int openGLGet_immediate()
+/**
+ * visu_gl_getImmediate:
+ *
+ * Get the value of the immediateDrawing option.
+ *
+ * Returns: the value of the immediateDrawing option.
+ */
+gboolean visu_gl_getImmediate()
 {
   return opengl_immediate;
 }
-gboolean openGLSet_stereoAngle(float angle)
+/**
+ * visu_gl_setStereoAngle:
+ * @angle: a positive floating point value.
+ *
+ * Change the angle of the eyes in the stereo output.
+ *
+ * Returns: TRUE if redraw should be done.
+ */
+gboolean visu_gl_setStereoAngle(float angle)
 {
   g_return_val_if_fail(angle > 0.f, FALSE);
 
@@ -493,11 +554,25 @@ gboolean openGLSet_stereoAngle(float angle)
 
   return stereoStatus;
 }
-float openGLGet_stereoAngle()
+/**
+ * visu_gl_getStereoAngle:
+ *
+ * Retrieve the angle of the eyes in the stereo output.
+ *
+ * Returns: the angle.
+ */
+float visu_gl_getStereoAngle()
 {
   return stereoAngles[0];
 }
-gboolean openGLGet_stereoCapability()
+/**
+ * visu_gl_getStereoCapability:
+ *
+ * Retrieve if the OpenGL window can render in stereo or not.
+ *
+ * Returns: TRUE if the OpenGL surface can draw in stereo.
+ */
+gboolean visu_gl_getStereoCapability()
 {
   GLboolean glStereo;
 
@@ -505,96 +580,119 @@ gboolean openGLGet_stereoCapability()
 
   return (gboolean)glStereo;
 }
-void openGLSet_stereo(gboolean status)
+/**
+ * visu_gl_setStereo:
+ * @status: a boolean.
+ *
+ * Change the type of rendering. The surface can be switch to stereo,
+ * only if the OpenGL has stereo capabilities (see
+ * visu_gl_getStereoCapability()).
+ */
+gboolean visu_gl_setStereo(gboolean status)
 {
   if (stereoStatus == status)
-    return;
+    return FALSE;
   stereoStatus = status;
+  return TRUE;
 }
-gboolean openGLGet_stereo()
+/**
+ * visu_gl_getStereo:
+ *
+ * Retrieve the status of the OpenGL surface.
+ *
+ * Returns: TRUE if the surface try to draw in stereo (may be TRUE,
+ *          even if visu_gl_getStereoCapability() returns FALSE, in
+ *          that case the stereo capability is not used).
+ */
+gboolean visu_gl_getStereo()
 {
   return stereoStatus;
 }
 
-
 /***************************/
 /* Dealing with parameters */
 /***************************/
 
-static gboolean readOpenGLAntialias(gchar **lines, int nbLines, int position,
-				    VisuData *dataObj _U_, GError **error)
+static gboolean readOpenGLAntialias(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+				    VisuData *dataObj _U_, VisuGlView *view _U_,
+                                    GError **error)
 {
   gboolean val;
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!tool_configFile_readBoolean(lines[0], position, &val, 1, error))
+  if (!tool_config_file_readBoolean(lines[0], position, &val, 1, error))
     return FALSE;
-  openGLSet_antialias((int)val);
+  visu_gl_setAntialias((int)val);
 
   return TRUE;
 }
 
-static gboolean readOpenGLImmediate(gchar **lines, int nbLines, int position,
-				    VisuData *dataObj _U_, GError **error)
+static gboolean readOpenGLImmediate(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+				    VisuData *dataObj _U_, VisuGlView *view _U_,
+                                    GError **error)
 {
   gboolean val;
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!tool_configFile_readBoolean(lines[0], position, &val, 1, error))
+  if (!tool_config_file_readBoolean(lines[0], position, &val, 1, error))
     return FALSE;
-  openGLSet_immediate((int)val);
+  visu_gl_setImmediate((int)val);
 
   return TRUE;
 }
-static gboolean readOpenGLTransparency(gchar **lines, int nbLines, int position,
-				       VisuData *dataObj _U_, GError **error)
+static gboolean readOpenGLTransparency(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+				       VisuData *dataObj _U_, VisuGlView *view _U_,
+                                       GError **error)
 {
   gboolean val;
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!tool_configFile_readBoolean(lines[0], position, &val, 1, error))
+  if (!tool_config_file_readBoolean(lines[0], position, &val, 1, error))
     return FALSE;
-  openGLSet_trueTransparency(val);
+  visu_gl_setTrueTransparency(val);
 
   return TRUE;
 }
-static gboolean readOpenGLStereo(gchar **lines, int nbLines, int position,
-				 VisuData *dataObj _U_, GError **error)
+static gboolean readOpenGLStereo(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+				 VisuData *dataObj _U_, VisuGlView *view _U_,
+                                 GError **error)
 {
   gboolean val;
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!tool_configFile_readBoolean(lines[0], position, &val, 1, error))
+  if (!tool_config_file_readBoolean(lines[0], position, &val, 1, error))
     return FALSE;
-  openGLSet_stereo(val);
+  visu_gl_setStereo(val);
 
   return TRUE;
 }
-static gboolean readOpenGLStereoAngle(gchar **lines, int nbLines, int position,
-				      VisuData *dataObj _U_, GError **error)
+static gboolean readOpenGLStereoAngle(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+				      VisuData *dataObj _U_, VisuGlView *view _U_,
+                                      GError **error)
 {
   float val;
   
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!tool_configFile_readFloat(lines[0], position, &val, 1, error))
+  if (!tool_config_file_readFloat(lines[0], position, &val, 1, error))
     return FALSE;
   if (val <= 0.f)
     {
-      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIG_FILE_ERROR, TOOL_CONFIG_FILE_ERROR_VALUE,
 			   _("Parse error at line %d: angle must be positive.\n"),
 			   position);
       return FALSE;
     }
-  openGLSet_stereoAngle(val);
+  visu_gl_setStereoAngle(val);
 
   return TRUE;
 }
-static void exportParametersOpenGL(GString *data, VisuData *dataObj _U_)
+static void exportParametersOpenGL(GString *data,
+                                   VisuData *dataObj _U_, VisuGlView *view _U_)
 {
   g_string_append_printf(data, "# %s\n", DESC_PARAMETER_OPENGL_ANTIALIAS);
   g_string_append_printf(data, "%s: %d\n\n", FLAG_PARAMETER_OPENGL_ANTIALIAS,
