@@ -47,42 +47,12 @@
 #include <gtk/gtk.h>
 #include <visu_pairs.h>
 
-/**
- * gtkPairsCylinderInit:
- *
- * This routine is used by V_Sim to initialise the Gtk part of
- * cylinder pair model. This should be called once on start-up.
- */
-void gtkPairsCylinderInit(void);
+void visu_ui_pairs_cylinder_init(void);
 
-/**
- * gtkPairsCylinderBuild_widgets:
- *
- * This routine create a container #GtkWidget that hold all widgets
- * necessary for handling cylinder pair model.
- *
- * Returns: a newly created #GtkWidget.
- */
-GtkWidget* gtkPairsCylinderBuild_widgets();
+GtkWidget* visu_ui_pairs_cylinder_initBuild();
 
-/**
- * gtkPairsCylinderSet_values:
- * @data: information about a pair.
- *
- * Change the widget values with the given information. This change trigger
- * no signals.
- */
-void gtkPairsCylinderSet_values(VisuPairData *data);
+void visu_ui_pairs_cylinder_setValues(VisuPairLink *data);
 
-/**
- * gtkPairsCylinderGet_valuesAsLabel:
- * @data: information about a pair
- *
- * Create an internationalised UTF-8 label that describes the
- * information about a pair.
- *
- * Returns: a newly allocated string.
- */
-gchar* gtkPairsCylinderGet_valuesAsLabel(VisuPairData *data);
+gchar* visu_ui_pairs_cylinder_getValues(VisuPairLink *data);
 
 #endif
