@@ -49,9 +49,9 @@
  *
  * Prototype of the functions used to initialise a new panel.
  *
- * Returns: a newly created #ToolPanel.
+ * Returns: a newly created #VisuUiPanel.
  */
-typedef ToolPanel* (*PanelInitFunc) ();
+typedef VisuUiPanel* (*PanelInitFunc) (VisuUiMain *main);
 
 #include "panelGeometry.h"
 #include "panelVibration.h"
@@ -69,19 +69,19 @@ typedef ToolPanel* (*PanelInitFunc) ();
 
 
 PanelInitFunc panelListAll[] = {
-  panelElementsInit,
-  panelAxes_init,
-  panelFogBgColor_init,
-  panelBrowser_init,
-  panelGeometry_init,
-  panelDataFileInit,
-  panelPlanesInit,
-  panelIsosurfacesInit,
-  panelMapInit,
-  panelVibration_init,
-  panelMethodInit,
-  panelOpenGL_init,
-  panelConfigInit,
+  visu_ui_panel_elements_init,
+  visu_ui_panel_axes_init,
+  visu_ui_panel_bg_init,
+  visu_ui_panel_browser_init,
+  visu_ui_panel_geometry_init,
+  visu_ui_panel_colorization_init,
+  visu_ui_panel_planes_init,
+  visu_ui_panel_surfaces_init,
+  visu_ui_panel_map_init,
+  visu_ui_panel_vibration_init,
+  visu_ui_panel_method_init,
+  visu_ui_panel_gl_init,
+  visu_ui_panel_config_init,
   (PanelInitFunc)0};
 
 #endif
