@@ -49,51 +49,20 @@
    to adjust resources values introduced with the
    atomic render method. */
 
-#include <visu_elements.h>
-
 #include <gtk/gtk.h>
 
 /***************/
 /* Public part */
 /***************/
 
-/**
- * panelElementAtomicInit_gtkPanel:
- *
- * Initialise the specific area in the element panel
- * for the atomic rendering method.
- */
-void panelElementAtomicInit_gtkPanel();
+void visu_ui_panel_elements_atomic_init();
 
-/**
- * panelElementAtomicInit_gtkMain:
- *
- * Initialise the gtk methods associated with
- * the atomic rendering method.
- */
-void panelElementAtomicInit_gtkMain();
+void visu_ui_panel_elements_atomic_initOpen();
 
-/**
- * panelElementAtomicCreate_gtkInterface:
- * 
- * Create the gtk widgets (a hbox with a spin with
- *  positive values) and return it.
- *
- * Returns: newly created widgets to handle atomic rendering
- * characteristics of elements.
- */
-GtkWidget* panelElementAtomicCreate_gtkInterface();
+void visu_ui_panel_elements_atomic_initMethod();
 
-/**
- * panelElementAtomicCallback_onElementChange:
- * @eleList: a list of #VisuElement.
- *
- * Call this routine with a list of #VisuElement to change the values
- * shown in the widgets controling the atomic rendering. The values to
- * be put are read from the first #VisuElement of the list. The list
- * is then stored for future changes to the widgets will be applied to
- * all these elements.
- */
-void panelElementAtomicCallback_onElementChange(GList *eleList);
+GtkWidget* visu_ui_panel_elements_atomic_initBuild();
+
+void visu_ui_panel_elements_atomic_onChange(GList *eleList);
    
 #endif
