@@ -64,7 +64,7 @@
  * @short_description: The gtk interface elements that can interfere
  * with renderingSpin parameters.
  *
- * <para>This is the gtk interface for all #RenderingSpin module
+ * <para>This is the gtk interface for all #VisuRenderingSpin module
  * parameters. They are split in two parts. The first part is placed
  * under the config tab and allows the user to modify the "global
  * properties" of the renderingSpin module such as cone's axe
@@ -116,7 +116,7 @@ struct FileChooserSpin_struct
   GtkWidget* apply[2];
   int fileKind;
 
-  VisuGtkPreview preview;
+  VisuUiPreview preview;
 };
 /* A special widget to select two kind of files at a time. */
 static gboolean gtkSpinCreate_fileChooser(VisuData *data, GtkWindow *parent);
@@ -150,18 +150,18 @@ static void sync_local_resources(GObject *trash, gpointer data);
 /***************/
 
 /* See h file for more info */
-void panelElementSpinInit_gtkPanel()
+void visu_ui_panel_elements_spin_init()
 {
-  panelElements_setInterfaceMethods(visu_rendering_getByName
+  visu_ui_panel_elements_setMethod(visu_rendering_getByName
 				    (VISU_RENDERING_SPIN_NAME),
 				    changeSomethingSpin,
 				    createGtkInterfaceForSpinMethod);
 }
 
 /* See h file for more info */
-void panelElementSpinInit_gtkConfig()
+void visu_ui_panel_elements_spin_initMethod()
 {
-  panelMethodSet_renderingInterface(visu_rendering_getByName
+  visu_ui_panel_method_set(visu_rendering_getByName
 				    (VISU_RENDERING_SPIN_NAME),
 				    createGtkConfigForSpinMethod,
 				    destroyGtkConfigForSpinMethod);
@@ -283,7 +283,7 @@ GtkWidget* createHidingModeRadioWidgets()
 {
   GtkWidget *hbox;
   GSList *radiobutton_group;
-  SpinDrawingPolicy policy;
+  VisuRenderingSpinDrawingPolicy policy;
 
   hbox = gtk_hbox_new(FALSE, 0);
   radioAlwaysSpin = gtk_radio_button_new_with_label(NULL, _("always"));
@@ -291,30 +291,30 @@ GtkWidget* createHidingModeRadioWidgets()
   radiobutton_group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(radioAlwaysSpin));
   gtk_box_pack_start(GTK_BOX(hbox), radioAlwaysSpin, TRUE, TRUE, 1);
   g_signal_connect(G_OBJECT(radioAlwaysSpin), "toggled",
-		   G_CALLBACK(onPolicyChanged), GINT_TO_POINTER(policyAlwaysSpin));
+		   G_CALLBACK(onPolicyChanged), GINT_TO_POINTER(VISU_RENDERING_SPIN_ALWAYS));
   radioEmptySpin = gtk_radio_button_new_with_label(NULL, _("never"));
   gtk_radio_button_set_group(GTK_RADIO_BUTTON(radioEmptySpin), radiobutton_group);
   radiobutton_group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(radioEmptySpin));
   gtk_box_pack_start(GTK_BOX(hbox), radioEmptySpin, TRUE, TRUE, 1);
   g_signal_connect(G_OBJECT(radioEmptySpin), "toggled",
-		   G_CALLBACK(onPolicyChanged), GINT_TO_POINTER(policyHideNullSpin));
+		   G_CALLBACK(onPolicyChanged), GINT_TO_POINTER(VISU_RENDERING_SPIN_HIDE_NULL));
   radioAtomicSpin = gtk_radio_button_new_with_label(NULL, _("atomic"));
   gtk_radio_button_set_group(GTK_RADIO_BUTTON(radioAtomicSpin), radiobutton_group);
   radiobutton_group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(radioAtomicSpin));
   gtk_box_pack_start(GTK_BOX(hbox), radioAtomicSpin, TRUE, TRUE, 1);
   g_signal_connect(G_OBJECT(radioAtomicSpin), "toggled",
-		   G_CALLBACK(onPolicyChanged), GINT_TO_POINTER(policyAtomicNullSpin));
+		   G_CALLBACK(onPolicyChanged), GINT_TO_POINTER(VISU_RENDERING_SPIN_ATOMIC_NULL));
   g_object_get(G_OBJECT(visu_rendering_getByName(VISU_RENDERING_SPIN_NAME)),
                "hiding-mode", &policy, NULL);
   switch (policy)
     {
-    case policyAlwaysSpin:
+    case VISU_RENDERING_SPIN_ALWAYS:
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radioAlwaysSpin), TRUE);
       break;
-    case policyHideNullSpin:
+    case VISU_RENDERING_SPIN_HIDE_NULL:
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radioEmptySpin), TRUE);
       break;
-    case policyAtomicNullSpin:
+    case VISU_RENDERING_SPIN_ATOMIC_NULL:
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radioAtomicSpin), TRUE);
       break;
     default:
@@ -334,7 +334,7 @@ static GtkWidget* createGtkConfigForSpinMethod()
   GtkWidget *labelPolicy;
   GtkWidget *hbox, *check, *label, *align;
   GSList *radiobutton_group;
-  SpinModulusPolicy modPol;
+  VisuRenderingSpinModulusPolicy modPol;
   VisuRendering *spin;
   gboolean atomic;
 
@@ -357,10 +357,10 @@ static GtkWidget* createGtkConfigForSpinMethod()
   check = gtk_check_button_new();
   gtk_box_pack_start(GTK_BOX(hbox), check, FALSE, FALSE, 10);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),
-			       (modPol != policyNoneModulus));
+			       (modPol != VISU_RENDERING_SPIN_CONSTANT));
   g_signal_connect(G_OBJECT(check), "toggled",
 		   G_CALLBACK(onPolicyModulusChanged),
-		   GINT_TO_POINTER(policyNoneModulus));
+		   GINT_TO_POINTER(VISU_RENDERING_SPIN_CONSTANT));
 
   hbox = gtk_hbox_new(FALSE, 0);
   radioPerTypeMod = gtk_radio_button_new_with_label(NULL, _("per node type"));
@@ -368,21 +368,21 @@ static GtkWidget* createGtkConfigForSpinMethod()
   radiobutton_group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(radioPerTypeMod));
   gtk_box_pack_start(GTK_BOX(hbox), radioPerTypeMod, TRUE, TRUE, 1);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radioPerTypeMod),
-			       modPol == policyPerTypeModulus);
-  gtk_widget_set_sensitive(radioPerTypeMod, (modPol != policyNoneModulus));
+			       modPol == VISU_RENDERING_SPIN_PER_TYPE);
+  gtk_widget_set_sensitive(radioPerTypeMod, (modPol != VISU_RENDERING_SPIN_CONSTANT));
   g_signal_connect(G_OBJECT(radioPerTypeMod), "toggled",
 		   G_CALLBACK(onPolicyModulusChanged),
-		   GINT_TO_POINTER(policyPerTypeModulus));
+		   GINT_TO_POINTER(VISU_RENDERING_SPIN_PER_TYPE));
   radioGlobalMod = gtk_radio_button_new_with_label(NULL, _("globaly"));
   gtk_radio_button_set_group(GTK_RADIO_BUTTON(radioGlobalMod), radiobutton_group);
   radiobutton_group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(radioGlobalMod));
   gtk_box_pack_start(GTK_BOX(hbox), radioGlobalMod, TRUE, TRUE, 1);
   g_signal_connect(G_OBJECT(radioGlobalMod), "toggled",
 		   G_CALLBACK(onPolicyModulusChanged),
-		   GINT_TO_POINTER(policyGlobalModulus));
+		   GINT_TO_POINTER(VISU_RENDERING_SPIN_GLOBAL));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radioGlobalMod),
-			       modPol == policyGlobalModulus);
-  gtk_widget_set_sensitive(radioGlobalMod, (modPol != policyNoneModulus));
+			       modPol == VISU_RENDERING_SPIN_GLOBAL);
+  gtk_widget_set_sensitive(radioGlobalMod, (modPol != VISU_RENDERING_SPIN_CONSTANT));
   gtk_widget_show_all(hbox);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
@@ -431,7 +431,7 @@ static GtkWidget* createGtkConfigForSpinMethod()
 
   gtk_widget_show_all(vbox);
 
-  configResourcesLoadedId = g_signal_connect(VISU_INSTANCE, "resourcesLoaded",
+  configResourcesLoadedId = g_signal_connect(VISU_OBJECT_INSTANCE, "resourcesLoaded",
 					     G_CALLBACK(sync_global_resources), NULL);
 
   return vbox;
@@ -439,7 +439,7 @@ static GtkWidget* createGtkConfigForSpinMethod()
 static void destroyGtkConfigForSpinMethod()
 {
   DBG_fprintf(stderr, "Gtk Spin: remove signal from config rendering widget.\n");
-  g_signal_handler_disconnect(VISU_INSTANCE, configResourcesLoadedId);
+  g_signal_handler_disconnect(VISU_OBJECT_INSTANCE, configResourcesLoadedId);
 }
 static void onPolicyChanged(GtkToggleButton *toggle, gpointer data)
 {
@@ -461,11 +461,11 @@ static void onPolicyChanged(GtkToggleButton *toggle, gpointer data)
   else
     gtk_widget_show(labelAtomic);
 
-  dataObj = toolPanelGet_visuData(TOOL_PANEL(PANEL_ELEMENTS));
+  dataObj = visu_ui_panel_getData(VISU_UI_PANEL(VISU_UI_PANEL_ELEMENTS));
   if (!dataObj)
     return;
-  visu_data_createAllNodes(dataObj);  
-  VISU_ADD_REDRAW;
+  g_signal_emit_by_name(G_OBJECT(dataObj), "RenderingChanged", (VisuElement*)0, NULL);
+  VISU_REDRAW_ADD;
 }
 static void onPolicyAtomicChanged(GtkToggleButton *toggle, gpointer data _U_)
 {
@@ -484,50 +484,54 @@ static void onPolicyAtomicChanged(GtkToggleButton *toggle, gpointer data _U_)
   else
     gtk_widget_show(labelAtomic);
 
-  dataObj = toolPanelGet_visuData(TOOL_PANEL(PANEL_ELEMENTS));
+  dataObj = visu_ui_panel_getData(VISU_UI_PANEL(VISU_UI_PANEL_ELEMENTS));
   if (!dataObj)
     return;
-  visu_data_createAllElements(dataObj);
-  visu_data_createAllNodes(dataObj);  
-  VISU_ADD_REDRAW;
+  g_signal_emit_by_name(G_OBJECT(dataObj), "ElementRenderingChanged", (VisuElement*)0, NULL);
+  g_signal_emit_by_name(G_OBJECT(dataObj), "RenderingChanged", (VisuElement*)0, NULL);
+  VISU_REDRAW_ADD;
 }
 static void onPolicyModulusChanged(GtkToggleButton *toggle, gpointer data)
 {
   VisuData *dataObj;
-  SpinModulusPolicy modPol;
+  VisuRenderingSpinModulusPolicy modPol;
 
-  if ((SpinModulusPolicy)data == policyNoneModulus)
+  if ((VisuRenderingSpinModulusPolicy)data == VISU_RENDERING_SPIN_CONSTANT)
     {
       if (!gtk_toggle_button_get_active(toggle))
-	modPol = policyNoneModulus;
+	modPol = VISU_RENDERING_SPIN_CONSTANT;
       else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radioPerTypeMod)))
-	modPol = policyPerTypeModulus;
+	modPol = VISU_RENDERING_SPIN_PER_TYPE;
       else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radioGlobalMod)))
-	modPol = policyGlobalModulus;
+	modPol = VISU_RENDERING_SPIN_GLOBAL;
       else
-	modPol = policyNoneModulus;
+	modPol = VISU_RENDERING_SPIN_CONSTANT;
+      gtk_widget_set_sensitive(radioGlobalMod, gtk_toggle_button_get_active(toggle));
+      gtk_widget_set_sensitive(radioPerTypeMod, gtk_toggle_button_get_active(toggle));
     }
   else
-    modPol = (SpinModulusPolicy)data;
-  gtk_widget_set_sensitive(radioGlobalMod, gtk_toggle_button_get_active(toggle));
-  gtk_widget_set_sensitive(radioPerTypeMod, gtk_toggle_button_get_active(toggle));
+    {
+      if (!gtk_toggle_button_get_active(toggle))
+        return;
+      modPol = (VisuRenderingSpinModulusPolicy)data;
+    }
 
   g_object_set(G_OBJECT(visu_rendering_getByName(VISU_RENDERING_SPIN_NAME)),
-               "modulus-mode", modPol, NULL);
+               "modulus-scaling", modPol, NULL);
 
-  dataObj = toolPanelGet_visuData(TOOL_PANEL(PANEL_ELEMENTS));
+  dataObj = visu_ui_panel_getData(VISU_UI_PANEL(VISU_UI_PANEL_ELEMENTS));
   if (!dataObj)
     return;
-  visu_data_createAllElements(dataObj);
-  visu_data_createAllNodes(dataObj);  
-  VISU_ADD_REDRAW;
+  g_signal_emit_by_name(G_OBJECT(dataObj), "ElementRenderingChanged", (VisuElement*)0, NULL);
+  g_signal_emit_by_name(G_OBJECT(dataObj), "RenderingChanged", (VisuElement*)0, NULL);
+  VISU_REDRAW_ADD;
 }
 
 /* Initialise the gtk methods associated with
    the spin rendering method. */
-void panelElementSpinInit_gtkMain()
+void visu_ui_panel_elements_spin_initOpen()
 {
-  visuGtkSet_renderingSpecificMethods(visu_rendering_getByName
+  visu_ui_setRenderingSpecificMethod(visu_rendering_getByName
 				      (VISU_RENDERING_SPIN_NAME),
 				      gtkSpinCreate_fileChooser);
 }
@@ -566,7 +570,7 @@ static gboolean gtkSpinCreate_fileChooser(VisuData *data, GtkWindow *parent)
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					      GTK_STOCK_OPEN, GTK_RESPONSE_OK,
 					      NULL);
-  directory = visuGtkGet_lastOpenDirectory();
+  directory = visu_ui_getLastOpenDirectory();
   if (directory)
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(fileSelection), directory);
 
@@ -616,7 +620,7 @@ static gboolean gtkSpinCreate_fileChooser(VisuData *data, GtkWindow *parent)
   gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(fileSelection), filterPos);
 
   /* The preview widget. */
-  visuGtkPreview_add(&fileChooserSpin.preview, GTK_FILE_CHOOSER(fileSelection));
+  visu_ui_preview_add(&fileChooserSpin.preview, GTK_FILE_CHOOSER(fileSelection));
   g_signal_connect(GTK_FILE_CHOOSER(fileSelection), "update-preview",
 		   G_CALLBACK(fileUpdatePreview), &fileChooserSpin);
 
@@ -771,7 +775,7 @@ static gboolean gtkSpinCreate_fileChooser(VisuData *data, GtkWindow *parent)
 
 	      directory = gtk_file_chooser_get_current_folder
 		(GTK_FILE_CHOOSER(fileSelection));
-	      visuGtkSet_lastOpenDirectory((char*)directory, VISU_DIR_FILE);
+	      visu_ui_setLastOpenDirectory((char*)directory, VISU_UI_DIR_FILE);
 	      g_free(directory);
 	      
 	      gtk_widget_destroy(fileSelection);
@@ -786,7 +790,6 @@ static gboolean gtkSpinCreate_fileChooser(VisuData *data, GtkWindow *parent)
 static gboolean fileSelected(struct FileChooserSpin_struct *values)
 {
   gchar *filename = NULL, *filenameUTF8;
-  int res;
   gchar *message;
 
   filename =
@@ -797,7 +800,6 @@ static gboolean fileSelected(struct FileChooserSpin_struct *values)
   if (!g_file_test(filename, G_FILE_TEST_IS_DIR))
     {
       DBG_fprintf(stderr, "Gtk Spin: select '%s' as file %d\n", filename, values->fileKind);
-      res = 0;
       if (values->files[values->fileKind])
 	g_free(values->files[values->fileKind]);
       /* filename is not freed here, it will be later. */
@@ -862,7 +864,7 @@ static void fileUpdatePreview(GtkFileChooser *chooser,
   /* We test if the selected filename is a directory or not. */
   if (filenames[0] && !g_file_test(filenames[0], G_FILE_TEST_IS_DIR) &&
       filenames[1] && !g_file_test(filenames[1], G_FILE_TEST_IS_DIR))
-    visuGtkPreview_update(&fileChooserSpin->preview, filenames);
+    visu_ui_preview_update(&fileChooserSpin->preview, filenames);
   if (filenames[0])
     g_free((gchar*)filenames[0]);
   if (filenames[1])
@@ -918,7 +920,7 @@ GtkWidget* createGtkInterfaceForSpinMethod()
   GtkWidget* hbox[7], *vbox, *label, *vboxAtomic;
   GtkWidget* shapeLabel, *hLabel, *rhLabel, *lLabel, *rlLabel, *ratioLabel, *lengthLabel;
   int i, j = 0;
-  SpinDrawingPolicy hide;
+  VisuRenderingSpinDrawingPolicy hide;
   gboolean atomic, useAt;
   VisuRendering *spin;
 
@@ -974,25 +976,25 @@ GtkWidget* createGtkInterfaceForSpinMethod()
   heightResourceSpin = gtk_spin_button_new_with_range(0, 9, 0.05);
   element_callback_ids[0] = g_signal_connect((gpointer)heightResourceSpin, "value-changed",
 					     G_CALLBACK(element_resource_callback),
-					     GINT_TO_POINTER(spin_elementHatRadius));
+					     GINT_TO_POINTER(VISU_RENDERING_SPIN_HAT_RADIUS));
   gtk_widget_show(heightResourceSpin);
 
   rheightResourceSpin = gtk_spin_button_new_with_range(0, 9, 0.05);
   element_callback_ids[1] = g_signal_connect((gpointer)rheightResourceSpin, "value-changed",
 					     G_CALLBACK(element_resource_callback),
-					     GINT_TO_POINTER(spin_elementTailRadius));
+					     GINT_TO_POINTER(VISU_RENDERING_SPIN_TAIL_RADIUS));
   gtk_widget_show(rheightResourceSpin);
 
   lengthResourceSpin = gtk_spin_button_new_with_range(0, 9, 0.05);
   element_callback_ids[2] = g_signal_connect((gpointer)lengthResourceSpin, "value-changed",
 					     G_CALLBACK(element_resource_callback),
-					     GINT_TO_POINTER(spin_elementHatLength));
+					     GINT_TO_POINTER(VISU_RENDERING_SPIN_HAT_LENGTH));
   gtk_widget_show(lengthResourceSpin);
 
   rlengthResourceSpin = gtk_spin_button_new_with_range(0, 9, 0.05);
   element_callback_ids[3] = g_signal_connect((gpointer)rlengthResourceSpin, "value-changed",
 					     G_CALLBACK(element_resource_callback),
-					     GINT_TO_POINTER(spin_elementTailLength));
+					     GINT_TO_POINTER(spin_VISU_RENDERING_SPIN_TAIL_LENGTH));
   gtk_widget_show(rlengthResourceSpin);
 
   /* Check box creation */
@@ -1003,38 +1005,38 @@ GtkWidget* createGtkInterfaceForSpinMethod()
   gtkw_use_element_color = gtk_check_button_new_with_label(_(" tail"));
   element_callback_ids[4] = g_signal_connect(gtkw_use_element_color, "toggled", 
 					     G_CALLBACK(element_resource_callback),
-					     GINT_TO_POINTER(spin_elementTailColor));
+					     GINT_TO_POINTER(VISU_RENDERING_SPIN_TAIL_COLOR));
   gtk_widget_show(gtkw_use_element_color);
 
   gtkw_use_element_color_hat = gtk_check_button_new_with_label(_(" hat"));
   element_callback_ids[5] = g_signal_connect(gtkw_use_element_color_hat, "toggled", 
 					     G_CALLBACK(element_resource_callback),
-					     GINT_TO_POINTER(spin_elementHatColor));
+					     GINT_TO_POINTER(VISU_RENDERING_SPIN_HAT_COLOR));
   gtk_widget_show(gtkw_use_element_color_hat);
 
   /* Combo boxes creation */
   gtkw_element_shape_number = gtk_combo_box_text_new();
-  for (i=0; i<nbSpinShapes; i++)
+  for (i=0; i<VISU_RENDERING_SPIN_N_SHAPES; i++)
     gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(gtkw_element_shape_number),
                               (const gchar*)0,
-			      visu_renderingSpin_getShapeNameI18n(i));
+			      visu_rendering_spin_getShapeNameI18n(i));
   /* set callback for the combo button. */
   element_callback_ids[6] = g_signal_connect(gtkw_element_shape_number, "changed",
 					     G_CALLBACK(element_resource_callback),
-					     GINT_TO_POINTER(spin_elementShape));
+					     GINT_TO_POINTER(VISU_RENDERING_SPIN_SHAPE));
   gtk_widget_show(gtkw_element_shape_number);
 
   /* Set the spins for the elipsoid shape. */
   ratioElipsoidSpin = gtk_spin_button_new_with_range(0, 9, 0.05);
   element_callback_ids[7] = g_signal_connect(G_OBJECT(ratioElipsoidSpin), "value-changed",
 					     G_CALLBACK(element_resource_callback),
-					     GINT_TO_POINTER(spin_elementBAxis));
+					     GINT_TO_POINTER(VISU_RENDERING_SPIN_B_AXIS));
   gtk_widget_show(ratioElipsoidSpin);
 
   lengthElipsoidSpin = gtk_spin_button_new_with_range(0, 9, 0.05);
   element_callback_ids[8] = g_signal_connect(G_OBJECT(lengthElipsoidSpin), "value-changed",
 					     G_CALLBACK(element_resource_callback),
-					     GINT_TO_POINTER(spin_elementAAxis));
+					     GINT_TO_POINTER(VISU_RENDERING_SPIN_A_AXIS));
   gtk_widget_show(lengthElipsoidSpin);
   ratioLabel = gtk_label_new(_("B axis: "));
   gtk_misc_set_alignment(GTK_MISC(ratioLabel), 1.0, 0.5);
@@ -1045,7 +1047,7 @@ GtkWidget* createGtkInterfaceForSpinMethod()
   useElementForElipsoid = gtk_check_button_new_with_label(_("Use element color"));
   element_callback_ids[9] = g_signal_connect(G_OBJECT(useElementForElipsoid), "toggled", 
 					     G_CALLBACK(element_resource_callback),
-					     GINT_TO_POINTER(spin_elementElipsoidColor));
+					     GINT_TO_POINTER(VISU_RENDERING_SPIN_ELIPSOID_COLOR));
   gtk_widget_show(useElementForElipsoid);
 
   /* Atomic options. */
@@ -1053,7 +1055,7 @@ GtkWidget* createGtkInterfaceForSpinMethod()
   gtk_widget_set_sensitive(expandAtomic, FALSE);
   gtk_expander_set_expanded(GTK_EXPANDER(expandAtomic), FALSE);
   gtk_widget_show(expandAtomic);
-  vboxAtomic = panelElementAtomicCreate_gtkInterface();
+  vboxAtomic = visu_ui_panel_elements_atomic_initBuild();
   gtk_container_add(GTK_CONTAINER(expandAtomic), vboxAtomic);
   labelAtomic = gtk_label_new(_("<i>Enable the atomic rendering in the method tab.</i>"));
   gtk_widget_show(labelAtomic);
@@ -1062,7 +1064,7 @@ GtkWidget* createGtkInterfaceForSpinMethod()
   spin = visu_rendering_getByName(VISU_RENDERING_SPIN_NAME);
   g_object_get(G_OBJECT(spin), "hiding-mode", &hide,
                "use-atomic", &useAt, NULL);
-  atomic = (useAt || hide == policyAtomicNullSpin);
+  atomic = (useAt || hide == VISU_RENDERING_SPIN_ATOMIC_NULL);
   gtk_widget_set_sensitive(expandAtomic, atomic);
   gtk_expander_set_expanded(GTK_EXPANDER(expandAtomic), atomic);
   if (atomic)
@@ -1106,7 +1108,7 @@ GtkWidget* createGtkInterfaceForSpinMethod()
   gtk_box_pack_start(GTK_BOX(vbox), expandAtomic, FALSE, FALSE, 0);
   gtk_box_pack_start(GTK_BOX(vbox), labelAtomic, FALSE, FALSE, 0);
 
-  g_signal_connect(VISU_INSTANCE, "resourcesLoaded",
+  g_signal_connect(VISU_OBJECT_INSTANCE, "resourcesLoaded",
 		   G_CALLBACK(sync_local_resources), NULL);
 
   return vbox;
@@ -1123,7 +1125,7 @@ static void changeSomethingSpin(GList *eleList)
     return;
 
   DBG_fprintf(stderr, "Gtk Spin: give the element change to the atomic part.\n");
-  panelElementAtomicCallback_onElementChange(eleList);
+  visu_ui_panel_elements_atomic_onChange(eleList);
 
   ele = (VisuElement*)eleList->data;
 
@@ -1142,27 +1144,27 @@ static void changeSomethingSpin(GList *eleList)
   g_signal_handler_block (useElementForElipsoid, element_callback_ids[9] );  
 
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(heightResourceSpin),
-			    rspin_getElementResource_float(ele, spin_elementHatRadius));
+			    visu_rendering_spin_getResourceFloat(ele, VISU_RENDERING_SPIN_HAT_RADIUS));
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(rheightResourceSpin),
-			    rspin_getElementResource_float(ele, spin_elementTailRadius));
+			    visu_rendering_spin_getResourceFloat(ele, VISU_RENDERING_SPIN_TAIL_RADIUS));
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(lengthResourceSpin),
-			    rspin_getElementResource_float(ele, spin_elementHatLength));
+			    visu_rendering_spin_getResourceFloat(ele, VISU_RENDERING_SPIN_HAT_LENGTH));
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(rlengthResourceSpin),
-			    rspin_getElementResource_float(ele, spin_elementTailLength));
+			    visu_rendering_spin_getResourceFloat(ele, spin_VISU_RENDERING_SPIN_TAIL_LENGTH));
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(lengthElipsoidSpin),
-			    rspin_getElementResource_float(ele, spin_elementAAxis));
+			    visu_rendering_spin_getResourceFloat(ele, VISU_RENDERING_SPIN_A_AXIS));
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(ratioElipsoidSpin),
-			    rspin_getElementResource_float(ele, spin_elementBAxis));
+			    visu_rendering_spin_getResourceFloat(ele, VISU_RENDERING_SPIN_B_AXIS));
   
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtkw_use_element_color),
-			       rspin_getElementResource_boolean(ele, spin_elementTailColor));
+			       visu_rendering_spin_getResourceBoolean(ele, VISU_RENDERING_SPIN_TAIL_COLOR));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtkw_use_element_color_hat),
-			       rspin_getElementResource_boolean(ele, spin_elementHatColor));
+			       visu_rendering_spin_getResourceBoolean(ele, VISU_RENDERING_SPIN_HAT_COLOR));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(useElementForElipsoid),
-			       rspin_getElementResource_boolean(ele, spin_elementElipsoidColor));
+			       visu_rendering_spin_getResourceBoolean(ele, VISU_RENDERING_SPIN_ELIPSOID_COLOR));
 
   gtk_combo_box_set_active(GTK_COMBO_BOX(gtkw_element_shape_number),
-			   rspin_getElementResource_uint(ele, spin_elementShape));
+			   visu_rendering_spin_getResourceUint(ele, VISU_RENDERING_SPIN_SHAPE));
 
   g_signal_handler_unblock (heightResourceSpin, element_callback_ids[0] );  
   g_signal_handler_unblock (rheightResourceSpin, element_callback_ids[1] );  
@@ -1184,16 +1186,13 @@ void element_resource_callback(GtkWidget* widget, gpointer data)
   gboolean refresh;
   GList *tmpLst, *eleList;
   VisuElement *ele;
-  SpinElementResources property;
+  VisuRenderingSpinResources property;
   gboolean new_bool;
   guint new_int;
   float new_float;
   VisuData *dataObj;
-  int id;
-  VisuOpenGLView *view;
-  VisuRendering *method;
 
-  eleList = panelElementsGet_selected();
+  eleList = visu_ui_panel_elements_getSelected();
   if (!eleList)
     return;
 
@@ -1204,21 +1203,21 @@ void element_resource_callback(GtkWidget* widget, gpointer data)
       ele = (VisuElement*)tmpLst->data;
       switch (property)
 	{
-	case spin_elementHatColor:
-	case spin_elementTailColor:
-	case spin_elementElipsoidColor:
+	case VISU_RENDERING_SPIN_HAT_COLOR:
+	case VISU_RENDERING_SPIN_TAIL_COLOR:
+	case VISU_RENDERING_SPIN_ELIPSOID_COLOR:
 	  new_bool = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
 
 	  DBG_fprintf(stderr, "GtkSpin : Set element '%d' property to %d\n",
 		      property, new_bool);
-	  refresh = rspin_setElementResource_boolean(ele, property, new_bool) || refresh;
+	  refresh = visu_rendering_spin_setResourceBoolean(ele, property, new_bool) || refresh;
 	  break;
-	case spin_elementShape:
+	case VISU_RENDERING_SPIN_SHAPE:
 	  new_int = (guint)gtk_combo_box_get_active(GTK_COMBO_BOX(widget));
 
 	  DBG_fprintf(stderr, "GtkSpin : Set element '%d' property to %d\n",
 		      property, new_int);
-	  refresh = rspin_setElementResource_uint(ele, property, new_int) || refresh;
+	  refresh = visu_rendering_spin_setResourceUint(ele, property, new_int) || refresh;
 	  if (new_int == VISU_RENDERING_SPIN_ELLIPSOID || new_int == VISU_RENDERING_SPIN_TORUS)
 	    {
 	      gtk_widget_show(vboxElipsoidShape);
@@ -1230,17 +1229,17 @@ void element_resource_callback(GtkWidget* widget, gpointer data)
 	      gtk_widget_show(vboxArrowShape);
 	    }
 	  break;
-	case spin_elementHatLength:
-	case spin_elementHatRadius:
-	case spin_elementTailLength:
-	case spin_elementTailRadius:
-	case spin_elementAAxis:
-	case spin_elementBAxis:
+	case VISU_RENDERING_SPIN_HAT_LENGTH:
+	case VISU_RENDERING_SPIN_HAT_RADIUS:
+	case spin_VISU_RENDERING_SPIN_TAIL_LENGTH:
+	case VISU_RENDERING_SPIN_TAIL_RADIUS:
+	case VISU_RENDERING_SPIN_A_AXIS:
+	case VISU_RENDERING_SPIN_B_AXIS:
 	  new_float = gtk_spin_button_get_value(GTK_SPIN_BUTTON(widget));
 
 	  DBG_fprintf(stderr, "GtkSpin : Set element '%d' property to %f\n",
 		      property, new_float);
-	  refresh = rspin_setElementResource_float(ele, property, new_float) || refresh;
+	  refresh = visu_rendering_spin_setResourceFloat(ele, property, new_float) || refresh;
 
 	  break;
 	default:
@@ -1251,17 +1250,18 @@ void element_resource_callback(GtkWidget* widget, gpointer data)
 
   if(need_redraw && refresh)
     {
-      dataObj = toolPanelGet_visuData(TOOL_PANEL(PANEL_ELEMENTS));
+      dataObj = visu_ui_panel_getData(VISU_UI_PANEL(VISU_UI_PANEL_ELEMENTS));
       if (!dataObj)
 	return;
 
-      method = visu_object_getRendering(VISU_INSTANCE);
-      view = visu_data_getOpenGLView(dataObj);
       for(tmpLst = eleList; tmpLst; tmpLst = g_list_next(tmpLst))
-        id = visu_rendering_createElement(method, (VisuElement*)tmpLst->data, view->camera,
-                                          MIN(view->window->width, view->window->height));
-      visu_data_createAllNodes(dataObj);  
-      VISU_ADD_REDRAW;
+        {
+          g_signal_emit_by_name(G_OBJECT(dataObj), "ElementRenderingChanged",
+                                (VisuElement*)tmpLst->data, NULL);
+          g_signal_emit_by_name(G_OBJECT(dataObj), "RenderingChanged",
+                                (VisuElement*)tmpLst->data, NULL);
+        }
+      VISU_REDRAW_ADD;
     }
 
   g_list_free(eleList);
@@ -1348,12 +1348,12 @@ void global_resource_callback(GtkWidget* button, gpointer data)
 
   if(need_redraw == 1)
     {
-      dataObj = toolPanelGet_visuData(TOOL_PANEL(PANEL_ELEMENTS));
+      dataObj = visu_ui_panel_getData(VISU_UI_PANEL(VISU_UI_PANEL_ELEMENTS));
       if (!dataObj)
 	return;
 
-      visu_data_createAllNodes(dataObj);  
-      VISU_ADD_REDRAW;
+      g_signal_emit_by_name(G_OBJECT(dataObj), "RenderingChanged", (VisuElement*)0, NULL);
+      VISU_REDRAW_ADD;
     }
 }
 
@@ -1362,17 +1362,17 @@ void set_view(GtkWidget* button _U_, gpointer data _U_)
   float theta;
   float phi;
   VisuData *dataObj;
-  VisuOpenGLView *view;
+  VisuGlView *view;
 
-  dataObj = toolPanelGet_visuData(TOOL_PANEL(PANEL_ELEMENTS));
-  if (!dataObj)
+  dataObj = visu_ui_panel_getData(VISU_UI_PANEL(VISU_UI_PANEL_ELEMENTS));
+  view = visu_ui_panel_getView(VISU_UI_PANEL(VISU_UI_PANEL_ELEMENTS));
+  if (!dataObj || !view)
     return;
-  view = visu_data_getOpenGLView(dataObj);
 
-  theta = fModulo(view->camera->theta, 360);
+  theta = tool_modulo_float(view->camera->theta, 360);
   if(theta > 180)
       theta = 360 - theta;
-  phi = fModulo(view->camera->phi, 360);
+  phi = tool_modulo_float(view->camera->phi, 360);
 
   need_redraw = 0;
 
@@ -1426,7 +1426,7 @@ static void sync_local_resources(GObject *trash _U_, gpointer data _U_)
   if(heightResourceSpin == NULL)
     return;
   
-  eleList = panelElementsGet_selected();
+  eleList = visu_ui_panel_elements_getSelected();
   if (!eleList)
     return;
 
@@ -1436,27 +1436,27 @@ static void sync_local_resources(GObject *trash _U_, gpointer data _U_)
   need_redraw = 0;
 
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(heightResourceSpin),
-			    rspin_getElementResource_float(ele, spin_elementHatRadius));
+			    visu_rendering_spin_getResourceFloat(ele, VISU_RENDERING_SPIN_HAT_RADIUS));
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(rheightResourceSpin),
-			    rspin_getElementResource_float(ele, spin_elementTailRadius));
+			    visu_rendering_spin_getResourceFloat(ele, VISU_RENDERING_SPIN_TAIL_RADIUS));
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(lengthResourceSpin),
-			    rspin_getElementResource_float(ele, spin_elementHatLength));
+			    visu_rendering_spin_getResourceFloat(ele, VISU_RENDERING_SPIN_HAT_LENGTH));
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(rlengthResourceSpin),
-			    rspin_getElementResource_float(ele, spin_elementTailLength));
+			    visu_rendering_spin_getResourceFloat(ele, spin_VISU_RENDERING_SPIN_TAIL_LENGTH));
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(lengthElipsoidSpin),
-			    rspin_getElementResource_float(ele, spin_elementAAxis));
+			    visu_rendering_spin_getResourceFloat(ele, VISU_RENDERING_SPIN_A_AXIS));
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(ratioElipsoidSpin),
-			    rspin_getElementResource_float(ele, spin_elementBAxis));
+			    visu_rendering_spin_getResourceFloat(ele, VISU_RENDERING_SPIN_B_AXIS));
   
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtkw_use_element_color),
-			       rspin_getElementResource_boolean(ele, spin_elementTailColor));
+			       visu_rendering_spin_getResourceBoolean(ele, VISU_RENDERING_SPIN_TAIL_COLOR));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtkw_use_element_color_hat),
-			       rspin_getElementResource_boolean(ele, spin_elementHatColor));
+			       visu_rendering_spin_getResourceBoolean(ele, VISU_RENDERING_SPIN_HAT_COLOR));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(useElementForElipsoid),
-			       rspin_getElementResource_boolean(ele, spin_elementElipsoidColor));
+			       visu_rendering_spin_getResourceBoolean(ele, VISU_RENDERING_SPIN_ELIPSOID_COLOR));
 
   gtk_combo_box_set_active(GTK_COMBO_BOX(gtkw_element_shape_number),
-			   rspin_getElementResource_uint(ele, spin_elementShape));
+			   visu_rendering_spin_getResourceUint(ele, VISU_RENDERING_SPIN_SHAPE));
 
   need_redraw = 1;
 }
