@@ -49,30 +49,30 @@
 #include <gtk/gtk.h>
 
 /**
- * panelElementSpinInit_gtkPanel:
+ * visu_ui_panel_elements_spin_init: (skip)
  * 
  * Initialise the specific area in the element panel
  * for the atomic rendering method.
  * 
  **/
-void panelElementSpinInit_gtkPanel();
+void visu_ui_panel_elements_spin_init();
 
 /**
- * panelElementSpinInit_gtkMain:
+ * visu_ui_panel_elements_spin_initOpen: (skip)
  * 
  * Initialise the gtk methods associated with
  * the spin rendering method.
  * 
  **/
-void panelElementSpinInit_gtkMain();
+void visu_ui_panel_elements_spin_initOpen();
 
 /**
- * panelElementSpinInit_gtkConfig:
+ * visu_ui_panel_elements_spin_initMethod: (skip)
  *
  * Initialise the specific area in the config panel
  * for the spin rendering method. 
  */
-void panelElementSpinInit_gtkConfig();
+void visu_ui_panel_elements_spin_initMethod();
 
 
 #endif
