@@ -92,6 +92,7 @@ static void onBoxLineWidthChanged(VisuUiLine *line, gint width, gpointer data);
 static void onBoxStippleChanged(VisuUiLine *line, gint stipple, gpointer data);
 static void onBoxLengthsToggled(GtkToggleButton *toggle, gpointer data);
 static void onBoxLegPosChanged(GtkSpinButton *spin, gpointer data);
+static void onAxesUsed(VisuUiLine *line, gboolean used, gpointer data);
 static void onAxesToggled(GtkToggleButton *toggle, gpointer data);
 static void onAxesWidthChanged(VisuUiLine *line, gint width, gpointer user_data);
 static void onAxesRGBChanged(VisuUiLine *line, float *rgb, gpointer data);
@@ -237,7 +238,7 @@ static GtkWidget *createInteriorAxes()
   spinYPos = gtk_spin_button_new_with_range(0., 1., 0.1);
   gtk_box_pack_start(GTK_BOX(hbox), spinYPos, FALSE, FALSE, 0);
   g_signal_connect(G_OBJECT(lineAxes), "use-changed",
-		   G_CALLBACK(onExtensionUsed), (gpointer)currentAxes);
+		   G_CALLBACK(onAxesUsed), (gpointer)0);
   g_signal_connect(G_OBJECT(lineAxes), "width-changed",
 		   G_CALLBACK(onAxesWidthChanged), (gpointer)0);
   g_signal_connect(G_OBJECT(lineAxes), "color-changed",
@@ -506,16 +507,24 @@ static void onExtensionUsed(VisuUiLine *line _U_, gboolean used, gpointer data)
   if (disableCallbacks || !data)
     return;
 
+  DBG_fprintf(stderr, "Panel Axes: toggle extension use.\n");
   visu_gl_ext_setActive(VISU_GL_EXT(data), used);
   if (VISU_IS_GL_EXT_SCALE(data))
     visu_gl_ext_scale_draw(VISU_GL_EXT_SCALE(data));
-  else if (VISU_IS_GL_EXT_AXES(data))
-    visu_gl_ext_axes_draw(VISU_GL_EXT_AXES(data));
   else if (VISU_IS_GL_EXT_BOX(data))
     visu_gl_ext_box_draw(VISU_GL_EXT_BOX(data));
   VISU_REDRAW_ADD;
 }
 
+static void onAxesUsed(VisuUiLine *line _U_, gboolean used, gpointer data _U_)
+{
+  if (disableCallbacks || !currentAxes)
+    return;
+
+  visu_gl_ext_setActive(VISU_GL_EXT(currentAxes), used);
+  visu_gl_ext_axes_draw(VISU_GL_EXT_AXES(currentAxes));
+  VISU_REDRAW_ADD;
+}
 static void onAxesWidthChanged(VisuUiLine *line _U_, gint width, gpointer data _U_)
 {
   if (disableCallbacks || !currentAxes)
