@@ -45,53 +45,18 @@
 #define PANELCONFIG_H
 
 #include <gtk/gtk.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 
 #include <visu_tools.h>
+#include <gtk_main.h>
 #include <gtk_renderingWindowWidget.h>
+#include <extraGtkFunctions/gtk_toolPanelWidget.h>
 
-#include "panelElements.h"
+VisuUiPanel* visu_ui_panel_config_init(VisuUiMain *ui);
 
-
-/**
- * panelConfigInit:
- *
- * Should be used in the list declared in externalModules.h to be loaded by
- * V_Sim on start-up. This routine will create the #ToolPanel where the configuration
- * stuff can be done, such as the auto-reloading.
- *
- * Returns: a newly created #ToolPanel object.
- */
-ToolPanel* panelConfigInit();
-
-/**
- * panelConfigSet_tabView:
- * @viewed: a boolean value.
- *
- * The note can show its tabs or not. Change this with that method.
- */
-void panelConfigSet_tabView(gboolean viewed);
-/**
- * panelConfigSet_automaticRefresh:
- * @window: the #VisuRenderingWindow to associated the auto refresh ;
- * @bool: a boolean value.
- *
- * V_Sim can poll the rendered file at periodic intervals to check if the file
- * has been modified. If true, the file is reloaded. Turn this functionality on or off
- * with this method. See panelConfigSet_refreshPeriod() to tune the period of the polling.
- */
-void panelConfigSet_automaticRefresh(VisuRenderingWindow *window, int bool);
-/**
- * panelConfigSet_refreshPeriod:
- * @window: the #VisuRenderingWindow to associated the auto refresh ;
- * @val: a floating point value in milliseconds.
- *
- * V_Sim can poll the rendered file at periodic intervals. Use this method to tune
- * the period. See panelConfigSet_automaticRefresh() to enable this functionality.
- */
-void panelConfigSet_refreshPeriod(VisuRenderingWindow *window, float val);
+void visu_ui_panel_config_setTabView(gboolean viewed);
+void visu_ui_panel_config_setAutomaticRefresh(VisuUiRenderingWindow *window, gboolean bool);
+void visu_ui_panel_config_setRefreshPeriod(VisuUiRenderingWindow *window, float val);
+GtkWidget* visu_ui_panel_config_getArea();
 
 #endif
 
