@@ -65,22 +65,25 @@
  * SECTION: panelElements
  * @short_description: The tab where #VisuElement characteristics can
  * be tuned.
+ *
+ * <para>It is possible to get the list of selected elements by
+ * calling visu_ui_panel_elements_getSelected().</para>
  */
 
 /**
  * panelElements:
  *
- * A pointer on the #ToolPanel that host the elements chooser.
+ * A pointer on the #VisuUiPanel that host the elements chooser.
  */
 static GtkWidget *panelElements;
 
 /* Functions used to initialise the
  * specific area in the panel of elements.
  */
-static VisuToolsInitFunc listInitRendenringGtkPanelFunc[] = {
-  panelElementAtomicInit_gtkPanel,
-  panelElementSpinInit_gtkPanel,
-  (VisuToolsInitFunc)0};
+static ToolInitFunc listInitRendenringGtkPanelFunc[] = {
+  visu_ui_panel_elements_atomic_init,
+  visu_ui_panel_elements_spin_init,
+  (ToolInitFunc)0};
 
 /* sensitive widgets */
 GtkWidget *vBoxElements;
@@ -96,15 +99,15 @@ gint sortVisuElements(gpointer a, gpointer b);
 struct GtkRenderingInterface_struct
 {
 /*   setSensitiveFunc sensitiveInterface; */
-  panelElements_changeFunc newElementInterface;
-  VisuGtkWidgetFunc createInterface;
+  VisuUiPanelElementsChangeFunc newElementInterface;
+  VisuUiNewWidgetFunc createInterface;
 };
 typedef struct GtkRenderingInterface_struct GtkRenderingInterface;
 GHashTable *listOfRenderingInterfaces;
-static panelElements_changeFunc updateRenderingMethodResources;
+static VisuUiPanelElementsChangeFunc updateRenderingMethodResources;
 
 /* Local methods. */
-static void createInteriorElements(GtkWidget *toolPanel);
+static void createInteriorElements(GtkWidget *visu_ui_panel);
 static void updateRenderingSpecificPart(VisuRendering *method);
 void createCallBacksElements();
 void setInitialValuesElements();
@@ -113,46 +116,46 @@ char *getDefaultLabelOfElement(VisuElement *element);
    renderingMethodElements pints then to this widget. If
    renderingMethodElements has already a target, this target is
    freed via gtk_widget_destroy. */
-static void changeRenderingMethodInterface(GtkWidget* interface);
+static void changeRenderingMethodInterface(GtkWidget* wd);
 /* It allows the client to set the method use to update
    user defined values. */
-static void setElementChangedFunc(panelElements_changeFunc func);
+static void setElementChangedFunc(VisuUiPanelElementsChangeFunc func);
 /* It reads the value of the interface methods. */
 static void getRenderingInterface(VisuRendering *method,
-				  panelElements_changeFunc *change,
-				  VisuGtkWidgetFunc *create);
+				  VisuUiPanelElementsChangeFunc *change,
+				  VisuUiNewWidgetFunc *create);
 
 /* Callbacks */
-static void onElementSelected(ElementComboBox *combo, GList *elements, gpointer data);
+static void onElementSelected(VisuUiElementCombobox *combo, GList *elements, gpointer data);
 static gboolean onElementChanged(GSignalInvocationHint *ihint, guint n_param_values,
                                  const GValue *param_values, gpointer data);
 static void resourcesChanged(GObject *object, VisuData *dataObj, gpointer data);
-static void colorVisuElementChanged(ColorComboBox *colorWd, ToolColor *color, gpointer userData);
-static void checkRenderedChanged(GtkToggleButton *button, gpointer data);
+static void colorVisuElementChanged(VisuUiColorCombobox *colorWd, ToolColor *color, gpointer userData);
+static void checkVisibilityChanged(GtkToggleButton *button, gpointer data);
 static void checkMaskedChanged(GtkToggleButton *button, gpointer data);
-static void refreshComboElements(GObject *obj, VisuData *dataObj, gpointer userData);
+static void onDataFocused(GObject *obj, VisuData *dataObj, gpointer userData);
 static void onRenderingMethodChanged(GObject *obj, VisuRendering *method,
 				     gpointer userData);
-static void onColorChanged(ColorComboBox *colorComboBox, guint colorId, gpointer data);
-static void onMaterialChanged(ColorComboBox *colorComboBox, Material mat, gpointer data);
+static void onColorChanged(VisuUiColorCombobox *colorComboBox, guint colorId, gpointer data);
+static void onMaterialChanged(VisuUiColorCombobox *colorComboBox, VisuGlLightMaterial mat, gpointer data);
 
 /**
- * panelElementsInit: (skip)
+ * visu_ui_panel_elements_init: (skip)
  *
  * Should be used in the list declared in externalModules.h to be loaded by
- * V_Sim on start-up. This routine will create the #ToolPanel where the element
+ * V_Sim on start-up. This routine will create the #VisuUiPanel where the element
  * stuff can be done, such as choosing a colour, setting the radius of
  * spheres...
  *
- * Returns: a newly created #ToolPanel object.
+ * Returns: a newly created #VisuUiPanel object.
  */
-ToolPanel* panelElementsInit()
+VisuUiPanel* visu_ui_panel_elements_init(VisuUiMain *ui)
 {
   gchar *cl = _("Set elements caracteristics");
   gchar *tl = _("Elements");
   int i;
 
-  panelElements = toolPanelNew_withIconFromPath("Panel_elements", cl, tl,
+  panelElements = visu_ui_panel_newWithIconFromPath("Panel_elements", cl, tl,
 						"stock-elements_20.png");
 
   /* Create the list of the available rendering method
@@ -164,18 +167,30 @@ ToolPanel* panelElementsInit()
     listInitRendenringGtkPanelFunc[i]();
 
   createInteriorElements(panelElements);
-  toolPanelSet_dockable(TOOL_PANEL(panelElements), TRUE);
+  visu_ui_panel_setDockable(VISU_UI_PANEL(panelElements), TRUE);
 
   if (!panelElements)
-    return (ToolPanel*)0;
+    return (VisuUiPanel*)0;
 
   /* Create the callbacks of all the sensitive widgets. */
   createCallBacksElements();
+  g_signal_connect(G_OBJECT(ui), "DataFocused",
+		   G_CALLBACK(onDataFocused), (gpointer)0);
+  g_signal_connect(VISU_OBJECT_INSTANCE, "renderingChanged",
+		   G_CALLBACK(onRenderingMethodChanged), (gpointer)0);
+  g_signal_connect(VISU_OBJECT_INSTANCE, "resourcesLoaded",
+		   G_CALLBACK(resourcesChanged), (gpointer)0);
+  g_signal_add_emission_hook(g_signal_lookup("ElementVisibilityChanged", VISU_TYPE_ELEMENT),
+                             0, onElementChanged, (gpointer)0, (GDestroyNotify)0);
+  g_signal_add_emission_hook(g_signal_lookup("ElementMaterialChanged", VISU_TYPE_ELEMENT),
+                             0, onElementChanged, (gpointer)0, (GDestroyNotify)0);
+  g_signal_add_emission_hook(g_signal_lookup("ElementPlaneChanged", VISU_TYPE_ELEMENT),
+                             0, onElementChanged, (gpointer)0, (GDestroyNotify)0);
 
-  return TOOL_PANEL(panelElements);
+  return VISU_UI_PANEL(panelElements);
 }
 
-static void createInteriorElements(GtkWidget *toolPanel)
+static void createInteriorElements(GtkWidget *visu_ui_panel)
 {
   GtkWidget *label, *expand, *image;
   GtkWidget *hbox;
@@ -205,7 +220,8 @@ static void createInteriorElements(GtkWidget *toolPanel)
   gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
   /* We create the tree widget that show the methods. */
-  elementsComboBox = elementComboBox_new(TRUE, FALSE, _("Element '%s'"));
+  elementsComboBox = visu_ui_element_combobox_new(TRUE, FALSE, _("Element '%s'"));
+  visu_ui_element_combobox_setUnphysicalStatus(VISU_UI_ELEMENT_COMBOBOX(elementsComboBox), TRUE);
   gtk_box_pack_start(GTK_BOX(hbox), elementsComboBox, TRUE, TRUE, 2);
 
   label = gtk_label_new("");
@@ -218,7 +234,7 @@ static void createInteriorElements(GtkWidget *toolPanel)
   gtk_box_pack_start(GTK_BOX(vBoxElements), hbox, FALSE, FALSE, 0);
 /*   label = gtk_label_new(_("Color: ")); */
 /*   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2); */
-  widgetVisuElementColor = colorComboBox_newWithRanges(TRUE);
+  widgetVisuElementColor = visu_ui_color_combobox_newWithRanges(TRUE);
   gtk_box_pack_start(GTK_BOX(hbox), widgetVisuElementColor, FALSE, FALSE, 2);
   align = gtk_alignment_new(1., 0.5, 0., 0.);
   gtk_box_pack_start(GTK_BOX(hbox), align, TRUE, TRUE, 2);
@@ -233,7 +249,7 @@ static void createInteriorElements(GtkWidget *toolPanel)
   gtk_widget_set_tooltip_text(checkMasked,
 		              _("Make nodes sensitive to the masking effect of planes."));
 
-  expand = colorComboBoxGet_rangesWidgets(COLOR_COMBOX(widgetVisuElementColor));
+  expand = visu_ui_color_combobox_getRangeWidgets(VISU_UI_COLOR_COMBOBOX(widgetVisuElementColor));
   gtk_box_pack_start(GTK_BOX(vBoxElements), expand, FALSE, FALSE, 0);
 
   label = gtk_label_new(_("<b>Rendering specific resources</b>"));
@@ -244,11 +260,11 @@ static void createInteriorElements(GtkWidget *toolPanel)
 
   DBG_fprintf(stderr, "Panel Elements: create the specific widgets.\n");
   renderingMethodElements = (GtkWidget*)0;
-  updateRenderingSpecificPart(visu_object_getRendering(VISU_INSTANCE));
+  updateRenderingSpecificPart(visu_object_getRendering(VISU_OBJECT_INSTANCE));
 
   gtk_widget_show_all(scrollView);
 
-  gtk_container_add(GTK_CONTAINER(toolPanel), scrollView);
+  gtk_container_add(GTK_CONTAINER(visu_ui_panel), scrollView);
 }
 
 void createCallBacksElements()
@@ -262,26 +278,9 @@ void createCallBacksElements()
   g_signal_connect(G_OBJECT(widgetVisuElementColor), "color-value-changed",
 		   G_CALLBACK(onColorChanged), (gpointer)0);
   g_signal_connect(G_OBJECT(checkRendered), "toggled",
-		   G_CALLBACK(checkRenderedChanged), (gpointer)0);
+		   G_CALLBACK(checkVisibilityChanged), (gpointer)0);
   g_signal_connect(G_OBJECT(checkMasked), "toggled",
 		   G_CALLBACK(checkMaskedChanged), (gpointer)0);
-  /* Connect the signal emitted by visu when a new file is loaded. */
-  g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
-		   G_CALLBACK(refreshComboElements), (gpointer)0);
-  /* Connect the signal emitted by visu when
-     a new rendering method is selected. */
-  g_signal_connect(VISU_INSTANCE, "renderingChanged",
-		   G_CALLBACK(onRenderingMethodChanged), (gpointer)0);
-  /* Connect the signal emitted by visu when
-     a new rendering method is selected. */
-  g_signal_connect(VISU_INSTANCE, "resourcesLoaded",
-		   G_CALLBACK(resourcesChanged), (gpointer)0);
-  g_signal_add_emission_hook(g_signal_lookup("ElementRenderedChanged", VISU_ELEMENT_TYPE),
-                             0, onElementChanged, (gpointer)0, (GDestroyNotify)0);
-  g_signal_add_emission_hook(g_signal_lookup("ElementMaterialChanged", VISU_ELEMENT_TYPE),
-                             0, onElementChanged, (gpointer)0, (GDestroyNotify)0);
-  g_signal_add_emission_hook(g_signal_lookup("ElementPlaneChanged", VISU_ELEMENT_TYPE),
-                             0, onElementChanged, (gpointer)0, (GDestroyNotify)0);
 }
 
 /*****************/
@@ -295,27 +294,21 @@ gint sortVisuElements(gpointer a, gpointer b)
 /*************/
 /* Callbacks */
 /*************/
-static void refreshComboElements(GObject *obj _U_, VisuData *dataObj, gpointer userData _U_)
+static void onDataFocused(GObject *obj _U_, VisuData *dataObj, gpointer userData _U_)
 {
+  DBG_fprintf(stderr,"Panel Element: caught 'DataFocused' signal.\n");
   if (dataObj)
-    {
-      DBG_fprintf(stderr,"Panel Element : creating %d labels for the"
-		  " combobox of VisuElements.\n", dataObj->ntype);
-      gtk_widget_set_sensitive(vBoxElements, TRUE);
-    }
+    gtk_widget_set_sensitive(vBoxElements, TRUE);
   else
-    {
-      DBG_fprintf(stderr, "Panel Element : there is no element available.\n");
-      gtk_widget_set_sensitive(vBoxElements, FALSE);
-    }
+    gtk_widget_set_sensitive(vBoxElements, FALSE);
 }
 static void updateRenderingSpecificPart(VisuRendering *method)
 {
-  panelElements_changeFunc change;
-  VisuGtkWidgetFunc create;
+  VisuUiPanelElementsChangeFunc change;
+  VisuUiNewWidgetFunc create;
 
-  change = (panelElements_changeFunc)0;
-  create = (VisuGtkWidgetFunc)0;
+  change = (VisuUiPanelElementsChangeFunc)0;
+  create = (VisuUiNewWidgetFunc)0;
   if (method)
     getRenderingInterface(method, &change, &create);
 
@@ -338,7 +331,7 @@ static gboolean onElementChanged(GSignalInvocationHint *ihint _U_, guint n_param
   GList *elements;
   VisuElement *ele;
 
-  elements = elementComboBoxGet_selectedElement(ELEMENT_COMBOX(elementsComboBox));
+  elements = visu_ui_element_combobox_getSelection(VISU_UI_ELEMENT_COMBOBOX(elementsComboBox));
   if (!elements)
     return TRUE;
 
@@ -355,12 +348,12 @@ static gboolean onElementChanged(GSignalInvocationHint *ihint _U_, guint n_param
                                visu_element_getRendered(ele));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkMasked),
                                visu_element_getSensitiveToPlanes(ele));
-  colorComboBoxSet_color(COLOR_COMBOX(widgetVisuElementColor), ele->rgb, FALSE);
-  colorComboBoxSet_material(COLOR_COMBOX(widgetVisuElementColor),
+  visu_ui_color_combobox_setRangeColor(VISU_UI_COLOR_COMBOBOX(widgetVisuElementColor), ele->rgb, FALSE);
+  visu_ui_color_combobox_setRangeMaterial(VISU_UI_COLOR_COMBOBOX(widgetVisuElementColor),
                             ele->material, FALSE);
   return TRUE;
 }
-static void onElementSelected(ElementComboBox *combo _U_, GList *elements,
+static void onElementSelected(VisuUiElementCombobox *combo _U_, GList *elements,
                               gpointer data _U_)
 {
   VisuElement *ele;
@@ -372,8 +365,8 @@ static void onElementSelected(ElementComboBox *combo _U_, GList *elements,
       ele = (VisuElement*)elements->data;
       DBG_fprintf(stderr, "Panel Element: set the selected VisuElement to '%s'.\n",
                   ele->name);
-      colorComboBoxSet_color(COLOR_COMBOX(widgetVisuElementColor), ele->rgb, FALSE);
-      colorComboBoxSet_material(COLOR_COMBOX(widgetVisuElementColor),
+      visu_ui_color_combobox_setRangeColor(VISU_UI_COLOR_COMBOBOX(widgetVisuElementColor), ele->rgb, FALSE);
+      visu_ui_color_combobox_setRangeMaterial(VISU_UI_COLOR_COMBOBOX(widgetVisuElementColor),
                                 ele->material, FALSE);
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkRendered),
 				   visu_element_getRendered(ele));
@@ -386,7 +379,7 @@ static void onElementSelected(ElementComboBox *combo _U_, GList *elements,
   if (updateRenderingMethodResources)
     updateRenderingMethodResources(elements);
 }
-static void colorVisuElementChanged(ColorComboBox *colorWd _U_, ToolColor *color,
+static void colorVisuElementChanged(VisuUiColorCombobox *colorWd _U_, ToolColor *color,
 			     gpointer userData _U_)
 {
   int res;
@@ -398,29 +391,31 @@ static void colorVisuElementChanged(ColorComboBox *colorWd _U_, ToolColor *color
               (gpointer) color);
 
   /* Get the selected elements. */
-  elements = elementComboBoxGet_selectedElement(ELEMENT_COMBOX(elementsComboBox));
+  elements = visu_ui_element_combobox_getSelection(VISU_UI_ELEMENT_COMBOBOX(elementsComboBox));
   g_return_if_fail(elements);
     
   /* If currentSelectedElement is NULL we apply the changes
      on all elements. */
-  dataObj = toolPanelGet_visuData(TOOL_PANEL(panelElements));
+  dataObj = VISU_DATA(visu_ui_panel_getFocused(VISU_UI_PANEL(panelElements)));
+  g_return_if_fail(!dataObj || VISU_IS_DATA(dataObj));
 
   refresh = FALSE;
   for (tmp = elements; tmp; tmp = g_list_next(tmp))
     {
       res = visu_element_setAllRGBValues((VisuElement*)tmp->data, color->rgba);
       if (res > 0)
-        visu_data_createNodes(dataObj, (VisuElement*)tmp->data);
+        g_signal_emit_by_name(G_OBJECT(dataObj), "RenderingChanged",
+                              (VisuElement*)tmp->data, NULL);
       refresh = refresh || (res != 0);
     }
   g_list_free(elements);
   if (refresh)
     {
       DBG_fprintf(stderr, "Panel Elements: color change, refresh.\n");
-      VISU_ADD_REDRAW;
+      VISU_REDRAW_ADD;
     }
 }
-static void onColorChanged(ColorComboBox *colorComboBox, guint colorId _U_,
+static void onColorChanged(VisuUiColorCombobox *colorComboBox, guint colorId _U_,
 			   gpointer data _U_)
 {
   int res;
@@ -430,33 +425,35 @@ static void onColorChanged(ColorComboBox *colorComboBox, guint colorId _U_,
   GList *elements, *tmp;
 
   /* Get the selected elements. */
-  elements = elementComboBoxGet_selectedElement(ELEMENT_COMBOX(elementsComboBox));
+  elements = visu_ui_element_combobox_getSelection(VISU_UI_ELEMENT_COMBOBOX(elementsComboBox));
   g_return_if_fail(elements);
     
   /* Get the values. */
-  rgbVal = colorComboBoxGet_color(colorComboBox);
+  rgbVal = visu_ui_color_combobox_getRangeColor(colorComboBox);
 
   /* If currentSelectedElement is NULL we apply the changes
      on all elements. */
-  dataObj = toolPanelGet_visuData(TOOL_PANEL(panelElements));
+  dataObj = VISU_DATA(visu_ui_panel_getFocused(VISU_UI_PANEL(panelElements)));
+  g_return_if_fail(!dataObj || VISU_IS_DATA(dataObj));
 
   refresh = FALSE;
   for (tmp = elements; tmp; tmp = g_list_next(tmp))
     {
       res = visu_element_setAllRGBValues((VisuElement*)tmp->data, rgbVal);
       if (res > 0)
-        visu_data_createNodes(dataObj, (VisuElement*)tmp->data);
+        g_signal_emit_by_name(G_OBJECT(dataObj), "RenderingChanged",
+                              (VisuElement*)tmp->data, NULL);
       refresh = refresh || (res != 0);
     }
   g_list_free(elements);
   if (refresh)
     {
       DBG_fprintf(stderr, "Panel Elements: RGB change, refresh.\n");
-      VISU_ADD_REDRAW;
+      VISU_REDRAW_ADD;
     }
   g_free(rgbVal);
 }
-static void onMaterialChanged(ColorComboBox *colorComboBox, Material mat _U_,
+static void onMaterialChanged(VisuUiColorCombobox *colorComboBox, VisuGlLightMaterial mat _U_,
 			      gpointer data _U_)
 {
   int res;
@@ -466,40 +463,57 @@ static void onMaterialChanged(ColorComboBox *colorComboBox, Material mat _U_,
   GList *elements, *tmp;
 
   /* Get the selected elements. */
-  elements = elementComboBoxGet_selectedElement(ELEMENT_COMBOX(elementsComboBox));
+  elements = visu_ui_element_combobox_getSelection(VISU_UI_ELEMENT_COMBOBOX(elementsComboBox));
   g_return_if_fail(elements);
     
   /* Get the values. */
-  matVal = colorComboBoxGet_material(colorComboBox);
+  matVal = visu_ui_color_combobox_getRangeMaterial(colorComboBox);
 
   /* If currentSelectedElement is NULL we apply the changes
      on all elements. */
-  dataObj = toolPanelGet_visuData(TOOL_PANEL(panelElements));
+  dataObj = VISU_DATA(visu_ui_panel_getFocused(VISU_UI_PANEL(panelElements)));
+  g_return_if_fail(!dataObj || VISU_IS_DATA(dataObj));
 
   refresh = FALSE;
   for (tmp = elements; tmp; tmp = g_list_next(tmp))
     {
       res = visu_element_setAllMaterialValues((VisuElement*)tmp->data, matVal);
       if (res > 0)
-        visu_data_createNodes(dataObj, (VisuElement*)tmp->data);
+        g_signal_emit_by_name(G_OBJECT(dataObj), "RenderingChanged",
+                              (VisuElement*)tmp->data, NULL);
       refresh = refresh || (res != 0);
     }
   g_list_free(elements);
   if (refresh)
     {
       DBG_fprintf(stderr, "Panel Elements: material change, refresh.\n");
-      VISU_ADD_REDRAW;
+      VISU_REDRAW_ADD;
     }
   g_free(matVal);
 }
+static gboolean askForHide(gpointer data _U_)
+{
+  VisuData *dataObj;
+  gboolean refresh;
+
+  dataObj = VISU_DATA(visu_ui_panel_getFocused(VISU_UI_PANEL(panelElements)));
+  g_return_val_if_fail(VISU_IS_DATA(dataObj), FALSE);
+  refresh = FALSE;
+  g_signal_emit_by_name(G_OBJECT(dataObj), "AskForShowHide", &refresh, NULL);
+  if (refresh)
+    {
+      g_signal_emit_by_name(G_OBJECT(dataObj), "VisibilityChanged", NULL);
+      VISU_REDRAW_ADD;
+    }
+  return FALSE;
+}
 static void checkMaskedChanged(GtkToggleButton *button, gpointer data _U_)
 {
   gboolean refresh;
-  VisuData *dataObj;
   GList *elements, *tmp;
 
   /* Get the selected elements. */
-  elements = elementComboBoxGet_selectedElement(ELEMENT_COMBOX(elementsComboBox));
+  elements = visu_ui_element_combobox_getSelection(VISU_UI_ELEMENT_COMBOBOX(elementsComboBox));
   g_return_if_fail(elements);
 
   refresh = FALSE;
@@ -510,19 +524,9 @@ static void checkMaskedChanged(GtkToggleButton *button, gpointer data _U_)
       refresh;
   g_list_free(elements);
   if (refresh)
-    {
-      dataObj = toolPanelGet_visuData(TOOL_PANEL(panelElements));
-      refresh = FALSE;
-      visu_data_emitAskForShowHideNodes(dataObj, &refresh);
-      if (refresh)
-	{
-	  visu_data_emitNodeRenderedChange(dataObj);
-	  visu_data_createAllNodes(dataObj);
-	  VISU_ADD_REDRAW;
-	}
-    }
+    g_idle_add(askForHide, (gpointer)0);
 }
-static void checkRenderedChanged(GtkToggleButton *button, gpointer data _U_)
+static void checkVisibilityChanged(GtkToggleButton *button, gpointer data _U_)
 {
   int res;
   gboolean refresh;
@@ -530,10 +534,11 @@ static void checkRenderedChanged(GtkToggleButton *button, gpointer data _U_)
   GList *elements, *tmp;
 
   /* Get the selected elements. */
-  elements = elementComboBoxGet_selectedElement(ELEMENT_COMBOX(elementsComboBox));
+  elements = visu_ui_element_combobox_getSelection(VISU_UI_ELEMENT_COMBOBOX(elementsComboBox));
   g_return_if_fail(elements);
 
-  dataObj = toolPanelGet_visuData(TOOL_PANEL(panelElements));
+  dataObj = VISU_DATA(visu_ui_panel_getFocused(VISU_UI_PANEL(panelElements)));
+  g_return_if_fail(!dataObj || VISU_IS_DATA(dataObj));
 
   refresh = FALSE;
   for (tmp = elements; tmp; tmp = g_list_next(tmp))
@@ -543,12 +548,13 @@ static void checkRenderedChanged(GtkToggleButton *button, gpointer data _U_)
       if (res)
 	{
 	  refresh = TRUE;
-	  visu_data_createNodes(dataObj, (VisuElement*)tmp->data);
+          g_signal_emit_by_name(G_OBJECT(dataObj), "RenderingChanged",
+                                (VisuElement*)tmp->data, NULL);
 	}
     }
   g_list_free(elements);
   if (refresh)
-    VISU_ADD_REDRAW;
+    VISU_REDRAW_ADD;
 }
 static void resourcesChanged(GObject *object _U_, VisuData *dataObj _U_,
 			     gpointer data _U_)
@@ -561,7 +567,7 @@ static void resourcesChanged(GObject *object _U_, VisuData *dataObj _U_,
 	      " signal, checking color pointers.\n");
 
   /* Get the selected iter. */
-  elements = elementComboBoxGet_selectedElement(ELEMENT_COMBOX(elementsComboBox));
+  elements = visu_ui_element_combobox_getSelection(VISU_UI_ELEMENT_COMBOBOX(elementsComboBox));
   if (!elements)
     return;
 
@@ -572,25 +578,26 @@ static void resourcesChanged(GObject *object _U_, VisuData *dataObj _U_,
   g_list_free(elements);
 }
 /**
- * panelElementsGet_selected:
+ * visu_ui_panel_elements_getSelected:
  *
  * This method is used to get a list of selected #VisuElement from the
  * element selector of this panel.
  *
  * Since: 3.6
  *
- * Returns: a list of #VisuElement, the list should be freed after use
- * by g_list_free().
+ * Returns: (transfer container) (element-type VisuElement*): a list
+ * of #VisuElement, the list should be freed after use by
+ * g_list_free().
  */
-GList* panelElementsGet_selected()
+GList* visu_ui_panel_elements_getSelected()
 {
-  return elementComboBoxGet_selectedElement(ELEMENT_COMBOX(elementsComboBox));
+  return visu_ui_element_combobox_getSelection(VISU_UI_ELEMENT_COMBOBOX(elementsComboBox));
 }
 
 
 /* It allows the client to set the method use to update
    user defined values. */
-static void setElementChangedFunc(panelElements_changeFunc func)
+static void setElementChangedFunc(VisuUiPanelElementsChangeFunc func)
 {
   updateRenderingMethodResources = func;
 }
@@ -600,7 +607,7 @@ static void setElementChangedFunc(panelElements_changeFunc func)
    freed via gtk_widget_destroy. If interface is a null pointer
    the previous renderingMethodElements is removed, but
    nothing replaces it. */
-static void changeRenderingMethodInterface(GtkWidget* interface)
+static void changeRenderingMethodInterface(GtkWidget* wd)
 {
   GList *elements;
 
@@ -614,20 +621,20 @@ static void changeRenderingMethodInterface(GtkWidget* interface)
       gtk_widget_destroy(renderingMethodElements);
     }
 
-  renderingMethodElements = interface;
+  renderingMethodElements = wd;
 
-  if (interface)
+  if (wd)
     {
-      gtk_box_pack_start(GTK_BOX(vBoxElements), interface,
+      gtk_box_pack_start(GTK_BOX(vBoxElements), wd,
 			 FALSE, FALSE, 5);
-      gtk_box_reorder_child(GTK_BOX(vBoxElements), interface, 6);
-      gtk_widget_show(interface);
+      gtk_box_reorder_child(GTK_BOX(vBoxElements), wd, 6);
+      gtk_widget_show(wd);
     }
 
   /* Force refresh on the specific area. */
   if (updateRenderingMethodResources)
     {
-      elements = elementComboBoxGet_selectedElement(ELEMENT_COMBOX(elementsComboBox));
+      elements = visu_ui_element_combobox_getSelection(VISU_UI_ELEMENT_COMBOBOX(elementsComboBox));
       updateRenderingMethodResources(elements);
       g_list_free(elements);
     }
@@ -637,70 +644,71 @@ static void changeRenderingMethodInterface(GtkWidget* interface)
 /* RenderingMethod gtk interface. */
 
 /**
- * panelElements_setInterfaceMethods:
+ * visu_ui_panel_elements_setMethod:
  * @method: a pointer on the method this interface is associated to ;
- * @change: the method to be called whenever the element selection is cahnged ;
- * @create: the method to be called when the interface must be built.
+ * @change: (scope call): the method to be called whenever the element
+ * selection is cahnged ;
+ * @create: (scope call): the method to be called when the interface must be built.
  *
  * This method allows to initiate the methods to deal with the rendering
  * specific interfaces.
  */
-void panelElements_setInterfaceMethods(VisuRendering *method,
-				       panelElements_changeFunc change,
-				       VisuGtkWidgetFunc create)
+void visu_ui_panel_elements_setMethod(VisuRendering *method,
+				       VisuUiPanelElementsChangeFunc change,
+				       VisuUiNewWidgetFunc create)
 {
-  GtkRenderingInterface *interface;
+  GtkRenderingInterface *wd;
 
   if (!method)
     return;
 
   /* Search for an already existing GtkRenderingInterface
      for this name. */
-  interface = g_hash_table_lookup(listOfRenderingInterfaces,
+  wd = g_hash_table_lookup(listOfRenderingInterfaces,
 				  (gpointer)method);
-  if (interface)
+  if (wd)
     {
-      interface->newElementInterface = change;
-      interface->createInterface = create;
+      wd->newElementInterface = change;
+      wd->createInterface = create;
     }
   else
     {
-      interface = g_malloc(sizeof(GtkRenderingInterface));
-      interface->newElementInterface = change;
-      interface->createInterface = create;
+      wd = g_malloc(sizeof(GtkRenderingInterface));
+      wd->newElementInterface = change;
+      wd->createInterface = create;
       g_hash_table_insert(listOfRenderingInterfaces,
 			  (gpointer)method,
-			  (gpointer)interface);
+			  (gpointer)wd);
     }
 }
 /* It reads the value of the interface methods. */
 static void getRenderingInterface(VisuRendering *method,
-				  panelElements_changeFunc *change,
-				  VisuGtkWidgetFunc *create)
+				  VisuUiPanelElementsChangeFunc *change,
+				  VisuUiNewWidgetFunc *create)
 {
-  GtkRenderingInterface *interface;
+  GtkRenderingInterface *wd;
 
-  *change = (panelElements_changeFunc)0;
-  *create = (VisuGtkWidgetFunc)0;
+  *change = (VisuUiPanelElementsChangeFunc)0;
+  *create = (VisuUiNewWidgetFunc)0;
   if (!method)
     return;
 
-  interface = g_hash_table_lookup(listOfRenderingInterfaces,
+  wd = g_hash_table_lookup(listOfRenderingInterfaces,
 				  (gpointer)method);
-  if (interface)
+  if (wd)
     {
-      *change = interface->newElementInterface;
-      *create = interface->createInterface;
+      *change = wd->newElementInterface;
+      *create = wd->createInterface;
     }
 }
 /**
- * panelElementsGet_static:
+ * visu_ui_panel_elements_getStatic:
  *
- * Retrives a pointer on this #ToolPanel.
+ * Retrives a pointer on this #VisuUiPanel.
  *
- * Returns: a pointer owned by V_Sim.
+ * Returns: (transfer none): a pointer owned by V_Sim.
  */
-GtkWidget* panelElementsGet_static()
+GtkWidget* visu_ui_panel_elements_getStatic()
 {
   return panelElements;
 }
