@@ -47,24 +47,24 @@
 #include <extraGtkFunctions/gtk_toolPanelWidget.h>
 
 /**
- * panelFogBgColor_init:
+ * visu_ui_panel_bg_init:
  *
  * Should be used in the list declared in externalModules.h to be loaded by
- * V_Sim on start-up. This routine will create the #ToolPanel where the fog
+ * V_Sim on start-up. This routine will create the #VisuUiPanel where the fog
  * and the background colour stuff can be tuned, such the position of
  * the fog, its colour...
  *
- * Returns: a newly created #ToolPanel object.
+ * Returns: a newly created #VisuUiPanel object.
  */
-ToolPanel* panelFogBgColor_init();
+VisuUiPanel* visu_ui_panel_bg_init();
 
 /**
- * panelFogBgColorSet_bgImage:
+ * visu_ui_panel_bg_setImage:
  * @filename: a path to a file.
  *
  * Set the background image.
  */
-void panelFogBgColorSet_bgImage(const gchar *filename);
+void visu_ui_panel_bg_setImage(const gchar *filename);
 
 #endif
 
