@@ -58,13 +58,13 @@ G_BEGIN_DECLS
    format or in ascii format. */
 
 /**
- * VisuAtomicShapeId:
+ * VisuRenderingAtomicShapeId:
  * @VISU_RENDERING_ATOMIC_SPHERE: draw sphere ;
  * @VISU_RENDERING_ATOMIC_CUBE: draw cube ;
  * @VISU_RENDERING_ATOMIC_ELLIPSOID: draw elipsoid ;
  * @VISU_RENDERING_ATOMIC_POINT: draw square dot ;
  * @VISU_RENDERING_ATOMIC_TORUS: draw torus ;
- * @nbAtomicShapes: number of shapes.
+ * @VISU_RENDERING_ATOMIC_N_SHAPES: number of shapes.
  *
  * This enum is used as identifier for shapes managed by the
  * attomic rendering method.
@@ -76,56 +76,56 @@ typedef enum
   VISU_RENDERING_ATOMIC_ELLIPSOID,
   VISU_RENDERING_ATOMIC_POINT,
   VISU_RENDERING_ATOMIC_TORUS,
-  nbAtomicShapes
-} VisuAtomicShapeId;
+  VISU_RENDERING_ATOMIC_N_SHAPES
+} VisuRenderingAtomicShapeId;
 
 /**
- * VISU_RENDERING_ATOMIC_TYPE:
+ * VISU_TYPE_RENDERING_ATOMIC:
  *
  * return the type of #VisuRenderingAtomic.
  */
-#define VISU_RENDERING_ATOMIC_TYPE	     (visu_rendering_atomic_get_type ())
+#define VISU_TYPE_RENDERING_ATOMIC	     (visu_rendering_atomic_get_type ())
 /**
  * VISU_RENDERING_ATOMIC:
  * @obj: a #GObject to cast.
  *
  * Cast the given @obj into #VisuRenderingAtomic type.
  */
-#define VISU_RENDERING_ATOMIC(obj)	     (G_TYPE_CHECK_INSTANCE_CAST(obj, VISU_RENDERING_ATOMIC_TYPE, VisuRenderingAtomic))
+#define VISU_RENDERING_ATOMIC(obj)	     (G_TYPE_CHECK_INSTANCE_CAST(obj, VISU_TYPE_RENDERING_ATOMIC, VisuRenderingAtomic))
 /**
  * VISU_RENDERING_ATOMIC_CLASS:
  * @klass: a #GObjectClass to cast.
  *
  * Cast the given @klass into #VisuRenderingAtomicClass.
  */
-#define VISU_RENDERING_ATOMIC_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST(klass, VISU_RENDERING_ATOMIC_TYPE, VisuRenderingAtomicClass))
+#define VISU_RENDERING_ATOMIC_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST(klass, VISU_TYPE_RENDERING_ATOMIC, VisuRenderingAtomicClass))
 /**
- * IS_VISU_RENDERING_ATOMIC_TYPE:
+ * VISU_IS_RENDERING_ATOMIC_TYPE:
  * @obj: a #GObject to test.
  *
  * Test if the given @ogj is of the type of #VisuRenderingAtomic object.
  */
-#define IS_VISU_RENDERING_ATOMIC_TYPE(obj)    (G_TYPE_CHECK_INSTANCE_TYPE(obj, VISU_RENDERING_ATOMIC_TYPE))
+#define VISU_IS_RENDERING_ATOMIC_TYPE(obj)    (G_TYPE_CHECK_INSTANCE_TYPE(obj, VISU_TYPE_RENDERING_ATOMIC))
 /**
- * IS_VISU_RENDERING_ATOMIC_CLASS:
+ * VISU_IS_RENDERING_ATOMIC_CLASS:
  * @klass: a #GObjectClass to test.
  *
  * Test if the given @klass is of the type of #VisuRenderingAtomicClass class.
  */
-#define IS_VISU_RENDERING_ATOMIC_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE(klass, VISU_RENDERING_ATOMIC_TYPE))
+#define VISU_IS_RENDERING_ATOMIC_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE(klass, VISU_TYPE_RENDERING_ATOMIC))
 /**
  * VISU_RENDERING_ATOMIC_GET_CLASS:
  * @obj: a #GObject to get the class of.
  *
  * It returns the class of the given @obj.
  */
-#define VISU_RENDERING_ATOMIC_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS(obj, VISU_RENDERING_ATOMIC_TYPE, VisuRenderingAtomicClass))
+#define VISU_RENDERING_ATOMIC_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS(obj, VISU_TYPE_RENDERING_ATOMIC, VisuRenderingAtomicClass))
 
 /**
  * visu_rendering_atomic_get_type:
  *
  * This method returns the type of #VisuRenderingAtomic, use
- * VISU_RENDERING_ATOMIC_TYPE instead.
+ * VISU_TYPE_RENDERING_ATOMIC instead.
  *
  * Returns: the type of #VisuRenderingAtomic.
  */
@@ -138,6 +138,19 @@ GType visu_rendering_atomic_get_type(void);
  */
 #define VISU_RENDERING_ATOMIC_NAME "Atom visualisation"
 
+/**
+ * VISU_RENDERING_ATOMIC_FORCES:
+ *
+ * Public name of the #VisuNodeProperty used to store forces on atoms.
+ */
+#define VISU_RENDERING_ATOMIC_FORCES "forces_id"
+/**
+ * VISU_RENDERING_ATOMIC_FORCES_ELE_MAX:
+ *
+ * Public name of the #VisuNodeProperty used to store the max of forces per element.
+ */
+#define VISU_RENDERING_ATOMIC_FORCES_ELE_MAX "max_ele_forces_id"
+
 typedef struct _VisuRenderingAtomicClass VisuRenderingAtomicClass;
 typedef struct _VisuRenderingAtomic VisuRenderingAtomic;
 
@@ -146,28 +159,30 @@ VisuRenderingAtomic* visu_rendering_atomic_new();
 /***********************/
 /* Different resources */
 /***********************/
-float visu_renderingAtomic_getRadius(VisuElement *ele);
-float visu_renderingAtomic_getRadiusDefault();
-int visu_renderingAtomic_setRadius(VisuElement* ele, float value);
+float visu_rendering_atomic_getRadius(VisuElement *ele);
+float visu_rendering_atomic_getRadiusDefault();
+int visu_rendering_atomic_setRadius(VisuElement* ele, float value);
 
-VisuAtomicShapeId visu_renderingAtomic_getShape(VisuElement *ele);
-VisuAtomicShapeId visu_renderingAtomic_getShapeDefault();
-const char* visu_renderingAtomic_getShapeName(VisuAtomicShapeId shape);
-const char* visu_renderingAtomic_getShapeNameDefault();
-int visu_renderingAtomic_setShape(VisuElement *ele, VisuAtomicShapeId shape);
-int visu_renderingAtomic_setShapeFromName(VisuElement *ele, const char* shape);
-const char** visu_renderingAtomic_getAllShapes();
-const char** visu_renderingAtomic_getAllShapesI18n();
+VisuRenderingAtomicShapeId visu_rendering_atomic_getShape(VisuElement *ele);
+VisuRenderingAtomicShapeId visu_rendering_atomic_getShapeDefault();
+const char* visu_rendering_atomic_getShapeName(VisuRenderingAtomicShapeId shape);
+const char* visu_rendering_atomic_getShapeNameDefault();
+int visu_rendering_atomic_setShape(VisuElement *ele, VisuRenderingAtomicShapeId shape);
+int visu_rendering_atomic_setShapeFromName(VisuElement *ele, const char* shape);
+const char** visu_rendering_atomic_getAllShapes();
+const char** visu_rendering_atomic_getAllShapesI18n();
 
-gboolean visu_renderingAtomic_setElipsoidParameters(VisuElement *ele, float ratio,
+gboolean visu_rendering_atomic_setElipsoidParameters(VisuElement *ele, float ratio,
 						    float phi, float theta);
-float visu_renderingAtomic_getElipsoidRatio(VisuElement *ele);
-float visu_renderingAtomic_getElipsoidPhi(VisuElement *ele);
-float visu_renderingAtomic_getElipsoidTheta(VisuElement *ele);
-gboolean visu_renderingAtomic_setElipsoidRatio(VisuElement *ele, float ratio);
-gboolean visu_renderingAtomic_setElipsoidPhi(VisuElement *ele, float phi);
-gboolean visu_renderingAtomic_setElipsoidTheta(VisuElement *ele, float theta);
+float visu_rendering_atomic_getElipsoidRatio(VisuElement *ele);
+float visu_rendering_atomic_getElipsoidPhi(VisuElement *ele);
+float visu_rendering_atomic_getElipsoidTheta(VisuElement *ele);
+gboolean visu_rendering_atomic_setElipsoidRatio(VisuElement *ele, float ratio);
+gboolean visu_rendering_atomic_setElipsoidPhi(VisuElement *ele, float phi);
+gboolean visu_rendering_atomic_setElipsoidTheta(VisuElement *ele, float theta);
 
+void visu_rendering_atomic_setForces(VisuData *dataObj, float *forces);
+float visu_rendering_atomic_getMaxForces(VisuData *dataObj);
 
 G_END_DECLS
 
