@@ -60,14 +60,15 @@
  */
 
 static gboolean read_nattyp_natnom(FILE *flux, GError **error,
-				   EndianId endian, gboolean store);
-static gboolean read_npas_temps(FILE *flux, GError **error, EndianId endian);
+				   ToolFortranEndianId endian, gboolean store);
+static gboolean read_npas_temps(FILE *flux, GError **error, ToolFortranEndianId endian);
 static int free_read_d3();
 static int read_d3_file(VisuData *data, FILE *flux, int set, GError **error);
 
 static char title[129];
-static unsigned int nat, ntypeD3, npas;
-static unsigned int *nattyp;
+static guint nat, ntypeD3, npas;
+static gdouble energy;
+static GArray *nattyp;
 static char **natnom;
 static double *x, *y, *z;
 static float *xf, *yf, *zf;
@@ -75,7 +76,8 @@ static GList *lst;
 
 
 static gboolean loadD3(VisuData *data, const gchar* filename,
-		       ToolFileFormat *format, int nSet, GError **error);
+		       ToolFileFormat *format, int nSet,
+                       GCancellable *cancel, GError **error);
 
 /******************************************************************************/
 
@@ -89,33 +91,39 @@ static gboolean loadD3(VisuData *data, const gchar* filename,
  */
 void initAtomicD3(VisuRendering *method)
 {
-   char *typeD3[] = {"*.d3", "*-posi.d3", "*.d3-posi", (char*)0};
-
+  const gchar *typeD3[] = {"*.d3", "*-posi.d3", "*.d3-posi", (char*)0};
+  
   visu_rendering_addFileFormat(method, 0,
                                tool_file_format_new(_("Native binary format"),
                                                     typeD3),
-                               10, loadD3, (GDestroyNotify)0);
+                               10, loadD3);
 }
 
 /******************************************************************************/
 
 static gboolean read_nattyp_natnom(FILE *flux, GError **error,
-				   EndianId endian, gboolean store)
+				   ToolFortranEndianId endian, gboolean store)
 {
-  unsigned int k;
+  guint k;
   gboolean valid;
-  unsigned int ncheck, mcheck;
+  guint ncheck, mcheck, *buf;
   gchar *name;
 
-  valid = toolFortranRead_flag(&ncheck, flux, error, endian);
+  g_return_val_if_fail((store && nattyp && natnom) || !store, FALSE);
+
+  DBG_fprintf(stderr, "Atomic D3: read nattyp and nattom (%d).\n", store);
+  valid = tool_fortran_readFlag(&ncheck, flux, error, endian);
   if (!valid) return valid;
-  valid = toolFortranRead_integer(nattyp, ntypeD3, flux, error,
+  buf = (store)?(guint*)nattyp->data:(guint*)0;
+  valid = tool_fortran_readInteger(buf, ntypeD3, flux, error,
 				  endian, FALSE, store);
   if (!valid) return valid;
+  if (store)
+    nattyp = g_array_set_size(nattyp, ntypeD3);
   for(k = 0; k < ntypeD3; k++)
     {
       name = (store)?natnom[k]:(gchar*)0;
-      valid = toolFortranRead_character(name, 8, flux, error,
+      valid = tool_fortran_readCharacter(name, 8, flux, error,
 					endian, FALSE, store);
       if (!valid) return valid;
       if (store)
@@ -124,7 +132,7 @@ static gboolean read_nattyp_natnom(FILE *flux, GError **error,
 	  g_strchomp(natnom[k]);
 	}
     }
-  valid = toolFortranRead_flag(&mcheck, flux, error, endian);
+  valid = tool_fortran_readFlag(&mcheck, flux, error, endian);
   if (!valid) return valid;
   if (ncheck != mcheck)
     {
@@ -134,19 +142,19 @@ static gboolean read_nattyp_natnom(FILE *flux, GError **error,
     }
   return TRUE;
 }
-static gboolean read_npas_temps(FILE *flux, GError **error, EndianId endian)
+static gboolean read_npas_temps(FILE *flux, GError **error, ToolFortranEndianId endian)
 {
-  unsigned int ncheck, mcheck;
+  guint ncheck, mcheck;
   gboolean valid;
   double temps;
   
-  valid = toolFortranRead_flag(&ncheck, flux, error, endian);
+  valid = tool_fortran_readFlag(&ncheck, flux, error, endian);
   if (!valid) return valid;
-  valid = toolFortranRead_integer(&npas, 1, flux, error, endian, FALSE, TRUE);
+  valid = tool_fortran_readInteger(&npas, 1, flux, error, endian, FALSE, TRUE);
   if (!valid) return valid;
-  valid = toolFortranRead_double(&temps, 1, flux, error, endian, FALSE, TRUE);
+  valid = tool_fortran_readDouble(&temps, 1, flux, error, endian, FALSE, TRUE);
   if (!valid) return valid;
-  valid = toolFortranRead_flag(&mcheck, flux, error, endian);
+  valid = tool_fortran_readFlag(&mcheck, flux, error, endian);
   if (!valid) return valid;
   if (ncheck != mcheck)
     {
@@ -156,11 +164,87 @@ static gboolean read_npas_temps(FILE *flux, GError **error, EndianId endian)
     }
   return TRUE;
 }
+static gboolean read_npas_temps_energy(FILE *flux, GError **error, ToolFortranEndianId endian)
+{
+  guint ncheck, mcheck;
+  gboolean valid;
+  double temps;
+  
+  valid = tool_fortran_readFlag(&ncheck, flux, error, endian);
+  if (!valid) return valid;
+  valid = tool_fortran_readInteger(&npas, 1, flux, error, endian, FALSE, TRUE);
+  if (!valid) return valid;
+  valid = tool_fortran_readDouble(&temps, 1, flux, error, endian, FALSE, TRUE);
+  if (!valid) return valid;
+  valid = tool_fortran_readDouble(&energy, 1, flux, error, endian, FALSE, TRUE);
+  if (!valid) return valid;
+  valid = tool_fortran_readFlag(&mcheck, flux, error, endian);
+  if (!valid) return valid;
+  if (ncheck != mcheck)
+    {
+      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+			   _("WARNING : wrong fortran syntax, flag size unmatched.\n"));
+      return FALSE;
+    }
+  return TRUE;
+}
+static gboolean read_unit(FILE *flux, GError **error, ToolFortranEndianId endian,
+                          ToolUnits *unit)
+{
+  gboolean valid;
+  gchar units[17];
+
+  DBG_fprintf(stderr, "Atomic D3 : read units.\n");
+  valid = tool_fortran_readCharacter(units, 16, flux, error,
+                                     endian, TRUE, TRUE);
+  if (!valid) return valid;
+  units[16] = '\0';
+  g_strchomp(units);
+  *unit = tool_physic_getUnitFromName(units);
+  DBG_fprintf(stderr, " | '%s' (%d)\n", units, *unit);
+  
+  return TRUE;
+}
+static gboolean read_periodicity(FILE *flux, GError **error, ToolFortranEndianId endian,
+                                 VisuBoxBoundaries *bc)
+{
+  gboolean valid;
+  gchar periodicity[5];
+
+  DBG_fprintf(stderr, "Atomic D3 : read periodicity.\n");
+  valid = tool_fortran_readCharacter(periodicity, 4, flux, error,
+                                     endian, TRUE, TRUE);
+  if (!valid) return valid;
+  periodicity[4] = '\0';
+  g_strchomp(periodicity);
+  DBG_fprintf(stderr, " | '%s'\n", periodicity);
+  if (!g_ascii_strcasecmp(periodicity, "Oxyz"))
+    *bc = VISU_BOX_PERIODIC;
+  else if (!g_ascii_strcasecmp(periodicity, "Ozx"))
+    *bc = VISU_BOX_SURFACE_ZX;
+  else if (!g_ascii_strcasecmp(periodicity, "Oxy"))
+    *bc = VISU_BOX_SURFACE_XY;
+  else if (!g_ascii_strcasecmp(periodicity, "Oyz"))
+    *bc = VISU_BOX_SURFACE_YZ;
+  else if (!g_ascii_strcasecmp(periodicity, "Ox"))
+    *bc = VISU_BOX_WIRE_X;
+  else if (!g_ascii_strcasecmp(periodicity, "Oy"))
+    *bc = VISU_BOX_WIRE_Y;
+  else if (!g_ascii_strcasecmp(periodicity, "Oz"))
+    *bc = VISU_BOX_WIRE_Z;
+  else if (!g_ascii_strcasecmp(periodicity, "O"))
+    *bc = VISU_BOX_FREE;
+  else
+    *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+                         _("unknwon peridicity flag '%s'"), periodicity);
+  return (*error == (GError*)0);
+}
 
 /******************************************************************************/
 
 static gboolean loadD3(VisuData *data, const gchar* filename,
-		       ToolFileFormat *format _U_, int nSet, GError **error)
+		       ToolFileFormat *format _U_, int nSet,
+                       GCancellable *cancel _U_, GError **error)
 {
   int res;
   FILE *readFrom;
@@ -192,23 +276,26 @@ static gboolean loadD3(VisuData *data, const gchar* filename,
 
 static int read_d3_file(VisuData *data, FILE *flux, int set, GError **error)
 {
-  int res, iSet;
-  unsigned int snat;
+  int iSet;
+  guint snat;
   VisuElement *type;
-  VisuElement **types;
+  GArray *types;
   gchar *infoUTF8;
   gboolean valid, store, readDouble, storeDouble;
-  EndianId endian;
-  unsigned int nn[2], i, j, ncheck;
+  ToolFortranEndianId endian;
+  guint nn[2], i, j, ncheck;
   double boxGeometry[6];
   float xyz[3];
   long offset;
   GList *tmpLst;
+  VisuBox *box;
+  ToolUnits unit;
+  VisuBoxBoundaries bc;
 
   g_return_val_if_fail(error && *error == (GError*)0, FALSE);
 
   natnom = (gchar**)0;
-  nattyp = (unsigned int*)0;
+  nattyp = (GArray*)0;
   x = (double*)0;
   y = (double*)0;
   z = (double*)0;
@@ -217,11 +304,13 @@ static int read_d3_file(VisuData *data, FILE *flux, int set, GError **error)
   zf = (float*)0;
   iSet = 0;
   storeDouble = TRUE;
+  unit = TOOL_UNITS_UNDEFINED;
+  bc = VISU_BOX_PERIODIC;
 
   /* Check the first element to find the endianness.
      The first element is an int equal to 128. */
   DBG_fprintf(stderr, "Atomic D3 : test for endianness.\n");
-  valid = toolFortranTest_endianness(128, flux, error, &endian);
+  valid = tool_fortran_testEndianness(128, flux, error, &endian);
   if (!valid)
     return -1;
 
@@ -234,19 +323,28 @@ static int read_d3_file(VisuData *data, FILE *flux, int set, GError **error)
 
       /* TITLE */
       DBG_fprintf(stderr, "Atomic D3 : read title.\n");
-      valid = toolFortranRead_character(title, 128, flux, error, endian, TRUE, TRUE);
+      valid = tool_fortran_readCharacter(title, 128, flux, error, endian, TRUE, TRUE);
       if (!valid)
 	return free_read_d3();
       title[128] = '\0';
       g_strchomp(title);
       DBG_fprintf(stderr, " | '%s'\n", title);
 
-      /* NPAS-TEMPS (optional) */
+      /* NPAS-TEMPS(-ENERGY) (optional) */
       offset = ftell(flux);
+      energy = G_MAXDOUBLE;
       valid = read_npas_temps(flux, error, endian);
       if (!valid)
 	{
 	  g_error_free(*error);
+          *error = (GError*)0;
+	  fseek(flux, offset, SEEK_SET);
+          valid = read_npas_temps_energy(flux, error, endian);
+        }
+      if (!valid)
+	{
+	  g_error_free(*error);
+          *error = (GError*)0;
 	  fseek(flux, offset, SEEK_SET);
 	  readDouble = TRUE;
 	  lst = g_list_prepend(lst, g_strdup(title));
@@ -254,12 +352,14 @@ static int read_d3_file(VisuData *data, FILE *flux, int set, GError **error)
       else
 	{
 	  readDouble = FALSE;
+          if (store && energy != G_MAXDOUBLE)
+            g_object_set(G_OBJECT(data), "totalEnergy", energy, NULL);
 	  lst = g_list_prepend(lst, g_strdup_printf("%04d - %s", npas, title));
 	}
 
       /* NAT-NTYPE */  
       DBG_fprintf(stderr, "Atomic D3 : read nat and ntype.\n");
-      valid = toolFortranRead_integer(nn, 2, flux, error, endian, TRUE, TRUE);
+      valid = tool_fortran_readInteger(nn, 2, flux, error, endian, TRUE, TRUE);
       if (!valid)
 	return free_read_d3();
       nat = nn[0];
@@ -269,7 +369,8 @@ static int read_d3_file(VisuData *data, FILE *flux, int set, GError **error)
       /* NATI-NOM */
       if (store)
 	{
-	  nattyp = g_malloc(ntypeD3 * sizeof(int));
+          DBG_fprintf(stderr, " | store nattyp and natom.\n");
+          nattyp = g_array_sized_new(FALSE, FALSE, sizeof(guint), ntypeD3);
 	  natnom = g_malloc(ntypeD3 * sizeof(char *));
 	  for(i=0; i<ntypeD3; i++)
 	    natnom[i] = g_malloc(9 * sizeof(char));
@@ -280,12 +381,14 @@ static int read_d3_file(VisuData *data, FILE *flux, int set, GError **error)
 	  DBG_fprintf(stderr, "! invalid nattyp or natnom.\n");
 	  return free_read_d3();
 	}
+      else
+        DBG_fprintf(stderr, " | read nattyp natom OK.\n");
       if (store)
 	{
 	  DBG_fprintf(stderr, " | check coherence in number of atoms.\n");
 	  snat = 0;
 	  for(i=0; i<ntypeD3; i++)
-	    snat = snat + nattyp[i];
+	    snat = snat + g_array_index(nattyp, guint, i);
 	  if(snat != nat)
 	    {
 	      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
@@ -296,7 +399,7 @@ static int read_d3_file(VisuData *data, FILE *flux, int set, GError **error)
 	}
          
       /* DXX-DYX-DYY-DZX-DZY-DZZ */
-      valid = toolFortranRead_double(boxGeometry, 6, flux, error, endian, TRUE, store);
+      valid = tool_fortran_readDouble(boxGeometry, 6, flux, error, endian, TRUE, store);
       if (!valid)
 	{
 	  DBG_fprintf(stderr, "! invalid box '%s'.\n", (*error)->message);
@@ -322,9 +425,9 @@ static int read_d3_file(VisuData *data, FILE *flux, int set, GError **error)
    
       /* X */
       if (readDouble)
-	valid = toolFortranRead_double(x, nat, flux, error, endian, TRUE, store);
+	valid = tool_fortran_readDouble(x, nat, flux, error, endian, TRUE, store);
       else
-	valid = toolFortranRead_real(xf, nat, flux, error, endian, TRUE, store);
+	valid = tool_fortran_readReal(xf, nat, flux, error, endian, TRUE, store);
       if (!valid)
 	{
 	  DBG_fprintf(stderr, "! invalid x coordinates '%s'.\n", (*error)->message);
@@ -333,9 +436,9 @@ static int read_d3_file(VisuData *data, FILE *flux, int set, GError **error)
    
       /* Y */      
       if (readDouble)
-	valid = toolFortranRead_double(y, nat, flux, error, endian, TRUE, store);
+	valid = tool_fortran_readDouble(y, nat, flux, error, endian, TRUE, store);
       else
-	valid = toolFortranRead_real(yf, nat, flux, error, endian, TRUE, store);
+	valid = tool_fortran_readReal(yf, nat, flux, error, endian, TRUE, store);
       if (!valid)
 	{
 	  DBG_fprintf(stderr, "! invalid y coordinates '%s'.\n", (*error)->message);
@@ -344,9 +447,9 @@ static int read_d3_file(VisuData *data, FILE *flux, int set, GError **error)
    
       /* Z */      
       if (readDouble)
-	valid = toolFortranRead_double(z, nat, flux, error, endian, TRUE, store);
+	valid = tool_fortran_readDouble(z, nat, flux, error, endian, TRUE, store);
       else
-	valid = toolFortranRead_real(zf, nat, flux, error, endian, TRUE, store);
+	valid = tool_fortran_readReal(zf, nat, flux, error, endian, TRUE, store);
       if (!valid)
 	{
 	  DBG_fprintf(stderr, "! invalid z coordinates '%s'.\n", (*error)->message);
@@ -355,13 +458,36 @@ static int read_d3_file(VisuData *data, FILE *flux, int set, GError **error)
 
       iSet += 1;
 
-      /* There is a strange thing with Fortran file, they
-	 seems to finish with '0x0a' character... */
-      offset = ftell(flux);
-      valid = toolFortranRead_flag(&ncheck, flux, error, endian);
-      if (!valid)
-	g_error_free(*error);
-      fseek(flux, offset, SEEK_SET);
+      /* Go to the next fortran flag holding 128. */
+      do
+        {
+          /* There is a strange thing with Fortran file, they
+             seems to finish with '0x0a' character... */
+          offset = ftell(flux);
+          valid = tool_fortran_readFlag(&ncheck, flux, error, endian);
+          if (!valid)
+            g_error_free(*error);
+          else if (ncheck == 16)
+            {
+              fseek(flux, offset, SEEK_SET);
+              /* Special case of units. */
+              if (!read_unit(flux, error, endian, &unit))
+                return free_read_d3();
+            }
+          else if (ncheck == 4)
+            {
+              fseek(flux, offset, SEEK_SET);
+              /* Special case of periodicity. */
+              if (!read_periodicity(flux, error, endian, &bc))
+                return free_read_d3();
+            }
+          else if (ncheck != 128)
+            fseek(flux, offset + 4 + ncheck + 4, SEEK_SET);
+          else
+            fseek(flux, offset, SEEK_SET);
+          valid = valid && (ncheck == 128);
+        }
+      while (!feof(flux) && !valid);
     }
   while (!feof(flux) && valid);
   lst = g_list_reverse(lst);
@@ -376,10 +502,11 @@ static int read_d3_file(VisuData *data, FILE *flux, int set, GError **error)
 
   DBG_fprintf(stderr, "Atomic d3 : nat = %d | ntypeD3 = %d\n", nat, ntypeD3);
   for(i = 0; i < ntypeD3; i++)
-    DBG_fprintf(stderr, " | natnom %d = '%s', nb %d\n", i, natnom[i], nattyp[i]);
+    DBG_fprintf(stderr, " | natnom %d = '%s', nb %d\n", i, natnom[i],
+                g_array_index(nattyp, guint, i));
   /* Now we have all the element and the number of atoms per element.
      So we allocate the memory. */
-  types = g_malloc(sizeof(VisuElement*) * ntypeD3);
+  types = g_array_sized_new(FALSE, FALSE, sizeof(VisuElement*), ntypeD3);
   for(i = 0; i < ntypeD3; i++)
     {
       /* adding nomloc to the hashtable */
@@ -389,7 +516,7 @@ static int read_d3_file(VisuData *data, FILE *flux, int set, GError **error)
           g_warning("Cannot create a new type for '%s'\n", natnom[i]);
           return 1;
 	}
-      types[i] = type;
+      g_array_insert_val(types, i, type);
     }
 
   DBG_fprintf(stderr, " | begin to transfer data to VisuData.\n");
@@ -413,17 +540,13 @@ static int read_d3_file(VisuData *data, FILE *flux, int set, GError **error)
       tmpLst = g_list_next(tmpLst);
     }
 
-  res = visu_data_setPopulation(data, ntypeD3, nattyp, types);
-  g_free(types);
-  if (!res)
-    {
-      g_error("FATAL ERROR! Can't store the nodes in the VisuData object.");
-    }
+  visu_node_array_allocate(VISU_NODE_ARRAY(data), types, nattyp);
+  g_array_free(types, TRUE);
 
   nat = 0;
   for (i = 0; i < ntypeD3; i++)
     {
-      for (j = 0; j < nattyp[i]; j++)
+      for (j = 0; j < g_array_index(nattyp, guint, i); j++)
 	{
 	  xyz[0] = (storeDouble)?(float)x[nat]:xf[nat];
 	  xyz[1] = (storeDouble)?(float)y[nat]:yf[nat];
@@ -434,8 +557,12 @@ static int read_d3_file(VisuData *data, FILE *flux, int set, GError **error)
     }
 
   /* We finish with the geometry. */
-  visu_data_setBoxGeometry(data, boxGeometry, VISU_DATA_BOX_PERIODIC);
-  visu_data_applyBoxGeometry(data);
+  box = visu_box_new(boxGeometry, bc);
+  visu_box_setMargin(box, visu_node_array_getMaxElementSize(VISU_NODE_ARRAY(data)) +
+                     visu_data_getAllNodeExtens(data, box), TRUE);
+  visu_box_setUnit(box, unit);
+  visu_boxed_setBox(VISU_BOXED(data), VISU_BOXED(box), FALSE);
+  g_object_unref(box);
   
   free_read_d3();
    
@@ -444,7 +571,7 @@ static int read_d3_file(VisuData *data, FILE *flux, int set, GError **error)
 
 static int free_read_d3()
 {
-  unsigned int i;
+  guint i;
   GList *tmpLst;
   
   DBG_fprintf(stderr, "Atomic d3: freeing tmp variables.\n");
@@ -456,7 +583,7 @@ static int free_read_d3()
       g_free(natnom);
     }
   if(nattyp)
-    g_free(nattyp);
+    g_array_free(nattyp, TRUE);
   if (x)
     g_free(x);
   if (y)
