@@ -1215,7 +1215,7 @@ static gboolean readElementElipsoid(VisuConfigFileEntry *entry _U_, gchar **line
 				    int position, VisuData *dataObj _U_, VisuGlView *view _U_, GError **error)
 {
   float size[2];
-  gboolean color[1];
+  gboolean color;
   gboolean res;
   VisuElement *ele;
   struct spinResources_struct *str;
@@ -1242,7 +1242,7 @@ static gboolean readElementElipsoid(VisuConfigFileEntry *entry _U_, gchar **line
       return FALSE;
     }
   /* Read the color params : 1 boolean. */
-  res = tool_config_file_readBooleanFromTokens(tokens, &id, color, 1, position, error);
+  res = tool_config_file_readBooleanFromTokens(tokens, &id, &color, 1, position, error);
   if (!res)
     {
       g_strfreev(tokens);
@@ -1254,7 +1254,7 @@ static gboolean readElementElipsoid(VisuConfigFileEntry *entry _U_, gchar **line
   str = getSpinResources(ele);
   str->aAxis         = size[0];
   str->bAxis         = size[1];
-  str->elipsoidColor = color[0];
+  str->elipsoidColor = color;
 
   return TRUE;
 }
