@@ -52,48 +52,48 @@
 #include <visu_tools.h>
 
 /**
- * SpinDrawingPolicy:
- * @policyAlwaysSpin: Arrows are drawn whatever the modulus value.
- * @policyHideNullSpin: Spin with a null modulus are hidden.
- * @policyAtomicNullSpin: Follow atomic rendering for null modulus.
- * @policyNbModes: a flag to count the number of modes.
+ * VisuRenderingSpinDrawingPolicy:
+ * @VISU_RENDERING_SPIN_ALWAYS: Arrows are drawn whatever the modulus value.
+ * @VISU_RENDERING_SPIN_HIDE_NULL: Spin with a null modulus are hidden.
+ * @VISU_RENDERING_SPIN_ATOMIC_NULL: Follow atomic rendering for null modulus.
+ * @VISU_RENDERING_SPIN_N_MODES: a flag to count the number of modes.
  *
  * Different policy to render the spin when the modulus is null. This
  * policy is applied for all #VisuElement.
  */
 typedef enum
   {
-    policyAlwaysSpin,    
-    policyHideNullSpin,  
-    policyAtomicNullSpin,
-    policyNbModes
-  } SpinDrawingPolicy;
+    VISU_RENDERING_SPIN_ALWAYS,    
+    VISU_RENDERING_SPIN_HIDE_NULL,  
+    VISU_RENDERING_SPIN_ATOMIC_NULL,
+    VISU_RENDERING_SPIN_N_MODES
+  } VisuRenderingSpinDrawingPolicy;
 /**
- * SpinModulusPolicy:
- * @policyNoneModulus: arrows have all the same size, whatever the
+ * VisuRenderingSpinModulusPolicy:
+ * @VISU_RENDERING_SPIN_CONSTANT: arrows have all the same size, whatever the
  * modulus value.
- * @policyPerTypeModulus: arrows are scaled per node type.
- * @policyGlobalModulus: arrows are scaled globaly.
- * @policyNbModulusModes: a flag to count the number of modes.
+ * @VISU_RENDERING_SPIN_PER_TYPE: arrows are scaled per node type.
+ * @VISU_RENDERING_SPIN_GLOBAL: arrows are scaled globaly.
+ * @VISU_RENDERING_SPIN_N_MODULUS_MODES: a flag to count the number of modes.
  *
  * Different policy to render the spin depending on the modulus.
  */
 typedef enum
   {
-    policyNoneModulus,    
-    policyPerTypeModulus,  
-    policyGlobalModulus,
-    policyNbModulusModes
-  } SpinModulusPolicy;
+    VISU_RENDERING_SPIN_CONSTANT,    
+    VISU_RENDERING_SPIN_PER_TYPE,  
+    VISU_RENDERING_SPIN_GLOBAL,
+    VISU_RENDERING_SPIN_N_MODULUS_MODES
+  } VisuRenderingSpinModulusPolicy;
 
 /**
- * VisuSpinShapeId:
+ * VisuRenderingSpinShapeId:
  * @VISU_RENDERING_SPIN_ARROW_SMOOTH: the shape is smooth and rounded ;
  * @VISU_RENDERING_SPIN_ARROW_SHARP: the shape is built on squares ;
  * @VISU_RENDERING_SPIN_ELLIPSOID: the shape is an ellipsoid ;
  * @VISU_RENDERING_SPIN_TORUS: the shape is a torus (direction of the arrow is
  * normal to the torus plane).
- * @nbSpinShapes: private.
+ * @VISU_RENDERING_SPIN_N_SHAPES: private.
  *
  * An identifier for the different shapes to draw elements.
  */
@@ -104,11 +104,11 @@ typedef enum
     VISU_RENDERING_SPIN_ELLIPSOID,
     VISU_RENDERING_SPIN_TORUS,
     /*< private >*/
-    nbSpinShapes
-  } VisuSpinShapeId;
+    VISU_RENDERING_SPIN_N_SHAPES
+  } VisuRenderingSpinShapeId;
 
 /**
- * SpinFileType:
+ * VisuRenderingSpinFileType:
  * @FILE_KIND_POSITION: define a position file ;
  * @FILE_KIND_SPIN: define a spin description file.
  *
@@ -118,24 +118,24 @@ typedef enum
   {
     FILE_KIND_POSITION,
     FILE_KIND_SPIN
-  } SpinFileType;
+  } VisuRenderingSpinFileType;
 
 /**
- * SPINVALUES_ID:
+ * VISU_RENDERING_SPIN_VALUES_ID:
  *
  * This flag should be used when creating a new spin rendering method
  * as the flag for the spin values as node properties (see
- * visu_node_property_newPointer()).
+ * visu_node_array_property_newPointer()).
  */
-#define SPINVALUES_ID     "spinRendering_values"
+#define VISU_RENDERING_SPIN_VALUES_ID     "spinRendering_values"
 /**
- * SPINMAXMODULUS_ID:
+ * VISU_RENDERING_SPIN_MAX_MODULUS_ID:
  *
  * This flag should be used when creating a new spin rendering method
  * as the flag for the max modulus values as a #VisuNode property (see
- * visu_node_property_newPointer()).
+ * visu_node_array_property_newPointer()).
  */
-#define SPINMAXMODULUS_ID "spinRendering_maxModulus"
+#define VISU_RENDERING_SPIN_MAX_MODULUS_ID "spinRendering_maxModulus"
 
 /**
  * VISU_RENDERING_SPIN_NAME:
@@ -145,63 +145,63 @@ typedef enum
 #define VISU_RENDERING_SPIN_NAME "Spin visualisation"
 
 /**
- * VISU_RENDERING_SPIN_TYPE:
+ * VISU_TYPE_RENDERING_SPIN:
  *
  * return the type of #VisuRenderingSpin.
  */
-#define VISU_RENDERING_SPIN_TYPE	     (visu_rendering_spin_get_type ())
+#define VISU_TYPE_RENDERING_SPIN	     (visu_rendering_spin_get_type ())
 /**
  * VISU_RENDERING_SPIN:
  * @obj: a #GObject to cast.
  *
  * Cast the given @obj into #VisuRenderingSpin type.
  */
-#define VISU_RENDERING_SPIN(obj)	     (G_TYPE_CHECK_INSTANCE_CAST(obj, VISU_RENDERING_SPIN_TYPE, VisuRenderingSpin))
+#define VISU_RENDERING_SPIN(obj)	     (G_TYPE_CHECK_INSTANCE_CAST(obj, VISU_TYPE_RENDERING_SPIN, VisuRenderingSpin))
 /**
  * VISU_RENDERING_SPIN_CLASS:
  * @klass: a #GObjectClass to cast.
  *
  * Cast the given @klass into #VisuRenderingSpinClass.
  */
-#define VISU_RENDERING_SPIN_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST(klass, VISU_RENDERING_SPIN_TYPE, VisuRenderingSpinClass))
+#define VISU_RENDERING_SPIN_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST(klass, VISU_TYPE_RENDERING_SPIN, VisuRenderingSpinClass))
 /**
- * IS_VISU_RENDERING_SPIN_TYPE:
+ * VISU_IS_RENDERING_SPIN:
  * @obj: a #GObject to test.
  *
  * Test if the given @ogj is of the type of #VisuRenderingSpin object.
  */
-#define IS_VISU_RENDERING_SPIN_TYPE(obj)    (G_TYPE_CHECK_INSTANCE_TYPE(obj, VISU_RENDERING_SPIN_TYPE))
+#define VISU_IS_RENDERING_SPIN(obj)    (G_TYPE_CHECK_INSTANCE_TYPE(obj, VISU_TYPE_RENDERING_SPIN))
 /**
- * IS_VISU_RENDERING_SPIN_CLASS:
+ * VISU_IS_RENDERING_SPIN_CLASS:
  * @klass: a #GObjectClass to test.
  *
  * Test if the given @klass is of the type of #VisuRenderingSpinClass class.
  */
-#define IS_VISU_RENDERING_SPIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE(klass, VISU_RENDERING_SPIN_TYPE))
+#define VISU_IS_RENDERING_SPIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE(klass, VISU_TYPE_RENDERING_SPIN))
 /**
  * VISU_RENDERING_SPIN_GET_CLASS:
  * @obj: a #GObject to get the class of.
  *
  * It returns the class of the given @obj.
  */
-#define VISU_RENDERING_SPIN_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS(obj, VISU_RENDERING_SPIN_TYPE, VisuRenderingSpinClass))
+#define VISU_RENDERING_SPIN_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS(obj, VISU_TYPE_RENDERING_SPIN, VisuRenderingSpinClass))
 
 /**
  * visu_rendering_spin_get_type:
  *
  * This method returns the type of #VisuRenderingSpin, use
- * VISU_RENDERING_SPIN_TYPE instead.
+ * VISU_TYPE_RENDERING_SPIN instead.
  *
  * Returns: the type of #VisuRenderingSpin.
  */
 GType visu_rendering_spin_get_type(void);
 
 /**
- * VisuRenderingSpinPriv:
+ * VisuRenderingSpinPrivate:
  *
  * An opaque structure.
  */
-typedef struct _VisuRenderingSpinPriv VisuRenderingSpinPriv;
+typedef struct _VisuRenderingSpinPrivate VisuRenderingSpinPrivate;
 typedef struct _VisuRenderingSpinClass VisuRenderingSpinClass;
 /**
  * VisuRenderingSpin:
@@ -212,7 +212,7 @@ struct _VisuRenderingSpin
 {
   VisuRendering method;
 
-  VisuRenderingSpinPriv *priv;
+  VisuRenderingSpinPrivate *priv;
 };
 typedef struct _VisuRenderingSpin VisuRenderingSpin;
 
@@ -221,60 +221,52 @@ VisuRenderingSpin* visu_rendering_spin_new();
 /***********************/
 /* Different resources */
 /***********************/
-const char* visu_renderingSpin_getShapeNameI18n(VisuSpinShapeId n);
-SpinDrawingPolicy visu_renderingSpin_getHidingPolicyFromName(const char *name);
-const char* visu_renderingSpin_getHidingPolicyName(SpinDrawingPolicy n);
-const char* visu_renderingSpin_getHidingPolicyNameI18n(SpinDrawingPolicy n);
+const char* visu_rendering_spin_getShapeNameI18n(VisuRenderingSpinShapeId n);
+VisuRenderingSpinDrawingPolicy visu_rendering_spin_getHidingPolicyFromName(const char *name);
+const char* visu_rendering_spin_getHidingPolicyName(VisuRenderingSpinDrawingPolicy n);
+const char* visu_rendering_spin_getHidingPolicyNameI18n(VisuRenderingSpinDrawingPolicy n);
 
 /**
- * SpinElementResources:
- * @spin_elementHatLength: the length of the pointing element ;
- * @spin_elementTailLength: the length of the tail ;
- * @spin_elementHatRadius: the raidus of the pointing element ;
- * @spin_elementTailRadius: the radius of the tail ;
- * @spin_elementHatColor: if TRUE, the pointing part use the color of the element ;
- * @spin_elementTailColor: if TRUE, the tail uses the color of the element ;
- * @spin_elementAAxis: the size of the A axis (elipsoid shape) ;
- * @spin_elementBAxis: the size of the B axis (elipsoid shape) ;
- * @spin_elementElipsoidColor: if TRUE, the elipsoid uses the color of the element ;
- * @spin_elementShape: an id to defined the shape (rounded arrow, elipsoid...) ;
- * @spin_nbElementResources: number of resources per element.
+ * VisuRenderingSpinResources:
+ * @VISU_RENDERING_SPIN_HAT_LENGTH: the length of the pointing element ;
+ * @spin_VISU_RENDERING_SPIN_TAIL_LENGTH: the length of the tail ;
+ * @VISU_RENDERING_SPIN_HAT_RADIUS: the raidus of the pointing element ;
+ * @VISU_RENDERING_SPIN_TAIL_RADIUS: the radius of the tail ;
+ * @VISU_RENDERING_SPIN_HAT_COLOR: if TRUE, the pointing part use the color of the element ;
+ * @VISU_RENDERING_SPIN_TAIL_COLOR: if TRUE, the tail uses the color of the element ;
+ * @VISU_RENDERING_SPIN_A_AXIS: the size of the A axis (elipsoid shape) ;
+ * @VISU_RENDERING_SPIN_B_AXIS: the size of the B axis (elipsoid shape) ;
+ * @VISU_RENDERING_SPIN_ELIPSOID_COLOR: if TRUE, the elipsoid uses the color of the element ;
+ * @VISU_RENDERING_SPIN_SHAPE: an id to defined the shape (rounded arrow, elipsoid...) ;
+ * @VISU_RENDERING_SPIN_N_RESOURCES: number of resources per element.
  * 
  * These are resources defined for each element. They can be accessed with
- * rspin_getElementResource() or rspin_getElementResource_boolean() and other
+ * visu_rendering_spin_getResource() or visu_rendering_spin_getResourceBoolean() and other
  * methods of the same kind.
  */
 typedef enum
   {
-    spin_elementHatLength,
-    spin_elementTailLength,
-    spin_elementHatRadius,
-    spin_elementTailRadius,
-    spin_elementHatColor,
-    spin_elementTailColor,
-    spin_elementAAxis,
-    spin_elementBAxis,
-    spin_elementElipsoidColor,
-    spin_elementShape,
-    spin_nbElementResources
-  } SpinElementResources;
+    VISU_RENDERING_SPIN_HAT_LENGTH,
+    spin_VISU_RENDERING_SPIN_TAIL_LENGTH,
+    VISU_RENDERING_SPIN_HAT_RADIUS,
+    VISU_RENDERING_SPIN_TAIL_RADIUS,
+    VISU_RENDERING_SPIN_HAT_COLOR,
+    VISU_RENDERING_SPIN_TAIL_COLOR,
+    VISU_RENDERING_SPIN_A_AXIS,
+    VISU_RENDERING_SPIN_B_AXIS,
+    VISU_RENDERING_SPIN_ELIPSOID_COLOR,
+    VISU_RENDERING_SPIN_SHAPE,
+    VISU_RENDERING_SPIN_N_RESOURCES
+  } VisuRenderingSpinResources;
 
+void visu_rendering_spin_getResource(VisuElement *ele,
+                                     VisuRenderingSpinResources property,
+                                     GValue *val);
+gboolean visu_rendering_spin_setResource(VisuElement *ele,
+                                         VisuRenderingSpinResources property,
+                                         GValue *val);
 /**
- * rspin_getElementResource:
- * @ele: a pointer to a #VisuElement object ;
- * @property: the id of the resource (see #SpinElementResources) ;
- * @type: a location to store the type.
- *
- * This is a generic method to access resources per element. Use rspin_setElementResource_boolean()
- * is favored if the type of the value is known (boolean in this exemple).
- * If the returned value is not NULL the argument @type contains the type of the returned value.
- *
- * Return value: a pointer to the location where the value for the given global 
- * resource is stored.
- */
-gpointer rspin_getElementResource(VisuElement *ele, SpinElementResources property, GType *type);
-/**
- * rspin_setElementResource_boolean:
+ * visu_rendering_spin_setResourceBoolean:
  * @ele: a pointer to a #VisuElement object ;
  * @property: the id of the property to set ;
  * @value: its value.
@@ -283,22 +275,22 @@ gpointer rspin_getElementResource(VisuElement *ele, SpinElementResources propert
  *
  * Returns: TRUE if the value was changed.
  */
-gboolean rspin_setElementResource_boolean(VisuElement *ele, SpinElementResources property,
+gboolean visu_rendering_spin_setResourceBoolean(VisuElement *ele, VisuRenderingSpinResources property,
 					  gboolean value);
 /**
- * rspin_setElementResource_uint:
+ * visu_rendering_spin_setResourceUint:
  * @ele: a pointer to a #VisuElement object ;
  * @property: the id of the property to set ;
  * @value: its value.
  *
- * This method is used to change element resources that are unsigned int.
+ * This method is used to change element resources that are guint.
  *
  * Returns: TRUE if the value was changed.
  */
-gboolean rspin_setElementResource_uint(VisuElement *ele, SpinElementResources property,
+gboolean visu_rendering_spin_setResourceUint(VisuElement *ele, VisuRenderingSpinResources property,
 				       guint value);
 /**
- * rspin_setElementResource_float:
+ * visu_rendering_spin_setResourceFloat:
  * @ele: a pointer to a #VisuElement object ;
  * @property: the id of the property to set ;
  * @value: its value.
@@ -307,10 +299,10 @@ gboolean rspin_setElementResource_uint(VisuElement *ele, SpinElementResources pr
  *
  * Returns: TRUE if the value was changed.
  */
-gboolean rspin_setElementResource_float(VisuElement *ele, SpinElementResources property,
+gboolean visu_rendering_spin_setResourceFloat(VisuElement *ele, VisuRenderingSpinResources property,
 					gfloat value);
 /**
- * rspin_getElementResource_boolean:
+ * visu_rendering_spin_getResourceBoolean:
  * @ele: a pointer to a #VisuElement object ;
  * @property: the id of the property to get.
  *
@@ -318,19 +310,19 @@ gboolean rspin_setElementResource_float(VisuElement *ele, SpinElementResources p
  *
  * Returns: the boolean value.
  */
-gboolean rspin_getElementResource_boolean(VisuElement *ele, SpinElementResources property);
+gboolean visu_rendering_spin_getResourceBoolean(VisuElement *ele, VisuRenderingSpinResources property);
 /**
- * rspin_getElementResource_uint:
+ * visu_rendering_spin_getResourceUint:
  * @ele: a pointer to a #VisuElement object ;
  * @property: the id of the property to get.
  *
- * This is the specific method to retrieve value of unsigned int element resources.
+ * This is the specific method to retrieve value of guint element resources.
  *
- * Returns: the unsigned int value.
+ * Returns: the guint value.
  */
-guint rspin_getElementResource_uint(VisuElement *ele, SpinElementResources property);
+guint visu_rendering_spin_getResourceUint(VisuElement *ele, VisuRenderingSpinResources property);
 /**
- * rspin_getElementResource_float:
+ * visu_rendering_spin_getResourceFloat:
  * @ele: a pointer to a #VisuElement object ;
  * @property: the id of the property to get.
  *
@@ -338,6 +330,6 @@ guint rspin_getElementResource_uint(VisuElement *ele, SpinElementResources prope
  *
  * Returns: the floating point value.
  */
-gfloat rspin_getElementResource_float(VisuElement *ele, SpinElementResources property);
+gfloat visu_rendering_spin_getResourceFloat(VisuElement *ele, VisuRenderingSpinResources property);
 
 #endif
