@@ -230,13 +230,13 @@ gchar** commandLineGet_isoNames(int *nb);
  */
 gchar* commandLineGet_scalarFieldFileName(void);
 /**
- * commandLineGet_isoSurfacesFileName:
+ * commandLineGet_isoVisuSurfacesFileName:
  *
  * This method retrieves the filename given by the option --iso-surfaces or -i.
  *
  * Returns: a filename, the string is owned by V_Sim.
  */
-gchar* commandLineGet_isoSurfacesFileName(void);
+gchar* commandLineGet_isoVisuSurfacesFileName(void);
 /**
  * commandLineGet_fitToBox:
  *
@@ -264,18 +264,6 @@ gchar* commandLineGet_resourcesFile(void);
  * Returns: a #GHashTable pointer owned by V_Sim.
  */
 GHashTable* commandLineGet_options(void);
-/**
- * commandLineGet_coloredMap:
- * @planeId: a location to store the plane to be used.
- *
- * If the return value is TRUE, then the user requests a coloured map
- * using the given plane. The scalar field is given by
- * '--scalar-filed' option (see commandLineGet_scalarFieldFileName())
- * and the shade by '--color-preset' (see
- * commandLineGet_presetColor()).
- *
- * Returns: TRUE if a coloured map is requested.
- */
 int* commandLineGet_coloredMap(void);
 /**
  * commandLineGet_logScale:
@@ -349,5 +337,8 @@ void commandLineFree_all(void);
 guint commandLineGet_mapPrecision(void);
 float* commandLineGet_mapMinMax(void);
 gchar* commandLineGet_introspect(void);
+GArray* commandLineGet_colorMinMax(void);
+const gchar* commandLineGet_programName(void);
+int commandLineGet_scalingColumn(void);
 
 #endif
