@@ -77,27 +77,68 @@ typedef gboolean (*VisuDumpWriteFunc) (ToolFileFormat *format, const char* fileN
 				       ToolVoidDataFunc functionWait, gpointer data);
 
 /**
- * VisuDump:
- * @bitmap: (in): TRUE if the format requires to export the view
- * into a bitmap ;
- * @glRequired: (in): TRUE if the method requires to run OpenGL.
- * @fileType: a #ToolFileFormat ;
- * @hasAlpha: TRUE if the format support alpha channel ;
- * @writeFunc: (scope call): a pointer to a write func.
+ * VISU_TYPE_DUMP:
  *
- * This structure is used to store a dumping extension. Such an
- * extension is characterized by its #ToolFileFormat and a method that can
- * write a file from the current rendered data.
+ * Return the associated #GType to the VisuDump objects.
+ */
+#define VISU_TYPE_DUMP         (visu_dump_get_type ())
+/**
+ * VISU_DUMP:
+ * @obj: the widget to cast.
+ *
+ * Cast the given object to a #VisuDump object.
+ */
+#define VISU_DUMP(obj)         (G_TYPE_CHECK_INSTANCE_CAST ((obj), VISU_TYPE_DUMP, VisuDump))
+/**
+ * VISU_DUMP_CLASS:
+ * @klass: the class to cast.
+ *
+ * Cast the given class to a #VisuDumpClass object.
+ */
+#define VISU_DUMP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VISU_TYPE_DUMP, VisuDumpClass))
+/**
+ * VISU_IS_DUMP:
+ * @obj: the object to test.
+ *
+ * Return if the given object is a valid #VisuDump object.
+ */
+#define VISU_IS_DUMP(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VISU_TYPE_DUMP))
+/**
+ * VISU_IS_DUMP_CLASS:
+ * @klass: the class to test.
+ *
+ * Return if the given class is a valid #VisuDumpClass class.
+ */
+#define VISU_IS_DUMP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VISU_TYPE_DUMP))
+/**
+ * VISU_DUMP_GET_CLASS:
+ * @obj: the widget to get the class of.
+ *
+ * Get the class of the given object.
+ */
+#define VISU_DUMP_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS(obj, VISU_TYPE_DUMP, VisuDumpClass))
+
+/**
+ * VisuDump:
+ *
+ * An opaque structure.
  */
 typedef struct _VisuDump VisuDump;
+/**
+ * VisuDumpClass:
+ *
+ * An opaque structure.
+ */
+typedef struct _VisuDumpClass VisuDumpClass;
 
-struct _VisuDump
-{
-  gboolean bitmap, glRequired;
-  ToolFileFormat *fileType;
-  gboolean hasAlpha;
-  VisuDumpWriteFunc writeFunc;
-};
+/**
+ * visu_dump_get_type
+ *
+ * #GType are unique numbers to identify objects.
+ *
+ * Returns: the #GType associated with #VisuDump objects.
+ */
+GType visu_dump_get_type(void);
 
 /**
  * VISU_ERROR_DUMP: (skip)
@@ -107,7 +148,7 @@ struct _VisuDump
 #define VISU_ERROR_DUMP visu_dump_getQuark()
 GQuark visu_dump_getQuark();
 /**
- * DumpErrorFlag:
+ * VisuDumpErrorFlag:
  * @DUMP_ERROR_OPENGL: Error with OpenGL dumping.
  * @DUMP_ERROR_FILE: Error when opening.
  * @DUMP_ERROR_ENCODE: Wrongness when computing the encoding format.
@@ -119,7 +160,7 @@ typedef enum
     DUMP_ERROR_OPENGL,
     DUMP_ERROR_FILE,
     DUMP_ERROR_ENCODE
-  } DumpErrorFlag;
+  } VisuDumpErrorFlag;
 
 
 /**
@@ -132,27 +173,33 @@ typedef enum
  *
  * Returns: a newly allocated #VisuDump.
  */
-typedef VisuDump* (*VisuDumpInitFunc) ();
+typedef const VisuDump* (*VisuDumpInitFunc) ();
 
-void visuDumpAdd(VisuDump *dump);
+VisuDump* visu_dump_new(const gchar* descr, const gchar** patterns,
+                        VisuDumpWriteFunc method, gboolean bitmap);
+void visu_dump_setHasAlpha(VisuDump *dump, gboolean hasAlpha);
+void visu_dump_setGl(VisuDump *dump, gboolean needGl);
+gboolean visu_dump_getBitmapStatus(VisuDump *dump);
+gboolean visu_dump_getGlStatus(VisuDump *dump);
+gboolean visu_dump_getAlphaStatus(VisuDump *dump);
 
-gboolean visu_dump_callWriteFunc(VisuDump *dump, const char* fileName,
-				 int width, int height, VisuData *dataObj,
-				 GArray* image, ToolVoidDataFunc functionWait,
-				 gpointer data, GError **error);
+gboolean visu_dump_write(VisuDump *dump, const char* fileName,
+                         int width, int height, VisuData *dataObj,
+                         GArray* image, ToolVoidDataFunc functionWait,
+                         gpointer data, GError **error);
 
 
 GList* visu_dump_getAllModules();
 gint visu_dump_getNModules();
 
 /**
- * visuDumpAbort:
+ * visu_dump_abort:
  * @obj: an object ;
  * @data: some data.
  *
  * Does nothing for the moment.
  */
-void visuDumpAbort(GObject *obj, gpointer data);
+void visu_dump_abort(GObject *obj, gpointer data);
 
 G_END_DECLS
 
