@@ -52,55 +52,46 @@
 G_BEGIN_DECLS
 
 /**
- * VISU_ELEMENT_MAX_NUMBER:
- *
- * We suppose that we have at most #VISU_ELEMENT_MAX_NUMBER element. If the
- * actual number of elements must be greater than #VISU_ELEMENT_MAX_NUMBER then
- * one should recompile with a greater value.
- */
-#define VISU_ELEMENT_MAX_NUMBER 500
-
-/**
- * VISU_ELEMENT_TYPE:
+ * VISU_TYPE_ELEMENT:
  *
  * return the type of #VisuElement.
  */
-#define VISU_ELEMENT_TYPE	     (visu_element_get_type ())
+#define VISU_TYPE_ELEMENT	     (visu_element_get_type ())
 /**
  * VISU_ELEMENT:
  * @obj: a #GObject to cast.
  *
  * Cast the given @obj into #VisuElement type.
  */
-#define VISU_ELEMENT(obj)	     (G_TYPE_CHECK_INSTANCE_CAST(obj, VISU_ELEMENT_TYPE, VisuElement))
+#define VISU_ELEMENT(obj)	     (G_TYPE_CHECK_INSTANCE_CAST(obj, VISU_TYPE_ELEMENT, VisuElement))
 /**
  * VISU_ELEMENT_CLASS:
  * @klass: a #GObjectClass to cast.
  *
  * Cast the given @klass into #VisuElementClass.
  */
-#define VISU_ELEMENT_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST(klass, VISU_ELEMENT_TYPE, VisuElementClass))
+#define VISU_ELEMENT_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST(klass, VISU_TYPE_ELEMENT, VisuElementClass))
 /**
- * IS_VISU_ELEMENT_TYPE:
+ * VISU_IS_ELEMENT_TYPE:
  * @obj: a #GObject to test.
  *
  * Test if the given @ogj is of the type of #VisuElement object.
  */
-#define IS_VISU_ELEMENT_TYPE(obj)    (G_TYPE_CHECK_INSTANCE_TYPE(obj, VISU_ELEMENT_TYPE))
+#define VISU_IS_ELEMENT_TYPE(obj)    (G_TYPE_CHECK_INSTANCE_TYPE(obj, VISU_TYPE_ELEMENT))
 /**
- * IS_VISU_ELEMENT_CLASS:
+ * VISU_IS_ELEMENT_CLASS:
  * @klass: a #GObjectClass to test.
  *
  * Test if the given @klass is of the type of #VisuElementClass class.
  */
-#define IS_VISU_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE(klass, VISU_ELEMENT_TYPE))
+#define VISU_IS_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE(klass, VISU_TYPE_ELEMENT))
 /**
  * VISU_ELEMENT_GET_CLASS:
  * @obj: a #GObject to get the class of.
  *
  * It returns the class of the given @obj.
  */
-#define VISU_ELEMENT_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS(obj, VISU_ELEMENT_TYPE, VisuElementClass))
+#define VISU_ELEMENT_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS(obj, VISU_TYPE_ELEMENT, VisuElementClass))
 
 /**
  * VisuElementClass:
@@ -109,27 +100,7 @@ G_BEGIN_DECLS
  */
 typedef struct _VisuElementClass VisuElementClass;
 
-/**
- * VisuElement:
- * @name: Name of the key used in the hashtable to find
- *   this element. The int variable is the number
- *   of this type.
- * @typeNumber: An integer unique for each VisuElement, it is
- *   used as a name for the opengl material associated
- *   with it.
- * @rgb: main color of the element  in [r, g, b, a] format.
- * @material: lighting effects for material in [amb, dif, shi, spe, emi] format.
- * @openGLIdentifier: the identifier that stores the glObjectList that
- *   draw this #VisuElement.
- * @materialIsUpToDate: A flag that is TRUE when the OpenGL list of
- *   the  material is up to date.
- * @rendered: A flag to store if all nodes of this element are rendered or not.
- *   Its default value is TRUE.
- * @sensitiveToMaskingPlanes: a flag to say if nodes of this element are sensitive
- *   to the masking effect of planes (default is TRUE).
- *
- * Structure to store the description of an element.
- */
+typedef struct _VisuElement VisuElement;
 struct _VisuElement
 {
   GObject parent;
@@ -149,7 +120,7 @@ struct _VisuElement
   /* lighting effects for material in [amb, dif, shi, spe, emi] format. */
   float material[5];
   /* the identifier that stores the glObjectList that draw this VisuElement. */
-  int openGLIdentifier;
+  int glMaterialId;
 
   /* A flag that is TRUE when the OpenGL list of the material is up to date. */
   gboolean materialIsUpToDate;
@@ -157,16 +128,18 @@ struct _VisuElement
      Its default value is TRUE. */
   gboolean rendered;
   /* A flag to say if the element is masked by planes. Default is TRUE. */
-  gboolean sensitiveToMaskingPlanes;
+  gboolean sensitiveToPlanes;
+  /* If the element should appear in the display list of elements or
+     if this element is an internal substitute. */
+  gboolean physical;
 
   gboolean dispose_has_run;
 };
-typedef struct _VisuElement VisuElement;
 
 /**
  * visu_element_get_type:
  *
- * This method returns the type of #VisuElement, use VISU_ELEMENT_TYPE instead.
+ * This method returns the type of #VisuElement, use VISU_TYPE_ELEMENT instead.
  *
  * Returns: the type of #VisuElement.
  */
@@ -188,9 +161,11 @@ gboolean visu_element_setSensitiveToPlanes(VisuElement *element, gboolean status
 
 void visu_element_createMaterial(VisuElement *ele);
 
-int visu_element_getIdentifierMaterial(VisuElement *ele);
+const gchar* visu_element_getName(const VisuElement *ele);
+int visu_element_getMaterialId(VisuElement *ele);
 gboolean visu_element_getRendered(VisuElement *element);
 gboolean visu_element_getSensitiveToPlanes(VisuElement *element);
+gboolean visu_element_getPhysical(VisuElement *ele);
 
 void visu_element_setUpdateNodesOnMaterialChange(void);
 void visu_element_unsetUpdateNodesOnMaterialChange(void);
