@@ -80,7 +80,8 @@ int main (int argc, char *argv[])
 #ifdef WITH_GOBJECT_INTROSPECTION
   GError *error;
 #endif
-  VisuRenderingWindow *window;
+  gboolean GUIerror;
+  VisuUiRenderingWindow *window;
 
 #if DEBUG == 1 && VISU_MEM_CHECK == 1
   g_mem_set_vtable(glib_mem_profiler_table);
@@ -102,6 +103,9 @@ int main (int argc, char *argv[])
   textdomain (GETTEXT_PACKAGE);
 #endif
 
+  DBG_fprintf(stderr, "Visu Main: initialise Gtk.\n");
+  GUIerror = gtk_init_check(&argc, &argv);
+
   DBG_fprintf(stderr, "--- Parse the command line ---\n");
   res = commandLineParse(argc, argv);
   if (res)
@@ -139,12 +143,12 @@ int main (int argc, char *argv[])
     {
 #ifdef WITH_GOBJECT_INTROSPECTION
       /* Additional classes. */
-      g_type_class_ref(VISU_RENDERING_TYPE);
-      g_type_class_ref(VISU_DATA_TYPE);
-      g_type_class_ref(VISU_GLEXT_SCALE_TYPE);
-      g_type_class_ref(VISU_MARKS_TYPE);
-      g_type_class_ref(RENDERING_WINDOW_TYPE);
-      g_type_class_ref(VISU_UIMAIN_TYPE);
+      g_type_class_ref(VISU_TYPE_RENDERING);
+      g_type_class_ref(VISU_TYPE_DATA);
+      g_type_class_ref(VISU_TYPE_GL_EXT_SCALE);
+      g_type_class_ref(VISU_TYPE_GL_EXT_MARKS);
+      g_type_class_ref(VISU_UI_TYPE_RENDERING_WINDOW);
+      g_type_class_ref(VISU_UI_TYPE_MAIN);
 
       DBG_fprintf(stderr, "Visu Main: call introspection for file '%s'.\n",
 		  commandLineGet_introspect());
@@ -160,9 +164,7 @@ int main (int argc, char *argv[])
       g_warning("Introspection required but not compiled.");
 #endif
     }
-
-  DBG_fprintf(stderr, "Visu Main: initialise Gtk.\n");
-  gtk_init(&argc, &argv);
+  g_return_val_if_fail(GUIerror, 1);
 
   gtk_window_set_default_icon_name("v_sim");
   gtk_icon_theme_append_search_path(gtk_icon_theme_get_default(),
@@ -175,18 +177,15 @@ int main (int argc, char *argv[])
 #endif
   /* 38713o still allocated by GLIB and GTK. */
 
-  initVisuBasic();
-  initOpenglGraphics();
+  visu_basic_init();
+  visu_gl_initGraphics();
 
   /* the default is V_Sim with gtk interface. */
   if (!strcmp(commandLineGet_windowMode(), "renderOnly"))
-    visuGtkMain(visuGtkCreate_main);
+    visu_ui_mainCreate(visu_ui_createInterface);
   else
-    visuGtkMain(visu_uiMainClass_createMain);
-  window = RENDERING_WINDOW(visuGtkGet_renderArea());
-
-  DBG_fprintf(stderr,"--- Initialising plugins ---\n");
-  visu_plugins_init();
+    visu_ui_mainCreate(visu_ui_main_class_createMain);
+  window = VISU_UI_RENDERING_WINDOW(visu_ui_getRenderWidget());
 
   DBG_fprintf(stderr, "Visu Main: test for help message.\n");
   if (visu_basic_showOptionHelp(FALSE))
@@ -197,25 +196,25 @@ int main (int argc, char *argv[])
     {
       dirname = g_path_get_dirname(visu_data_getFile(newData, FILE_KIND_POSITION,
 						    (ToolFileFormat**)0));
-      normDir = normalize_path(dirname);
-      visuGtkSet_lastOpenDirectory((char*)normDir, VISU_DIR_FILE);
+      normDir = tool_path_normalize(dirname);
+      visu_ui_setLastOpenDirectory((char*)normDir, VISU_UI_DIR_FILE);
       g_free(dirname);
       g_free(normDir);
 
-      visu_rendering_window_loadFile(window, newData, commandLineGet_iSet());
+      visu_ui_rendering_window_loadFile(window, newData, commandLineGet_iSet());
 
       /* Run the command line. */
       if (!strcmp(commandLineGet_windowMode(), "renderOnly"))
-	g_idle_add(visuGtkRun_commandLine, (gpointer)0);
+	g_idle_add(visu_ui_runCommandLine, (gpointer)0);
       else
 	{
 	  g_idle_add(visu_ui_main_initPanels, (gpointer)0);
-	  g_idle_add(visu_ui_main_runCommandLine, (gpointer)visuGtkGet_panel());
+	  g_idle_add(visu_ui_main_runCommandLine, (gpointer)visu_ui_getPanel());
 	}
     }
   else
     {
-      visu_rendering_window_setData(window, (VisuData*)0);
+      visu_ui_rendering_window_setData(window, (VisuData*)0);
 
       /* Run the command line. */
       if (strcmp(commandLineGet_windowMode(), "renderOnly"))
@@ -226,5 +225,13 @@ int main (int argc, char *argv[])
   gtk_main();
   DBG_fprintf(stderr, "Visu Main: quit main GTK loop.\n");
 
+  visu_plugins_free();
+  visu_basic_freeAll();
+  commandLineFree_all();
+
+#if DEBUG == 1
+  g_mem_profile();
+#endif
+
   return 0;
 }
