@@ -91,7 +91,7 @@ int main (int argc, char *argv[])
 #endif
 
   /* the default is V_Sim with gtk interface. */
-  visuGtkMain(visuGtkCreate_main);
+  visu_ui_mainCreate(visu_ui_createInterface);
 
   DBG_fprintf(stderr, "Visu Main: starting main GTK loop.\n");
   gtk_main();
