@@ -113,6 +113,9 @@ gchar* tool_path_normalize(const gchar* path);
 gboolean g_file_set_contents(const gchar *fileName, const gchar *str,
 			     gsize len, GError **error);
 #endif
+#if GLIB_MINOR_VERSION < 27
+void g_list_free_full(GList *list, GDestroyNotify free_func);
+#endif
 
 gboolean tool_XML_substitute(GString *output, const gchar *filename,
 				 const gchar *tag, GError **error);
